/*
 * This Source Code Form is subject to the terms of the
 * Mozilla Public License, v. 2.0. 
 * If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/.
 */

package org.midica.config;

import static org.junit.jupiter.api.Assertions.*;

import java.lang.reflect.InvocationTargetException;

import javax.swing.JComboBox;

import org.junit.Test;
import org.midica.Midica;
import org.midica.TestUtil;
import org.midica.ui.UiView;

/**
 * This is the test class for {@link Dict}.
 * 
 * @author Jan Trukenmüller
 */
public class DictTest {
	
	private static UiView         uiView;
	private static JComboBox<?>[] cbxs;
	
	/**
	 * Initializes midica in test mode, if not yet done.
	 * 
	 * @throws InvocationTargetException  on interruptions while initializing Midica.
	 * @throws InterruptedException       on exceptions while initializing Midica.
	 */
	public DictTest() throws InvocationTargetException, InterruptedException {
		TestUtil.initMidica();
		
		uiView = Midica.uiController.getView();
		cbxs   = uiView.getConfigComboboxes();
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: international (lower-case)
	 * - half tone: sharp
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsIntLcSharp() {
		
		// test default (+n/-n)
		assertEquals( "c-5",  Dict.getNote(0)   );
		assertEquals( "c#-5", Dict.getNote(1)   );
		assertEquals( "d-5",  Dict.getNote(2)   );
		assertEquals( "d#-5", Dict.getNote(3)   );
		assertEquals( "e-5",  Dict.getNote(4)   );
		assertEquals( "f-5",  Dict.getNote(5)   );
		assertEquals( "f#-5", Dict.getNote(6)   );
		assertEquals( "g-5",  Dict.getNote(7)   );
		assertEquals( "g#-5", Dict.getNote(8)   );
		assertEquals( "a-5",  Dict.getNote(9)   );
		assertEquals( "a#-5", Dict.getNote(10)  );
		assertEquals( "b-5",  Dict.getNote(11)  );
		assertEquals( "c-4",  Dict.getNote(12)  );
		assertEquals( "c#-4", Dict.getNote(13)  );
		assertEquals( "d-4",  Dict.getNote(14)  );
		assertEquals( "d#-4", Dict.getNote(15)  );
		assertEquals( "e-4",  Dict.getNote(16)  );
		assertEquals( "f-4",  Dict.getNote(17)  );
		assertEquals( "f#-4", Dict.getNote(18)  );
		assertEquals( "g-4",  Dict.getNote(19)  );
		assertEquals( "g#-4", Dict.getNote(20)  );
		assertEquals( "a-4",  Dict.getNote(21)  );
		assertEquals( "a#-4", Dict.getNote(22)  );
		assertEquals( "b-4",  Dict.getNote(23)  );
		assertEquals( "c-3",  Dict.getNote(24)  );
		assertEquals( "c#-3", Dict.getNote(25)  );
		assertEquals( "d-3",  Dict.getNote(26)  );
		assertEquals( "d#-3", Dict.getNote(27)  );
		assertEquals( "e-3",  Dict.getNote(28)  );
		assertEquals( "f-3",  Dict.getNote(29)  );
		assertEquals( "f#-3", Dict.getNote(30)  );
		assertEquals( "g-3",  Dict.getNote(31)  );
		assertEquals( "g#-3", Dict.getNote(32)  );
		assertEquals( "a-3",  Dict.getNote(33)  );
		assertEquals( "a#-3", Dict.getNote(34)  );
		assertEquals( "b-3",  Dict.getNote(35)  );
		assertEquals( "c-2",  Dict.getNote(36)  );
		assertEquals( "c#-2", Dict.getNote(37)  );
		assertEquals( "d-2",  Dict.getNote(38)  );
		assertEquals( "d#-2", Dict.getNote(39)  );
		assertEquals( "e-2",  Dict.getNote(40)  );
		assertEquals( "f-2",  Dict.getNote(41)  );
		assertEquals( "f#-2", Dict.getNote(42)  );
		assertEquals( "g-2",  Dict.getNote(43)  );
		assertEquals( "g#-2", Dict.getNote(44)  );
		assertEquals( "a-2",  Dict.getNote(45)  );
		assertEquals( "a#-2", Dict.getNote(46)  );
		assertEquals( "b-2",  Dict.getNote(47)  );
		assertEquals( "c-",   Dict.getNote(48)  );
		assertEquals( "c#-",  Dict.getNote(49)  );
		assertEquals( "d-",   Dict.getNote(50)  );
		assertEquals( "d#-",  Dict.getNote(51)  );
		assertEquals( "e-",   Dict.getNote(52)  );
		assertEquals( "f-",   Dict.getNote(53)  );
		assertEquals( "f#-",  Dict.getNote(54)  );
		assertEquals( "g-",   Dict.getNote(55)  );
		assertEquals( "g#-",  Dict.getNote(56)  );
		assertEquals( "a-",   Dict.getNote(57)  );
		assertEquals( "a#-",  Dict.getNote(58)  );
		assertEquals( "b-",   Dict.getNote(59)  );
		assertEquals( "c",    Dict.getNote(60)  );
		assertEquals( "c#",   Dict.getNote(61)  );
		assertEquals( "d",    Dict.getNote(62)  );
		assertEquals( "d#",   Dict.getNote(63)  );
		assertEquals( "e",    Dict.getNote(64)  );
		assertEquals( "f",    Dict.getNote(65)  );
		assertEquals( "f#",   Dict.getNote(66)  );
		assertEquals( "g",    Dict.getNote(67)  );
		assertEquals( "g#",   Dict.getNote(68)  );
		assertEquals( "a",    Dict.getNote(69)  );
		assertEquals( "a#",   Dict.getNote(70)  );
		assertEquals( "b",    Dict.getNote(71)  );
		assertEquals( "c+",   Dict.getNote(72)  );
		assertEquals( "c#+",  Dict.getNote(73)  );
		assertEquals( "d+",   Dict.getNote(74)  );
		assertEquals( "d#+",  Dict.getNote(75)  );
		assertEquals( "e+",   Dict.getNote(76)  );
		assertEquals( "f+",   Dict.getNote(77)  );
		assertEquals( "f#+",  Dict.getNote(78)  );
		assertEquals( "g+",   Dict.getNote(79)  );
		assertEquals( "g#+",  Dict.getNote(80)  );
		assertEquals( "a+",   Dict.getNote(81)  );
		assertEquals( "a#+",  Dict.getNote(82)  );
		assertEquals( "b+",   Dict.getNote(83)  );
		assertEquals( "c+2",  Dict.getNote(84)  );
		assertEquals( "c#+2", Dict.getNote(85)  );
		assertEquals( "d+2",  Dict.getNote(86)  );
		assertEquals( "d#+2", Dict.getNote(87)  );
		assertEquals( "e+2",  Dict.getNote(88)  );
		assertEquals( "f+2",  Dict.getNote(89)  );
		assertEquals( "f#+2", Dict.getNote(90)  );
		assertEquals( "g+2",  Dict.getNote(91)  );
		assertEquals( "g#+2", Dict.getNote(92)  );
		assertEquals( "a+2",  Dict.getNote(93)  );
		assertEquals( "a#+2", Dict.getNote(94)  );
		assertEquals( "b+2",  Dict.getNote(95)  );
		assertEquals( "c+3",  Dict.getNote(96)  );
		assertEquals( "c#+3", Dict.getNote(97)  );
		assertEquals( "d+3",  Dict.getNote(98)  );
		assertEquals( "d#+3", Dict.getNote(99)  );
		assertEquals( "e+3",  Dict.getNote(100) );
		assertEquals( "f+3",  Dict.getNote(101) );
		assertEquals( "f#+3", Dict.getNote(102) );
		assertEquals( "g+3",  Dict.getNote(103) );
		assertEquals( "g#+3", Dict.getNote(104) );
		assertEquals( "a+3",  Dict.getNote(105) );
		assertEquals( "a#+3", Dict.getNote(106) );
		assertEquals( "b+3",  Dict.getNote(107) );
		assertEquals( "c+4",  Dict.getNote(108) );
		assertEquals( "c#+4", Dict.getNote(109) );
		assertEquals( "d+4",  Dict.getNote(110) );
		assertEquals( "d#+4", Dict.getNote(111) );
		assertEquals( "e+4",  Dict.getNote(112) );
		assertEquals( "f+4",  Dict.getNote(113) );
		assertEquals( "f#+4", Dict.getNote(114) );
		assertEquals( "g+4",  Dict.getNote(115) );
		assertEquals( "g#+4", Dict.getNote(116) );
		assertEquals( "a+4",  Dict.getNote(117) );
		assertEquals( "a#+4", Dict.getNote(118) );
		assertEquals( "b+4",  Dict.getNote(119) );
		assertEquals( "c+5",  Dict.getNote(120) );
		assertEquals( "c#+5", Dict.getNote(121) );
		assertEquals( "d+5",  Dict.getNote(122) );
		assertEquals( "d#+5", Dict.getNote(123) );
		assertEquals( "e+5",  Dict.getNote(124) );
		assertEquals( "f+5",  Dict.getNote(125) );
		assertEquals( "f#+5", Dict.getNote(126) );
		assertEquals( "g+5",  Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "c-----",  Dict.getNote(0)   );
		assertEquals( "c#-----", Dict.getNote(1)   );
		assertEquals( "d-----",  Dict.getNote(2)   );
		assertEquals( "d#-----", Dict.getNote(3)   );
		assertEquals( "e-----",  Dict.getNote(4)   );
		assertEquals( "f-----",  Dict.getNote(5)   );
		assertEquals( "f#-----", Dict.getNote(6)   );
		assertEquals( "g-----",  Dict.getNote(7)   );
		assertEquals( "g#-----", Dict.getNote(8)   );
		assertEquals( "a-----",  Dict.getNote(9)   );
		assertEquals( "a#-----", Dict.getNote(10)  );
		assertEquals( "b-----",  Dict.getNote(11)  );
		assertEquals( "c----",   Dict.getNote(12)  );
		assertEquals( "c#----",  Dict.getNote(13)  );
		assertEquals( "d----",   Dict.getNote(14)  );
		assertEquals( "d#----",  Dict.getNote(15)  );
		assertEquals( "e----",   Dict.getNote(16)  );
		assertEquals( "f----",   Dict.getNote(17)  );
		assertEquals( "f#----",  Dict.getNote(18)  );
		assertEquals( "g----",   Dict.getNote(19)  );
		assertEquals( "g#----",  Dict.getNote(20)  );
		assertEquals( "a----",   Dict.getNote(21)  );
		assertEquals( "a#----",  Dict.getNote(22)  );
		assertEquals( "b----",   Dict.getNote(23)  );
		assertEquals( "c---",    Dict.getNote(24)  );
		assertEquals( "c#---",   Dict.getNote(25)  );
		assertEquals( "d---",    Dict.getNote(26)  );
		assertEquals( "d#---",   Dict.getNote(27)  );
		assertEquals( "e---",    Dict.getNote(28)  );
		assertEquals( "f---",    Dict.getNote(29)  );
		assertEquals( "f#---",   Dict.getNote(30)  );
		assertEquals( "g---",    Dict.getNote(31)  );
		assertEquals( "g#---",   Dict.getNote(32)  );
		assertEquals( "a---",    Dict.getNote(33)  );
		assertEquals( "a#---",   Dict.getNote(34)  );
		assertEquals( "b---",    Dict.getNote(35)  );
		assertEquals( "c--",     Dict.getNote(36)  );
		assertEquals( "c#--",    Dict.getNote(37)  );
		assertEquals( "d--",     Dict.getNote(38)  );
		assertEquals( "d#--",    Dict.getNote(39)  );
		assertEquals( "e--",     Dict.getNote(40)  );
		assertEquals( "f--",     Dict.getNote(41)  );
		assertEquals( "f#--",    Dict.getNote(42)  );
		assertEquals( "g--",     Dict.getNote(43)  );
		assertEquals( "g#--",    Dict.getNote(44)  );
		assertEquals( "a--",     Dict.getNote(45)  );
		assertEquals( "a#--",    Dict.getNote(46)  );
		assertEquals( "b--",     Dict.getNote(47)  );
		assertEquals( "c-",      Dict.getNote(48)  );
		assertEquals( "c#-",     Dict.getNote(49)  );
		assertEquals( "d-",      Dict.getNote(50)  );
		assertEquals( "d#-",     Dict.getNote(51)  );
		assertEquals( "e-",      Dict.getNote(52)  );
		assertEquals( "f-",      Dict.getNote(53)  );
		assertEquals( "f#-",     Dict.getNote(54)  );
		assertEquals( "g-",      Dict.getNote(55)  );
		assertEquals( "g#-",     Dict.getNote(56)  );
		assertEquals( "a-",      Dict.getNote(57)  );
		assertEquals( "a#-",     Dict.getNote(58)  );
		assertEquals( "b-",      Dict.getNote(59)  );
		assertEquals( "c",       Dict.getNote(60)  );
		assertEquals( "c#",      Dict.getNote(61)  );
		assertEquals( "d",       Dict.getNote(62)  );
		assertEquals( "d#",      Dict.getNote(63)  );
		assertEquals( "e",       Dict.getNote(64)  );
		assertEquals( "f",       Dict.getNote(65)  );
		assertEquals( "f#",      Dict.getNote(66)  );
		assertEquals( "g",       Dict.getNote(67)  );
		assertEquals( "g#",      Dict.getNote(68)  );
		assertEquals( "a",       Dict.getNote(69)  );
		assertEquals( "a#",      Dict.getNote(70)  );
		assertEquals( "b",       Dict.getNote(71)  );
		assertEquals( "c+",      Dict.getNote(72)  );
		assertEquals( "c#+",     Dict.getNote(73)  );
		assertEquals( "d+",      Dict.getNote(74)  );
		assertEquals( "d#+",     Dict.getNote(75)  );
		assertEquals( "e+",      Dict.getNote(76)  );
		assertEquals( "f+",      Dict.getNote(77)  );
		assertEquals( "f#+",     Dict.getNote(78)  );
		assertEquals( "g+",      Dict.getNote(79)  );
		assertEquals( "g#+",     Dict.getNote(80)  );
		assertEquals( "a+",      Dict.getNote(81)  );
		assertEquals( "a#+",     Dict.getNote(82)  );
		assertEquals( "b+",      Dict.getNote(83)  );
		assertEquals( "c++",     Dict.getNote(84)  );
		assertEquals( "c#++",    Dict.getNote(85)  );
		assertEquals( "d++",     Dict.getNote(86)  );
		assertEquals( "d#++",    Dict.getNote(87)  );
		assertEquals( "e++",     Dict.getNote(88)  );
		assertEquals( "f++",     Dict.getNote(89)  );
		assertEquals( "f#++",    Dict.getNote(90)  );
		assertEquals( "g++",     Dict.getNote(91)  );
		assertEquals( "g#++",    Dict.getNote(92)  );
		assertEquals( "a++",     Dict.getNote(93)  );
		assertEquals( "a#++",    Dict.getNote(94)  );
		assertEquals( "b++",     Dict.getNote(95)  );
		assertEquals( "c+++",    Dict.getNote(96)  );
		assertEquals( "c#+++",   Dict.getNote(97)  );
		assertEquals( "d+++",    Dict.getNote(98)  );
		assertEquals( "d#+++",   Dict.getNote(99)  );
		assertEquals( "e+++",    Dict.getNote(100) );
		assertEquals( "f+++",    Dict.getNote(101) );
		assertEquals( "f#+++",   Dict.getNote(102) );
		assertEquals( "g+++",    Dict.getNote(103) );
		assertEquals( "g#+++",   Dict.getNote(104) );
		assertEquals( "a+++",    Dict.getNote(105) );
		assertEquals( "a#+++",   Dict.getNote(106) );
		assertEquals( "b+++",    Dict.getNote(107) );
		assertEquals( "c++++",   Dict.getNote(108) );
		assertEquals( "c#++++",  Dict.getNote(109) );
		assertEquals( "d++++",   Dict.getNote(110) );
		assertEquals( "d#++++",  Dict.getNote(111) );
		assertEquals( "e++++",   Dict.getNote(112) );
		assertEquals( "f++++",   Dict.getNote(113) );
		assertEquals( "f#++++",  Dict.getNote(114) );
		assertEquals( "g++++",   Dict.getNote(115) );
		assertEquals( "g#++++",  Dict.getNote(116) );
		assertEquals( "a++++",   Dict.getNote(117) );
		assertEquals( "a#++++",  Dict.getNote(118) );
		assertEquals( "b++++",   Dict.getNote(119) );
		assertEquals( "c+++++",  Dict.getNote(120) );
		assertEquals( "c#+++++", Dict.getNote(121) );
		assertEquals( "d+++++",  Dict.getNote(122) );
		assertEquals( "d#+++++", Dict.getNote(123) );
		assertEquals( "e+++++",  Dict.getNote(124) );
		assertEquals( "f+++++",  Dict.getNote(125) );
		assertEquals( "f#+++++", Dict.getNote(126) );
		assertEquals( "g+++++",  Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "c-1",  Dict.getNote(0)   );
		assertEquals( "c#-1", Dict.getNote(1)   );
		assertEquals( "d-1",  Dict.getNote(2)   );
		assertEquals( "d#-1", Dict.getNote(3)   );
		assertEquals( "e-1",  Dict.getNote(4)   );
		assertEquals( "f-1",  Dict.getNote(5)   );
		assertEquals( "f#-1", Dict.getNote(6)   );
		assertEquals( "g-1",  Dict.getNote(7)   );
		assertEquals( "g#-1", Dict.getNote(8)   );
		assertEquals( "a-1",  Dict.getNote(9)   );
		assertEquals( "a#-1", Dict.getNote(10)  );
		assertEquals( "b-1",  Dict.getNote(11)  );
		assertEquals( "c0",   Dict.getNote(12)  );
		assertEquals( "c#0",  Dict.getNote(13)  );
		assertEquals( "d0",   Dict.getNote(14)  );
		assertEquals( "d#0",  Dict.getNote(15)  );
		assertEquals( "e0",   Dict.getNote(16)  );
		assertEquals( "f0",   Dict.getNote(17)  );
		assertEquals( "f#0",  Dict.getNote(18)  );
		assertEquals( "g0",   Dict.getNote(19)  );
		assertEquals( "g#0",  Dict.getNote(20)  );
		assertEquals( "a0",   Dict.getNote(21)  );
		assertEquals( "a#0",  Dict.getNote(22)  );
		assertEquals( "b0",   Dict.getNote(23)  );
		assertEquals( "c1",   Dict.getNote(24)  );
		assertEquals( "c#1",  Dict.getNote(25)  );
		assertEquals( "d1",   Dict.getNote(26)  );
		assertEquals( "d#1",  Dict.getNote(27)  );
		assertEquals( "e1",   Dict.getNote(28)  );
		assertEquals( "f1",   Dict.getNote(29)  );
		assertEquals( "f#1",  Dict.getNote(30)  );
		assertEquals( "g1",   Dict.getNote(31)  );
		assertEquals( "g#1",  Dict.getNote(32)  );
		assertEquals( "a1",   Dict.getNote(33)  );
		assertEquals( "a#1",  Dict.getNote(34)  );
		assertEquals( "b1",   Dict.getNote(35)  );
		assertEquals( "c2",   Dict.getNote(36)  );
		assertEquals( "c#2",  Dict.getNote(37)  );
		assertEquals( "d2",   Dict.getNote(38)  );
		assertEquals( "d#2",  Dict.getNote(39)  );
		assertEquals( "e2",   Dict.getNote(40)  );
		assertEquals( "f2",   Dict.getNote(41)  );
		assertEquals( "f#2",  Dict.getNote(42)  );
		assertEquals( "g2",   Dict.getNote(43)  );
		assertEquals( "g#2",  Dict.getNote(44)  );
		assertEquals( "a2",   Dict.getNote(45)  );
		assertEquals( "a#2",  Dict.getNote(46)  );
		assertEquals( "b2",   Dict.getNote(47)  );
		assertEquals( "c3",   Dict.getNote(48)  );
		assertEquals( "c#3",  Dict.getNote(49)  );
		assertEquals( "d3",   Dict.getNote(50)  );
		assertEquals( "d#3",  Dict.getNote(51)  );
		assertEquals( "e3",   Dict.getNote(52)  );
		assertEquals( "f3",   Dict.getNote(53)  );
		assertEquals( "f#3",  Dict.getNote(54)  );
		assertEquals( "g3",   Dict.getNote(55)  );
		assertEquals( "g#3",  Dict.getNote(56)  );
		assertEquals( "a3",   Dict.getNote(57)  );
		assertEquals( "a#3",  Dict.getNote(58)  );
		assertEquals( "b3",   Dict.getNote(59)  );
		assertEquals( "c4",   Dict.getNote(60)  );
		assertEquals( "c#4",  Dict.getNote(61)  );
		assertEquals( "d4",   Dict.getNote(62)  );
		assertEquals( "d#4",  Dict.getNote(63)  );
		assertEquals( "e4",   Dict.getNote(64)  );
		assertEquals( "f4",   Dict.getNote(65)  );
		assertEquals( "f#4",  Dict.getNote(66)  );
		assertEquals( "g4",   Dict.getNote(67)  );
		assertEquals( "g#4",  Dict.getNote(68)  );
		assertEquals( "a4",   Dict.getNote(69)  );
		assertEquals( "a#4",  Dict.getNote(70)  );
		assertEquals( "b4",   Dict.getNote(71)  );
		assertEquals( "c5",   Dict.getNote(72)  );
		assertEquals( "c#5",  Dict.getNote(73)  );
		assertEquals( "d5",   Dict.getNote(74)  );
		assertEquals( "d#5",  Dict.getNote(75)  );
		assertEquals( "e5",   Dict.getNote(76)  );
		assertEquals( "f5",   Dict.getNote(77)  );
		assertEquals( "f#5",  Dict.getNote(78)  );
		assertEquals( "g5",   Dict.getNote(79)  );
		assertEquals( "g#5",  Dict.getNote(80)  );
		assertEquals( "a5",   Dict.getNote(81)  );
		assertEquals( "a#5",  Dict.getNote(82)  );
		assertEquals( "b5",   Dict.getNote(83)  );
		assertEquals( "c6",   Dict.getNote(84)  );
		assertEquals( "c#6",  Dict.getNote(85)  );
		assertEquals( "d6",   Dict.getNote(86)  );
		assertEquals( "d#6",  Dict.getNote(87)  );
		assertEquals( "e6",   Dict.getNote(88)  );
		assertEquals( "f6",   Dict.getNote(89)  );
		assertEquals( "f#6",  Dict.getNote(90)  );
		assertEquals( "g6",   Dict.getNote(91)  );
		assertEquals( "g#6",  Dict.getNote(92)  );
		assertEquals( "a6",   Dict.getNote(93)  );
		assertEquals( "a#6",  Dict.getNote(94)  );
		assertEquals( "b6",   Dict.getNote(95)  );
		assertEquals( "c7",   Dict.getNote(96)  );
		assertEquals( "c#7",  Dict.getNote(97)  );
		assertEquals( "d7",   Dict.getNote(98)  );
		assertEquals( "d#7",  Dict.getNote(99)  );
		assertEquals( "e7",   Dict.getNote(100) );
		assertEquals( "f7",   Dict.getNote(101) );
		assertEquals( "f#7",  Dict.getNote(102) );
		assertEquals( "g7",   Dict.getNote(103) );
		assertEquals( "g#7",  Dict.getNote(104) );
		assertEquals( "a7",   Dict.getNote(105) );
		assertEquals( "a#7",  Dict.getNote(106) );
		assertEquals( "b7",   Dict.getNote(107) );
		assertEquals( "c8",   Dict.getNote(108) );
		assertEquals( "c#8",  Dict.getNote(109) );
		assertEquals( "d8",   Dict.getNote(110) );
		assertEquals( "d#8",  Dict.getNote(111) );
		assertEquals( "e8",   Dict.getNote(112) );
		assertEquals( "f8",   Dict.getNote(113) );
		assertEquals( "f#8",  Dict.getNote(114) );
		assertEquals( "g8",   Dict.getNote(115) );
		assertEquals( "g#8",  Dict.getNote(116) );
		assertEquals( "a8",   Dict.getNote(117) );
		assertEquals( "a#8",  Dict.getNote(118) );
		assertEquals( "b8",   Dict.getNote(119) );
		assertEquals( "c9",   Dict.getNote(120) );
		assertEquals( "c#9",  Dict.getNote(121) );
		assertEquals( "d9",   Dict.getNote(122) );
		assertEquals( "d#9",  Dict.getNote(123) );
		assertEquals( "e9",   Dict.getNote(124) );
		assertEquals( "f9",   Dict.getNote(125) );
		assertEquals( "f#9",  Dict.getNote(126) );
		assertEquals( "g9",   Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "C'''",     Dict.getNote(0)   );
		assertEquals( "C#'''",    Dict.getNote(1)   );
		assertEquals( "D'''",     Dict.getNote(2)   );
		assertEquals( "D#'''",    Dict.getNote(3)   );
		assertEquals( "E'''",     Dict.getNote(4)   );
		assertEquals( "F'''",     Dict.getNote(5)   );
		assertEquals( "F#'''",    Dict.getNote(6)   );
		assertEquals( "G'''",     Dict.getNote(7)   );
		assertEquals( "G#'''",    Dict.getNote(8)   );
		assertEquals( "A'''",     Dict.getNote(9)   );
		assertEquals( "A#'''",    Dict.getNote(10)  );
		assertEquals( "B'''",     Dict.getNote(11)  );
		assertEquals( "C''",      Dict.getNote(12)  );
		assertEquals( "C#''",     Dict.getNote(13)  );
		assertEquals( "D''",      Dict.getNote(14)  );
		assertEquals( "D#''",     Dict.getNote(15)  );
		assertEquals( "E''",      Dict.getNote(16)  );
		assertEquals( "F''",      Dict.getNote(17)  );
		assertEquals( "F#''",     Dict.getNote(18)  );
		assertEquals( "G''",      Dict.getNote(19)  );
		assertEquals( "G#''",     Dict.getNote(20)  );
		assertEquals( "A''",      Dict.getNote(21)  );
		assertEquals( "A#''",     Dict.getNote(22)  );
		assertEquals( "B''",      Dict.getNote(23)  );
		assertEquals( "C'",       Dict.getNote(24)  );
		assertEquals( "C#'",      Dict.getNote(25)  );
		assertEquals( "D'",       Dict.getNote(26)  );
		assertEquals( "D#'",      Dict.getNote(27)  );
		assertEquals( "E'",       Dict.getNote(28)  );
		assertEquals( "F'",       Dict.getNote(29)  );
		assertEquals( "F#'",      Dict.getNote(30)  );
		assertEquals( "G'",       Dict.getNote(31)  );
		assertEquals( "G#'",      Dict.getNote(32)  );
		assertEquals( "A'",       Dict.getNote(33)  );
		assertEquals( "A#'",      Dict.getNote(34)  );
		assertEquals( "B'",       Dict.getNote(35)  );
		assertEquals( "C",        Dict.getNote(36)  );
		assertEquals( "C#",       Dict.getNote(37)  );
		assertEquals( "D",        Dict.getNote(38)  );
		assertEquals( "D#",       Dict.getNote(39)  );
		assertEquals( "E",        Dict.getNote(40)  );
		assertEquals( "F",        Dict.getNote(41)  );
		assertEquals( "F#",       Dict.getNote(42)  );
		assertEquals( "G",        Dict.getNote(43)  );
		assertEquals( "G#",       Dict.getNote(44)  );
		assertEquals( "A",        Dict.getNote(45)  );
		assertEquals( "A#",       Dict.getNote(46)  );
		assertEquals( "B",        Dict.getNote(47)  );
		assertEquals( "c",        Dict.getNote(48)  );
		assertEquals( "c#",       Dict.getNote(49)  );
		assertEquals( "d",        Dict.getNote(50)  );
		assertEquals( "d#",       Dict.getNote(51)  );
		assertEquals( "e",        Dict.getNote(52)  );
		assertEquals( "f",        Dict.getNote(53)  );
		assertEquals( "f#",       Dict.getNote(54)  );
		assertEquals( "g",        Dict.getNote(55)  );
		assertEquals( "g#",       Dict.getNote(56)  );
		assertEquals( "a",        Dict.getNote(57)  );
		assertEquals( "a#",       Dict.getNote(58)  );
		assertEquals( "b",        Dict.getNote(59)  );
		assertEquals( "c'",       Dict.getNote(60)  );
		assertEquals( "c#'",      Dict.getNote(61)  );
		assertEquals( "d'",       Dict.getNote(62)  );
		assertEquals( "d#'",      Dict.getNote(63)  );
		assertEquals( "e'",       Dict.getNote(64)  );
		assertEquals( "f'",       Dict.getNote(65)  );
		assertEquals( "f#'",      Dict.getNote(66)  );
		assertEquals( "g'",       Dict.getNote(67)  );
		assertEquals( "g#'",      Dict.getNote(68)  );
		assertEquals( "a'",       Dict.getNote(69)  );
		assertEquals( "a#'",      Dict.getNote(70)  );
		assertEquals( "b'",       Dict.getNote(71)  );
		assertEquals( "c''",      Dict.getNote(72)  );
		assertEquals( "c#''",     Dict.getNote(73)  );
		assertEquals( "d''",      Dict.getNote(74)  );
		assertEquals( "d#''",     Dict.getNote(75)  );
		assertEquals( "e''",      Dict.getNote(76)  );
		assertEquals( "f''",      Dict.getNote(77)  );
		assertEquals( "f#''",     Dict.getNote(78)  );
		assertEquals( "g''",      Dict.getNote(79)  );
		assertEquals( "g#''",     Dict.getNote(80)  );
		assertEquals( "a''",      Dict.getNote(81)  );
		assertEquals( "a#''",     Dict.getNote(82)  );
		assertEquals( "b''",      Dict.getNote(83)  );
		assertEquals( "c'''",     Dict.getNote(84)  );
		assertEquals( "c#'''",    Dict.getNote(85)  );
		assertEquals( "d'''",     Dict.getNote(86)  );
		assertEquals( "d#'''",    Dict.getNote(87)  );
		assertEquals( "e'''",     Dict.getNote(88)  );
		assertEquals( "f'''",     Dict.getNote(89)  );
		assertEquals( "f#'''",    Dict.getNote(90)  );
		assertEquals( "g'''",     Dict.getNote(91)  );
		assertEquals( "g#'''",    Dict.getNote(92)  );
		assertEquals( "a'''",     Dict.getNote(93)  );
		assertEquals( "a#'''",    Dict.getNote(94)  );
		assertEquals( "b'''",     Dict.getNote(95)  );
		assertEquals( "c''''",    Dict.getNote(96)  );
		assertEquals( "c#''''",   Dict.getNote(97)  );
		assertEquals( "d''''",    Dict.getNote(98)  );
		assertEquals( "d#''''",   Dict.getNote(99)  );
		assertEquals( "e''''",    Dict.getNote(100) );
		assertEquals( "f''''",    Dict.getNote(101) );
		assertEquals( "f#''''",   Dict.getNote(102) );
		assertEquals( "g''''",    Dict.getNote(103) );
		assertEquals( "g#''''",   Dict.getNote(104) );
		assertEquals( "a''''",    Dict.getNote(105) );
		assertEquals( "a#''''",   Dict.getNote(106) );
		assertEquals( "b''''",    Dict.getNote(107) );
		assertEquals( "c'''''",   Dict.getNote(108) );
		assertEquals( "c#'''''",  Dict.getNote(109) );
		assertEquals( "d'''''",   Dict.getNote(110) );
		assertEquals( "d#'''''",  Dict.getNote(111) );
		assertEquals( "e'''''",   Dict.getNote(112) );
		assertEquals( "f'''''",   Dict.getNote(113) );
		assertEquals( "f#'''''",  Dict.getNote(114) );
		assertEquals( "g'''''",   Dict.getNote(115) );
		assertEquals( "g#'''''",  Dict.getNote(116) );
		assertEquals( "a'''''",   Dict.getNote(117) );
		assertEquals( "a#'''''",  Dict.getNote(118) );
		assertEquals( "b'''''",   Dict.getNote(119) );
		assertEquals( "c''''''",  Dict.getNote(120) );
		assertEquals( "c#''''''", Dict.getNote(121) );
		assertEquals( "d''''''",  Dict.getNote(122) );
		assertEquals( "d#''''''", Dict.getNote(123) );
		assertEquals( "e''''''",  Dict.getNote(124) );
		assertEquals( "f''''''",  Dict.getNote(125) );
		assertEquals( "f#''''''", Dict.getNote(126) );
		assertEquals( "g''''''",  Dict.getNote(127) );
		
		// switch back to default
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: international (upper-case)
	 * - half tone: flat
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsIntUcFlat() {
		
		// switch config
		cbxs[1].setSelectedIndex(1); // international (upper-case)
		cbxs[3].setSelectedIndex(1); // flat
		
		// test default (+n/-n)
		assertEquals( "C-5",  Dict.getNote(0)   );
		assertEquals( "Db-5", Dict.getNote(1)   );
		assertEquals( "D-5",  Dict.getNote(2)   );
		assertEquals( "Eb-5", Dict.getNote(3)   );
		assertEquals( "E-5",  Dict.getNote(4)   );
		assertEquals( "F-5",  Dict.getNote(5)   );
		assertEquals( "Gb-5", Dict.getNote(6)   );
		assertEquals( "G-5",  Dict.getNote(7)   );
		assertEquals( "Ab-5", Dict.getNote(8)   );
		assertEquals( "A-5",  Dict.getNote(9)   );
		assertEquals( "Bb-5", Dict.getNote(10)  );
		assertEquals( "B-5",  Dict.getNote(11)  );
		assertEquals( "C-4",  Dict.getNote(12)  );
		assertEquals( "Db-4", Dict.getNote(13)  );
		assertEquals( "D-4",  Dict.getNote(14)  );
		assertEquals( "Eb-4", Dict.getNote(15)  );
		assertEquals( "E-4",  Dict.getNote(16)  );
		assertEquals( "F-4",  Dict.getNote(17)  );
		assertEquals( "Gb-4", Dict.getNote(18)  );
		assertEquals( "G-4",  Dict.getNote(19)  );
		assertEquals( "Ab-4", Dict.getNote(20)  );
		assertEquals( "A-4",  Dict.getNote(21)  );
		assertEquals( "Bb-4", Dict.getNote(22)  );
		assertEquals( "B-4",  Dict.getNote(23)  );
		assertEquals( "C-3",  Dict.getNote(24)  );
		assertEquals( "Db-3", Dict.getNote(25)  );
		assertEquals( "D-3",  Dict.getNote(26)  );
		assertEquals( "Eb-3", Dict.getNote(27)  );
		assertEquals( "E-3",  Dict.getNote(28)  );
		assertEquals( "F-3",  Dict.getNote(29)  );
		assertEquals( "Gb-3", Dict.getNote(30)  );
		assertEquals( "G-3",  Dict.getNote(31)  );
		assertEquals( "Ab-3", Dict.getNote(32)  );
		assertEquals( "A-3",  Dict.getNote(33)  );
		assertEquals( "Bb-3", Dict.getNote(34)  );
		assertEquals( "B-3",  Dict.getNote(35)  );
		assertEquals( "C-2",  Dict.getNote(36)  );
		assertEquals( "Db-2", Dict.getNote(37)  );
		assertEquals( "D-2",  Dict.getNote(38)  );
		assertEquals( "Eb-2", Dict.getNote(39)  );
		assertEquals( "E-2",  Dict.getNote(40)  );
		assertEquals( "F-2",  Dict.getNote(41)  );
		assertEquals( "Gb-2", Dict.getNote(42)  );
		assertEquals( "G-2",  Dict.getNote(43)  );
		assertEquals( "Ab-2", Dict.getNote(44)  );
		assertEquals( "A-2",  Dict.getNote(45)  );
		assertEquals( "Bb-2", Dict.getNote(46)  );
		assertEquals( "B-2",  Dict.getNote(47)  );
		assertEquals( "C-",   Dict.getNote(48)  );
		assertEquals( "Db-",  Dict.getNote(49)  );
		assertEquals( "D-",   Dict.getNote(50)  );
		assertEquals( "Eb-",  Dict.getNote(51)  );
		assertEquals( "E-",   Dict.getNote(52)  );
		assertEquals( "F-",   Dict.getNote(53)  );
		assertEquals( "Gb-",  Dict.getNote(54)  );
		assertEquals( "G-",   Dict.getNote(55)  );
		assertEquals( "Ab-",  Dict.getNote(56)  );
		assertEquals( "A-",   Dict.getNote(57)  );
		assertEquals( "Bb-",  Dict.getNote(58)  );
		assertEquals( "B-",   Dict.getNote(59)  );
		assertEquals( "C",    Dict.getNote(60)  );
		assertEquals( "Db",   Dict.getNote(61)  );
		assertEquals( "D",    Dict.getNote(62)  );
		assertEquals( "Eb",   Dict.getNote(63)  );
		assertEquals( "E",    Dict.getNote(64)  );
		assertEquals( "F",    Dict.getNote(65)  );
		assertEquals( "Gb",   Dict.getNote(66)  );
		assertEquals( "G",    Dict.getNote(67)  );
		assertEquals( "Ab",   Dict.getNote(68)  );
		assertEquals( "A",    Dict.getNote(69)  );
		assertEquals( "Bb",   Dict.getNote(70)  );
		assertEquals( "B",    Dict.getNote(71)  );
		assertEquals( "C+",   Dict.getNote(72)  );
		assertEquals( "Db+",  Dict.getNote(73)  );
		assertEquals( "D+",   Dict.getNote(74)  );
		assertEquals( "Eb+",  Dict.getNote(75)  );
		assertEquals( "E+",   Dict.getNote(76)  );
		assertEquals( "F+",   Dict.getNote(77)  );
		assertEquals( "Gb+",  Dict.getNote(78)  );
		assertEquals( "G+",   Dict.getNote(79)  );
		assertEquals( "Ab+",  Dict.getNote(80)  );
		assertEquals( "A+",   Dict.getNote(81)  );
		assertEquals( "Bb+",  Dict.getNote(82)  );
		assertEquals( "B+",   Dict.getNote(83)  );
		assertEquals( "C+2",  Dict.getNote(84)  );
		assertEquals( "Db+2", Dict.getNote(85)  );
		assertEquals( "D+2",  Dict.getNote(86)  );
		assertEquals( "Eb+2", Dict.getNote(87)  );
		assertEquals( "E+2",  Dict.getNote(88)  );
		assertEquals( "F+2",  Dict.getNote(89)  );
		assertEquals( "Gb+2", Dict.getNote(90)  );
		assertEquals( "G+2",  Dict.getNote(91)  );
		assertEquals( "Ab+2", Dict.getNote(92)  );
		assertEquals( "A+2",  Dict.getNote(93)  );
		assertEquals( "Bb+2", Dict.getNote(94)  );
		assertEquals( "B+2",  Dict.getNote(95)  );
		assertEquals( "C+3",  Dict.getNote(96)  );
		assertEquals( "Db+3", Dict.getNote(97)  );
		assertEquals( "D+3",  Dict.getNote(98)  );
		assertEquals( "Eb+3", Dict.getNote(99)  );
		assertEquals( "E+3",  Dict.getNote(100) );
		assertEquals( "F+3",  Dict.getNote(101) );
		assertEquals( "Gb+3", Dict.getNote(102) );
		assertEquals( "G+3",  Dict.getNote(103) );
		assertEquals( "Ab+3", Dict.getNote(104) );
		assertEquals( "A+3",  Dict.getNote(105) );
		assertEquals( "Bb+3", Dict.getNote(106) );
		assertEquals( "B+3",  Dict.getNote(107) );
		assertEquals( "C+4",  Dict.getNote(108) );
		assertEquals( "Db+4", Dict.getNote(109) );
		assertEquals( "D+4",  Dict.getNote(110) );
		assertEquals( "Eb+4", Dict.getNote(111) );
		assertEquals( "E+4",  Dict.getNote(112) );
		assertEquals( "F+4",  Dict.getNote(113) );
		assertEquals( "Gb+4", Dict.getNote(114) );
		assertEquals( "G+4",  Dict.getNote(115) );
		assertEquals( "Ab+4", Dict.getNote(116) );
		assertEquals( "A+4",  Dict.getNote(117) );
		assertEquals( "Bb+4", Dict.getNote(118) );
		assertEquals( "B+4",  Dict.getNote(119) );
		assertEquals( "C+5",  Dict.getNote(120) );
		assertEquals( "Db+5", Dict.getNote(121) );
		assertEquals( "D+5",  Dict.getNote(122) );
		assertEquals( "Eb+5", Dict.getNote(123) );
		assertEquals( "E+5",  Dict.getNote(124) );
		assertEquals( "F+5",  Dict.getNote(125) );
		assertEquals( "Gb+5", Dict.getNote(126) );
		assertEquals( "G+5",  Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "C-----",  Dict.getNote(0)   );
		assertEquals( "Db-----", Dict.getNote(1)   );
		assertEquals( "D-----",  Dict.getNote(2)   );
		assertEquals( "Eb-----", Dict.getNote(3)   );
		assertEquals( "E-----",  Dict.getNote(4)   );
		assertEquals( "F-----",  Dict.getNote(5)   );
		assertEquals( "Gb-----", Dict.getNote(6)   );
		assertEquals( "G-----",  Dict.getNote(7)   );
		assertEquals( "Ab-----", Dict.getNote(8)   );
		assertEquals( "A-----",  Dict.getNote(9)   );
		assertEquals( "Bb-----", Dict.getNote(10)  );
		assertEquals( "B-----",  Dict.getNote(11)  );
		assertEquals( "C----",   Dict.getNote(12)  );
		assertEquals( "Db----",  Dict.getNote(13)  );
		assertEquals( "D----",   Dict.getNote(14)  );
		assertEquals( "Eb----",  Dict.getNote(15)  );
		assertEquals( "E----",   Dict.getNote(16)  );
		assertEquals( "F----",   Dict.getNote(17)  );
		assertEquals( "Gb----",  Dict.getNote(18)  );
		assertEquals( "G----",   Dict.getNote(19)  );
		assertEquals( "Ab----",  Dict.getNote(20)  );
		assertEquals( "A----",   Dict.getNote(21)  );
		assertEquals( "Bb----",  Dict.getNote(22)  );
		assertEquals( "B----",   Dict.getNote(23)  );
		assertEquals( "C---",    Dict.getNote(24)  );
		assertEquals( "Db---",   Dict.getNote(25)  );
		assertEquals( "D---",    Dict.getNote(26)  );
		assertEquals( "Eb---",   Dict.getNote(27)  );
		assertEquals( "E---",    Dict.getNote(28)  );
		assertEquals( "F---",    Dict.getNote(29)  );
		assertEquals( "Gb---",   Dict.getNote(30)  );
		assertEquals( "G---",    Dict.getNote(31)  );
		assertEquals( "Ab---",   Dict.getNote(32)  );
		assertEquals( "A---",    Dict.getNote(33)  );
		assertEquals( "Bb---",   Dict.getNote(34)  );
		assertEquals( "B---",    Dict.getNote(35)  );
		assertEquals( "C--",     Dict.getNote(36)  );
		assertEquals( "Db--",    Dict.getNote(37)  );
		assertEquals( "D--",     Dict.getNote(38)  );
		assertEquals( "Eb--",    Dict.getNote(39)  );
		assertEquals( "E--",     Dict.getNote(40)  );
		assertEquals( "F--",     Dict.getNote(41)  );
		assertEquals( "Gb--",    Dict.getNote(42)  );
		assertEquals( "G--",     Dict.getNote(43)  );
		assertEquals( "Ab--",    Dict.getNote(44)  );
		assertEquals( "A--",     Dict.getNote(45)  );
		assertEquals( "Bb--",    Dict.getNote(46)  );
		assertEquals( "B--",     Dict.getNote(47)  );
		assertEquals( "C-",      Dict.getNote(48)  );
		assertEquals( "Db-",     Dict.getNote(49)  );
		assertEquals( "D-",      Dict.getNote(50)  );
		assertEquals( "Eb-",     Dict.getNote(51)  );
		assertEquals( "E-",      Dict.getNote(52)  );
		assertEquals( "F-",      Dict.getNote(53)  );
		assertEquals( "Gb-",     Dict.getNote(54)  );
		assertEquals( "G-",      Dict.getNote(55)  );
		assertEquals( "Ab-",     Dict.getNote(56)  );
		assertEquals( "A-",      Dict.getNote(57)  );
		assertEquals( "Bb-",     Dict.getNote(58)  );
		assertEquals( "B-",      Dict.getNote(59)  );
		assertEquals( "C",       Dict.getNote(60)  );
		assertEquals( "Db",      Dict.getNote(61)  );
		assertEquals( "D",       Dict.getNote(62)  );
		assertEquals( "Eb",      Dict.getNote(63)  );
		assertEquals( "E",       Dict.getNote(64)  );
		assertEquals( "F",       Dict.getNote(65)  );
		assertEquals( "Gb",      Dict.getNote(66)  );
		assertEquals( "G",       Dict.getNote(67)  );
		assertEquals( "Ab",      Dict.getNote(68)  );
		assertEquals( "A",       Dict.getNote(69)  );
		assertEquals( "Bb",      Dict.getNote(70)  );
		assertEquals( "B",       Dict.getNote(71)  );
		assertEquals( "C+",      Dict.getNote(72)  );
		assertEquals( "Db+",     Dict.getNote(73)  );
		assertEquals( "D+",      Dict.getNote(74)  );
		assertEquals( "Eb+",     Dict.getNote(75)  );
		assertEquals( "E+",      Dict.getNote(76)  );
		assertEquals( "F+",      Dict.getNote(77)  );
		assertEquals( "Gb+",     Dict.getNote(78)  );
		assertEquals( "G+",      Dict.getNote(79)  );
		assertEquals( "Ab+",     Dict.getNote(80)  );
		assertEquals( "A+",      Dict.getNote(81)  );
		assertEquals( "Bb+",     Dict.getNote(82)  );
		assertEquals( "B+",      Dict.getNote(83)  );
		assertEquals( "C++",     Dict.getNote(84)  );
		assertEquals( "Db++",    Dict.getNote(85)  );
		assertEquals( "D++",     Dict.getNote(86)  );
		assertEquals( "Eb++",    Dict.getNote(87)  );
		assertEquals( "E++",     Dict.getNote(88)  );
		assertEquals( "F++",     Dict.getNote(89)  );
		assertEquals( "Gb++",    Dict.getNote(90)  );
		assertEquals( "G++",     Dict.getNote(91)  );
		assertEquals( "Ab++",    Dict.getNote(92)  );
		assertEquals( "A++",     Dict.getNote(93)  );
		assertEquals( "Bb++",    Dict.getNote(94)  );
		assertEquals( "B++",     Dict.getNote(95)  );
		assertEquals( "C+++",    Dict.getNote(96)  );
		assertEquals( "Db+++",   Dict.getNote(97)  );
		assertEquals( "D+++",    Dict.getNote(98)  );
		assertEquals( "Eb+++",   Dict.getNote(99)  );
		assertEquals( "E+++",    Dict.getNote(100) );
		assertEquals( "F+++",    Dict.getNote(101) );
		assertEquals( "Gb+++",   Dict.getNote(102) );
		assertEquals( "G+++",    Dict.getNote(103) );
		assertEquals( "Ab+++",   Dict.getNote(104) );
		assertEquals( "A+++",    Dict.getNote(105) );
		assertEquals( "Bb+++",   Dict.getNote(106) );
		assertEquals( "B+++",    Dict.getNote(107) );
		assertEquals( "C++++",   Dict.getNote(108) );
		assertEquals( "Db++++",  Dict.getNote(109) );
		assertEquals( "D++++",   Dict.getNote(110) );
		assertEquals( "Eb++++",  Dict.getNote(111) );
		assertEquals( "E++++",   Dict.getNote(112) );
		assertEquals( "F++++",   Dict.getNote(113) );
		assertEquals( "Gb++++",  Dict.getNote(114) );
		assertEquals( "G++++",   Dict.getNote(115) );
		assertEquals( "Ab++++",  Dict.getNote(116) );
		assertEquals( "A++++",   Dict.getNote(117) );
		assertEquals( "Bb++++",  Dict.getNote(118) );
		assertEquals( "B++++",   Dict.getNote(119) );
		assertEquals( "C+++++",  Dict.getNote(120) );
		assertEquals( "Db+++++", Dict.getNote(121) );
		assertEquals( "D+++++",  Dict.getNote(122) );
		assertEquals( "Eb+++++", Dict.getNote(123) );
		assertEquals( "E+++++",  Dict.getNote(124) );
		assertEquals( "F+++++",  Dict.getNote(125) );
		assertEquals( "Gb+++++", Dict.getNote(126) );
		assertEquals( "G+++++",  Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "C-1",  Dict.getNote(0)   );
		assertEquals( "Db-1", Dict.getNote(1)   );
		assertEquals( "D-1",  Dict.getNote(2)   );
		assertEquals( "Eb-1", Dict.getNote(3)   );
		assertEquals( "E-1",  Dict.getNote(4)   );
		assertEquals( "F-1",  Dict.getNote(5)   );
		assertEquals( "Gb-1", Dict.getNote(6)   );
		assertEquals( "G-1",  Dict.getNote(7)   );
		assertEquals( "Ab-1", Dict.getNote(8)   );
		assertEquals( "A-1",  Dict.getNote(9)   );
		assertEquals( "Bb-1", Dict.getNote(10)  );
		assertEquals( "B-1",  Dict.getNote(11)  );
		assertEquals( "C0",   Dict.getNote(12)  );
		assertEquals( "Db0",  Dict.getNote(13)  );
		assertEquals( "D0",   Dict.getNote(14)  );
		assertEquals( "Eb0",  Dict.getNote(15)  );
		assertEquals( "E0",   Dict.getNote(16)  );
		assertEquals( "F0",   Dict.getNote(17)  );
		assertEquals( "Gb0",  Dict.getNote(18)  );
		assertEquals( "G0",   Dict.getNote(19)  );
		assertEquals( "Ab0",  Dict.getNote(20)  );
		assertEquals( "A0",   Dict.getNote(21)  );
		assertEquals( "Bb0",  Dict.getNote(22)  );
		assertEquals( "B0",   Dict.getNote(23)  );
		assertEquals( "C1",   Dict.getNote(24)  );
		assertEquals( "Db1",  Dict.getNote(25)  );
		assertEquals( "D1",   Dict.getNote(26)  );
		assertEquals( "Eb1",  Dict.getNote(27)  );
		assertEquals( "E1",   Dict.getNote(28)  );
		assertEquals( "F1",   Dict.getNote(29)  );
		assertEquals( "Gb1",  Dict.getNote(30)  );
		assertEquals( "G1",   Dict.getNote(31)  );
		assertEquals( "Ab1",  Dict.getNote(32)  );
		assertEquals( "A1",   Dict.getNote(33)  );
		assertEquals( "Bb1",  Dict.getNote(34)  );
		assertEquals( "B1",   Dict.getNote(35)  );
		assertEquals( "C2",   Dict.getNote(36)  );
		assertEquals( "Db2",  Dict.getNote(37)  );
		assertEquals( "D2",   Dict.getNote(38)  );
		assertEquals( "Eb2",  Dict.getNote(39)  );
		assertEquals( "E2",   Dict.getNote(40)  );
		assertEquals( "F2",   Dict.getNote(41)  );
		assertEquals( "Gb2",  Dict.getNote(42)  );
		assertEquals( "G2",   Dict.getNote(43)  );
		assertEquals( "Ab2",  Dict.getNote(44)  );
		assertEquals( "A2",   Dict.getNote(45)  );
		assertEquals( "Bb2",  Dict.getNote(46)  );
		assertEquals( "B2",   Dict.getNote(47)  );
		assertEquals( "C3",   Dict.getNote(48)  );
		assertEquals( "Db3",  Dict.getNote(49)  );
		assertEquals( "D3",   Dict.getNote(50)  );
		assertEquals( "Eb3",  Dict.getNote(51)  );
		assertEquals( "E3",   Dict.getNote(52)  );
		assertEquals( "F3",   Dict.getNote(53)  );
		assertEquals( "Gb3",  Dict.getNote(54)  );
		assertEquals( "G3",   Dict.getNote(55)  );
		assertEquals( "Ab3",  Dict.getNote(56)  );
		assertEquals( "A3",   Dict.getNote(57)  );
		assertEquals( "Bb3",  Dict.getNote(58)  );
		assertEquals( "B3",   Dict.getNote(59)  );
		assertEquals( "C4",   Dict.getNote(60)  );
		assertEquals( "Db4",  Dict.getNote(61)  );
		assertEquals( "D4",   Dict.getNote(62)  );
		assertEquals( "Eb4",  Dict.getNote(63)  );
		assertEquals( "E4",   Dict.getNote(64)  );
		assertEquals( "F4",   Dict.getNote(65)  );
		assertEquals( "Gb4",  Dict.getNote(66)  );
		assertEquals( "G4",   Dict.getNote(67)  );
		assertEquals( "Ab4",  Dict.getNote(68)  );
		assertEquals( "A4",   Dict.getNote(69)  );
		assertEquals( "Bb4",  Dict.getNote(70)  );
		assertEquals( "B4",   Dict.getNote(71)  );
		assertEquals( "C5",   Dict.getNote(72)  );
		assertEquals( "Db5",  Dict.getNote(73)  );
		assertEquals( "D5",   Dict.getNote(74)  );
		assertEquals( "Eb5",  Dict.getNote(75)  );
		assertEquals( "E5",   Dict.getNote(76)  );
		assertEquals( "F5",   Dict.getNote(77)  );
		assertEquals( "Gb5",  Dict.getNote(78)  );
		assertEquals( "G5",   Dict.getNote(79)  );
		assertEquals( "Ab5",  Dict.getNote(80)  );
		assertEquals( "A5",   Dict.getNote(81)  );
		assertEquals( "Bb5",  Dict.getNote(82)  );
		assertEquals( "B5",   Dict.getNote(83)  );
		assertEquals( "C6",   Dict.getNote(84)  );
		assertEquals( "Db6",  Dict.getNote(85)  );
		assertEquals( "D6",   Dict.getNote(86)  );
		assertEquals( "Eb6",  Dict.getNote(87)  );
		assertEquals( "E6",   Dict.getNote(88)  );
		assertEquals( "F6",   Dict.getNote(89)  );
		assertEquals( "Gb6",  Dict.getNote(90)  );
		assertEquals( "G6",   Dict.getNote(91)  );
		assertEquals( "Ab6",  Dict.getNote(92)  );
		assertEquals( "A6",   Dict.getNote(93)  );
		assertEquals( "Bb6",  Dict.getNote(94)  );
		assertEquals( "B6",   Dict.getNote(95)  );
		assertEquals( "C7",   Dict.getNote(96)  );
		assertEquals( "Db7",  Dict.getNote(97)  );
		assertEquals( "D7",   Dict.getNote(98)  );
		assertEquals( "Eb7",  Dict.getNote(99)  );
		assertEquals( "E7",   Dict.getNote(100) );
		assertEquals( "F7",   Dict.getNote(101) );
		assertEquals( "Gb7",  Dict.getNote(102) );
		assertEquals( "G7",   Dict.getNote(103) );
		assertEquals( "Ab7",  Dict.getNote(104) );
		assertEquals( "A7",   Dict.getNote(105) );
		assertEquals( "Bb7",  Dict.getNote(106) );
		assertEquals( "B7",   Dict.getNote(107) );
		assertEquals( "C8",   Dict.getNote(108) );
		assertEquals( "Db8",  Dict.getNote(109) );
		assertEquals( "D8",   Dict.getNote(110) );
		assertEquals( "Eb8",  Dict.getNote(111) );
		assertEquals( "E8",   Dict.getNote(112) );
		assertEquals( "F8",   Dict.getNote(113) );
		assertEquals( "Gb8",  Dict.getNote(114) );
		assertEquals( "G8",   Dict.getNote(115) );
		assertEquals( "Ab8",  Dict.getNote(116) );
		assertEquals( "A8",   Dict.getNote(117) );
		assertEquals( "Bb8",  Dict.getNote(118) );
		assertEquals( "B8",   Dict.getNote(119) );
		assertEquals( "C9",   Dict.getNote(120) );
		assertEquals( "Db9",  Dict.getNote(121) );
		assertEquals( "D9",   Dict.getNote(122) );
		assertEquals( "Eb9",  Dict.getNote(123) );
		assertEquals( "E9",   Dict.getNote(124) );
		assertEquals( "F9",   Dict.getNote(125) );
		assertEquals( "Gb9",  Dict.getNote(126) );
		assertEquals( "G9",   Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "C'''",     Dict.getNote(0)   );
		assertEquals( "Db'''",    Dict.getNote(1)   );
		assertEquals( "D'''",     Dict.getNote(2)   );
		assertEquals( "Eb'''",    Dict.getNote(3)   );
		assertEquals( "E'''",     Dict.getNote(4)   );
		assertEquals( "F'''",     Dict.getNote(5)   );
		assertEquals( "Gb'''",    Dict.getNote(6)   );
		assertEquals( "G'''",     Dict.getNote(7)   );
		assertEquals( "Ab'''",    Dict.getNote(8)   );
		assertEquals( "A'''",     Dict.getNote(9)   );
		assertEquals( "Bb'''",    Dict.getNote(10)  );
		assertEquals( "B'''",     Dict.getNote(11)  );
		assertEquals( "C''",      Dict.getNote(12)  );
		assertEquals( "Db''",     Dict.getNote(13)  );
		assertEquals( "D''",      Dict.getNote(14)  );
		assertEquals( "Eb''",     Dict.getNote(15)  );
		assertEquals( "E''",      Dict.getNote(16)  );
		assertEquals( "F''",      Dict.getNote(17)  );
		assertEquals( "Gb''",     Dict.getNote(18)  );
		assertEquals( "G''",      Dict.getNote(19)  );
		assertEquals( "Ab''",     Dict.getNote(20)  );
		assertEquals( "A''",      Dict.getNote(21)  );
		assertEquals( "Bb''",     Dict.getNote(22)  );
		assertEquals( "B''",      Dict.getNote(23)  );
		assertEquals( "C'",       Dict.getNote(24)  );
		assertEquals( "Db'",      Dict.getNote(25)  );
		assertEquals( "D'",       Dict.getNote(26)  );
		assertEquals( "Eb'",      Dict.getNote(27)  );
		assertEquals( "E'",       Dict.getNote(28)  );
		assertEquals( "F'",       Dict.getNote(29)  );
		assertEquals( "Gb'",      Dict.getNote(30)  );
		assertEquals( "G'",       Dict.getNote(31)  );
		assertEquals( "Ab'",      Dict.getNote(32)  );
		assertEquals( "A'",       Dict.getNote(33)  );
		assertEquals( "Bb'",      Dict.getNote(34)  );
		assertEquals( "B'",       Dict.getNote(35)  );
		assertEquals( "C",        Dict.getNote(36)  );
		assertEquals( "Db",       Dict.getNote(37)  );
		assertEquals( "D",        Dict.getNote(38)  );
		assertEquals( "Eb",       Dict.getNote(39)  );
		assertEquals( "E",        Dict.getNote(40)  );
		assertEquals( "F",        Dict.getNote(41)  );
		assertEquals( "Gb",       Dict.getNote(42)  );
		assertEquals( "G",        Dict.getNote(43)  );
		assertEquals( "Ab",       Dict.getNote(44)  );
		assertEquals( "A",        Dict.getNote(45)  );
		assertEquals( "Bb",       Dict.getNote(46)  );
		assertEquals( "B",        Dict.getNote(47)  );
		assertEquals( "c",        Dict.getNote(48)  );
		assertEquals( "db",       Dict.getNote(49)  );
		assertEquals( "d",        Dict.getNote(50)  );
		assertEquals( "eb",       Dict.getNote(51)  );
		assertEquals( "e",        Dict.getNote(52)  );
		assertEquals( "f",        Dict.getNote(53)  );
		assertEquals( "gb",       Dict.getNote(54)  );
		assertEquals( "g",        Dict.getNote(55)  );
		assertEquals( "ab",       Dict.getNote(56)  );
		assertEquals( "a",        Dict.getNote(57)  );
		assertEquals( "bb",       Dict.getNote(58)  );
		assertEquals( "b",        Dict.getNote(59)  );
		assertEquals( "c'",       Dict.getNote(60)  );
		assertEquals( "db'",      Dict.getNote(61)  );
		assertEquals( "d'",       Dict.getNote(62)  );
		assertEquals( "eb'",      Dict.getNote(63)  );
		assertEquals( "e'",       Dict.getNote(64)  );
		assertEquals( "f'",       Dict.getNote(65)  );
		assertEquals( "gb'",      Dict.getNote(66)  );
		assertEquals( "g'",       Dict.getNote(67)  );
		assertEquals( "ab'",      Dict.getNote(68)  );
		assertEquals( "a'",       Dict.getNote(69)  );
		assertEquals( "bb'",      Dict.getNote(70)  );
		assertEquals( "b'",       Dict.getNote(71)  );
		assertEquals( "c''",      Dict.getNote(72)  );
		assertEquals( "db''",     Dict.getNote(73)  );
		assertEquals( "d''",      Dict.getNote(74)  );
		assertEquals( "eb''",     Dict.getNote(75)  );
		assertEquals( "e''",      Dict.getNote(76)  );
		assertEquals( "f''",      Dict.getNote(77)  );
		assertEquals( "gb''",     Dict.getNote(78)  );
		assertEquals( "g''",      Dict.getNote(79)  );
		assertEquals( "ab''",     Dict.getNote(80)  );
		assertEquals( "a''",      Dict.getNote(81)  );
		assertEquals( "bb''",     Dict.getNote(82)  );
		assertEquals( "b''",      Dict.getNote(83)  );
		assertEquals( "c'''",     Dict.getNote(84)  );
		assertEquals( "db'''",    Dict.getNote(85)  );
		assertEquals( "d'''",     Dict.getNote(86)  );
		assertEquals( "eb'''",    Dict.getNote(87)  );
		assertEquals( "e'''",     Dict.getNote(88)  );
		assertEquals( "f'''",     Dict.getNote(89)  );
		assertEquals( "gb'''",    Dict.getNote(90)  );
		assertEquals( "g'''",     Dict.getNote(91)  );
		assertEquals( "ab'''",    Dict.getNote(92)  );
		assertEquals( "a'''",     Dict.getNote(93)  );
		assertEquals( "bb'''",    Dict.getNote(94)  );
		assertEquals( "b'''",     Dict.getNote(95)  );
		assertEquals( "c''''",    Dict.getNote(96)  );
		assertEquals( "db''''",   Dict.getNote(97)  );
		assertEquals( "d''''",    Dict.getNote(98)  );
		assertEquals( "eb''''",   Dict.getNote(99)  );
		assertEquals( "e''''",    Dict.getNote(100) );
		assertEquals( "f''''",    Dict.getNote(101) );
		assertEquals( "gb''''",   Dict.getNote(102) );
		assertEquals( "g''''",    Dict.getNote(103) );
		assertEquals( "ab''''",   Dict.getNote(104) );
		assertEquals( "a''''",    Dict.getNote(105) );
		assertEquals( "bb''''",   Dict.getNote(106) );
		assertEquals( "b''''",    Dict.getNote(107) );
		assertEquals( "c'''''",   Dict.getNote(108) );
		assertEquals( "db'''''",  Dict.getNote(109) );
		assertEquals( "d'''''",   Dict.getNote(110) );
		assertEquals( "eb'''''",  Dict.getNote(111) );
		assertEquals( "e'''''",   Dict.getNote(112) );
		assertEquals( "f'''''",   Dict.getNote(113) );
		assertEquals( "gb'''''",  Dict.getNote(114) );
		assertEquals( "g'''''",   Dict.getNote(115) );
		assertEquals( "ab'''''",  Dict.getNote(116) );
		assertEquals( "a'''''",   Dict.getNote(117) );
		assertEquals( "bb'''''",  Dict.getNote(118) );
		assertEquals( "b'''''",   Dict.getNote(119) );
		assertEquals( "c''''''",  Dict.getNote(120) );
		assertEquals( "db''''''", Dict.getNote(121) );
		assertEquals( "d''''''",  Dict.getNote(122) );
		assertEquals( "eb''''''", Dict.getNote(123) );
		assertEquals( "e''''''",  Dict.getNote(124) );
		assertEquals( "f''''''",  Dict.getNote(125) );
		assertEquals( "gb''''''", Dict.getNote(126) );
		assertEquals( "g''''''",  Dict.getNote(127) );
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[3].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: italian (upper-case)
	 * - half tone: diesis
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsItUcDiesis() {
		
		// switch config
		cbxs[1].setSelectedIndex(3); // italian (upper-case) 
		cbxs[2].setSelectedIndex(1); // -diesis/-bemolle
		
		// test default (+n/-n)
		assertEquals( "Do-5",         Dict.getNote(0)   );
		assertEquals( "Do-diesis-5",  Dict.getNote(1)   );
		assertEquals( "Re-5",         Dict.getNote(2)   );
		assertEquals( "Re-diesis-5",  Dict.getNote(3)   );
		assertEquals( "Mi-5",         Dict.getNote(4)   );
		assertEquals( "Fa-5",         Dict.getNote(5)   );
		assertEquals( "Fa-diesis-5",  Dict.getNote(6)   );
		assertEquals( "Sol-5",        Dict.getNote(7)   );
		assertEquals( "Sol-diesis-5", Dict.getNote(8)   );
		assertEquals( "La-5",         Dict.getNote(9)   );
		assertEquals( "La-diesis-5",  Dict.getNote(10)  );
		assertEquals( "Si-5",         Dict.getNote(11)  );
		assertEquals( "Do-4",         Dict.getNote(12)  );
		assertEquals( "Do-diesis-4",  Dict.getNote(13)  );
		assertEquals( "Re-4",         Dict.getNote(14)  );
		assertEquals( "Re-diesis-4",  Dict.getNote(15)  );
		assertEquals( "Mi-4",         Dict.getNote(16)  );
		assertEquals( "Fa-4",         Dict.getNote(17)  );
		assertEquals( "Fa-diesis-4",  Dict.getNote(18)  );
		assertEquals( "Sol-4",        Dict.getNote(19)  );
		assertEquals( "Sol-diesis-4", Dict.getNote(20)  );
		assertEquals( "La-4",         Dict.getNote(21)  );
		assertEquals( "La-diesis-4",  Dict.getNote(22)  );
		assertEquals( "Si-4",         Dict.getNote(23)  );
		assertEquals( "Do-3",         Dict.getNote(24)  );
		assertEquals( "Do-diesis-3",  Dict.getNote(25)  );
		assertEquals( "Re-3",         Dict.getNote(26)  );
		assertEquals( "Re-diesis-3",  Dict.getNote(27)  );
		assertEquals( "Mi-3",         Dict.getNote(28)  );
		assertEquals( "Fa-3",         Dict.getNote(29)  );
		assertEquals( "Fa-diesis-3",  Dict.getNote(30)  );
		assertEquals( "Sol-3",        Dict.getNote(31)  );
		assertEquals( "Sol-diesis-3", Dict.getNote(32)  );
		assertEquals( "La-3",         Dict.getNote(33)  );
		assertEquals( "La-diesis-3",  Dict.getNote(34)  );
		assertEquals( "Si-3",         Dict.getNote(35)  );
		assertEquals( "Do-2",         Dict.getNote(36)  );
		assertEquals( "Do-diesis-2",  Dict.getNote(37)  );
		assertEquals( "Re-2",         Dict.getNote(38)  );
		assertEquals( "Re-diesis-2",  Dict.getNote(39)  );
		assertEquals( "Mi-2",         Dict.getNote(40)  );
		assertEquals( "Fa-2",         Dict.getNote(41)  );
		assertEquals( "Fa-diesis-2",  Dict.getNote(42)  );
		assertEquals( "Sol-2",        Dict.getNote(43)  );
		assertEquals( "Sol-diesis-2", Dict.getNote(44)  );
		assertEquals( "La-2",         Dict.getNote(45)  );
		assertEquals( "La-diesis-2",  Dict.getNote(46)  );
		assertEquals( "Si-2",         Dict.getNote(47)  );
		assertEquals( "Do-",          Dict.getNote(48)  );
		assertEquals( "Do-diesis-",   Dict.getNote(49)  );
		assertEquals( "Re-",          Dict.getNote(50)  );
		assertEquals( "Re-diesis-",   Dict.getNote(51)  );
		assertEquals( "Mi-",          Dict.getNote(52)  );
		assertEquals( "Fa-",          Dict.getNote(53)  );
		assertEquals( "Fa-diesis-",   Dict.getNote(54)  );
		assertEquals( "Sol-",         Dict.getNote(55)  );
		assertEquals( "Sol-diesis-",  Dict.getNote(56)  );
		assertEquals( "La-",          Dict.getNote(57)  );
		assertEquals( "La-diesis-",   Dict.getNote(58)  );
		assertEquals( "Si-",          Dict.getNote(59)  );
		assertEquals( "Do",           Dict.getNote(60)  );
		assertEquals( "Do-diesis",    Dict.getNote(61)  );
		assertEquals( "Re",           Dict.getNote(62)  );
		assertEquals( "Re-diesis",    Dict.getNote(63)  );
		assertEquals( "Mi",           Dict.getNote(64)  );
		assertEquals( "Fa",           Dict.getNote(65)  );
		assertEquals( "Fa-diesis",    Dict.getNote(66)  );
		assertEquals( "Sol",          Dict.getNote(67)  );
		assertEquals( "Sol-diesis",   Dict.getNote(68)  );
		assertEquals( "La",           Dict.getNote(69)  );
		assertEquals( "La-diesis",    Dict.getNote(70)  );
		assertEquals( "Si",           Dict.getNote(71)  );
		assertEquals( "Do+",          Dict.getNote(72)  );
		assertEquals( "Do-diesis+",   Dict.getNote(73)  );
		assertEquals( "Re+",          Dict.getNote(74)  );
		assertEquals( "Re-diesis+",   Dict.getNote(75)  );
		assertEquals( "Mi+",          Dict.getNote(76)  );
		assertEquals( "Fa+",          Dict.getNote(77)  );
		assertEquals( "Fa-diesis+",   Dict.getNote(78)  );
		assertEquals( "Sol+",         Dict.getNote(79)  );
		assertEquals( "Sol-diesis+",  Dict.getNote(80)  );
		assertEquals( "La+",          Dict.getNote(81)  );
		assertEquals( "La-diesis+",   Dict.getNote(82)  );
		assertEquals( "Si+",          Dict.getNote(83)  );
		assertEquals( "Do+2",         Dict.getNote(84)  );
		assertEquals( "Do-diesis+2",  Dict.getNote(85)  );
		assertEquals( "Re+2",         Dict.getNote(86)  );
		assertEquals( "Re-diesis+2",  Dict.getNote(87)  );
		assertEquals( "Mi+2",         Dict.getNote(88)  );
		assertEquals( "Fa+2",         Dict.getNote(89)  );
		assertEquals( "Fa-diesis+2",  Dict.getNote(90)  );
		assertEquals( "Sol+2",        Dict.getNote(91)  );
		assertEquals( "Sol-diesis+2", Dict.getNote(92)  );
		assertEquals( "La+2",         Dict.getNote(93)  );
		assertEquals( "La-diesis+2",  Dict.getNote(94)  );
		assertEquals( "Si+2",         Dict.getNote(95)  );
		assertEquals( "Do+3",         Dict.getNote(96)  );
		assertEquals( "Do-diesis+3",  Dict.getNote(97)  );
		assertEquals( "Re+3",         Dict.getNote(98)  );
		assertEquals( "Re-diesis+3",  Dict.getNote(99)  );
		assertEquals( "Mi+3",         Dict.getNote(100) );
		assertEquals( "Fa+3",         Dict.getNote(101) );
		assertEquals( "Fa-diesis+3",  Dict.getNote(102) );
		assertEquals( "Sol+3",        Dict.getNote(103) );
		assertEquals( "Sol-diesis+3", Dict.getNote(104) );
		assertEquals( "La+3",         Dict.getNote(105) );
		assertEquals( "La-diesis+3",  Dict.getNote(106) );
		assertEquals( "Si+3",         Dict.getNote(107) );
		assertEquals( "Do+4",         Dict.getNote(108) );
		assertEquals( "Do-diesis+4",  Dict.getNote(109) );
		assertEquals( "Re+4",         Dict.getNote(110) );
		assertEquals( "Re-diesis+4",  Dict.getNote(111) );
		assertEquals( "Mi+4",         Dict.getNote(112) );
		assertEquals( "Fa+4",         Dict.getNote(113) );
		assertEquals( "Fa-diesis+4",  Dict.getNote(114) );
		assertEquals( "Sol+4",        Dict.getNote(115) );
		assertEquals( "Sol-diesis+4", Dict.getNote(116) );
		assertEquals( "La+4",         Dict.getNote(117) );
		assertEquals( "La-diesis+4",  Dict.getNote(118) );
		assertEquals( "Si+4",         Dict.getNote(119) );
		assertEquals( "Do+5",         Dict.getNote(120) );
		assertEquals( "Do-diesis+5",  Dict.getNote(121) );
		assertEquals( "Re+5",         Dict.getNote(122) );
		assertEquals( "Re-diesis+5",  Dict.getNote(123) );
		assertEquals( "Mi+5",         Dict.getNote(124) );
		assertEquals( "Fa+5",         Dict.getNote(125) );
		assertEquals( "Fa-diesis+5",  Dict.getNote(126) );
		assertEquals( "Sol+5",        Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "Do-----",         Dict.getNote(0)   );
		assertEquals( "Do-diesis-----",  Dict.getNote(1)   );
		assertEquals( "Re-----",         Dict.getNote(2)   );
		assertEquals( "Re-diesis-----",  Dict.getNote(3)   );
		assertEquals( "Mi-----",         Dict.getNote(4)   );
		assertEquals( "Fa-----",         Dict.getNote(5)   );
		assertEquals( "Fa-diesis-----",  Dict.getNote(6)   );
		assertEquals( "Sol-----",        Dict.getNote(7)   );
		assertEquals( "Sol-diesis-----", Dict.getNote(8)   );
		assertEquals( "La-----",         Dict.getNote(9)   );
		assertEquals( "La-diesis-----",  Dict.getNote(10)  );
		assertEquals( "Si-----",         Dict.getNote(11)  );
		assertEquals( "Do----",          Dict.getNote(12)  );
		assertEquals( "Do-diesis----",   Dict.getNote(13)  );
		assertEquals( "Re----",          Dict.getNote(14)  );
		assertEquals( "Re-diesis----",   Dict.getNote(15)  );
		assertEquals( "Mi----",          Dict.getNote(16)  );
		assertEquals( "Fa----",          Dict.getNote(17)  );
		assertEquals( "Fa-diesis----",   Dict.getNote(18)  );
		assertEquals( "Sol----",         Dict.getNote(19)  );
		assertEquals( "Sol-diesis----",  Dict.getNote(20)  );
		assertEquals( "La----",          Dict.getNote(21)  );
		assertEquals( "La-diesis----",   Dict.getNote(22)  );
		assertEquals( "Si----",          Dict.getNote(23)  );
		assertEquals( "Do---",           Dict.getNote(24)  );
		assertEquals( "Do-diesis---",    Dict.getNote(25)  );
		assertEquals( "Re---",           Dict.getNote(26)  );
		assertEquals( "Re-diesis---",    Dict.getNote(27)  );
		assertEquals( "Mi---",           Dict.getNote(28)  );
		assertEquals( "Fa---",           Dict.getNote(29)  );
		assertEquals( "Fa-diesis---",    Dict.getNote(30)  );
		assertEquals( "Sol---",          Dict.getNote(31)  );
		assertEquals( "Sol-diesis---",   Dict.getNote(32)  );
		assertEquals( "La---",           Dict.getNote(33)  );
		assertEquals( "La-diesis---",    Dict.getNote(34)  );
		assertEquals( "Si---",           Dict.getNote(35)  );
		assertEquals( "Do--",            Dict.getNote(36)  );
		assertEquals( "Do-diesis--",     Dict.getNote(37)  );
		assertEquals( "Re--",            Dict.getNote(38)  );
		assertEquals( "Re-diesis--",     Dict.getNote(39)  );
		assertEquals( "Mi--",            Dict.getNote(40)  );
		assertEquals( "Fa--",            Dict.getNote(41)  );
		assertEquals( "Fa-diesis--",     Dict.getNote(42)  );
		assertEquals( "Sol--",           Dict.getNote(43)  );
		assertEquals( "Sol-diesis--",    Dict.getNote(44)  );
		assertEquals( "La--",            Dict.getNote(45)  );
		assertEquals( "La-diesis--",     Dict.getNote(46)  );
		assertEquals( "Si--",            Dict.getNote(47)  );
		assertEquals( "Do-",             Dict.getNote(48)  );
		assertEquals( "Do-diesis-",      Dict.getNote(49)  );
		assertEquals( "Re-",             Dict.getNote(50)  );
		assertEquals( "Re-diesis-",      Dict.getNote(51)  );
		assertEquals( "Mi-",             Dict.getNote(52)  );
		assertEquals( "Fa-",             Dict.getNote(53)  );
		assertEquals( "Fa-diesis-",      Dict.getNote(54)  );
		assertEquals( "Sol-",            Dict.getNote(55)  );
		assertEquals( "Sol-diesis-",     Dict.getNote(56)  );
		assertEquals( "La-",             Dict.getNote(57)  );
		assertEquals( "La-diesis-",      Dict.getNote(58)  );
		assertEquals( "Si-",             Dict.getNote(59)  );
		assertEquals( "Do",              Dict.getNote(60)  );
		assertEquals( "Do-diesis",       Dict.getNote(61)  );
		assertEquals( "Re",              Dict.getNote(62)  );
		assertEquals( "Re-diesis",       Dict.getNote(63)  );
		assertEquals( "Mi",              Dict.getNote(64)  );
		assertEquals( "Fa",              Dict.getNote(65)  );
		assertEquals( "Fa-diesis",       Dict.getNote(66)  );
		assertEquals( "Sol",             Dict.getNote(67)  );
		assertEquals( "Sol-diesis",      Dict.getNote(68)  );
		assertEquals( "La",              Dict.getNote(69)  );
		assertEquals( "La-diesis",       Dict.getNote(70)  );
		assertEquals( "Si",              Dict.getNote(71)  );
		assertEquals( "Do+",             Dict.getNote(72)  );
		assertEquals( "Do-diesis+",      Dict.getNote(73)  );
		assertEquals( "Re+",             Dict.getNote(74)  );
		assertEquals( "Re-diesis+",      Dict.getNote(75)  );
		assertEquals( "Mi+",             Dict.getNote(76)  );
		assertEquals( "Fa+",             Dict.getNote(77)  );
		assertEquals( "Fa-diesis+",      Dict.getNote(78)  );
		assertEquals( "Sol+",            Dict.getNote(79)  );
		assertEquals( "Sol-diesis+",     Dict.getNote(80)  );
		assertEquals( "La+",             Dict.getNote(81)  );
		assertEquals( "La-diesis+",      Dict.getNote(82)  );
		assertEquals( "Si+",             Dict.getNote(83)  );
		assertEquals( "Do++",            Dict.getNote(84)  );
		assertEquals( "Do-diesis++",     Dict.getNote(85)  );
		assertEquals( "Re++",            Dict.getNote(86)  );
		assertEquals( "Re-diesis++",     Dict.getNote(87)  );
		assertEquals( "Mi++",            Dict.getNote(88)  );
		assertEquals( "Fa++",            Dict.getNote(89)  );
		assertEquals( "Fa-diesis++",     Dict.getNote(90)  );
		assertEquals( "Sol++",           Dict.getNote(91)  );
		assertEquals( "Sol-diesis++",    Dict.getNote(92)  );
		assertEquals( "La++",            Dict.getNote(93)  );
		assertEquals( "La-diesis++",     Dict.getNote(94)  );
		assertEquals( "Si++",            Dict.getNote(95)  );
		assertEquals( "Do+++",           Dict.getNote(96)  );
		assertEquals( "Do-diesis+++",    Dict.getNote(97)  );
		assertEquals( "Re+++",           Dict.getNote(98)  );
		assertEquals( "Re-diesis+++",    Dict.getNote(99)  );
		assertEquals( "Mi+++",           Dict.getNote(100) );
		assertEquals( "Fa+++",           Dict.getNote(101) );
		assertEquals( "Fa-diesis+++",    Dict.getNote(102) );
		assertEquals( "Sol+++",          Dict.getNote(103) );
		assertEquals( "Sol-diesis+++",   Dict.getNote(104) );
		assertEquals( "La+++",           Dict.getNote(105) );
		assertEquals( "La-diesis+++",    Dict.getNote(106) );
		assertEquals( "Si+++",           Dict.getNote(107) );
		assertEquals( "Do++++",          Dict.getNote(108) );
		assertEquals( "Do-diesis++++",   Dict.getNote(109) );
		assertEquals( "Re++++",          Dict.getNote(110) );
		assertEquals( "Re-diesis++++",   Dict.getNote(111) );
		assertEquals( "Mi++++",          Dict.getNote(112) );
		assertEquals( "Fa++++",          Dict.getNote(113) );
		assertEquals( "Fa-diesis++++",   Dict.getNote(114) );
		assertEquals( "Sol++++",         Dict.getNote(115) );
		assertEquals( "Sol-diesis++++",  Dict.getNote(116) );
		assertEquals( "La++++",          Dict.getNote(117) );
		assertEquals( "La-diesis++++",   Dict.getNote(118) );
		assertEquals( "Si++++",          Dict.getNote(119) );
		assertEquals( "Do+++++",         Dict.getNote(120) );
		assertEquals( "Do-diesis+++++",  Dict.getNote(121) );
		assertEquals( "Re+++++",         Dict.getNote(122) );
		assertEquals( "Re-diesis+++++",  Dict.getNote(123) );
		assertEquals( "Mi+++++",         Dict.getNote(124) );
		assertEquals( "Fa+++++",         Dict.getNote(125) );
		assertEquals( "Fa-diesis+++++",  Dict.getNote(126) );
		assertEquals( "Sol+++++",        Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "Do-1",         Dict.getNote(0)   );
		assertEquals( "Do-diesis-1",  Dict.getNote(1)   );
		assertEquals( "Re-1",         Dict.getNote(2)   );
		assertEquals( "Re-diesis-1",  Dict.getNote(3)   );
		assertEquals( "Mi-1",         Dict.getNote(4)   );
		assertEquals( "Fa-1",         Dict.getNote(5)   );
		assertEquals( "Fa-diesis-1",  Dict.getNote(6)   );
		assertEquals( "Sol-1",        Dict.getNote(7)   );
		assertEquals( "Sol-diesis-1", Dict.getNote(8)   );
		assertEquals( "La-1",         Dict.getNote(9)   );
		assertEquals( "La-diesis-1",  Dict.getNote(10)  );
		assertEquals( "Si-1",         Dict.getNote(11)  );
		assertEquals( "Do0",          Dict.getNote(12)  );
		assertEquals( "Do-diesis0",   Dict.getNote(13)  );
		assertEquals( "Re0",          Dict.getNote(14)  );
		assertEquals( "Re-diesis0",   Dict.getNote(15)  );
		assertEquals( "Mi0",          Dict.getNote(16)  );
		assertEquals( "Fa0",          Dict.getNote(17)  );
		assertEquals( "Fa-diesis0",   Dict.getNote(18)  );
		assertEquals( "Sol0",         Dict.getNote(19)  );
		assertEquals( "Sol-diesis0",  Dict.getNote(20)  );
		assertEquals( "La0",          Dict.getNote(21)  );
		assertEquals( "La-diesis0",   Dict.getNote(22)  );
		assertEquals( "Si0",          Dict.getNote(23)  );
		assertEquals( "Do1",          Dict.getNote(24)  );
		assertEquals( "Do-diesis1",   Dict.getNote(25)  );
		assertEquals( "Re1",          Dict.getNote(26)  );
		assertEquals( "Re-diesis1",   Dict.getNote(27)  );
		assertEquals( "Mi1",          Dict.getNote(28)  );
		assertEquals( "Fa1",          Dict.getNote(29)  );
		assertEquals( "Fa-diesis1",   Dict.getNote(30)  );
		assertEquals( "Sol1",         Dict.getNote(31)  );
		assertEquals( "Sol-diesis1",  Dict.getNote(32)  );
		assertEquals( "La1",          Dict.getNote(33)  );
		assertEquals( "La-diesis1",   Dict.getNote(34)  );
		assertEquals( "Si1",          Dict.getNote(35)  );
		assertEquals( "Do2",          Dict.getNote(36)  );
		assertEquals( "Do-diesis2",   Dict.getNote(37)  );
		assertEquals( "Re2",          Dict.getNote(38)  );
		assertEquals( "Re-diesis2",   Dict.getNote(39)  );
		assertEquals( "Mi2",          Dict.getNote(40)  );
		assertEquals( "Fa2",          Dict.getNote(41)  );
		assertEquals( "Fa-diesis2",   Dict.getNote(42)  );
		assertEquals( "Sol2",         Dict.getNote(43)  );
		assertEquals( "Sol-diesis2",  Dict.getNote(44)  );
		assertEquals( "La2",          Dict.getNote(45)  );
		assertEquals( "La-diesis2",   Dict.getNote(46)  );
		assertEquals( "Si2",          Dict.getNote(47)  );
		assertEquals( "Do3",          Dict.getNote(48)  );
		assertEquals( "Do-diesis3",   Dict.getNote(49)  );
		assertEquals( "Re3",          Dict.getNote(50)  );
		assertEquals( "Re-diesis3",   Dict.getNote(51)  );
		assertEquals( "Mi3",          Dict.getNote(52)  );
		assertEquals( "Fa3",          Dict.getNote(53)  );
		assertEquals( "Fa-diesis3",   Dict.getNote(54)  );
		assertEquals( "Sol3",         Dict.getNote(55)  );
		assertEquals( "Sol-diesis3",  Dict.getNote(56)  );
		assertEquals( "La3",          Dict.getNote(57)  );
		assertEquals( "La-diesis3",   Dict.getNote(58)  );
		assertEquals( "Si3",          Dict.getNote(59)  );
		assertEquals( "Do4",          Dict.getNote(60)  );
		assertEquals( "Do-diesis4",   Dict.getNote(61)  );
		assertEquals( "Re4",          Dict.getNote(62)  );
		assertEquals( "Re-diesis4",   Dict.getNote(63)  );
		assertEquals( "Mi4",          Dict.getNote(64)  );
		assertEquals( "Fa4",          Dict.getNote(65)  );
		assertEquals( "Fa-diesis4",   Dict.getNote(66)  );
		assertEquals( "Sol4",         Dict.getNote(67)  );
		assertEquals( "Sol-diesis4",  Dict.getNote(68)  );
		assertEquals( "La4",          Dict.getNote(69)  );
		assertEquals( "La-diesis4",   Dict.getNote(70)  );
		assertEquals( "Si4",          Dict.getNote(71)  );
		assertEquals( "Do5",          Dict.getNote(72)  );
		assertEquals( "Do-diesis5",   Dict.getNote(73)  );
		assertEquals( "Re5",          Dict.getNote(74)  );
		assertEquals( "Re-diesis5",   Dict.getNote(75)  );
		assertEquals( "Mi5",          Dict.getNote(76)  );
		assertEquals( "Fa5",          Dict.getNote(77)  );
		assertEquals( "Fa-diesis5",   Dict.getNote(78)  );
		assertEquals( "Sol5",         Dict.getNote(79)  );
		assertEquals( "Sol-diesis5",  Dict.getNote(80)  );
		assertEquals( "La5",          Dict.getNote(81)  );
		assertEquals( "La-diesis5",   Dict.getNote(82)  );
		assertEquals( "Si5",          Dict.getNote(83)  );
		assertEquals( "Do6",          Dict.getNote(84)  );
		assertEquals( "Do-diesis6",   Dict.getNote(85)  );
		assertEquals( "Re6",          Dict.getNote(86)  );
		assertEquals( "Re-diesis6",   Dict.getNote(87)  );
		assertEquals( "Mi6",          Dict.getNote(88)  );
		assertEquals( "Fa6",          Dict.getNote(89)  );
		assertEquals( "Fa-diesis6",   Dict.getNote(90)  );
		assertEquals( "Sol6",         Dict.getNote(91)  );
		assertEquals( "Sol-diesis6",  Dict.getNote(92)  );
		assertEquals( "La6",          Dict.getNote(93)  );
		assertEquals( "La-diesis6",   Dict.getNote(94)  );
		assertEquals( "Si6",          Dict.getNote(95)  );
		assertEquals( "Do7",          Dict.getNote(96)  );
		assertEquals( "Do-diesis7",   Dict.getNote(97)  );
		assertEquals( "Re7",          Dict.getNote(98)  );
		assertEquals( "Re-diesis7",   Dict.getNote(99)  );
		assertEquals( "Mi7",          Dict.getNote(100) );
		assertEquals( "Fa7",          Dict.getNote(101) );
		assertEquals( "Fa-diesis7",   Dict.getNote(102) );
		assertEquals( "Sol7",         Dict.getNote(103) );
		assertEquals( "Sol-diesis7",  Dict.getNote(104) );
		assertEquals( "La7",          Dict.getNote(105) );
		assertEquals( "La-diesis7",   Dict.getNote(106) );
		assertEquals( "Si7",          Dict.getNote(107) );
		assertEquals( "Do8",          Dict.getNote(108) );
		assertEquals( "Do-diesis8",   Dict.getNote(109) );
		assertEquals( "Re8",          Dict.getNote(110) );
		assertEquals( "Re-diesis8",   Dict.getNote(111) );
		assertEquals( "Mi8",          Dict.getNote(112) );
		assertEquals( "Fa8",          Dict.getNote(113) );
		assertEquals( "Fa-diesis8",   Dict.getNote(114) );
		assertEquals( "Sol8",         Dict.getNote(115) );
		assertEquals( "Sol-diesis8",  Dict.getNote(116) );
		assertEquals( "La8",          Dict.getNote(117) );
		assertEquals( "La-diesis8",   Dict.getNote(118) );
		assertEquals( "Si8",          Dict.getNote(119) );
		assertEquals( "Do9",          Dict.getNote(120) );
		assertEquals( "Do-diesis9",   Dict.getNote(121) );
		assertEquals( "Re9",          Dict.getNote(122) );
		assertEquals( "Re-diesis9",   Dict.getNote(123) );
		assertEquals( "Mi9",          Dict.getNote(124) );
		assertEquals( "Fa9",          Dict.getNote(125) );
		assertEquals( "Fa-diesis9",   Dict.getNote(126) );
		assertEquals( "Sol9",         Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "Do'''",           Dict.getNote(0)   );
		assertEquals( "Do-diesis'''",    Dict.getNote(1)   );
		assertEquals( "Re'''",           Dict.getNote(2)   );
		assertEquals( "Re-diesis'''",    Dict.getNote(3)   );
		assertEquals( "Mi'''",           Dict.getNote(4)   );
		assertEquals( "Fa'''",           Dict.getNote(5)   );
		assertEquals( "Fa-diesis'''",    Dict.getNote(6)   );
		assertEquals( "Sol'''",          Dict.getNote(7)   );
		assertEquals( "Sol-diesis'''",   Dict.getNote(8)   );
		assertEquals( "La'''",           Dict.getNote(9)   );
		assertEquals( "La-diesis'''",    Dict.getNote(10)  );
		assertEquals( "Si'''",           Dict.getNote(11)  );
		assertEquals( "Do''",            Dict.getNote(12)  );
		assertEquals( "Do-diesis''",     Dict.getNote(13)  );
		assertEquals( "Re''",            Dict.getNote(14)  );
		assertEquals( "Re-diesis''",     Dict.getNote(15)  );
		assertEquals( "Mi''",            Dict.getNote(16)  );
		assertEquals( "Fa''",            Dict.getNote(17)  );
		assertEquals( "Fa-diesis''",     Dict.getNote(18)  );
		assertEquals( "Sol''",           Dict.getNote(19)  );
		assertEquals( "Sol-diesis''",    Dict.getNote(20)  );
		assertEquals( "La''",            Dict.getNote(21)  );
		assertEquals( "La-diesis''",     Dict.getNote(22)  );
		assertEquals( "Si''",            Dict.getNote(23)  );
		assertEquals( "Do'",             Dict.getNote(24)  );
		assertEquals( "Do-diesis'",      Dict.getNote(25)  );
		assertEquals( "Re'",             Dict.getNote(26)  );
		assertEquals( "Re-diesis'",      Dict.getNote(27)  );
		assertEquals( "Mi'",             Dict.getNote(28)  );
		assertEquals( "Fa'",             Dict.getNote(29)  );
		assertEquals( "Fa-diesis'",      Dict.getNote(30)  );
		assertEquals( "Sol'",            Dict.getNote(31)  );
		assertEquals( "Sol-diesis'",     Dict.getNote(32)  );
		assertEquals( "La'",             Dict.getNote(33)  );
		assertEquals( "La-diesis'",      Dict.getNote(34)  );
		assertEquals( "Si'",             Dict.getNote(35)  );
		assertEquals( "Do",              Dict.getNote(36)  );
		assertEquals( "Do-diesis",       Dict.getNote(37)  );
		assertEquals( "Re",              Dict.getNote(38)  );
		assertEquals( "Re-diesis",       Dict.getNote(39)  );
		assertEquals( "Mi",              Dict.getNote(40)  );
		assertEquals( "Fa",              Dict.getNote(41)  );
		assertEquals( "Fa-diesis",       Dict.getNote(42)  );
		assertEquals( "Sol",             Dict.getNote(43)  );
		assertEquals( "Sol-diesis",      Dict.getNote(44)  );
		assertEquals( "La",              Dict.getNote(45)  );
		assertEquals( "La-diesis",       Dict.getNote(46)  );
		assertEquals( "Si",              Dict.getNote(47)  );
		assertEquals( "do",              Dict.getNote(48)  );
		assertEquals( "do-diesis",       Dict.getNote(49)  );
		assertEquals( "re",              Dict.getNote(50)  );
		assertEquals( "re-diesis",       Dict.getNote(51)  );
		assertEquals( "mi",              Dict.getNote(52)  );
		assertEquals( "fa",              Dict.getNote(53)  );
		assertEquals( "fa-diesis",       Dict.getNote(54)  );
		assertEquals( "sol",             Dict.getNote(55)  );
		assertEquals( "sol-diesis",      Dict.getNote(56)  );
		assertEquals( "la",              Dict.getNote(57)  );
		assertEquals( "la-diesis",       Dict.getNote(58)  );
		assertEquals( "si",              Dict.getNote(59)  );
		assertEquals( "do'",             Dict.getNote(60)  );
		assertEquals( "do-diesis'",      Dict.getNote(61)  );
		assertEquals( "re'",             Dict.getNote(62)  );
		assertEquals( "re-diesis'",      Dict.getNote(63)  );
		assertEquals( "mi'",             Dict.getNote(64)  );
		assertEquals( "fa'",             Dict.getNote(65)  );
		assertEquals( "fa-diesis'",      Dict.getNote(66)  );
		assertEquals( "sol'",            Dict.getNote(67)  );
		assertEquals( "sol-diesis'",     Dict.getNote(68)  );
		assertEquals( "la'",             Dict.getNote(69)  );
		assertEquals( "la-diesis'",      Dict.getNote(70)  );
		assertEquals( "si'",             Dict.getNote(71)  );
		assertEquals( "do''",            Dict.getNote(72)  );
		assertEquals( "do-diesis''",     Dict.getNote(73)  );
		assertEquals( "re''",            Dict.getNote(74)  );
		assertEquals( "re-diesis''",     Dict.getNote(75)  );
		assertEquals( "mi''",            Dict.getNote(76)  );
		assertEquals( "fa''",            Dict.getNote(77)  );
		assertEquals( "fa-diesis''",     Dict.getNote(78)  );
		assertEquals( "sol''",           Dict.getNote(79)  );
		assertEquals( "sol-diesis''",    Dict.getNote(80)  );
		assertEquals( "la''",            Dict.getNote(81)  );
		assertEquals( "la-diesis''",     Dict.getNote(82)  );
		assertEquals( "si''",            Dict.getNote(83)  );
		assertEquals( "do'''",           Dict.getNote(84)  );
		assertEquals( "do-diesis'''",    Dict.getNote(85)  );
		assertEquals( "re'''",           Dict.getNote(86)  );
		assertEquals( "re-diesis'''",    Dict.getNote(87)  );
		assertEquals( "mi'''",           Dict.getNote(88)  );
		assertEquals( "fa'''",           Dict.getNote(89)  );
		assertEquals( "fa-diesis'''",    Dict.getNote(90)  );
		assertEquals( "sol'''",          Dict.getNote(91)  );
		assertEquals( "sol-diesis'''",   Dict.getNote(92)  );
		assertEquals( "la'''",           Dict.getNote(93)  );
		assertEquals( "la-diesis'''",    Dict.getNote(94)  );
		assertEquals( "si'''",           Dict.getNote(95)  );
		assertEquals( "do''''",          Dict.getNote(96)  );
		assertEquals( "do-diesis''''",   Dict.getNote(97)  );
		assertEquals( "re''''",          Dict.getNote(98)  );
		assertEquals( "re-diesis''''",   Dict.getNote(99)  );
		assertEquals( "mi''''",          Dict.getNote(100) );
		assertEquals( "fa''''",          Dict.getNote(101) );
		assertEquals( "fa-diesis''''",   Dict.getNote(102) );
		assertEquals( "sol''''",         Dict.getNote(103) );
		assertEquals( "sol-diesis''''",  Dict.getNote(104) );
		assertEquals( "la''''",          Dict.getNote(105) );
		assertEquals( "la-diesis''''",   Dict.getNote(106) );
		assertEquals( "si''''",          Dict.getNote(107) );
		assertEquals( "do'''''",         Dict.getNote(108) );
		assertEquals( "do-diesis'''''",  Dict.getNote(109) );
		assertEquals( "re'''''",         Dict.getNote(110) );
		assertEquals( "re-diesis'''''",  Dict.getNote(111) );
		assertEquals( "mi'''''",         Dict.getNote(112) );
		assertEquals( "fa'''''",         Dict.getNote(113) );
		assertEquals( "fa-diesis'''''",  Dict.getNote(114) );
		assertEquals( "sol'''''",        Dict.getNote(115) );
		assertEquals( "sol-diesis'''''", Dict.getNote(116) );
		assertEquals( "la'''''",         Dict.getNote(117) );
		assertEquals( "la-diesis'''''",  Dict.getNote(118) );
		assertEquals( "si'''''",         Dict.getNote(119) );
		assertEquals( "do''''''",        Dict.getNote(120) );
		assertEquals( "do-diesis''''''", Dict.getNote(121) );
		assertEquals( "re''''''",        Dict.getNote(122) );
		assertEquals( "re-diesis''''''", Dict.getNote(123) );
		assertEquals( "mi''''''",        Dict.getNote(124) );
		assertEquals( "fa''''''",        Dict.getNote(125) );
		assertEquals( "fa-diesis''''''", Dict.getNote(126) );
		assertEquals( "sol''''''",       Dict.getNote(127) );
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[2].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: italian (lower-case)
	 * - half tone: bemolle
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsItLcBemolle() {
		
		// switch config
		cbxs[1].setSelectedIndex(2); // italian (lower-case) 
		cbxs[2].setSelectedIndex(1); // -dieses/-bemolle
		cbxs[3].setSelectedIndex(1); // flat
		
		// test default (+n/-n)
		assertEquals( "do-5",          Dict.getNote(0)   );
		assertEquals( "re-bemolle-5",  Dict.getNote(1)   );
		assertEquals( "re-5",          Dict.getNote(2)   );
		assertEquals( "mi-bemolle-5",  Dict.getNote(3)   );
		assertEquals( "mi-5",          Dict.getNote(4)   );
		assertEquals( "fa-5",          Dict.getNote(5)   );
		assertEquals( "sol-bemolle-5", Dict.getNote(6)   );
		assertEquals( "sol-5",         Dict.getNote(7)   );
		assertEquals( "la-bemolle-5",  Dict.getNote(8)   );
		assertEquals( "la-5",          Dict.getNote(9)   );
		assertEquals( "si-bemolle-5",  Dict.getNote(10)  );
		assertEquals( "si-5",          Dict.getNote(11)  );
		assertEquals( "do-4",          Dict.getNote(12)  );
		assertEquals( "re-bemolle-4",  Dict.getNote(13)  );
		assertEquals( "re-4",          Dict.getNote(14)  );
		assertEquals( "mi-bemolle-4",  Dict.getNote(15)  );
		assertEquals( "mi-4",          Dict.getNote(16)  );
		assertEquals( "fa-4",          Dict.getNote(17)  );
		assertEquals( "sol-bemolle-4", Dict.getNote(18)  );
		assertEquals( "sol-4",         Dict.getNote(19)  );
		assertEquals( "la-bemolle-4",  Dict.getNote(20)  );
		assertEquals( "la-4",          Dict.getNote(21)  );
		assertEquals( "si-bemolle-4",  Dict.getNote(22)  );
		assertEquals( "si-4",          Dict.getNote(23)  );
		assertEquals( "do-3",          Dict.getNote(24)  );
		assertEquals( "re-bemolle-3",  Dict.getNote(25)  );
		assertEquals( "re-3",          Dict.getNote(26)  );
		assertEquals( "mi-bemolle-3",  Dict.getNote(27)  );
		assertEquals( "mi-3",          Dict.getNote(28)  );
		assertEquals( "fa-3",          Dict.getNote(29)  );
		assertEquals( "sol-bemolle-3", Dict.getNote(30)  );
		assertEquals( "sol-3",         Dict.getNote(31)  );
		assertEquals( "la-bemolle-3",  Dict.getNote(32)  );
		assertEquals( "la-3",          Dict.getNote(33)  );
		assertEquals( "si-bemolle-3",  Dict.getNote(34)  );
		assertEquals( "si-3",          Dict.getNote(35)  );
		assertEquals( "do-2",          Dict.getNote(36)  );
		assertEquals( "re-bemolle-2",  Dict.getNote(37)  );
		assertEquals( "re-2",          Dict.getNote(38)  );
		assertEquals( "mi-bemolle-2",  Dict.getNote(39)  );
		assertEquals( "mi-2",          Dict.getNote(40)  );
		assertEquals( "fa-2",          Dict.getNote(41)  );
		assertEquals( "sol-bemolle-2", Dict.getNote(42)  );
		assertEquals( "sol-2",         Dict.getNote(43)  );
		assertEquals( "la-bemolle-2",  Dict.getNote(44)  );
		assertEquals( "la-2",          Dict.getNote(45)  );
		assertEquals( "si-bemolle-2",  Dict.getNote(46)  );
		assertEquals( "si-2",          Dict.getNote(47)  );
		assertEquals( "do-",           Dict.getNote(48)  );
		assertEquals( "re-bemolle-",   Dict.getNote(49)  );
		assertEquals( "re-",           Dict.getNote(50)  );
		assertEquals( "mi-bemolle-",   Dict.getNote(51)  );
		assertEquals( "mi-",           Dict.getNote(52)  );
		assertEquals( "fa-",           Dict.getNote(53)  );
		assertEquals( "sol-bemolle-",  Dict.getNote(54)  );
		assertEquals( "sol-",          Dict.getNote(55)  );
		assertEquals( "la-bemolle-",   Dict.getNote(56)  );
		assertEquals( "la-",           Dict.getNote(57)  );
		assertEquals( "si-bemolle-",   Dict.getNote(58)  );
		assertEquals( "si-",           Dict.getNote(59)  );
		assertEquals( "do",            Dict.getNote(60)  );
		assertEquals( "re-bemolle",    Dict.getNote(61)  );
		assertEquals( "re",            Dict.getNote(62)  );
		assertEquals( "mi-bemolle",    Dict.getNote(63)  );
		assertEquals( "mi",            Dict.getNote(64)  );
		assertEquals( "fa",            Dict.getNote(65)  );
		assertEquals( "sol-bemolle",   Dict.getNote(66)  );
		assertEquals( "sol",           Dict.getNote(67)  );
		assertEquals( "la-bemolle",    Dict.getNote(68)  );
		assertEquals( "la",            Dict.getNote(69)  );
		assertEquals( "si-bemolle",    Dict.getNote(70)  );
		assertEquals( "si",            Dict.getNote(71)  );
		assertEquals( "do+",           Dict.getNote(72)  );
		assertEquals( "re-bemolle+",   Dict.getNote(73)  );
		assertEquals( "re+",           Dict.getNote(74)  );
		assertEquals( "mi-bemolle+",   Dict.getNote(75)  );
		assertEquals( "mi+",           Dict.getNote(76)  );
		assertEquals( "fa+",           Dict.getNote(77)  );
		assertEquals( "sol-bemolle+",  Dict.getNote(78)  );
		assertEquals( "sol+",          Dict.getNote(79)  );
		assertEquals( "la-bemolle+",   Dict.getNote(80)  );
		assertEquals( "la+",           Dict.getNote(81)  );
		assertEquals( "si-bemolle+",   Dict.getNote(82)  );
		assertEquals( "si+",           Dict.getNote(83)  );
		assertEquals( "do+2",          Dict.getNote(84)  );
		assertEquals( "re-bemolle+2",  Dict.getNote(85)  );
		assertEquals( "re+2",          Dict.getNote(86)  );
		assertEquals( "mi-bemolle+2",  Dict.getNote(87)  );
		assertEquals( "mi+2",          Dict.getNote(88)  );
		assertEquals( "fa+2",          Dict.getNote(89)  );
		assertEquals( "sol-bemolle+2", Dict.getNote(90)  );
		assertEquals( "sol+2",         Dict.getNote(91)  );
		assertEquals( "la-bemolle+2",  Dict.getNote(92)  );
		assertEquals( "la+2",          Dict.getNote(93)  );
		assertEquals( "si-bemolle+2",  Dict.getNote(94)  );
		assertEquals( "si+2",          Dict.getNote(95)  );
		assertEquals( "do+3",          Dict.getNote(96)  );
		assertEquals( "re-bemolle+3",  Dict.getNote(97)  );
		assertEquals( "re+3",          Dict.getNote(98)  );
		assertEquals( "mi-bemolle+3",  Dict.getNote(99)  );
		assertEquals( "mi+3",          Dict.getNote(100) );
		assertEquals( "fa+3",          Dict.getNote(101) );
		assertEquals( "sol-bemolle+3", Dict.getNote(102) );
		assertEquals( "sol+3",         Dict.getNote(103) );
		assertEquals( "la-bemolle+3",  Dict.getNote(104) );
		assertEquals( "la+3",          Dict.getNote(105) );
		assertEquals( "si-bemolle+3",  Dict.getNote(106) );
		assertEquals( "si+3",          Dict.getNote(107) );
		assertEquals( "do+4",          Dict.getNote(108) );
		assertEquals( "re-bemolle+4",  Dict.getNote(109) );
		assertEquals( "re+4",          Dict.getNote(110) );
		assertEquals( "mi-bemolle+4",  Dict.getNote(111) );
		assertEquals( "mi+4",          Dict.getNote(112) );
		assertEquals( "fa+4",          Dict.getNote(113) );
		assertEquals( "sol-bemolle+4", Dict.getNote(114) );
		assertEquals( "sol+4",         Dict.getNote(115) );
		assertEquals( "la-bemolle+4",  Dict.getNote(116) );
		assertEquals( "la+4",          Dict.getNote(117) );
		assertEquals( "si-bemolle+4",  Dict.getNote(118) );
		assertEquals( "si+4",          Dict.getNote(119) );
		assertEquals( "do+5",          Dict.getNote(120) );
		assertEquals( "re-bemolle+5",  Dict.getNote(121) );
		assertEquals( "re+5",          Dict.getNote(122) );
		assertEquals( "mi-bemolle+5",  Dict.getNote(123) );
		assertEquals( "mi+5",          Dict.getNote(124) );
		assertEquals( "fa+5",          Dict.getNote(125) );
		assertEquals( "sol-bemolle+5", Dict.getNote(126) );
		assertEquals( "sol+5",         Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "do-----",          Dict.getNote(0)   );
		assertEquals( "re-bemolle-----",  Dict.getNote(1)   );
		assertEquals( "re-----",          Dict.getNote(2)   );
		assertEquals( "mi-bemolle-----",  Dict.getNote(3)   );
		assertEquals( "mi-----",          Dict.getNote(4)   );
		assertEquals( "fa-----",          Dict.getNote(5)   );
		assertEquals( "sol-bemolle-----", Dict.getNote(6)   );
		assertEquals( "sol-----",         Dict.getNote(7)   );
		assertEquals( "la-bemolle-----",  Dict.getNote(8)   );
		assertEquals( "la-----",          Dict.getNote(9)   );
		assertEquals( "si-bemolle-----",  Dict.getNote(10)  );
		assertEquals( "si-----",          Dict.getNote(11)  );
		assertEquals( "do----",           Dict.getNote(12)  );
		assertEquals( "re-bemolle----",   Dict.getNote(13)  );
		assertEquals( "re----",           Dict.getNote(14)  );
		assertEquals( "mi-bemolle----",   Dict.getNote(15)  );
		assertEquals( "mi----",           Dict.getNote(16)  );
		assertEquals( "fa----",           Dict.getNote(17)  );
		assertEquals( "sol-bemolle----",  Dict.getNote(18)  );
		assertEquals( "sol----",          Dict.getNote(19)  );
		assertEquals( "la-bemolle----",   Dict.getNote(20)  );
		assertEquals( "la----",           Dict.getNote(21)  );
		assertEquals( "si-bemolle----",   Dict.getNote(22)  );
		assertEquals( "si----",           Dict.getNote(23)  );
		assertEquals( "do---",            Dict.getNote(24)  );
		assertEquals( "re-bemolle---",    Dict.getNote(25)  );
		assertEquals( "re---",            Dict.getNote(26)  );
		assertEquals( "mi-bemolle---",    Dict.getNote(27)  );
		assertEquals( "mi---",            Dict.getNote(28)  );
		assertEquals( "fa---",            Dict.getNote(29)  );
		assertEquals( "sol-bemolle---",   Dict.getNote(30)  );
		assertEquals( "sol---",           Dict.getNote(31)  );
		assertEquals( "la-bemolle---",    Dict.getNote(32)  );
		assertEquals( "la---",            Dict.getNote(33)  );
		assertEquals( "si-bemolle---",    Dict.getNote(34)  );
		assertEquals( "si---",            Dict.getNote(35)  );
		assertEquals( "do--",             Dict.getNote(36)  );
		assertEquals( "re-bemolle--",     Dict.getNote(37)  );
		assertEquals( "re--",             Dict.getNote(38)  );
		assertEquals( "mi-bemolle--",     Dict.getNote(39)  );
		assertEquals( "mi--",             Dict.getNote(40)  );
		assertEquals( "fa--",             Dict.getNote(41)  );
		assertEquals( "sol-bemolle--",    Dict.getNote(42)  );
		assertEquals( "sol--",            Dict.getNote(43)  );
		assertEquals( "la-bemolle--",     Dict.getNote(44)  );
		assertEquals( "la--",             Dict.getNote(45)  );
		assertEquals( "si-bemolle--",     Dict.getNote(46)  );
		assertEquals( "si--",             Dict.getNote(47)  );
		assertEquals( "do-",              Dict.getNote(48)  );
		assertEquals( "re-bemolle-",      Dict.getNote(49)  );
		assertEquals( "re-",              Dict.getNote(50)  );
		assertEquals( "mi-bemolle-",      Dict.getNote(51)  );
		assertEquals( "mi-",              Dict.getNote(52)  );
		assertEquals( "fa-",              Dict.getNote(53)  );
		assertEquals( "sol-bemolle-",     Dict.getNote(54)  );
		assertEquals( "sol-",             Dict.getNote(55)  );
		assertEquals( "la-bemolle-",      Dict.getNote(56)  );
		assertEquals( "la-",              Dict.getNote(57)  );
		assertEquals( "si-bemolle-",      Dict.getNote(58)  );
		assertEquals( "si-",              Dict.getNote(59)  );
		assertEquals( "do",               Dict.getNote(60)  );
		assertEquals( "re-bemolle",       Dict.getNote(61)  );
		assertEquals( "re",               Dict.getNote(62)  );
		assertEquals( "mi-bemolle",       Dict.getNote(63)  );
		assertEquals( "mi",               Dict.getNote(64)  );
		assertEquals( "fa",               Dict.getNote(65)  );
		assertEquals( "sol-bemolle",      Dict.getNote(66)  );
		assertEquals( "sol",              Dict.getNote(67)  );
		assertEquals( "la-bemolle",       Dict.getNote(68)  );
		assertEquals( "la",               Dict.getNote(69)  );
		assertEquals( "si-bemolle",       Dict.getNote(70)  );
		assertEquals( "si",               Dict.getNote(71)  );
		assertEquals( "do+",              Dict.getNote(72)  );
		assertEquals( "re-bemolle+",      Dict.getNote(73)  );
		assertEquals( "re+",              Dict.getNote(74)  );
		assertEquals( "mi-bemolle+",      Dict.getNote(75)  );
		assertEquals( "mi+",              Dict.getNote(76)  );
		assertEquals( "fa+",              Dict.getNote(77)  );
		assertEquals( "sol-bemolle+",     Dict.getNote(78)  );
		assertEquals( "sol+",             Dict.getNote(79)  );
		assertEquals( "la-bemolle+",      Dict.getNote(80)  );
		assertEquals( "la+",              Dict.getNote(81)  );
		assertEquals( "si-bemolle+",      Dict.getNote(82)  );
		assertEquals( "si+",              Dict.getNote(83)  );
		assertEquals( "do++",             Dict.getNote(84)  );
		assertEquals( "re-bemolle++",     Dict.getNote(85)  );
		assertEquals( "re++",             Dict.getNote(86)  );
		assertEquals( "mi-bemolle++",     Dict.getNote(87)  );
		assertEquals( "mi++",             Dict.getNote(88)  );
		assertEquals( "fa++",             Dict.getNote(89)  );
		assertEquals( "sol-bemolle++",    Dict.getNote(90)  );
		assertEquals( "sol++",            Dict.getNote(91)  );
		assertEquals( "la-bemolle++",     Dict.getNote(92)  );
		assertEquals( "la++",             Dict.getNote(93)  );
		assertEquals( "si-bemolle++",     Dict.getNote(94)  );
		assertEquals( "si++",             Dict.getNote(95)  );
		assertEquals( "do+++",            Dict.getNote(96)  );
		assertEquals( "re-bemolle+++",    Dict.getNote(97)  );
		assertEquals( "re+++",            Dict.getNote(98)  );
		assertEquals( "mi-bemolle+++",    Dict.getNote(99)  );
		assertEquals( "mi+++",            Dict.getNote(100) );
		assertEquals( "fa+++",            Dict.getNote(101) );
		assertEquals( "sol-bemolle+++",   Dict.getNote(102) );
		assertEquals( "sol+++",           Dict.getNote(103) );
		assertEquals( "la-bemolle+++",    Dict.getNote(104) );
		assertEquals( "la+++",            Dict.getNote(105) );
		assertEquals( "si-bemolle+++",    Dict.getNote(106) );
		assertEquals( "si+++",            Dict.getNote(107) );
		assertEquals( "do++++",           Dict.getNote(108) );
		assertEquals( "re-bemolle++++",   Dict.getNote(109) );
		assertEquals( "re++++",           Dict.getNote(110) );
		assertEquals( "mi-bemolle++++",   Dict.getNote(111) );
		assertEquals( "mi++++",           Dict.getNote(112) );
		assertEquals( "fa++++",           Dict.getNote(113) );
		assertEquals( "sol-bemolle++++",  Dict.getNote(114) );
		assertEquals( "sol++++",          Dict.getNote(115) );
		assertEquals( "la-bemolle++++",   Dict.getNote(116) );
		assertEquals( "la++++",           Dict.getNote(117) );
		assertEquals( "si-bemolle++++",   Dict.getNote(118) );
		assertEquals( "si++++",           Dict.getNote(119) );
		assertEquals( "do+++++",          Dict.getNote(120) );
		assertEquals( "re-bemolle+++++",  Dict.getNote(121) );
		assertEquals( "re+++++",          Dict.getNote(122) );
		assertEquals( "mi-bemolle+++++",  Dict.getNote(123) );
		assertEquals( "mi+++++",          Dict.getNote(124) );
		assertEquals( "fa+++++",          Dict.getNote(125) );
		assertEquals( "sol-bemolle+++++", Dict.getNote(126) );
		assertEquals( "sol+++++",         Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "do-1",          Dict.getNote(0)   );
		assertEquals( "re-bemolle-1",  Dict.getNote(1)   );
		assertEquals( "re-1",          Dict.getNote(2)   );
		assertEquals( "mi-bemolle-1",  Dict.getNote(3)   );
		assertEquals( "mi-1",          Dict.getNote(4)   );
		assertEquals( "fa-1",          Dict.getNote(5)   );
		assertEquals( "sol-bemolle-1", Dict.getNote(6)   );
		assertEquals( "sol-1",         Dict.getNote(7)   );
		assertEquals( "la-bemolle-1",  Dict.getNote(8)   );
		assertEquals( "la-1",          Dict.getNote(9)   );
		assertEquals( "si-bemolle-1",  Dict.getNote(10)  );
		assertEquals( "si-1",          Dict.getNote(11)  );
		assertEquals( "do0",           Dict.getNote(12)  );
		assertEquals( "re-bemolle0",   Dict.getNote(13)  );
		assertEquals( "re0",           Dict.getNote(14)  );
		assertEquals( "mi-bemolle0",   Dict.getNote(15)  );
		assertEquals( "mi0",           Dict.getNote(16)  );
		assertEquals( "fa0",           Dict.getNote(17)  );
		assertEquals( "sol-bemolle0",  Dict.getNote(18)  );
		assertEquals( "sol0",          Dict.getNote(19)  );
		assertEquals( "la-bemolle0",   Dict.getNote(20)  );
		assertEquals( "la0",           Dict.getNote(21)  );
		assertEquals( "si-bemolle0",   Dict.getNote(22)  );
		assertEquals( "si0",           Dict.getNote(23)  );
		assertEquals( "do1",           Dict.getNote(24)  );
		assertEquals( "re-bemolle1",   Dict.getNote(25)  );
		assertEquals( "re1",           Dict.getNote(26)  );
		assertEquals( "mi-bemolle1",   Dict.getNote(27)  );
		assertEquals( "mi1",           Dict.getNote(28)  );
		assertEquals( "fa1",           Dict.getNote(29)  );
		assertEquals( "sol-bemolle1",  Dict.getNote(30)  );
		assertEquals( "sol1",          Dict.getNote(31)  );
		assertEquals( "la-bemolle1",   Dict.getNote(32)  );
		assertEquals( "la1",           Dict.getNote(33)  );
		assertEquals( "si-bemolle1",   Dict.getNote(34)  );
		assertEquals( "si1",           Dict.getNote(35)  );
		assertEquals( "do2",           Dict.getNote(36)  );
		assertEquals( "re-bemolle2",   Dict.getNote(37)  );
		assertEquals( "re2",           Dict.getNote(38)  );
		assertEquals( "mi-bemolle2",   Dict.getNote(39)  );
		assertEquals( "mi2",           Dict.getNote(40)  );
		assertEquals( "fa2",           Dict.getNote(41)  );
		assertEquals( "sol-bemolle2",  Dict.getNote(42)  );
		assertEquals( "sol2",          Dict.getNote(43)  );
		assertEquals( "la-bemolle2",   Dict.getNote(44)  );
		assertEquals( "la2",           Dict.getNote(45)  );
		assertEquals( "si-bemolle2",   Dict.getNote(46)  );
		assertEquals( "si2",           Dict.getNote(47)  );
		assertEquals( "do3",           Dict.getNote(48)  );
		assertEquals( "re-bemolle3",   Dict.getNote(49)  );
		assertEquals( "re3",           Dict.getNote(50)  );
		assertEquals( "mi-bemolle3",   Dict.getNote(51)  );
		assertEquals( "mi3",           Dict.getNote(52)  );
		assertEquals( "fa3",           Dict.getNote(53)  );
		assertEquals( "sol-bemolle3",  Dict.getNote(54)  );
		assertEquals( "sol3",          Dict.getNote(55)  );
		assertEquals( "la-bemolle3",   Dict.getNote(56)  );
		assertEquals( "la3",           Dict.getNote(57)  );
		assertEquals( "si-bemolle3",   Dict.getNote(58)  );
		assertEquals( "si3",           Dict.getNote(59)  );
		assertEquals( "do4",           Dict.getNote(60)  );
		assertEquals( "re-bemolle4",   Dict.getNote(61)  );
		assertEquals( "re4",           Dict.getNote(62)  );
		assertEquals( "mi-bemolle4",   Dict.getNote(63)  );
		assertEquals( "mi4",           Dict.getNote(64)  );
		assertEquals( "fa4",           Dict.getNote(65)  );
		assertEquals( "sol-bemolle4",  Dict.getNote(66)  );
		assertEquals( "sol4",          Dict.getNote(67)  );
		assertEquals( "la-bemolle4",   Dict.getNote(68)  );
		assertEquals( "la4",           Dict.getNote(69)  );
		assertEquals( "si-bemolle4",   Dict.getNote(70)  );
		assertEquals( "si4",           Dict.getNote(71)  );
		assertEquals( "do5",           Dict.getNote(72)  );
		assertEquals( "re-bemolle5",   Dict.getNote(73)  );
		assertEquals( "re5",           Dict.getNote(74)  );
		assertEquals( "mi-bemolle5",   Dict.getNote(75)  );
		assertEquals( "mi5",           Dict.getNote(76)  );
		assertEquals( "fa5",           Dict.getNote(77)  );
		assertEquals( "sol-bemolle5",  Dict.getNote(78)  );
		assertEquals( "sol5",          Dict.getNote(79)  );
		assertEquals( "la-bemolle5",   Dict.getNote(80)  );
		assertEquals( "la5",           Dict.getNote(81)  );
		assertEquals( "si-bemolle5",   Dict.getNote(82)  );
		assertEquals( "si5",           Dict.getNote(83)  );
		assertEquals( "do6",           Dict.getNote(84)  );
		assertEquals( "re-bemolle6",   Dict.getNote(85)  );
		assertEquals( "re6",           Dict.getNote(86)  );
		assertEquals( "mi-bemolle6",   Dict.getNote(87)  );
		assertEquals( "mi6",           Dict.getNote(88)  );
		assertEquals( "fa6",           Dict.getNote(89)  );
		assertEquals( "sol-bemolle6",  Dict.getNote(90)  );
		assertEquals( "sol6",          Dict.getNote(91)  );
		assertEquals( "la-bemolle6",   Dict.getNote(92)  );
		assertEquals( "la6",           Dict.getNote(93)  );
		assertEquals( "si-bemolle6",   Dict.getNote(94)  );
		assertEquals( "si6",           Dict.getNote(95)  );
		assertEquals( "do7",           Dict.getNote(96)  );
		assertEquals( "re-bemolle7",   Dict.getNote(97)  );
		assertEquals( "re7",           Dict.getNote(98)  );
		assertEquals( "mi-bemolle7",   Dict.getNote(99)  );
		assertEquals( "mi7",           Dict.getNote(100) );
		assertEquals( "fa7",           Dict.getNote(101) );
		assertEquals( "sol-bemolle7",  Dict.getNote(102) );
		assertEquals( "sol7",          Dict.getNote(103) );
		assertEquals( "la-bemolle7",   Dict.getNote(104) );
		assertEquals( "la7",           Dict.getNote(105) );
		assertEquals( "si-bemolle7",   Dict.getNote(106) );
		assertEquals( "si7",           Dict.getNote(107) );
		assertEquals( "do8",           Dict.getNote(108) );
		assertEquals( "re-bemolle8",   Dict.getNote(109) );
		assertEquals( "re8",           Dict.getNote(110) );
		assertEquals( "mi-bemolle8",   Dict.getNote(111) );
		assertEquals( "mi8",           Dict.getNote(112) );
		assertEquals( "fa8",           Dict.getNote(113) );
		assertEquals( "sol-bemolle8",  Dict.getNote(114) );
		assertEquals( "sol8",          Dict.getNote(115) );
		assertEquals( "la-bemolle8",   Dict.getNote(116) );
		assertEquals( "la8",           Dict.getNote(117) );
		assertEquals( "si-bemolle8",   Dict.getNote(118) );
		assertEquals( "si8",           Dict.getNote(119) );
		assertEquals( "do9",           Dict.getNote(120) );
		assertEquals( "re-bemolle9",   Dict.getNote(121) );
		assertEquals( "re9",           Dict.getNote(122) );
		assertEquals( "mi-bemolle9",   Dict.getNote(123) );
		assertEquals( "mi9",           Dict.getNote(124) );
		assertEquals( "fa9",           Dict.getNote(125) );
		assertEquals( "sol-bemolle9",  Dict.getNote(126) );
		assertEquals( "sol9",          Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "Do'''",             Dict.getNote(0)   );
		assertEquals( "Re-bemolle'''",     Dict.getNote(1)   );
		assertEquals( "Re'''",             Dict.getNote(2)   );
		assertEquals( "Mi-bemolle'''",     Dict.getNote(3)   );
		assertEquals( "Mi'''",             Dict.getNote(4)   );
		assertEquals( "Fa'''",             Dict.getNote(5)   );
		assertEquals( "Sol-bemolle'''",    Dict.getNote(6)   );
		assertEquals( "Sol'''",            Dict.getNote(7)   );
		assertEquals( "La-bemolle'''",     Dict.getNote(8)   );
		assertEquals( "La'''",             Dict.getNote(9)   );
		assertEquals( "Si-bemolle'''",     Dict.getNote(10)  );
		assertEquals( "Si'''",             Dict.getNote(11)  );
		assertEquals( "Do''",              Dict.getNote(12)  );
		assertEquals( "Re-bemolle''",      Dict.getNote(13)  );
		assertEquals( "Re''",              Dict.getNote(14)  );
		assertEquals( "Mi-bemolle''",      Dict.getNote(15)  );
		assertEquals( "Mi''",              Dict.getNote(16)  );
		assertEquals( "Fa''",              Dict.getNote(17)  );
		assertEquals( "Sol-bemolle''",     Dict.getNote(18)  );
		assertEquals( "Sol''",             Dict.getNote(19)  );
		assertEquals( "La-bemolle''",      Dict.getNote(20)  );
		assertEquals( "La''",              Dict.getNote(21)  );
		assertEquals( "Si-bemolle''",      Dict.getNote(22)  );
		assertEquals( "Si''",              Dict.getNote(23)  );
		assertEquals( "Do'",               Dict.getNote(24)  );
		assertEquals( "Re-bemolle'",       Dict.getNote(25)  );
		assertEquals( "Re'",               Dict.getNote(26)  );
		assertEquals( "Mi-bemolle'",       Dict.getNote(27)  );
		assertEquals( "Mi'",               Dict.getNote(28)  );
		assertEquals( "Fa'",               Dict.getNote(29)  );
		assertEquals( "Sol-bemolle'",      Dict.getNote(30)  );
		assertEquals( "Sol'",              Dict.getNote(31)  );
		assertEquals( "La-bemolle'",       Dict.getNote(32)  );
		assertEquals( "La'",               Dict.getNote(33)  );
		assertEquals( "Si-bemolle'",       Dict.getNote(34)  );
		assertEquals( "Si'",               Dict.getNote(35)  );
		assertEquals( "Do",                Dict.getNote(36)  );
		assertEquals( "Re-bemolle",        Dict.getNote(37)  );
		assertEquals( "Re",                Dict.getNote(38)  );
		assertEquals( "Mi-bemolle",        Dict.getNote(39)  );
		assertEquals( "Mi",                Dict.getNote(40)  );
		assertEquals( "Fa",                Dict.getNote(41)  );
		assertEquals( "Sol-bemolle",       Dict.getNote(42)  );
		assertEquals( "Sol",               Dict.getNote(43)  );
		assertEquals( "La-bemolle",        Dict.getNote(44)  );
		assertEquals( "La",                Dict.getNote(45)  );
		assertEquals( "Si-bemolle",        Dict.getNote(46)  );
		assertEquals( "Si",                Dict.getNote(47)  );
		assertEquals( "do",                Dict.getNote(48)  );
		assertEquals( "re-bemolle",        Dict.getNote(49)  );
		assertEquals( "re",                Dict.getNote(50)  );
		assertEquals( "mi-bemolle",        Dict.getNote(51)  );
		assertEquals( "mi",                Dict.getNote(52)  );
		assertEquals( "fa",                Dict.getNote(53)  );
		assertEquals( "sol-bemolle",       Dict.getNote(54)  );
		assertEquals( "sol",               Dict.getNote(55)  );
		assertEquals( "la-bemolle",        Dict.getNote(56)  );
		assertEquals( "la",                Dict.getNote(57)  );
		assertEquals( "si-bemolle",        Dict.getNote(58)  );
		assertEquals( "si",                Dict.getNote(59)  );
		assertEquals( "do'",               Dict.getNote(60)  );
		assertEquals( "re-bemolle'",       Dict.getNote(61)  );
		assertEquals( "re'",               Dict.getNote(62)  );
		assertEquals( "mi-bemolle'",       Dict.getNote(63)  );
		assertEquals( "mi'",               Dict.getNote(64)  );
		assertEquals( "fa'",               Dict.getNote(65)  );
		assertEquals( "sol-bemolle'",      Dict.getNote(66)  );
		assertEquals( "sol'",              Dict.getNote(67)  );
		assertEquals( "la-bemolle'",       Dict.getNote(68)  );
		assertEquals( "la'",               Dict.getNote(69)  );
		assertEquals( "si-bemolle'",       Dict.getNote(70)  );
		assertEquals( "si'",               Dict.getNote(71)  );
		assertEquals( "do''",              Dict.getNote(72)  );
		assertEquals( "re-bemolle''",      Dict.getNote(73)  );
		assertEquals( "re''",              Dict.getNote(74)  );
		assertEquals( "mi-bemolle''",      Dict.getNote(75)  );
		assertEquals( "mi''",              Dict.getNote(76)  );
		assertEquals( "fa''",              Dict.getNote(77)  );
		assertEquals( "sol-bemolle''",     Dict.getNote(78)  );
		assertEquals( "sol''",             Dict.getNote(79)  );
		assertEquals( "la-bemolle''",      Dict.getNote(80)  );
		assertEquals( "la''",              Dict.getNote(81)  );
		assertEquals( "si-bemolle''",      Dict.getNote(82)  );
		assertEquals( "si''",              Dict.getNote(83)  );
		assertEquals( "do'''",             Dict.getNote(84)  );
		assertEquals( "re-bemolle'''",     Dict.getNote(85)  );
		assertEquals( "re'''",             Dict.getNote(86)  );
		assertEquals( "mi-bemolle'''",     Dict.getNote(87)  );
		assertEquals( "mi'''",             Dict.getNote(88)  );
		assertEquals( "fa'''",             Dict.getNote(89)  );
		assertEquals( "sol-bemolle'''",    Dict.getNote(90)  );
		assertEquals( "sol'''",            Dict.getNote(91)  );
		assertEquals( "la-bemolle'''",     Dict.getNote(92)  );
		assertEquals( "la'''",             Dict.getNote(93)  );
		assertEquals( "si-bemolle'''",     Dict.getNote(94)  );
		assertEquals( "si'''",             Dict.getNote(95)  );
		assertEquals( "do''''",            Dict.getNote(96)  );
		assertEquals( "re-bemolle''''",    Dict.getNote(97)  );
		assertEquals( "re''''",            Dict.getNote(98)  );
		assertEquals( "mi-bemolle''''",    Dict.getNote(99)  );
		assertEquals( "mi''''",            Dict.getNote(100) );
		assertEquals( "fa''''",            Dict.getNote(101) );
		assertEquals( "sol-bemolle''''",   Dict.getNote(102) );
		assertEquals( "sol''''",           Dict.getNote(103) );
		assertEquals( "la-bemolle''''",    Dict.getNote(104) );
		assertEquals( "la''''",            Dict.getNote(105) );
		assertEquals( "si-bemolle''''",    Dict.getNote(106) );
		assertEquals( "si''''",            Dict.getNote(107) );
		assertEquals( "do'''''",           Dict.getNote(108) );
		assertEquals( "re-bemolle'''''",   Dict.getNote(109) );
		assertEquals( "re'''''",           Dict.getNote(110) );
		assertEquals( "mi-bemolle'''''",   Dict.getNote(111) );
		assertEquals( "mi'''''",           Dict.getNote(112) );
		assertEquals( "fa'''''",           Dict.getNote(113) );
		assertEquals( "sol-bemolle'''''",  Dict.getNote(114) );
		assertEquals( "sol'''''",          Dict.getNote(115) );
		assertEquals( "la-bemolle'''''",   Dict.getNote(116) );
		assertEquals( "la'''''",           Dict.getNote(117) );
		assertEquals( "si-bemolle'''''",   Dict.getNote(118) );
		assertEquals( "si'''''",           Dict.getNote(119) );
		assertEquals( "do''''''",          Dict.getNote(120) );
		assertEquals( "re-bemolle''''''",  Dict.getNote(121) );
		assertEquals( "re''''''",          Dict.getNote(122) );
		assertEquals( "mi-bemolle''''''",  Dict.getNote(123) );
		assertEquals( "mi''''''",          Dict.getNote(124) );
		assertEquals( "fa''''''",          Dict.getNote(125) );
		assertEquals( "sol-bemolle''''''", Dict.getNote(126) );
		assertEquals( "sol''''''",         Dict.getNote(127) );
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[2].setSelectedIndex(0);
		cbxs[3].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: german (lower-case)
	 * - half tone: -is
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsGerLcCis() {
		
		// switch config
		cbxs[1].setSelectedIndex(4); // german (lower-case)
		cbxs[2].setSelectedIndex(2); // -is/-es
		
		// test default (+n/-n)
		assertEquals( "c-5",   Dict.getNote(0)   );
		assertEquals( "cis-5", Dict.getNote(1)   );
		assertEquals( "d-5",   Dict.getNote(2)   );
		assertEquals( "dis-5", Dict.getNote(3)   );
		assertEquals( "e-5",   Dict.getNote(4)   );
		assertEquals( "f-5",   Dict.getNote(5)   );
		assertEquals( "fis-5", Dict.getNote(6)   );
		assertEquals( "g-5",   Dict.getNote(7)   );
		assertEquals( "gis-5", Dict.getNote(8)   );
		assertEquals( "a-5",   Dict.getNote(9)   );
		assertEquals( "b-5",   Dict.getNote(10)  );
		assertEquals( "h-5",   Dict.getNote(11)  );
		assertEquals( "c-4",   Dict.getNote(12)  );
		assertEquals( "cis-4", Dict.getNote(13)  );
		assertEquals( "d-4",   Dict.getNote(14)  );
		assertEquals( "dis-4", Dict.getNote(15)  );
		assertEquals( "e-4",   Dict.getNote(16)  );
		assertEquals( "f-4",   Dict.getNote(17)  );
		assertEquals( "fis-4", Dict.getNote(18)  );
		assertEquals( "g-4",   Dict.getNote(19)  );
		assertEquals( "gis-4", Dict.getNote(20)  );
		assertEquals( "a-4",   Dict.getNote(21)  );
		assertEquals( "b-4",   Dict.getNote(22)  );
		assertEquals( "h-4",   Dict.getNote(23)  );
		assertEquals( "c-3",   Dict.getNote(24)  );
		assertEquals( "cis-3", Dict.getNote(25)  );
		assertEquals( "d-3",   Dict.getNote(26)  );
		assertEquals( "dis-3", Dict.getNote(27)  );
		assertEquals( "e-3",   Dict.getNote(28)  );
		assertEquals( "f-3",   Dict.getNote(29)  );
		assertEquals( "fis-3", Dict.getNote(30)  );
		assertEquals( "g-3",   Dict.getNote(31)  );
		assertEquals( "gis-3", Dict.getNote(32)  );
		assertEquals( "a-3",   Dict.getNote(33)  );
		assertEquals( "b-3",   Dict.getNote(34)  );
		assertEquals( "h-3",   Dict.getNote(35)  );
		assertEquals( "c-2",   Dict.getNote(36)  );
		assertEquals( "cis-2", Dict.getNote(37)  );
		assertEquals( "d-2",   Dict.getNote(38)  );
		assertEquals( "dis-2", Dict.getNote(39)  );
		assertEquals( "e-2",   Dict.getNote(40)  );
		assertEquals( "f-2",   Dict.getNote(41)  );
		assertEquals( "fis-2", Dict.getNote(42)  );
		assertEquals( "g-2",   Dict.getNote(43)  );
		assertEquals( "gis-2", Dict.getNote(44)  );
		assertEquals( "a-2",   Dict.getNote(45)  );
		assertEquals( "b-2",   Dict.getNote(46)  );
		assertEquals( "h-2",   Dict.getNote(47)  );
		assertEquals( "c-",    Dict.getNote(48)  );
		assertEquals( "cis-",  Dict.getNote(49)  );
		assertEquals( "d-",    Dict.getNote(50)  );
		assertEquals( "dis-",  Dict.getNote(51)  );
		assertEquals( "e-",    Dict.getNote(52)  );
		assertEquals( "f-",    Dict.getNote(53)  );
		assertEquals( "fis-",  Dict.getNote(54)  );
		assertEquals( "g-",    Dict.getNote(55)  );
		assertEquals( "gis-",  Dict.getNote(56)  );
		assertEquals( "a-",    Dict.getNote(57)  );
		assertEquals( "b-",    Dict.getNote(58)  );
		assertEquals( "h-",    Dict.getNote(59)  );
		assertEquals( "c",     Dict.getNote(60)  );
		assertEquals( "cis",   Dict.getNote(61)  );
		assertEquals( "d",     Dict.getNote(62)  );
		assertEquals( "dis",   Dict.getNote(63)  );
		assertEquals( "e",     Dict.getNote(64)  );
		assertEquals( "f",     Dict.getNote(65)  );
		assertEquals( "fis",   Dict.getNote(66)  );
		assertEquals( "g",     Dict.getNote(67)  );
		assertEquals( "gis",   Dict.getNote(68)  );
		assertEquals( "a",     Dict.getNote(69)  );
		assertEquals( "b",     Dict.getNote(70)  );
		assertEquals( "h",     Dict.getNote(71)  );
		assertEquals( "c+",    Dict.getNote(72)  );
		assertEquals( "cis+",  Dict.getNote(73)  );
		assertEquals( "d+",    Dict.getNote(74)  );
		assertEquals( "dis+",  Dict.getNote(75)  );
		assertEquals( "e+",    Dict.getNote(76)  );
		assertEquals( "f+",    Dict.getNote(77)  );
		assertEquals( "fis+",  Dict.getNote(78)  );
		assertEquals( "g+",    Dict.getNote(79)  );
		assertEquals( "gis+",  Dict.getNote(80)  );
		assertEquals( "a+",    Dict.getNote(81)  );
		assertEquals( "b+",    Dict.getNote(82)  );
		assertEquals( "h+",    Dict.getNote(83)  );
		assertEquals( "c+2",   Dict.getNote(84)  );
		assertEquals( "cis+2", Dict.getNote(85)  );
		assertEquals( "d+2",   Dict.getNote(86)  );
		assertEquals( "dis+2", Dict.getNote(87)  );
		assertEquals( "e+2",   Dict.getNote(88)  );
		assertEquals( "f+2",   Dict.getNote(89)  );
		assertEquals( "fis+2", Dict.getNote(90)  );
		assertEquals( "g+2",   Dict.getNote(91)  );
		assertEquals( "gis+2", Dict.getNote(92)  );
		assertEquals( "a+2",   Dict.getNote(93)  );
		assertEquals( "b+2",   Dict.getNote(94)  );
		assertEquals( "h+2",   Dict.getNote(95)  );
		assertEquals( "c+3",   Dict.getNote(96)  );
		assertEquals( "cis+3", Dict.getNote(97)  );
		assertEquals( "d+3",   Dict.getNote(98)  );
		assertEquals( "dis+3", Dict.getNote(99)  );
		assertEquals( "e+3",   Dict.getNote(100) );
		assertEquals( "f+3",   Dict.getNote(101) );
		assertEquals( "fis+3", Dict.getNote(102) );
		assertEquals( "g+3",   Dict.getNote(103) );
		assertEquals( "gis+3", Dict.getNote(104) );
		assertEquals( "a+3",   Dict.getNote(105) );
		assertEquals( "b+3",   Dict.getNote(106) );
		assertEquals( "h+3",   Dict.getNote(107) );
		assertEquals( "c+4",   Dict.getNote(108) );
		assertEquals( "cis+4", Dict.getNote(109) );
		assertEquals( "d+4",   Dict.getNote(110) );
		assertEquals( "dis+4", Dict.getNote(111) );
		assertEquals( "e+4",   Dict.getNote(112) );
		assertEquals( "f+4",   Dict.getNote(113) );
		assertEquals( "fis+4", Dict.getNote(114) );
		assertEquals( "g+4",   Dict.getNote(115) );
		assertEquals( "gis+4", Dict.getNote(116) );
		assertEquals( "a+4",   Dict.getNote(117) );
		assertEquals( "b+4",   Dict.getNote(118) );
		assertEquals( "h+4",   Dict.getNote(119) );
		assertEquals( "c+5",   Dict.getNote(120) );
		assertEquals( "cis+5", Dict.getNote(121) );
		assertEquals( "d+5",   Dict.getNote(122) );
		assertEquals( "dis+5", Dict.getNote(123) );
		assertEquals( "e+5",   Dict.getNote(124) );
		assertEquals( "f+5",   Dict.getNote(125) );
		assertEquals( "fis+5", Dict.getNote(126) );
		assertEquals( "g+5",   Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "c-----",   Dict.getNote(0)   );
		assertEquals( "cis-----", Dict.getNote(1)   );
		assertEquals( "d-----",   Dict.getNote(2)   );
		assertEquals( "dis-----", Dict.getNote(3)   );
		assertEquals( "e-----",   Dict.getNote(4)   );
		assertEquals( "f-----",   Dict.getNote(5)   );
		assertEquals( "fis-----", Dict.getNote(6)   );
		assertEquals( "g-----",   Dict.getNote(7)   );
		assertEquals( "gis-----", Dict.getNote(8)   );
		assertEquals( "a-----",   Dict.getNote(9)   );
		assertEquals( "b-----",   Dict.getNote(10)  );
		assertEquals( "h-----",   Dict.getNote(11)  );
		assertEquals( "c----",    Dict.getNote(12)  );
		assertEquals( "cis----",  Dict.getNote(13)  );
		assertEquals( "d----",    Dict.getNote(14)  );
		assertEquals( "dis----",  Dict.getNote(15)  );
		assertEquals( "e----",    Dict.getNote(16)  );
		assertEquals( "f----",    Dict.getNote(17)  );
		assertEquals( "fis----",  Dict.getNote(18)  );
		assertEquals( "g----",    Dict.getNote(19)  );
		assertEquals( "gis----",  Dict.getNote(20)  );
		assertEquals( "a----",    Dict.getNote(21)  );
		assertEquals( "b----",    Dict.getNote(22)  );
		assertEquals( "h----",    Dict.getNote(23)  );
		assertEquals( "c---",     Dict.getNote(24)  );
		assertEquals( "cis---",   Dict.getNote(25)  );
		assertEquals( "d---",     Dict.getNote(26)  );
		assertEquals( "dis---",   Dict.getNote(27)  );
		assertEquals( "e---",     Dict.getNote(28)  );
		assertEquals( "f---",     Dict.getNote(29)  );
		assertEquals( "fis---",   Dict.getNote(30)  );
		assertEquals( "g---",     Dict.getNote(31)  );
		assertEquals( "gis---",   Dict.getNote(32)  );
		assertEquals( "a---",     Dict.getNote(33)  );
		assertEquals( "b---",     Dict.getNote(34)  );
		assertEquals( "h---",     Dict.getNote(35)  );
		assertEquals( "c--",      Dict.getNote(36)  );
		assertEquals( "cis--",    Dict.getNote(37)  );
		assertEquals( "d--",      Dict.getNote(38)  );
		assertEquals( "dis--",    Dict.getNote(39)  );
		assertEquals( "e--",      Dict.getNote(40)  );
		assertEquals( "f--",      Dict.getNote(41)  );
		assertEquals( "fis--",    Dict.getNote(42)  );
		assertEquals( "g--",      Dict.getNote(43)  );
		assertEquals( "gis--",    Dict.getNote(44)  );
		assertEquals( "a--",      Dict.getNote(45)  );
		assertEquals( "b--",      Dict.getNote(46)  );
		assertEquals( "h--",      Dict.getNote(47)  );
		assertEquals( "c-",       Dict.getNote(48)  );
		assertEquals( "cis-",     Dict.getNote(49)  );
		assertEquals( "d-",       Dict.getNote(50)  );
		assertEquals( "dis-",     Dict.getNote(51)  );
		assertEquals( "e-",       Dict.getNote(52)  );
		assertEquals( "f-",       Dict.getNote(53)  );
		assertEquals( "fis-",     Dict.getNote(54)  );
		assertEquals( "g-",       Dict.getNote(55)  );
		assertEquals( "gis-",     Dict.getNote(56)  );
		assertEquals( "a-",       Dict.getNote(57)  );
		assertEquals( "b-",       Dict.getNote(58)  );
		assertEquals( "h-",       Dict.getNote(59)  );
		assertEquals( "c",        Dict.getNote(60)  );
		assertEquals( "cis",      Dict.getNote(61)  );
		assertEquals( "d",        Dict.getNote(62)  );
		assertEquals( "dis",      Dict.getNote(63)  );
		assertEquals( "e",        Dict.getNote(64)  );
		assertEquals( "f",        Dict.getNote(65)  );
		assertEquals( "fis",      Dict.getNote(66)  );
		assertEquals( "g",        Dict.getNote(67)  );
		assertEquals( "gis",      Dict.getNote(68)  );
		assertEquals( "a",        Dict.getNote(69)  );
		assertEquals( "b",        Dict.getNote(70)  );
		assertEquals( "h",        Dict.getNote(71)  );
		assertEquals( "c+",       Dict.getNote(72)  );
		assertEquals( "cis+",     Dict.getNote(73)  );
		assertEquals( "d+",       Dict.getNote(74)  );
		assertEquals( "dis+",     Dict.getNote(75)  );
		assertEquals( "e+",       Dict.getNote(76)  );
		assertEquals( "f+",       Dict.getNote(77)  );
		assertEquals( "fis+",     Dict.getNote(78)  );
		assertEquals( "g+",       Dict.getNote(79)  );
		assertEquals( "gis+",     Dict.getNote(80)  );
		assertEquals( "a+",       Dict.getNote(81)  );
		assertEquals( "b+",       Dict.getNote(82)  );
		assertEquals( "h+",       Dict.getNote(83)  );
		assertEquals( "c++",      Dict.getNote(84)  );
		assertEquals( "cis++",    Dict.getNote(85)  );
		assertEquals( "d++",      Dict.getNote(86)  );
		assertEquals( "dis++",    Dict.getNote(87)  );
		assertEquals( "e++",      Dict.getNote(88)  );
		assertEquals( "f++",      Dict.getNote(89)  );
		assertEquals( "fis++",    Dict.getNote(90)  );
		assertEquals( "g++",      Dict.getNote(91)  );
		assertEquals( "gis++",    Dict.getNote(92)  );
		assertEquals( "a++",      Dict.getNote(93)  );
		assertEquals( "b++",      Dict.getNote(94)  );
		assertEquals( "h++",      Dict.getNote(95)  );
		assertEquals( "c+++",     Dict.getNote(96)  );
		assertEquals( "cis+++",   Dict.getNote(97)  );
		assertEquals( "d+++",     Dict.getNote(98)  );
		assertEquals( "dis+++",   Dict.getNote(99)  );
		assertEquals( "e+++",     Dict.getNote(100) );
		assertEquals( "f+++",     Dict.getNote(101) );
		assertEquals( "fis+++",   Dict.getNote(102) );
		assertEquals( "g+++",     Dict.getNote(103) );
		assertEquals( "gis+++",   Dict.getNote(104) );
		assertEquals( "a+++",     Dict.getNote(105) );
		assertEquals( "b+++",     Dict.getNote(106) );
		assertEquals( "h+++",     Dict.getNote(107) );
		assertEquals( "c++++",    Dict.getNote(108) );
		assertEquals( "cis++++",  Dict.getNote(109) );
		assertEquals( "d++++",    Dict.getNote(110) );
		assertEquals( "dis++++",  Dict.getNote(111) );
		assertEquals( "e++++",    Dict.getNote(112) );
		assertEquals( "f++++",    Dict.getNote(113) );
		assertEquals( "fis++++",  Dict.getNote(114) );
		assertEquals( "g++++",    Dict.getNote(115) );
		assertEquals( "gis++++",  Dict.getNote(116) );
		assertEquals( "a++++",    Dict.getNote(117) );
		assertEquals( "b++++",    Dict.getNote(118) );
		assertEquals( "h++++",    Dict.getNote(119) );
		assertEquals( "c+++++",   Dict.getNote(120) );
		assertEquals( "cis+++++", Dict.getNote(121) );
		assertEquals( "d+++++",   Dict.getNote(122) );
		assertEquals( "dis+++++", Dict.getNote(123) );
		assertEquals( "e+++++",   Dict.getNote(124) );
		assertEquals( "f+++++",   Dict.getNote(125) );
		assertEquals( "fis+++++", Dict.getNote(126) );
		assertEquals( "g+++++",   Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "c-1",   Dict.getNote(0)   );
		assertEquals( "cis-1", Dict.getNote(1)   );
		assertEquals( "d-1",   Dict.getNote(2)   );
		assertEquals( "dis-1", Dict.getNote(3)   );
		assertEquals( "e-1",   Dict.getNote(4)   );
		assertEquals( "f-1",   Dict.getNote(5)   );
		assertEquals( "fis-1", Dict.getNote(6)   );
		assertEquals( "g-1",   Dict.getNote(7)   );
		assertEquals( "gis-1", Dict.getNote(8)   );
		assertEquals( "a-1",   Dict.getNote(9)   );
		assertEquals( "b-1",   Dict.getNote(10)  );
		assertEquals( "h-1",   Dict.getNote(11)  );
		assertEquals( "c0",    Dict.getNote(12)  );
		assertEquals( "cis0",  Dict.getNote(13)  );
		assertEquals( "d0",    Dict.getNote(14)  );
		assertEquals( "dis0",  Dict.getNote(15)  );
		assertEquals( "e0",    Dict.getNote(16)  );
		assertEquals( "f0",    Dict.getNote(17)  );
		assertEquals( "fis0",  Dict.getNote(18)  );
		assertEquals( "g0",    Dict.getNote(19)  );
		assertEquals( "gis0",  Dict.getNote(20)  );
		assertEquals( "a0",    Dict.getNote(21)  );
		assertEquals( "b0",    Dict.getNote(22)  );
		assertEquals( "h0",    Dict.getNote(23)  );
		assertEquals( "c1",    Dict.getNote(24)  );
		assertEquals( "cis1",  Dict.getNote(25)  );
		assertEquals( "d1",    Dict.getNote(26)  );
		assertEquals( "dis1",  Dict.getNote(27)  );
		assertEquals( "e1",    Dict.getNote(28)  );
		assertEquals( "f1",    Dict.getNote(29)  );
		assertEquals( "fis1",  Dict.getNote(30)  );
		assertEquals( "g1",    Dict.getNote(31)  );
		assertEquals( "gis1",  Dict.getNote(32)  );
		assertEquals( "a1",    Dict.getNote(33)  );
		assertEquals( "b1",    Dict.getNote(34)  );
		assertEquals( "h1",    Dict.getNote(35)  );
		assertEquals( "c2",    Dict.getNote(36)  );
		assertEquals( "cis2",  Dict.getNote(37)  );
		assertEquals( "d2",    Dict.getNote(38)  );
		assertEquals( "dis2",  Dict.getNote(39)  );
		assertEquals( "e2",    Dict.getNote(40)  );
		assertEquals( "f2",    Dict.getNote(41)  );
		assertEquals( "fis2",  Dict.getNote(42)  );
		assertEquals( "g2",    Dict.getNote(43)  );
		assertEquals( "gis2",  Dict.getNote(44)  );
		assertEquals( "a2",    Dict.getNote(45)  );
		assertEquals( "b2",    Dict.getNote(46)  );
		assertEquals( "h2",    Dict.getNote(47)  );
		assertEquals( "c3",    Dict.getNote(48)  );
		assertEquals( "cis3",  Dict.getNote(49)  );
		assertEquals( "d3",    Dict.getNote(50)  );
		assertEquals( "dis3",  Dict.getNote(51)  );
		assertEquals( "e3",    Dict.getNote(52)  );
		assertEquals( "f3",    Dict.getNote(53)  );
		assertEquals( "fis3",  Dict.getNote(54)  );
		assertEquals( "g3",    Dict.getNote(55)  );
		assertEquals( "gis3",  Dict.getNote(56)  );
		assertEquals( "a3",    Dict.getNote(57)  );
		assertEquals( "b3",    Dict.getNote(58)  );
		assertEquals( "h3",    Dict.getNote(59)  );
		assertEquals( "c4",    Dict.getNote(60)  );
		assertEquals( "cis4",  Dict.getNote(61)  );
		assertEquals( "d4",    Dict.getNote(62)  );
		assertEquals( "dis4",  Dict.getNote(63)  );
		assertEquals( "e4",    Dict.getNote(64)  );
		assertEquals( "f4",    Dict.getNote(65)  );
		assertEquals( "fis4",  Dict.getNote(66)  );
		assertEquals( "g4",    Dict.getNote(67)  );
		assertEquals( "gis4",  Dict.getNote(68)  );
		assertEquals( "a4",    Dict.getNote(69)  );
		assertEquals( "b4",    Dict.getNote(70)  );
		assertEquals( "h4",    Dict.getNote(71)  );
		assertEquals( "c5",    Dict.getNote(72)  );
		assertEquals( "cis5",  Dict.getNote(73)  );
		assertEquals( "d5",    Dict.getNote(74)  );
		assertEquals( "dis5",  Dict.getNote(75)  );
		assertEquals( "e5",    Dict.getNote(76)  );
		assertEquals( "f5",    Dict.getNote(77)  );
		assertEquals( "fis5",  Dict.getNote(78)  );
		assertEquals( "g5",    Dict.getNote(79)  );
		assertEquals( "gis5",  Dict.getNote(80)  );
		assertEquals( "a5",    Dict.getNote(81)  );
		assertEquals( "b5",    Dict.getNote(82)  );
		assertEquals( "h5",    Dict.getNote(83)  );
		assertEquals( "c6",    Dict.getNote(84)  );
		assertEquals( "cis6",  Dict.getNote(85)  );
		assertEquals( "d6",    Dict.getNote(86)  );
		assertEquals( "dis6",  Dict.getNote(87)  );
		assertEquals( "e6",    Dict.getNote(88)  );
		assertEquals( "f6",    Dict.getNote(89)  );
		assertEquals( "fis6",  Dict.getNote(90)  );
		assertEquals( "g6",    Dict.getNote(91)  );
		assertEquals( "gis6",  Dict.getNote(92)  );
		assertEquals( "a6",    Dict.getNote(93)  );
		assertEquals( "b6",    Dict.getNote(94)  );
		assertEquals( "h6",    Dict.getNote(95)  );
		assertEquals( "c7",    Dict.getNote(96)  );
		assertEquals( "cis7",  Dict.getNote(97)  );
		assertEquals( "d7",    Dict.getNote(98)  );
		assertEquals( "dis7",  Dict.getNote(99)  );
		assertEquals( "e7",    Dict.getNote(100) );
		assertEquals( "f7",    Dict.getNote(101) );
		assertEquals( "fis7",  Dict.getNote(102) );
		assertEquals( "g7",    Dict.getNote(103) );
		assertEquals( "gis7",  Dict.getNote(104) );
		assertEquals( "a7",    Dict.getNote(105) );
		assertEquals( "b7",    Dict.getNote(106) );
		assertEquals( "h7",    Dict.getNote(107) );
		assertEquals( "c8",    Dict.getNote(108) );
		assertEquals( "cis8",  Dict.getNote(109) );
		assertEquals( "d8",    Dict.getNote(110) );
		assertEquals( "dis8",  Dict.getNote(111) );
		assertEquals( "e8",    Dict.getNote(112) );
		assertEquals( "f8",    Dict.getNote(113) );
		assertEquals( "fis8",  Dict.getNote(114) );
		assertEquals( "g8",    Dict.getNote(115) );
		assertEquals( "gis8",  Dict.getNote(116) );
		assertEquals( "a8",    Dict.getNote(117) );
		assertEquals( "b8",    Dict.getNote(118) );
		assertEquals( "h8",    Dict.getNote(119) );
		assertEquals( "c9",    Dict.getNote(120) );
		assertEquals( "cis9",  Dict.getNote(121) );
		assertEquals( "d9",    Dict.getNote(122) );
		assertEquals( "dis9",  Dict.getNote(123) );
		assertEquals( "e9",    Dict.getNote(124) );
		assertEquals( "f9",    Dict.getNote(125) );
		assertEquals( "fis9",  Dict.getNote(126) );
		assertEquals( "g9",    Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "C'''",      Dict.getNote(0)   );
		assertEquals( "Cis'''",    Dict.getNote(1)   );
		assertEquals( "D'''",      Dict.getNote(2)   );
		assertEquals( "Dis'''",    Dict.getNote(3)   );
		assertEquals( "E'''",      Dict.getNote(4)   );
		assertEquals( "F'''",      Dict.getNote(5)   );
		assertEquals( "Fis'''",    Dict.getNote(6)   );
		assertEquals( "G'''",      Dict.getNote(7)   );
		assertEquals( "Gis'''",    Dict.getNote(8)   );
		assertEquals( "A'''",      Dict.getNote(9)   );
		assertEquals( "B'''",      Dict.getNote(10)  );
		assertEquals( "H'''",      Dict.getNote(11)  );
		assertEquals( "C''",       Dict.getNote(12)  );
		assertEquals( "Cis''",     Dict.getNote(13)  );
		assertEquals( "D''",       Dict.getNote(14)  );
		assertEquals( "Dis''",     Dict.getNote(15)  );
		assertEquals( "E''",       Dict.getNote(16)  );
		assertEquals( "F''",       Dict.getNote(17)  );
		assertEquals( "Fis''",     Dict.getNote(18)  );
		assertEquals( "G''",       Dict.getNote(19)  );
		assertEquals( "Gis''",     Dict.getNote(20)  );
		assertEquals( "A''",       Dict.getNote(21)  );
		assertEquals( "B''",       Dict.getNote(22)  );
		assertEquals( "H''",       Dict.getNote(23)  );
		assertEquals( "C'",        Dict.getNote(24)  );
		assertEquals( "Cis'",      Dict.getNote(25)  );
		assertEquals( "D'",        Dict.getNote(26)  );
		assertEquals( "Dis'",      Dict.getNote(27)  );
		assertEquals( "E'",        Dict.getNote(28)  );
		assertEquals( "F'",        Dict.getNote(29)  );
		assertEquals( "Fis'",      Dict.getNote(30)  );
		assertEquals( "G'",        Dict.getNote(31)  );
		assertEquals( "Gis'",      Dict.getNote(32)  );
		assertEquals( "A'",        Dict.getNote(33)  );
		assertEquals( "B'",        Dict.getNote(34)  );
		assertEquals( "H'",        Dict.getNote(35)  );
		assertEquals( "C",         Dict.getNote(36)  );
		assertEquals( "Cis",       Dict.getNote(37)  );
		assertEquals( "D",         Dict.getNote(38)  );
		assertEquals( "Dis",       Dict.getNote(39)  );
		assertEquals( "E",         Dict.getNote(40)  );
		assertEquals( "F",         Dict.getNote(41)  );
		assertEquals( "Fis",       Dict.getNote(42)  );
		assertEquals( "G",         Dict.getNote(43)  );
		assertEquals( "Gis",       Dict.getNote(44)  );
		assertEquals( "A",         Dict.getNote(45)  );
		assertEquals( "B",         Dict.getNote(46)  );
		assertEquals( "H",         Dict.getNote(47)  );
		assertEquals( "c",         Dict.getNote(48)  );
		assertEquals( "cis",       Dict.getNote(49)  );
		assertEquals( "d",         Dict.getNote(50)  );
		assertEquals( "dis",       Dict.getNote(51)  );
		assertEquals( "e",         Dict.getNote(52)  );
		assertEquals( "f",         Dict.getNote(53)  );
		assertEquals( "fis",       Dict.getNote(54)  );
		assertEquals( "g",         Dict.getNote(55)  );
		assertEquals( "gis",       Dict.getNote(56)  );
		assertEquals( "a",         Dict.getNote(57)  );
		assertEquals( "b",         Dict.getNote(58)  );
		assertEquals( "h",         Dict.getNote(59)  );
		assertEquals( "c'",        Dict.getNote(60)  );
		assertEquals( "cis'",      Dict.getNote(61)  );
		assertEquals( "d'",        Dict.getNote(62)  );
		assertEquals( "dis'",      Dict.getNote(63)  );
		assertEquals( "e'",        Dict.getNote(64)  );
		assertEquals( "f'",        Dict.getNote(65)  );
		assertEquals( "fis'",      Dict.getNote(66)  );
		assertEquals( "g'",        Dict.getNote(67)  );
		assertEquals( "gis'",      Dict.getNote(68)  );
		assertEquals( "a'",        Dict.getNote(69)  );
		assertEquals( "b'",        Dict.getNote(70)  );
		assertEquals( "h'",        Dict.getNote(71)  );
		assertEquals( "c''",       Dict.getNote(72)  );
		assertEquals( "cis''",     Dict.getNote(73)  );
		assertEquals( "d''",       Dict.getNote(74)  );
		assertEquals( "dis''",     Dict.getNote(75)  );
		assertEquals( "e''",       Dict.getNote(76)  );
		assertEquals( "f''",       Dict.getNote(77)  );
		assertEquals( "fis''",     Dict.getNote(78)  );
		assertEquals( "g''",       Dict.getNote(79)  );
		assertEquals( "gis''",     Dict.getNote(80)  );
		assertEquals( "a''",       Dict.getNote(81)  );
		assertEquals( "b''",       Dict.getNote(82)  );
		assertEquals( "h''",       Dict.getNote(83)  );
		assertEquals( "c'''",      Dict.getNote(84)  );
		assertEquals( "cis'''",    Dict.getNote(85)  );
		assertEquals( "d'''",      Dict.getNote(86)  );
		assertEquals( "dis'''",    Dict.getNote(87)  );
		assertEquals( "e'''",      Dict.getNote(88)  );
		assertEquals( "f'''",      Dict.getNote(89)  );
		assertEquals( "fis'''",    Dict.getNote(90)  );
		assertEquals( "g'''",      Dict.getNote(91)  );
		assertEquals( "gis'''",    Dict.getNote(92)  );
		assertEquals( "a'''",      Dict.getNote(93)  );
		assertEquals( "b'''",      Dict.getNote(94)  );
		assertEquals( "h'''",      Dict.getNote(95)  );
		assertEquals( "c''''",     Dict.getNote(96)  );
		assertEquals( "cis''''",   Dict.getNote(97)  );
		assertEquals( "d''''",     Dict.getNote(98)  );
		assertEquals( "dis''''",   Dict.getNote(99)  );
		assertEquals( "e''''",     Dict.getNote(100) );
		assertEquals( "f''''",     Dict.getNote(101) );
		assertEquals( "fis''''",   Dict.getNote(102) );
		assertEquals( "g''''",     Dict.getNote(103) );
		assertEquals( "gis''''",   Dict.getNote(104) );
		assertEquals( "a''''",     Dict.getNote(105) );
		assertEquals( "b''''",     Dict.getNote(106) );
		assertEquals( "h''''",     Dict.getNote(107) );
		assertEquals( "c'''''",    Dict.getNote(108) );
		assertEquals( "cis'''''",  Dict.getNote(109) );
		assertEquals( "d'''''",    Dict.getNote(110) );
		assertEquals( "dis'''''",  Dict.getNote(111) );
		assertEquals( "e'''''",    Dict.getNote(112) );
		assertEquals( "f'''''",    Dict.getNote(113) );
		assertEquals( "fis'''''",  Dict.getNote(114) );
		assertEquals( "g'''''",    Dict.getNote(115) );
		assertEquals( "gis'''''",  Dict.getNote(116) );
		assertEquals( "a'''''",    Dict.getNote(117) );
		assertEquals( "b'''''",    Dict.getNote(118) );
		assertEquals( "h'''''",    Dict.getNote(119) );
		assertEquals( "c''''''",   Dict.getNote(120) );
		assertEquals( "cis''''''", Dict.getNote(121) );
		assertEquals( "d''''''",   Dict.getNote(122) );
		assertEquals( "dis''''''", Dict.getNote(123) );
		assertEquals( "e''''''",   Dict.getNote(124) );
		assertEquals( "f''''''",   Dict.getNote(125) );
		assertEquals( "fis''''''", Dict.getNote(126) );
		assertEquals( "g''''''",   Dict.getNote(127) );
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[2].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests octave configurations.
	 * 
	 * Using the following config:
	 * 
	 * - note system: german (upper-case)
	 * - half tone: -es
	 * - octave naming: all possibilities:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsGerUcCes() {
		
		// switch config
		cbxs[1].setSelectedIndex(5); // german (upper-case)
		cbxs[2].setSelectedIndex(2); // -is/-es
		cbxs[3].setSelectedIndex(1); // flat
		
		// test default (+n/-n)
		assertEquals( "C-5",   Dict.getNote(0)   );
		assertEquals( "Des-5", Dict.getNote(1)   );
		assertEquals( "D-5",   Dict.getNote(2)   );
		assertEquals( "Es-5",  Dict.getNote(3)   );
		assertEquals( "E-5",   Dict.getNote(4)   );
		assertEquals( "F-5",   Dict.getNote(5)   );
		assertEquals( "Ges-5", Dict.getNote(6)   );
		assertEquals( "G-5",   Dict.getNote(7)   );
		assertEquals( "As-5",  Dict.getNote(8)   );
		assertEquals( "A-5",   Dict.getNote(9)   );
		assertEquals( "B-5",   Dict.getNote(10)  );
		assertEquals( "H-5",   Dict.getNote(11)  );
		assertEquals( "C-4",   Dict.getNote(12)  );
		assertEquals( "Des-4", Dict.getNote(13)  );
		assertEquals( "D-4",   Dict.getNote(14)  );
		assertEquals( "Es-4",  Dict.getNote(15)  );
		assertEquals( "E-4",   Dict.getNote(16)  );
		assertEquals( "F-4",   Dict.getNote(17)  );
		assertEquals( "Ges-4", Dict.getNote(18)  );
		assertEquals( "G-4",   Dict.getNote(19)  );
		assertEquals( "As-4",  Dict.getNote(20)  );
		assertEquals( "A-4",   Dict.getNote(21)  );
		assertEquals( "B-4",   Dict.getNote(22)  );
		assertEquals( "H-4",   Dict.getNote(23)  );
		assertEquals( "C-3",   Dict.getNote(24)  );
		assertEquals( "Des-3", Dict.getNote(25)  );
		assertEquals( "D-3",   Dict.getNote(26)  );
		assertEquals( "Es-3",  Dict.getNote(27)  );
		assertEquals( "E-3",   Dict.getNote(28)  );
		assertEquals( "F-3",   Dict.getNote(29)  );
		assertEquals( "Ges-3", Dict.getNote(30)  );
		assertEquals( "G-3",   Dict.getNote(31)  );
		assertEquals( "As-3",  Dict.getNote(32)  );
		assertEquals( "A-3",   Dict.getNote(33)  );
		assertEquals( "B-3",   Dict.getNote(34)  );
		assertEquals( "H-3",   Dict.getNote(35)  );
		assertEquals( "C-2",   Dict.getNote(36)  );
		assertEquals( "Des-2", Dict.getNote(37)  );
		assertEquals( "D-2",   Dict.getNote(38)  );
		assertEquals( "Es-2",  Dict.getNote(39)  );
		assertEquals( "E-2",   Dict.getNote(40)  );
		assertEquals( "F-2",   Dict.getNote(41)  );
		assertEquals( "Ges-2", Dict.getNote(42)  );
		assertEquals( "G-2",   Dict.getNote(43)  );
		assertEquals( "As-2",  Dict.getNote(44)  );
		assertEquals( "A-2",   Dict.getNote(45)  );
		assertEquals( "B-2",   Dict.getNote(46)  );
		assertEquals( "H-2",   Dict.getNote(47)  );
		assertEquals( "C-",    Dict.getNote(48)  );
		assertEquals( "Des-",  Dict.getNote(49)  );
		assertEquals( "D-",    Dict.getNote(50)  );
		assertEquals( "Es-",   Dict.getNote(51)  );
		assertEquals( "E-",    Dict.getNote(52)  );
		assertEquals( "F-",    Dict.getNote(53)  );
		assertEquals( "Ges-",  Dict.getNote(54)  );
		assertEquals( "G-",    Dict.getNote(55)  );
		assertEquals( "As-",   Dict.getNote(56)  );
		assertEquals( "A-",    Dict.getNote(57)  );
		assertEquals( "B-",    Dict.getNote(58)  );
		assertEquals( "H-",    Dict.getNote(59)  );
		assertEquals( "C",     Dict.getNote(60)  );
		assertEquals( "Des",   Dict.getNote(61)  );
		assertEquals( "D",     Dict.getNote(62)  );
		assertEquals( "Es",    Dict.getNote(63)  );
		assertEquals( "E",     Dict.getNote(64)  );
		assertEquals( "F",     Dict.getNote(65)  );
		assertEquals( "Ges",   Dict.getNote(66)  );
		assertEquals( "G",     Dict.getNote(67)  );
		assertEquals( "As",    Dict.getNote(68)  );
		assertEquals( "A",     Dict.getNote(69)  );
		assertEquals( "B",     Dict.getNote(70)  );
		assertEquals( "H",     Dict.getNote(71)  );
		assertEquals( "C+",    Dict.getNote(72)  );
		assertEquals( "Des+",  Dict.getNote(73)  );
		assertEquals( "D+",    Dict.getNote(74)  );
		assertEquals( "Es+",   Dict.getNote(75)  );
		assertEquals( "E+",    Dict.getNote(76)  );
		assertEquals( "F+",    Dict.getNote(77)  );
		assertEquals( "Ges+",  Dict.getNote(78)  );
		assertEquals( "G+",    Dict.getNote(79)  );
		assertEquals( "As+",   Dict.getNote(80)  );
		assertEquals( "A+",    Dict.getNote(81)  );
		assertEquals( "B+",    Dict.getNote(82)  );
		assertEquals( "H+",    Dict.getNote(83)  );
		assertEquals( "C+2",   Dict.getNote(84)  );
		assertEquals( "Des+2", Dict.getNote(85)  );
		assertEquals( "D+2",   Dict.getNote(86)  );
		assertEquals( "Es+2",  Dict.getNote(87)  );
		assertEquals( "E+2",   Dict.getNote(88)  );
		assertEquals( "F+2",   Dict.getNote(89)  );
		assertEquals( "Ges+2", Dict.getNote(90)  );
		assertEquals( "G+2",   Dict.getNote(91)  );
		assertEquals( "As+2",  Dict.getNote(92)  );
		assertEquals( "A+2",   Dict.getNote(93)  );
		assertEquals( "B+2",   Dict.getNote(94)  );
		assertEquals( "H+2",   Dict.getNote(95)  );
		assertEquals( "C+3",   Dict.getNote(96)  );
		assertEquals( "Des+3", Dict.getNote(97)  );
		assertEquals( "D+3",   Dict.getNote(98)  );
		assertEquals( "Es+3",  Dict.getNote(99)  );
		assertEquals( "E+3",   Dict.getNote(100) );
		assertEquals( "F+3",   Dict.getNote(101) );
		assertEquals( "Ges+3", Dict.getNote(102) );
		assertEquals( "G+3",   Dict.getNote(103) );
		assertEquals( "As+3",  Dict.getNote(104) );
		assertEquals( "A+3",   Dict.getNote(105) );
		assertEquals( "B+3",   Dict.getNote(106) );
		assertEquals( "H+3",   Dict.getNote(107) );
		assertEquals( "C+4",   Dict.getNote(108) );
		assertEquals( "Des+4", Dict.getNote(109) );
		assertEquals( "D+4",   Dict.getNote(110) );
		assertEquals( "Es+4",  Dict.getNote(111) );
		assertEquals( "E+4",   Dict.getNote(112) );
		assertEquals( "F+4",   Dict.getNote(113) );
		assertEquals( "Ges+4", Dict.getNote(114) );
		assertEquals( "G+4",   Dict.getNote(115) );
		assertEquals( "As+4",  Dict.getNote(116) );
		assertEquals( "A+4",   Dict.getNote(117) );
		assertEquals( "B+4",   Dict.getNote(118) );
		assertEquals( "H+4",   Dict.getNote(119) );
		assertEquals( "C+5",   Dict.getNote(120) );
		assertEquals( "Des+5", Dict.getNote(121) );
		assertEquals( "D+5",   Dict.getNote(122) );
		assertEquals( "Es+5",  Dict.getNote(123) );
		assertEquals( "E+5",   Dict.getNote(124) );
		assertEquals( "F+5",   Dict.getNote(125) );
		assertEquals( "Ges+5", Dict.getNote(126) );
		assertEquals( "G+5",   Dict.getNote(127) );
		
		// test +/-
		cbxs[4].setSelectedIndex(1);
		assertEquals( "C-----",   Dict.getNote(0)   );
		assertEquals( "Des-----", Dict.getNote(1)   );
		assertEquals( "D-----",   Dict.getNote(2)   );
		assertEquals( "Es-----",  Dict.getNote(3)   );
		assertEquals( "E-----",   Dict.getNote(4)   );
		assertEquals( "F-----",   Dict.getNote(5)   );
		assertEquals( "Ges-----", Dict.getNote(6)   );
		assertEquals( "G-----",   Dict.getNote(7)   );
		assertEquals( "As-----",  Dict.getNote(8)   );
		assertEquals( "A-----",   Dict.getNote(9)   );
		assertEquals( "B-----",   Dict.getNote(10)  );
		assertEquals( "H-----",   Dict.getNote(11)  );
		assertEquals( "C----",    Dict.getNote(12)  );
		assertEquals( "Des----",  Dict.getNote(13)  );
		assertEquals( "D----",    Dict.getNote(14)  );
		assertEquals( "Es----",   Dict.getNote(15)  );
		assertEquals( "E----",    Dict.getNote(16)  );
		assertEquals( "F----",    Dict.getNote(17)  );
		assertEquals( "Ges----",  Dict.getNote(18)  );
		assertEquals( "G----",    Dict.getNote(19)  );
		assertEquals( "As----",   Dict.getNote(20)  );
		assertEquals( "A----",    Dict.getNote(21)  );
		assertEquals( "B----",    Dict.getNote(22)  );
		assertEquals( "H----",    Dict.getNote(23)  );
		assertEquals( "C---",     Dict.getNote(24)  );
		assertEquals( "Des---",   Dict.getNote(25)  );
		assertEquals( "D---",     Dict.getNote(26)  );
		assertEquals( "Es---",    Dict.getNote(27)  );
		assertEquals( "E---",     Dict.getNote(28)  );
		assertEquals( "F---",     Dict.getNote(29)  );
		assertEquals( "Ges---",   Dict.getNote(30)  );
		assertEquals( "G---",     Dict.getNote(31)  );
		assertEquals( "As---",    Dict.getNote(32)  );
		assertEquals( "A---",     Dict.getNote(33)  );
		assertEquals( "B---",     Dict.getNote(34)  );
		assertEquals( "H---",     Dict.getNote(35)  );
		assertEquals( "C--",      Dict.getNote(36)  );
		assertEquals( "Des--",    Dict.getNote(37)  );
		assertEquals( "D--",      Dict.getNote(38)  );
		assertEquals( "Es--",     Dict.getNote(39)  );
		assertEquals( "E--",      Dict.getNote(40)  );
		assertEquals( "F--",      Dict.getNote(41)  );
		assertEquals( "Ges--",    Dict.getNote(42)  );
		assertEquals( "G--",      Dict.getNote(43)  );
		assertEquals( "As--",     Dict.getNote(44)  );
		assertEquals( "A--",      Dict.getNote(45)  );
		assertEquals( "B--",      Dict.getNote(46)  );
		assertEquals( "H--",      Dict.getNote(47)  );
		assertEquals( "C-",       Dict.getNote(48)  );
		assertEquals( "Des-",     Dict.getNote(49)  );
		assertEquals( "D-",       Dict.getNote(50)  );
		assertEquals( "Es-",      Dict.getNote(51)  );
		assertEquals( "E-",       Dict.getNote(52)  );
		assertEquals( "F-",       Dict.getNote(53)  );
		assertEquals( "Ges-",     Dict.getNote(54)  );
		assertEquals( "G-",       Dict.getNote(55)  );
		assertEquals( "As-",      Dict.getNote(56)  );
		assertEquals( "A-",       Dict.getNote(57)  );
		assertEquals( "B-",       Dict.getNote(58)  );
		assertEquals( "H-",       Dict.getNote(59)  );
		assertEquals( "C",        Dict.getNote(60)  );
		assertEquals( "Des",      Dict.getNote(61)  );
		assertEquals( "D",        Dict.getNote(62)  );
		assertEquals( "Es",       Dict.getNote(63)  );
		assertEquals( "E",        Dict.getNote(64)  );
		assertEquals( "F",        Dict.getNote(65)  );
		assertEquals( "Ges",      Dict.getNote(66)  );
		assertEquals( "G",        Dict.getNote(67)  );
		assertEquals( "As",       Dict.getNote(68)  );
		assertEquals( "A",        Dict.getNote(69)  );
		assertEquals( "B",        Dict.getNote(70)  );
		assertEquals( "H",        Dict.getNote(71)  );
		assertEquals( "C+",       Dict.getNote(72)  );
		assertEquals( "Des+",     Dict.getNote(73)  );
		assertEquals( "D+",       Dict.getNote(74)  );
		assertEquals( "Es+",      Dict.getNote(75)  );
		assertEquals( "E+",       Dict.getNote(76)  );
		assertEquals( "F+",       Dict.getNote(77)  );
		assertEquals( "Ges+",     Dict.getNote(78)  );
		assertEquals( "G+",       Dict.getNote(79)  );
		assertEquals( "As+",      Dict.getNote(80)  );
		assertEquals( "A+",       Dict.getNote(81)  );
		assertEquals( "B+",       Dict.getNote(82)  );
		assertEquals( "H+",       Dict.getNote(83)  );
		assertEquals( "C++",      Dict.getNote(84)  );
		assertEquals( "Des++",    Dict.getNote(85)  );
		assertEquals( "D++",      Dict.getNote(86)  );
		assertEquals( "Es++",     Dict.getNote(87)  );
		assertEquals( "E++",      Dict.getNote(88)  );
		assertEquals( "F++",      Dict.getNote(89)  );
		assertEquals( "Ges++",    Dict.getNote(90)  );
		assertEquals( "G++",      Dict.getNote(91)  );
		assertEquals( "As++",     Dict.getNote(92)  );
		assertEquals( "A++",      Dict.getNote(93)  );
		assertEquals( "B++",      Dict.getNote(94)  );
		assertEquals( "H++",      Dict.getNote(95)  );
		assertEquals( "C+++",     Dict.getNote(96)  );
		assertEquals( "Des+++",   Dict.getNote(97)  );
		assertEquals( "D+++",     Dict.getNote(98)  );
		assertEquals( "Es+++",    Dict.getNote(99)  );
		assertEquals( "E+++",     Dict.getNote(100) );
		assertEquals( "F+++",     Dict.getNote(101) );
		assertEquals( "Ges+++",   Dict.getNote(102) );
		assertEquals( "G+++",     Dict.getNote(103) );
		assertEquals( "As+++",    Dict.getNote(104) );
		assertEquals( "A+++",     Dict.getNote(105) );
		assertEquals( "B+++",     Dict.getNote(106) );
		assertEquals( "H+++",     Dict.getNote(107) );
		assertEquals( "C++++",    Dict.getNote(108) );
		assertEquals( "Des++++",  Dict.getNote(109) );
		assertEquals( "D++++",    Dict.getNote(110) );
		assertEquals( "Es++++",   Dict.getNote(111) );
		assertEquals( "E++++",    Dict.getNote(112) );
		assertEquals( "F++++",    Dict.getNote(113) );
		assertEquals( "Ges++++",  Dict.getNote(114) );
		assertEquals( "G++++",    Dict.getNote(115) );
		assertEquals( "As++++",   Dict.getNote(116) );
		assertEquals( "A++++",    Dict.getNote(117) );
		assertEquals( "B++++",    Dict.getNote(118) );
		assertEquals( "H++++",    Dict.getNote(119) );
		assertEquals( "C+++++",   Dict.getNote(120) );
		assertEquals( "Des+++++", Dict.getNote(121) );
		assertEquals( "D+++++",   Dict.getNote(122) );
		assertEquals( "Es+++++",  Dict.getNote(123) );
		assertEquals( "E+++++",   Dict.getNote(124) );
		assertEquals( "F+++++",   Dict.getNote(125) );
		assertEquals( "Ges+++++", Dict.getNote(126) );
		assertEquals( "G+++++",   Dict.getNote(127) );
		
		// test international
		cbxs[4].setSelectedIndex(2);
		assertEquals( "C-1",   Dict.getNote(0)   );
		assertEquals( "Des-1", Dict.getNote(1)   );
		assertEquals( "D-1",   Dict.getNote(2)   );
		assertEquals( "Es-1",  Dict.getNote(3)   );
		assertEquals( "E-1",   Dict.getNote(4)   );
		assertEquals( "F-1",   Dict.getNote(5)   );
		assertEquals( "Ges-1", Dict.getNote(6)   );
		assertEquals( "G-1",   Dict.getNote(7)   );
		assertEquals( "As-1",  Dict.getNote(8)   );
		assertEquals( "A-1",   Dict.getNote(9)   );
		assertEquals( "B-1",   Dict.getNote(10)  );
		assertEquals( "H-1",   Dict.getNote(11)  );
		assertEquals( "C0",    Dict.getNote(12)  );
		assertEquals( "Des0",  Dict.getNote(13)  );
		assertEquals( "D0",    Dict.getNote(14)  );
		assertEquals( "Es0",   Dict.getNote(15)  );
		assertEquals( "E0",    Dict.getNote(16)  );
		assertEquals( "F0",    Dict.getNote(17)  );
		assertEquals( "Ges0",  Dict.getNote(18)  );
		assertEquals( "G0",    Dict.getNote(19)  );
		assertEquals( "As0",   Dict.getNote(20)  );
		assertEquals( "A0",    Dict.getNote(21)  );
		assertEquals( "B0",    Dict.getNote(22)  );
		assertEquals( "H0",    Dict.getNote(23)  );
		assertEquals( "C1",    Dict.getNote(24)  );
		assertEquals( "Des1",  Dict.getNote(25)  );
		assertEquals( "D1",    Dict.getNote(26)  );
		assertEquals( "Es1",   Dict.getNote(27)  );
		assertEquals( "E1",    Dict.getNote(28)  );
		assertEquals( "F1",    Dict.getNote(29)  );
		assertEquals( "Ges1",  Dict.getNote(30)  );
		assertEquals( "G1",    Dict.getNote(31)  );
		assertEquals( "As1",   Dict.getNote(32)  );
		assertEquals( "A1",    Dict.getNote(33)  );
		assertEquals( "B1",    Dict.getNote(34)  );
		assertEquals( "H1",    Dict.getNote(35)  );
		assertEquals( "C2",    Dict.getNote(36)  );
		assertEquals( "Des2",  Dict.getNote(37)  );
		assertEquals( "D2",    Dict.getNote(38)  );
		assertEquals( "Es2",   Dict.getNote(39)  );
		assertEquals( "E2",    Dict.getNote(40)  );
		assertEquals( "F2",    Dict.getNote(41)  );
		assertEquals( "Ges2",  Dict.getNote(42)  );
		assertEquals( "G2",    Dict.getNote(43)  );
		assertEquals( "As2",   Dict.getNote(44)  );
		assertEquals( "A2",    Dict.getNote(45)  );
		assertEquals( "B2",    Dict.getNote(46)  );
		assertEquals( "H2",    Dict.getNote(47)  );
		assertEquals( "C3",    Dict.getNote(48)  );
		assertEquals( "Des3",  Dict.getNote(49)  );
		assertEquals( "D3",    Dict.getNote(50)  );
		assertEquals( "Es3",   Dict.getNote(51)  );
		assertEquals( "E3",    Dict.getNote(52)  );
		assertEquals( "F3",    Dict.getNote(53)  );
		assertEquals( "Ges3",  Dict.getNote(54)  );
		assertEquals( "G3",    Dict.getNote(55)  );
		assertEquals( "As3",   Dict.getNote(56)  );
		assertEquals( "A3",    Dict.getNote(57)  );
		assertEquals( "B3",    Dict.getNote(58)  );
		assertEquals( "H3",    Dict.getNote(59)  );
		assertEquals( "C4",    Dict.getNote(60)  );
		assertEquals( "Des4",  Dict.getNote(61)  );
		assertEquals( "D4",    Dict.getNote(62)  );
		assertEquals( "Es4",   Dict.getNote(63)  );
		assertEquals( "E4",    Dict.getNote(64)  );
		assertEquals( "F4",    Dict.getNote(65)  );
		assertEquals( "Ges4",  Dict.getNote(66)  );
		assertEquals( "G4",    Dict.getNote(67)  );
		assertEquals( "As4",   Dict.getNote(68)  );
		assertEquals( "A4",    Dict.getNote(69)  );
		assertEquals( "B4",    Dict.getNote(70)  );
		assertEquals( "H4",    Dict.getNote(71)  );
		assertEquals( "C5",    Dict.getNote(72)  );
		assertEquals( "Des5",  Dict.getNote(73)  );
		assertEquals( "D5",    Dict.getNote(74)  );
		assertEquals( "Es5",   Dict.getNote(75)  );
		assertEquals( "E5",    Dict.getNote(76)  );
		assertEquals( "F5",    Dict.getNote(77)  );
		assertEquals( "Ges5",  Dict.getNote(78)  );
		assertEquals( "G5",    Dict.getNote(79)  );
		assertEquals( "As5",   Dict.getNote(80)  );
		assertEquals( "A5",    Dict.getNote(81)  );
		assertEquals( "B5",    Dict.getNote(82)  );
		assertEquals( "H5",    Dict.getNote(83)  );
		assertEquals( "C6",    Dict.getNote(84)  );
		assertEquals( "Des6",  Dict.getNote(85)  );
		assertEquals( "D6",    Dict.getNote(86)  );
		assertEquals( "Es6",   Dict.getNote(87)  );
		assertEquals( "E6",    Dict.getNote(88)  );
		assertEquals( "F6",    Dict.getNote(89)  );
		assertEquals( "Ges6",  Dict.getNote(90)  );
		assertEquals( "G6",    Dict.getNote(91)  );
		assertEquals( "As6",   Dict.getNote(92)  );
		assertEquals( "A6",    Dict.getNote(93)  );
		assertEquals( "B6",    Dict.getNote(94)  );
		assertEquals( "H6",    Dict.getNote(95)  );
		assertEquals( "C7",    Dict.getNote(96)  );
		assertEquals( "Des7",  Dict.getNote(97)  );
		assertEquals( "D7",    Dict.getNote(98)  );
		assertEquals( "Es7",   Dict.getNote(99)  );
		assertEquals( "E7",    Dict.getNote(100) );
		assertEquals( "F7",    Dict.getNote(101) );
		assertEquals( "Ges7",  Dict.getNote(102) );
		assertEquals( "G7",    Dict.getNote(103) );
		assertEquals( "As7",   Dict.getNote(104) );
		assertEquals( "A7",    Dict.getNote(105) );
		assertEquals( "B7",    Dict.getNote(106) );
		assertEquals( "H7",    Dict.getNote(107) );
		assertEquals( "C8",    Dict.getNote(108) );
		assertEquals( "Des8",  Dict.getNote(109) );
		assertEquals( "D8",    Dict.getNote(110) );
		assertEquals( "Es8",   Dict.getNote(111) );
		assertEquals( "E8",    Dict.getNote(112) );
		assertEquals( "F8",    Dict.getNote(113) );
		assertEquals( "Ges8",  Dict.getNote(114) );
		assertEquals( "G8",    Dict.getNote(115) );
		assertEquals( "As8",   Dict.getNote(116) );
		assertEquals( "A8",    Dict.getNote(117) );
		assertEquals( "B8",    Dict.getNote(118) );
		assertEquals( "H8",    Dict.getNote(119) );
		assertEquals( "C9",    Dict.getNote(120) );
		assertEquals( "Des9",  Dict.getNote(121) );
		assertEquals( "D9",    Dict.getNote(122) );
		assertEquals( "Es9",   Dict.getNote(123) );
		assertEquals( "E9",    Dict.getNote(124) );
		assertEquals( "F9",    Dict.getNote(125) );
		assertEquals( "Ges9",  Dict.getNote(126) );
		assertEquals( "G9",    Dict.getNote(127) );
		
		// test german
		cbxs[4].setSelectedIndex(3);
		assertEquals( "C'''",      Dict.getNote(0)   );
		assertEquals( "Des'''",    Dict.getNote(1)   );
		assertEquals( "D'''",      Dict.getNote(2)   );
		assertEquals( "Es'''",     Dict.getNote(3)   );
		assertEquals( "E'''",      Dict.getNote(4)   );
		assertEquals( "F'''",      Dict.getNote(5)   );
		assertEquals( "Ges'''",    Dict.getNote(6)   );
		assertEquals( "G'''",      Dict.getNote(7)   );
		assertEquals( "As'''",     Dict.getNote(8)   );
		assertEquals( "A'''",      Dict.getNote(9)   );
		assertEquals( "B'''",      Dict.getNote(10)  );
		assertEquals( "H'''",      Dict.getNote(11)  );
		assertEquals( "C''",       Dict.getNote(12)  );
		assertEquals( "Des''",     Dict.getNote(13)  );
		assertEquals( "D''",       Dict.getNote(14)  );
		assertEquals( "Es''",      Dict.getNote(15)  );
		assertEquals( "E''",       Dict.getNote(16)  );
		assertEquals( "F''",       Dict.getNote(17)  );
		assertEquals( "Ges''",     Dict.getNote(18)  );
		assertEquals( "G''",       Dict.getNote(19)  );
		assertEquals( "As''",      Dict.getNote(20)  );
		assertEquals( "A''",       Dict.getNote(21)  );
		assertEquals( "B''",       Dict.getNote(22)  );
		assertEquals( "H''",       Dict.getNote(23)  );
		assertEquals( "C'",        Dict.getNote(24)  );
		assertEquals( "Des'",      Dict.getNote(25)  );
		assertEquals( "D'",        Dict.getNote(26)  );
		assertEquals( "Es'",       Dict.getNote(27)  );
		assertEquals( "E'",        Dict.getNote(28)  );
		assertEquals( "F'",        Dict.getNote(29)  );
		assertEquals( "Ges'",      Dict.getNote(30)  );
		assertEquals( "G'",        Dict.getNote(31)  );
		assertEquals( "As'",       Dict.getNote(32)  );
		assertEquals( "A'",        Dict.getNote(33)  );
		assertEquals( "B'",        Dict.getNote(34)  );
		assertEquals( "H'",        Dict.getNote(35)  );
		assertEquals( "C",         Dict.getNote(36)  );
		assertEquals( "Des",       Dict.getNote(37)  );
		assertEquals( "D",         Dict.getNote(38)  );
		assertEquals( "Es",        Dict.getNote(39)  );
		assertEquals( "E",         Dict.getNote(40)  );
		assertEquals( "F",         Dict.getNote(41)  );
		assertEquals( "Ges",       Dict.getNote(42)  );
		assertEquals( "G",         Dict.getNote(43)  );
		assertEquals( "As",        Dict.getNote(44)  );
		assertEquals( "A",         Dict.getNote(45)  );
		assertEquals( "B",         Dict.getNote(46)  );
		assertEquals( "H",         Dict.getNote(47)  );
		assertEquals( "c",         Dict.getNote(48)  );
		assertEquals( "des",       Dict.getNote(49)  );
		assertEquals( "d",         Dict.getNote(50)  );
		assertEquals( "es",        Dict.getNote(51)  );
		assertEquals( "e",         Dict.getNote(52)  );
		assertEquals( "f",         Dict.getNote(53)  );
		assertEquals( "ges",       Dict.getNote(54)  );
		assertEquals( "g",         Dict.getNote(55)  );
		assertEquals( "as",        Dict.getNote(56)  );
		assertEquals( "a",         Dict.getNote(57)  );
		assertEquals( "b",         Dict.getNote(58)  );
		assertEquals( "h",         Dict.getNote(59)  );
		assertEquals( "c'",        Dict.getNote(60)  );
		assertEquals( "des'",      Dict.getNote(61)  );
		assertEquals( "d'",        Dict.getNote(62)  );
		assertEquals( "es'",       Dict.getNote(63)  );
		assertEquals( "e'",        Dict.getNote(64)  );
		assertEquals( "f'",        Dict.getNote(65)  );
		assertEquals( "ges'",      Dict.getNote(66)  );
		assertEquals( "g'",        Dict.getNote(67)  );
		assertEquals( "as'",       Dict.getNote(68)  );
		assertEquals( "a'",        Dict.getNote(69)  );
		assertEquals( "b'",        Dict.getNote(70)  );
		assertEquals( "h'",        Dict.getNote(71)  );
		assertEquals( "c''",       Dict.getNote(72)  );
		assertEquals( "des''",     Dict.getNote(73)  );
		assertEquals( "d''",       Dict.getNote(74)  );
		assertEquals( "es''",      Dict.getNote(75)  );
		assertEquals( "e''",       Dict.getNote(76)  );
		assertEquals( "f''",       Dict.getNote(77)  );
		assertEquals( "ges''",     Dict.getNote(78)  );
		assertEquals( "g''",       Dict.getNote(79)  );
		assertEquals( "as''",      Dict.getNote(80)  );
		assertEquals( "a''",       Dict.getNote(81)  );
		assertEquals( "b''",       Dict.getNote(82)  );
		assertEquals( "h''",       Dict.getNote(83)  );
		assertEquals( "c'''",      Dict.getNote(84)  );
		assertEquals( "des'''",    Dict.getNote(85)  );
		assertEquals( "d'''",      Dict.getNote(86)  );
		assertEquals( "es'''",     Dict.getNote(87)  );
		assertEquals( "e'''",      Dict.getNote(88)  );
		assertEquals( "f'''",      Dict.getNote(89)  );
		assertEquals( "ges'''",    Dict.getNote(90)  );
		assertEquals( "g'''",      Dict.getNote(91)  );
		assertEquals( "as'''",     Dict.getNote(92)  );
		assertEquals( "a'''",      Dict.getNote(93)  );
		assertEquals( "b'''",      Dict.getNote(94)  );
		assertEquals( "h'''",      Dict.getNote(95)  );
		assertEquals( "c''''",     Dict.getNote(96)  );
		assertEquals( "des''''",   Dict.getNote(97)  );
		assertEquals( "d''''",     Dict.getNote(98)  );
		assertEquals( "es''''",    Dict.getNote(99)  );
		assertEquals( "e''''",     Dict.getNote(100) );
		assertEquals( "f''''",     Dict.getNote(101) );
		assertEquals( "ges''''",   Dict.getNote(102) );
		assertEquals( "g''''",     Dict.getNote(103) );
		assertEquals( "as''''",    Dict.getNote(104) );
		assertEquals( "a''''",     Dict.getNote(105) );
		assertEquals( "b''''",     Dict.getNote(106) );
		assertEquals( "h''''",     Dict.getNote(107) );
		assertEquals( "c'''''",    Dict.getNote(108) );
		assertEquals( "des'''''",  Dict.getNote(109) );
		assertEquals( "d'''''",    Dict.getNote(110) );
		assertEquals( "es'''''",   Dict.getNote(111) );
		assertEquals( "e'''''",    Dict.getNote(112) );
		assertEquals( "f'''''",    Dict.getNote(113) );
		assertEquals( "ges'''''",  Dict.getNote(114) );
		assertEquals( "g'''''",    Dict.getNote(115) );
		assertEquals( "as'''''",   Dict.getNote(116) );
		assertEquals( "a'''''",    Dict.getNote(117) );
		assertEquals( "b'''''",    Dict.getNote(118) );
		assertEquals( "h'''''",    Dict.getNote(119) );
		assertEquals( "c''''''",   Dict.getNote(120) );
		assertEquals( "des''''''", Dict.getNote(121) );
		assertEquals( "d''''''",   Dict.getNote(122) );
		assertEquals( "es''''''",  Dict.getNote(123) );
		assertEquals( "e''''''",   Dict.getNote(124) );
		assertEquals( "f''''''",   Dict.getNote(125) );
		assertEquals( "ges''''''", Dict.getNote(126) );
		assertEquals( "g''''''",   Dict.getNote(127) );
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[2].setSelectedIndex(0);
		cbxs[3].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
	
	/**
	 * Tests all octave configurations and the alternative note names.
	 * 
	 * Using all possible combinations of the following configs:
	 * 
	 * - note system:
	 *     - international lc
	 *     - international uc
	 *     - italian lc
	 *     - italian uc
	 *     - german lc
	 *     - german uc
	 * - half tone:
	 *     - sharp
	 *     - flat
	 *     - diesis
	 *     - bemolle
	 *     - -is
	 *     - -es
	 * - octave naming:
	 *     - +n/-n
	 *     - +/-
	 *     - international
	 *     - german
	 */
	@Test
	public void testOctaveSystemsAutomated() {
		
		StringBuilder noteNames    = new StringBuilder("");
		StringBuilder altNoteNames = new StringBuilder("");
		
		// note system
		for (int i = 0; i < 6; i++) {
			cbxs[1].setSelectedIndex(i);
			
			// half tone
			for (int j = 0; j < 3; j++) {
				cbxs[2].setSelectedIndex(j);
				
				// sharp/flat
				for (int k = 0; k < 2; k++) {
					cbxs[3].setSelectedIndex(k);
					
					// octave naming
					for (int l = 0; l < 4; l++) {
						cbxs[4].setSelectedIndex(l);
						
						String configHeader = Config.get(Config.NOTE) + "/"
							+ Config.get(Config.HALF_TONE) + "/"
							+ Config.get(Config.SHARP_FLAT) + "/"
							+ Config.get(Config.OCTAVE) + ":\n";
						
						noteNames.append(configHeader);
						altNoteNames.append(configHeader);
						for (int num = 0; num < 128; num++) {
							if (num > 0) {
								noteNames.append(",");
								altNoteNames.append(",");
							}
							noteNames.append(Dict.getNote(num));
							altNoteNames.append(Dict.getNoteAlternatives(num));
						}
						noteNames.append("\n");
						altNoteNames.append("\n");
					}
				}
			}
		}
		
		assertEquals(
			"cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,c#-5,d-5,d#-5,e-5,f-5,f#-5,g-5,g#-5,a-5,a#-5,b-5,c-4,c#-4,d-4,d#-4,e-4,f-4,f#-4,g-4,g#-4,a-4,a#-4,b-4,c-3,c#-3,d-3,d#-3,e-3,f-3,f#-3,g-3,g#-3,a-3,a#-3,b-3,c-2,c#-2,d-2,d#-2,e-2,f-2,f#-2,g-2,g#-2,a-2,a#-2,b-2,c-,c#-,d-,d#-,e-,f-,f#-,g-,g#-,a-,a#-,b-,c,c#,d,d#,e,f,f#,g,g#,a,a#,b,c+,c#+,d+,d#+,e+,f+,f#+,g+,g#+,a+,a#+,b+,c+2,c#+2,d+2,d#+2,e+2,f+2,f#+2,g+2,g#+2,a+2,a#+2,b+2,c+3,c#+3,d+3,d#+3,e+3,f+3,f#+3,g+3,g#+3,a+3,a#+3,b+3,c+4,c#+4,d+4,d#+4,e+4,f+4,f#+4,g+4,g#+4,a+4,a#+4,b+4,c+5,c#+5,d+5,d#+5,e+5,f+5,f#+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,c#-----,d-----,d#-----,e-----,f-----,f#-----,g-----,g#-----,a-----,a#-----,b-----,c----,c#----,d----,d#----,e----,f----,f#----,g----,g#----,a----,a#----,b----,c---,c#---,d---,d#---,e---,f---,f#---,g---,g#---,a---,a#---,b---,c--,c#--,d--,d#--,e--,f--,f#--,g--,g#--,a--,a#--,b--,c-,c#-,d-,d#-,e-,f-,f#-,g-,g#-,a-,a#-,b-,c,c#,d,d#,e,f,f#,g,g#,a,a#,b,c+,c#+,d+,d#+,e+,f+,f#+,g+,g#+,a+,a#+,b+,c++,c#++,d++,d#++,e++,f++,f#++,g++,g#++,a++,a#++,b++,c+++,c#+++,d+++,d#+++,e+++,f+++,f#+++,g+++,g#+++,a+++,a#+++,b+++,c++++,c#++++,d++++,d#++++,e++++,f++++,f#++++,g++++,g#++++,a++++,a#++++,b++++,c+++++,c#+++++,d+++++,d#+++++,e+++++,f+++++,f#+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,c#-1,d-1,d#-1,e-1,f-1,f#-1,g-1,g#-1,a-1,a#-1,b-1,c0,c#0,d0,d#0,e0,f0,f#0,g0,g#0,a0,a#0,b0,c1,c#1,d1,d#1,e1,f1,f#1,g1,g#1,a1,a#1,b1,c2,c#2,d2,d#2,e2,f2,f#2,g2,g#2,a2,a#2,b2,c3,c#3,d3,d#3,e3,f3,f#3,g3,g#3,a3,a#3,b3,c4,c#4,d4,d#4,e4,f4,f#4,g4,g#4,a4,a#4,b4,c5,c#5,d5,d#5,e5,f5,f#5,g5,g#5,a5,a#5,b5,c6,c#6,d6,d#6,e6,f6,f#6,g6,g#6,a6,a#6,b6,c7,c#7,d7,d#7,e7,f7,f#7,g7,g#7,a7,a#7,b7,c8,c#8,d8,d#8,e8,f8,f#8,g8,g#8,a8,a#8,b8,c9,c#9,d9,d#9,e9,f9,f#9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C#''',D''',D#''',E''',F''',F#''',G''',G#''',A''',A#''',B''',C'',C#'',D'',D#'',E'',F'',F#'',G'',G#'',A'',A#'',B'',C',C#',D',D#',E',F',F#',G',G#',A',A#',B',C,C#,D,D#,E,F,F#,G,G#,A,A#,B,c,c#,d,d#,e,f,f#,g,g#,a,a#,b,c',c#',d',d#',e',f',f#',g',g#',a',a#',b',c'',c#'',d'',d#'',e'',f'',f#'',g'',g#'',a'',a#'',b'',c''',c#''',d''',d#''',e''',f''',f#''',g''',g#''',a''',a#''',b''',c'''',c#'''',d'''',d#'''',e'''',f'''',f#'''',g'''',g#'''',a'''',a#'''',b'''',c''''',c#''''',d''''',d#''''',e''''',f''''',f#''''',g''''',g#''''',a''''',a#''''',b''''',c'''''',c#'''''',d'''''',d#'''''',e'''''',f'''''',f#'''''',g''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,db-5,d-5,eb-5,e-5,f-5,gb-5,g-5,ab-5,a-5,bb-5,b-5,c-4,db-4,d-4,eb-4,e-4,f-4,gb-4,g-4,ab-4,a-4,bb-4,b-4,c-3,db-3,d-3,eb-3,e-3,f-3,gb-3,g-3,ab-3,a-3,bb-3,b-3,c-2,db-2,d-2,eb-2,e-2,f-2,gb-2,g-2,ab-2,a-2,bb-2,b-2,c-,db-,d-,eb-,e-,f-,gb-,g-,ab-,a-,bb-,b-,c,db,d,eb,e,f,gb,g,ab,a,bb,b,c+,db+,d+,eb+,e+,f+,gb+,g+,ab+,a+,bb+,b+,c+2,db+2,d+2,eb+2,e+2,f+2,gb+2,g+2,ab+2,a+2,bb+2,b+2,c+3,db+3,d+3,eb+3,e+3,f+3,gb+3,g+3,ab+3,a+3,bb+3,b+3,c+4,db+4,d+4,eb+4,e+4,f+4,gb+4,g+4,ab+4,a+4,bb+4,b+4,c+5,db+5,d+5,eb+5,e+5,f+5,gb+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,db-----,d-----,eb-----,e-----,f-----,gb-----,g-----,ab-----,a-----,bb-----,b-----,c----,db----,d----,eb----,e----,f----,gb----,g----,ab----,a----,bb----,b----,c---,db---,d---,eb---,e---,f---,gb---,g---,ab---,a---,bb---,b---,c--,db--,d--,eb--,e--,f--,gb--,g--,ab--,a--,bb--,b--,c-,db-,d-,eb-,e-,f-,gb-,g-,ab-,a-,bb-,b-,c,db,d,eb,e,f,gb,g,ab,a,bb,b,c+,db+,d+,eb+,e+,f+,gb+,g+,ab+,a+,bb+,b+,c++,db++,d++,eb++,e++,f++,gb++,g++,ab++,a++,bb++,b++,c+++,db+++,d+++,eb+++,e+++,f+++,gb+++,g+++,ab+++,a+++,bb+++,b+++,c++++,db++++,d++++,eb++++,e++++,f++++,gb++++,g++++,ab++++,a++++,bb++++,b++++,c+++++,db+++++,d+++++,eb+++++,e+++++,f+++++,gb+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,db-1,d-1,eb-1,e-1,f-1,gb-1,g-1,ab-1,a-1,bb-1,b-1,c0,db0,d0,eb0,e0,f0,gb0,g0,ab0,a0,bb0,b0,c1,db1,d1,eb1,e1,f1,gb1,g1,ab1,a1,bb1,b1,c2,db2,d2,eb2,e2,f2,gb2,g2,ab2,a2,bb2,b2,c3,db3,d3,eb3,e3,f3,gb3,g3,ab3,a3,bb3,b3,c4,db4,d4,eb4,e4,f4,gb4,g4,ab4,a4,bb4,b4,c5,db5,d5,eb5,e5,f5,gb5,g5,ab5,a5,bb5,b5,c6,db6,d6,eb6,e6,f6,gb6,g6,ab6,a6,bb6,b6,c7,db7,d7,eb7,e7,f7,gb7,g7,ab7,a7,bb7,b7,c8,db8,d8,eb8,e8,f8,gb8,g8,ab8,a8,bb8,b8,c9,db9,d9,eb9,e9,f9,gb9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Db''',D''',Eb''',E''',F''',Gb''',G''',Ab''',A''',Bb''',B''',C'',Db'',D'',Eb'',E'',F'',Gb'',G'',Ab'',A'',Bb'',B'',C',Db',D',Eb',E',F',Gb',G',Ab',A',Bb',B',C,Db,D,Eb,E,F,Gb,G,Ab,A,Bb,B,c,db,d,eb,e,f,gb,g,ab,a,bb,b,c',db',d',eb',e',f',gb',g',ab',a',bb',b',c'',db'',d'',eb'',e'',f'',gb'',g'',ab'',a'',bb'',b'',c''',db''',d''',eb''',e''',f''',gb''',g''',ab''',a''',bb''',b''',c'''',db'''',d'''',eb'''',e'''',f'''',gb'''',g'''',ab'''',a'''',bb'''',b'''',c''''',db''''',d''''',eb''''',e''''',f''''',gb''''',g''''',ab''''',a''''',bb''''',b''''',c'''''',db'''''',d'''''',eb'''''',e'''''',f'''''',gb'''''',g''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,c-diesis-5,d-5,d-diesis-5,e-5,f-5,f-diesis-5,g-5,g-diesis-5,a-5,a-diesis-5,b-5,c-4,c-diesis-4,d-4,d-diesis-4,e-4,f-4,f-diesis-4,g-4,g-diesis-4,a-4,a-diesis-4,b-4,c-3,c-diesis-3,d-3,d-diesis-3,e-3,f-3,f-diesis-3,g-3,g-diesis-3,a-3,a-diesis-3,b-3,c-2,c-diesis-2,d-2,d-diesis-2,e-2,f-2,f-diesis-2,g-2,g-diesis-2,a-2,a-diesis-2,b-2,c-,c-diesis-,d-,d-diesis-,e-,f-,f-diesis-,g-,g-diesis-,a-,a-diesis-,b-,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,a-diesis,b,c+,c-diesis+,d+,d-diesis+,e+,f+,f-diesis+,g+,g-diesis+,a+,a-diesis+,b+,c+2,c-diesis+2,d+2,d-diesis+2,e+2,f+2,f-diesis+2,g+2,g-diesis+2,a+2,a-diesis+2,b+2,c+3,c-diesis+3,d+3,d-diesis+3,e+3,f+3,f-diesis+3,g+3,g-diesis+3,a+3,a-diesis+3,b+3,c+4,c-diesis+4,d+4,d-diesis+4,e+4,f+4,f-diesis+4,g+4,g-diesis+4,a+4,a-diesis+4,b+4,c+5,c-diesis+5,d+5,d-diesis+5,e+5,f+5,f-diesis+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,c-diesis-----,d-----,d-diesis-----,e-----,f-----,f-diesis-----,g-----,g-diesis-----,a-----,a-diesis-----,b-----,c----,c-diesis----,d----,d-diesis----,e----,f----,f-diesis----,g----,g-diesis----,a----,a-diesis----,b----,c---,c-diesis---,d---,d-diesis---,e---,f---,f-diesis---,g---,g-diesis---,a---,a-diesis---,b---,c--,c-diesis--,d--,d-diesis--,e--,f--,f-diesis--,g--,g-diesis--,a--,a-diesis--,b--,c-,c-diesis-,d-,d-diesis-,e-,f-,f-diesis-,g-,g-diesis-,a-,a-diesis-,b-,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,a-diesis,b,c+,c-diesis+,d+,d-diesis+,e+,f+,f-diesis+,g+,g-diesis+,a+,a-diesis+,b+,c++,c-diesis++,d++,d-diesis++,e++,f++,f-diesis++,g++,g-diesis++,a++,a-diesis++,b++,c+++,c-diesis+++,d+++,d-diesis+++,e+++,f+++,f-diesis+++,g+++,g-diesis+++,a+++,a-diesis+++,b+++,c++++,c-diesis++++,d++++,d-diesis++++,e++++,f++++,f-diesis++++,g++++,g-diesis++++,a++++,a-diesis++++,b++++,c+++++,c-diesis+++++,d+++++,d-diesis+++++,e+++++,f+++++,f-diesis+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,c-diesis-1,d-1,d-diesis-1,e-1,f-1,f-diesis-1,g-1,g-diesis-1,a-1,a-diesis-1,b-1,c0,c-diesis0,d0,d-diesis0,e0,f0,f-diesis0,g0,g-diesis0,a0,a-diesis0,b0,c1,c-diesis1,d1,d-diesis1,e1,f1,f-diesis1,g1,g-diesis1,a1,a-diesis1,b1,c2,c-diesis2,d2,d-diesis2,e2,f2,f-diesis2,g2,g-diesis2,a2,a-diesis2,b2,c3,c-diesis3,d3,d-diesis3,e3,f3,f-diesis3,g3,g-diesis3,a3,a-diesis3,b3,c4,c-diesis4,d4,d-diesis4,e4,f4,f-diesis4,g4,g-diesis4,a4,a-diesis4,b4,c5,c-diesis5,d5,d-diesis5,e5,f5,f-diesis5,g5,g-diesis5,a5,a-diesis5,b5,c6,c-diesis6,d6,d-diesis6,e6,f6,f-diesis6,g6,g-diesis6,a6,a-diesis6,b6,c7,c-diesis7,d7,d-diesis7,e7,f7,f-diesis7,g7,g-diesis7,a7,a-diesis7,b7,c8,c-diesis8,d8,d-diesis8,e8,f8,f-diesis8,g8,g-diesis8,a8,a-diesis8,b8,c9,c-diesis9,d9,d-diesis9,e9,f9,f-diesis9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C-diesis''',D''',D-diesis''',E''',F''',F-diesis''',G''',G-diesis''',A''',A-diesis''',B''',C'',C-diesis'',D'',D-diesis'',E'',F'',F-diesis'',G'',G-diesis'',A'',A-diesis'',B'',C',C-diesis',D',D-diesis',E',F',F-diesis',G',G-diesis',A',A-diesis',B',C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,A-diesis,B,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,a-diesis,b,c',c-diesis',d',d-diesis',e',f',f-diesis',g',g-diesis',a',a-diesis',b',c'',c-diesis'',d'',d-diesis'',e'',f'',f-diesis'',g'',g-diesis'',a'',a-diesis'',b'',c''',c-diesis''',d''',d-diesis''',e''',f''',f-diesis''',g''',g-diesis''',a''',a-diesis''',b''',c'''',c-diesis'''',d'''',d-diesis'''',e'''',f'''',f-diesis'''',g'''',g-diesis'''',a'''',a-diesis'''',b'''',c''''',c-diesis''''',d''''',d-diesis''''',e''''',f''''',f-diesis''''',g''''',g-diesis''''',a''''',a-diesis''''',b''''',c'''''',c-diesis'''''',d'''''',d-diesis'''''',e'''''',f'''''',f-diesis'''''',g''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,d-bemolle-5,d-5,e-bemolle-5,e-5,f-5,g-bemolle-5,g-5,a-bemolle-5,a-5,b-bemolle-5,b-5,c-4,d-bemolle-4,d-4,e-bemolle-4,e-4,f-4,g-bemolle-4,g-4,a-bemolle-4,a-4,b-bemolle-4,b-4,c-3,d-bemolle-3,d-3,e-bemolle-3,e-3,f-3,g-bemolle-3,g-3,a-bemolle-3,a-3,b-bemolle-3,b-3,c-2,d-bemolle-2,d-2,e-bemolle-2,e-2,f-2,g-bemolle-2,g-2,a-bemolle-2,a-2,b-bemolle-2,b-2,c-,d-bemolle-,d-,e-bemolle-,e-,f-,g-bemolle-,g-,a-bemolle-,a-,b-bemolle-,b-,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b-bemolle,b,c+,d-bemolle+,d+,e-bemolle+,e+,f+,g-bemolle+,g+,a-bemolle+,a+,b-bemolle+,b+,c+2,d-bemolle+2,d+2,e-bemolle+2,e+2,f+2,g-bemolle+2,g+2,a-bemolle+2,a+2,b-bemolle+2,b+2,c+3,d-bemolle+3,d+3,e-bemolle+3,e+3,f+3,g-bemolle+3,g+3,a-bemolle+3,a+3,b-bemolle+3,b+3,c+4,d-bemolle+4,d+4,e-bemolle+4,e+4,f+4,g-bemolle+4,g+4,a-bemolle+4,a+4,b-bemolle+4,b+4,c+5,d-bemolle+5,d+5,e-bemolle+5,e+5,f+5,g-bemolle+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,d-bemolle-----,d-----,e-bemolle-----,e-----,f-----,g-bemolle-----,g-----,a-bemolle-----,a-----,b-bemolle-----,b-----,c----,d-bemolle----,d----,e-bemolle----,e----,f----,g-bemolle----,g----,a-bemolle----,a----,b-bemolle----,b----,c---,d-bemolle---,d---,e-bemolle---,e---,f---,g-bemolle---,g---,a-bemolle---,a---,b-bemolle---,b---,c--,d-bemolle--,d--,e-bemolle--,e--,f--,g-bemolle--,g--,a-bemolle--,a--,b-bemolle--,b--,c-,d-bemolle-,d-,e-bemolle-,e-,f-,g-bemolle-,g-,a-bemolle-,a-,b-bemolle-,b-,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b-bemolle,b,c+,d-bemolle+,d+,e-bemolle+,e+,f+,g-bemolle+,g+,a-bemolle+,a+,b-bemolle+,b+,c++,d-bemolle++,d++,e-bemolle++,e++,f++,g-bemolle++,g++,a-bemolle++,a++,b-bemolle++,b++,c+++,d-bemolle+++,d+++,e-bemolle+++,e+++,f+++,g-bemolle+++,g+++,a-bemolle+++,a+++,b-bemolle+++,b+++,c++++,d-bemolle++++,d++++,e-bemolle++++,e++++,f++++,g-bemolle++++,g++++,a-bemolle++++,a++++,b-bemolle++++,b++++,c+++++,d-bemolle+++++,d+++++,e-bemolle+++++,e+++++,f+++++,g-bemolle+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,d-bemolle-1,d-1,e-bemolle-1,e-1,f-1,g-bemolle-1,g-1,a-bemolle-1,a-1,b-bemolle-1,b-1,c0,d-bemolle0,d0,e-bemolle0,e0,f0,g-bemolle0,g0,a-bemolle0,a0,b-bemolle0,b0,c1,d-bemolle1,d1,e-bemolle1,e1,f1,g-bemolle1,g1,a-bemolle1,a1,b-bemolle1,b1,c2,d-bemolle2,d2,e-bemolle2,e2,f2,g-bemolle2,g2,a-bemolle2,a2,b-bemolle2,b2,c3,d-bemolle3,d3,e-bemolle3,e3,f3,g-bemolle3,g3,a-bemolle3,a3,b-bemolle3,b3,c4,d-bemolle4,d4,e-bemolle4,e4,f4,g-bemolle4,g4,a-bemolle4,a4,b-bemolle4,b4,c5,d-bemolle5,d5,e-bemolle5,e5,f5,g-bemolle5,g5,a-bemolle5,a5,b-bemolle5,b5,c6,d-bemolle6,d6,e-bemolle6,e6,f6,g-bemolle6,g6,a-bemolle6,a6,b-bemolle6,b6,c7,d-bemolle7,d7,e-bemolle7,e7,f7,g-bemolle7,g7,a-bemolle7,a7,b-bemolle7,b7,c8,d-bemolle8,d8,e-bemolle8,e8,f8,g-bemolle8,g8,a-bemolle8,a8,b-bemolle8,b8,c9,d-bemolle9,d9,e-bemolle9,e9,f9,g-bemolle9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',D-bemolle''',D''',E-bemolle''',E''',F''',G-bemolle''',G''',A-bemolle''',A''',B-bemolle''',B''',C'',D-bemolle'',D'',E-bemolle'',E'',F'',G-bemolle'',G'',A-bemolle'',A'',B-bemolle'',B'',C',D-bemolle',D',E-bemolle',E',F',G-bemolle',G',A-bemolle',A',B-bemolle',B',C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B-bemolle,B,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b-bemolle,b,c',d-bemolle',d',e-bemolle',e',f',g-bemolle',g',a-bemolle',a',b-bemolle',b',c'',d-bemolle'',d'',e-bemolle'',e'',f'',g-bemolle'',g'',a-bemolle'',a'',b-bemolle'',b'',c''',d-bemolle''',d''',e-bemolle''',e''',f''',g-bemolle''',g''',a-bemolle''',a''',b-bemolle''',b''',c'''',d-bemolle'''',d'''',e-bemolle'''',e'''',f'''',g-bemolle'''',g'''',a-bemolle'''',a'''',b-bemolle'''',b'''',c''''',d-bemolle''''',d''''',e-bemolle''''',e''''',f''''',g-bemolle''''',g''''',a-bemolle''''',a''''',b-bemolle''''',b''''',c'''''',d-bemolle'''''',d'''''',e-bemolle'''''',e'''''',f'''''',g-bemolle'''''',g''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,cis-5,d-5,dis-5,e-5,f-5,fis-5,g-5,gis-5,a-5,ais-5,b-5,c-4,cis-4,d-4,dis-4,e-4,f-4,fis-4,g-4,gis-4,a-4,ais-4,b-4,c-3,cis-3,d-3,dis-3,e-3,f-3,fis-3,g-3,gis-3,a-3,ais-3,b-3,c-2,cis-2,d-2,dis-2,e-2,f-2,fis-2,g-2,gis-2,a-2,ais-2,b-2,c-,cis-,d-,dis-,e-,f-,fis-,g-,gis-,a-,ais-,b-,c,cis,d,dis,e,f,fis,g,gis,a,ais,b,c+,cis+,d+,dis+,e+,f+,fis+,g+,gis+,a+,ais+,b+,c+2,cis+2,d+2,dis+2,e+2,f+2,fis+2,g+2,gis+2,a+2,ais+2,b+2,c+3,cis+3,d+3,dis+3,e+3,f+3,fis+3,g+3,gis+3,a+3,ais+3,b+3,c+4,cis+4,d+4,dis+4,e+4,f+4,fis+4,g+4,gis+4,a+4,ais+4,b+4,c+5,cis+5,d+5,dis+5,e+5,f+5,fis+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,cis-----,d-----,dis-----,e-----,f-----,fis-----,g-----,gis-----,a-----,ais-----,b-----,c----,cis----,d----,dis----,e----,f----,fis----,g----,gis----,a----,ais----,b----,c---,cis---,d---,dis---,e---,f---,fis---,g---,gis---,a---,ais---,b---,c--,cis--,d--,dis--,e--,f--,fis--,g--,gis--,a--,ais--,b--,c-,cis-,d-,dis-,e-,f-,fis-,g-,gis-,a-,ais-,b-,c,cis,d,dis,e,f,fis,g,gis,a,ais,b,c+,cis+,d+,dis+,e+,f+,fis+,g+,gis+,a+,ais+,b+,c++,cis++,d++,dis++,e++,f++,fis++,g++,gis++,a++,ais++,b++,c+++,cis+++,d+++,dis+++,e+++,f+++,fis+++,g+++,gis+++,a+++,ais+++,b+++,c++++,cis++++,d++++,dis++++,e++++,f++++,fis++++,g++++,gis++++,a++++,ais++++,b++++,c+++++,cis+++++,d+++++,dis+++++,e+++++,f+++++,fis+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,cis-1,d-1,dis-1,e-1,f-1,fis-1,g-1,gis-1,a-1,ais-1,b-1,c0,cis0,d0,dis0,e0,f0,fis0,g0,gis0,a0,ais0,b0,c1,cis1,d1,dis1,e1,f1,fis1,g1,gis1,a1,ais1,b1,c2,cis2,d2,dis2,e2,f2,fis2,g2,gis2,a2,ais2,b2,c3,cis3,d3,dis3,e3,f3,fis3,g3,gis3,a3,ais3,b3,c4,cis4,d4,dis4,e4,f4,fis4,g4,gis4,a4,ais4,b4,c5,cis5,d5,dis5,e5,f5,fis5,g5,gis5,a5,ais5,b5,c6,cis6,d6,dis6,e6,f6,fis6,g6,gis6,a6,ais6,b6,c7,cis7,d7,dis7,e7,f7,fis7,g7,gis7,a7,ais7,b7,c8,cis8,d8,dis8,e8,f8,fis8,g8,gis8,a8,ais8,b8,c9,cis9,d9,dis9,e9,f9,fis9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',Cis''',D''',Dis''',E''',F''',Fis''',G''',Gis''',A''',Ais''',B''',C'',Cis'',D'',Dis'',E'',F'',Fis'',G'',Gis'',A'',Ais'',B'',C',Cis',D',Dis',E',F',Fis',G',Gis',A',Ais',B',C,Cis,D,Dis,E,F,Fis,G,Gis,A,Ais,B,c,cis,d,dis,e,f,fis,g,gis,a,ais,b,c',cis',d',dis',e',f',fis',g',gis',a',ais',b',c'',cis'',d'',dis'',e'',f'',fis'',g'',gis'',a'',ais'',b'',c''',cis''',d''',dis''',e''',f''',fis''',g''',gis''',a''',ais''',b''',c'''',cis'''',d'''',dis'''',e'''',f'''',fis'''',g'''',gis'''',a'''',ais'''',b'''',c''''',cis''''',d''''',dis''''',e''''',f''''',fis''''',g''''',gis''''',a''''',ais''''',b''''',c'''''',cis'''''',d'''''',dis'''''',e'''''',f'''''',fis'''''',g''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,des-5,d-5,es-5,e-5,f-5,ges-5,g-5,as-5,a-5,bes-5,b-5,c-4,des-4,d-4,es-4,e-4,f-4,ges-4,g-4,as-4,a-4,bes-4,b-4,c-3,des-3,d-3,es-3,e-3,f-3,ges-3,g-3,as-3,a-3,bes-3,b-3,c-2,des-2,d-2,es-2,e-2,f-2,ges-2,g-2,as-2,a-2,bes-2,b-2,c-,des-,d-,es-,e-,f-,ges-,g-,as-,a-,bes-,b-,c,des,d,es,e,f,ges,g,as,a,bes,b,c+,des+,d+,es+,e+,f+,ges+,g+,as+,a+,bes+,b+,c+2,des+2,d+2,es+2,e+2,f+2,ges+2,g+2,as+2,a+2,bes+2,b+2,c+3,des+3,d+3,es+3,e+3,f+3,ges+3,g+3,as+3,a+3,bes+3,b+3,c+4,des+4,d+4,es+4,e+4,f+4,ges+4,g+4,as+4,a+4,bes+4,b+4,c+5,des+5,d+5,es+5,e+5,f+5,ges+5,g+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,des-----,d-----,es-----,e-----,f-----,ges-----,g-----,as-----,a-----,bes-----,b-----,c----,des----,d----,es----,e----,f----,ges----,g----,as----,a----,bes----,b----,c---,des---,d---,es---,e---,f---,ges---,g---,as---,a---,bes---,b---,c--,des--,d--,es--,e--,f--,ges--,g--,as--,a--,bes--,b--,c-,des-,d-,es-,e-,f-,ges-,g-,as-,a-,bes-,b-,c,des,d,es,e,f,ges,g,as,a,bes,b,c+,des+,d+,es+,e+,f+,ges+,g+,as+,a+,bes+,b+,c++,des++,d++,es++,e++,f++,ges++,g++,as++,a++,bes++,b++,c+++,des+++,d+++,es+++,e+++,f+++,ges+++,g+++,as+++,a+++,bes+++,b+++,c++++,des++++,d++++,es++++,e++++,f++++,ges++++,g++++,as++++,a++++,bes++++,b++++,c+++++,des+++++,d+++++,es+++++,e+++++,f+++++,ges+++++,g+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,des-1,d-1,es-1,e-1,f-1,ges-1,g-1,as-1,a-1,bes-1,b-1,c0,des0,d0,es0,e0,f0,ges0,g0,as0,a0,bes0,b0,c1,des1,d1,es1,e1,f1,ges1,g1,as1,a1,bes1,b1,c2,des2,d2,es2,e2,f2,ges2,g2,as2,a2,bes2,b2,c3,des3,d3,es3,e3,f3,ges3,g3,as3,a3,bes3,b3,c4,des4,d4,es4,e4,f4,ges4,g4,as4,a4,bes4,b4,c5,des5,d5,es5,e5,f5,ges5,g5,as5,a5,bes5,b5,c6,des6,d6,es6,e6,f6,ges6,g6,as6,a6,bes6,b6,c7,des7,d7,es7,e7,f7,ges7,g7,as7,a7,bes7,b7,c8,des8,d8,es8,e8,f8,ges8,g8,as8,a8,bes8,b8,c9,des9,d9,es9,e9,f9,ges9,g9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Des''',D''',Es''',E''',F''',Ges''',G''',As''',A''',Bes''',B''',C'',Des'',D'',Es'',E'',F'',Ges'',G'',As'',A'',Bes'',B'',C',Des',D',Es',E',F',Ges',G',As',A',Bes',B',C,Des,D,Es,E,F,Ges,G,As,A,Bes,B,c,des,d,es,e,f,ges,g,as,a,bes,b,c',des',d',es',e',f',ges',g',as',a',bes',b',c'',des'',d'',es'',e'',f'',ges'',g'',as'',a'',bes'',b'',c''',des''',d''',es''',e''',f''',ges''',g''',as''',a''',bes''',b''',c'''',des'''',d'''',es'''',e'''',f'''',ges'''',g'''',as'''',a'''',bes'''',b'''',c''''',des''''',d''''',es''''',e''''',f''''',ges''''',g''''',as''''',a''''',bes''''',b''''',c'''''',des'''''',d'''''',es'''''',e'''''',f'''''',ges'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,C#-5,D-5,D#-5,E-5,F-5,F#-5,G-5,G#-5,A-5,A#-5,B-5,C-4,C#-4,D-4,D#-4,E-4,F-4,F#-4,G-4,G#-4,A-4,A#-4,B-4,C-3,C#-3,D-3,D#-3,E-3,F-3,F#-3,G-3,G#-3,A-3,A#-3,B-3,C-2,C#-2,D-2,D#-2,E-2,F-2,F#-2,G-2,G#-2,A-2,A#-2,B-2,C-,C#-,D-,D#-,E-,F-,F#-,G-,G#-,A-,A#-,B-,C,C#,D,D#,E,F,F#,G,G#,A,A#,B,C+,C#+,D+,D#+,E+,F+,F#+,G+,G#+,A+,A#+,B+,C+2,C#+2,D+2,D#+2,E+2,F+2,F#+2,G+2,G#+2,A+2,A#+2,B+2,C+3,C#+3,D+3,D#+3,E+3,F+3,F#+3,G+3,G#+3,A+3,A#+3,B+3,C+4,C#+4,D+4,D#+4,E+4,F+4,F#+4,G+4,G#+4,A+4,A#+4,B+4,C+5,C#+5,D+5,D#+5,E+5,F+5,F#+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,C#-----,D-----,D#-----,E-----,F-----,F#-----,G-----,G#-----,A-----,A#-----,B-----,C----,C#----,D----,D#----,E----,F----,F#----,G----,G#----,A----,A#----,B----,C---,C#---,D---,D#---,E---,F---,F#---,G---,G#---,A---,A#---,B---,C--,C#--,D--,D#--,E--,F--,F#--,G--,G#--,A--,A#--,B--,C-,C#-,D-,D#-,E-,F-,F#-,G-,G#-,A-,A#-,B-,C,C#,D,D#,E,F,F#,G,G#,A,A#,B,C+,C#+,D+,D#+,E+,F+,F#+,G+,G#+,A+,A#+,B+,C++,C#++,D++,D#++,E++,F++,F#++,G++,G#++,A++,A#++,B++,C+++,C#+++,D+++,D#+++,E+++,F+++,F#+++,G+++,G#+++,A+++,A#+++,B+++,C++++,C#++++,D++++,D#++++,E++++,F++++,F#++++,G++++,G#++++,A++++,A#++++,B++++,C+++++,C#+++++,D+++++,D#+++++,E+++++,F+++++,F#+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,C#-1,D-1,D#-1,E-1,F-1,F#-1,G-1,G#-1,A-1,A#-1,B-1,C0,C#0,D0,D#0,E0,F0,F#0,G0,G#0,A0,A#0,B0,C1,C#1,D1,D#1,E1,F1,F#1,G1,G#1,A1,A#1,B1,C2,C#2,D2,D#2,E2,F2,F#2,G2,G#2,A2,A#2,B2,C3,C#3,D3,D#3,E3,F3,F#3,G3,G#3,A3,A#3,B3,C4,C#4,D4,D#4,E4,F4,F#4,G4,G#4,A4,A#4,B4,C5,C#5,D5,D#5,E5,F5,F#5,G5,G#5,A5,A#5,B5,C6,C#6,D6,D#6,E6,F6,F#6,G6,G#6,A6,A#6,B6,C7,C#7,D7,D#7,E7,F7,F#7,G7,G#7,A7,A#7,B7,C8,C#8,D8,D#8,E8,F8,F#8,G8,G#8,A8,A#8,B8,C9,C#9,D9,D#9,E9,F9,F#9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C#''',D''',D#''',E''',F''',F#''',G''',G#''',A''',A#''',B''',C'',C#'',D'',D#'',E'',F'',F#'',G'',G#'',A'',A#'',B'',C',C#',D',D#',E',F',F#',G',G#',A',A#',B',C,C#,D,D#,E,F,F#,G,G#,A,A#,B,c,c#,d,d#,e,f,f#,g,g#,a,a#,b,c',c#',d',d#',e',f',f#',g',g#',a',a#',b',c'',c#'',d'',d#'',e'',f'',f#'',g'',g#'',a'',a#'',b'',c''',c#''',d''',d#''',e''',f''',f#''',g''',g#''',a''',a#''',b''',c'''',c#'''',d'''',d#'''',e'''',f'''',f#'''',g'''',g#'''',a'''',a#'''',b'''',c''''',c#''''',d''''',d#''''',e''''',f''''',f#''''',g''''',g#''''',a''''',a#''''',b''''',c'''''',c#'''''',d'''''',d#'''''',e'''''',f'''''',f#'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,Db-5,D-5,Eb-5,E-5,F-5,Gb-5,G-5,Ab-5,A-5,Bb-5,B-5,C-4,Db-4,D-4,Eb-4,E-4,F-4,Gb-4,G-4,Ab-4,A-4,Bb-4,B-4,C-3,Db-3,D-3,Eb-3,E-3,F-3,Gb-3,G-3,Ab-3,A-3,Bb-3,B-3,C-2,Db-2,D-2,Eb-2,E-2,F-2,Gb-2,G-2,Ab-2,A-2,Bb-2,B-2,C-,Db-,D-,Eb-,E-,F-,Gb-,G-,Ab-,A-,Bb-,B-,C,Db,D,Eb,E,F,Gb,G,Ab,A,Bb,B,C+,Db+,D+,Eb+,E+,F+,Gb+,G+,Ab+,A+,Bb+,B+,C+2,Db+2,D+2,Eb+2,E+2,F+2,Gb+2,G+2,Ab+2,A+2,Bb+2,B+2,C+3,Db+3,D+3,Eb+3,E+3,F+3,Gb+3,G+3,Ab+3,A+3,Bb+3,B+3,C+4,Db+4,D+4,Eb+4,E+4,F+4,Gb+4,G+4,Ab+4,A+4,Bb+4,B+4,C+5,Db+5,D+5,Eb+5,E+5,F+5,Gb+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,Db-----,D-----,Eb-----,E-----,F-----,Gb-----,G-----,Ab-----,A-----,Bb-----,B-----,C----,Db----,D----,Eb----,E----,F----,Gb----,G----,Ab----,A----,Bb----,B----,C---,Db---,D---,Eb---,E---,F---,Gb---,G---,Ab---,A---,Bb---,B---,C--,Db--,D--,Eb--,E--,F--,Gb--,G--,Ab--,A--,Bb--,B--,C-,Db-,D-,Eb-,E-,F-,Gb-,G-,Ab-,A-,Bb-,B-,C,Db,D,Eb,E,F,Gb,G,Ab,A,Bb,B,C+,Db+,D+,Eb+,E+,F+,Gb+,G+,Ab+,A+,Bb+,B+,C++,Db++,D++,Eb++,E++,F++,Gb++,G++,Ab++,A++,Bb++,B++,C+++,Db+++,D+++,Eb+++,E+++,F+++,Gb+++,G+++,Ab+++,A+++,Bb+++,B+++,C++++,Db++++,D++++,Eb++++,E++++,F++++,Gb++++,G++++,Ab++++,A++++,Bb++++,B++++,C+++++,Db+++++,D+++++,Eb+++++,E+++++,F+++++,Gb+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,Db-1,D-1,Eb-1,E-1,F-1,Gb-1,G-1,Ab-1,A-1,Bb-1,B-1,C0,Db0,D0,Eb0,E0,F0,Gb0,G0,Ab0,A0,Bb0,B0,C1,Db1,D1,Eb1,E1,F1,Gb1,G1,Ab1,A1,Bb1,B1,C2,Db2,D2,Eb2,E2,F2,Gb2,G2,Ab2,A2,Bb2,B2,C3,Db3,D3,Eb3,E3,F3,Gb3,G3,Ab3,A3,Bb3,B3,C4,Db4,D4,Eb4,E4,F4,Gb4,G4,Ab4,A4,Bb4,B4,C5,Db5,D5,Eb5,E5,F5,Gb5,G5,Ab5,A5,Bb5,B5,C6,Db6,D6,Eb6,E6,F6,Gb6,G6,Ab6,A6,Bb6,B6,C7,Db7,D7,Eb7,E7,F7,Gb7,G7,Ab7,A7,Bb7,B7,C8,Db8,D8,Eb8,E8,F8,Gb8,G8,Ab8,A8,Bb8,B8,C9,Db9,D9,Eb9,E9,F9,Gb9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Db''',D''',Eb''',E''',F''',Gb''',G''',Ab''',A''',Bb''',B''',C'',Db'',D'',Eb'',E'',F'',Gb'',G'',Ab'',A'',Bb'',B'',C',Db',D',Eb',E',F',Gb',G',Ab',A',Bb',B',C,Db,D,Eb,E,F,Gb,G,Ab,A,Bb,B,c,db,d,eb,e,f,gb,g,ab,a,bb,b,c',db',d',eb',e',f',gb',g',ab',a',bb',b',c'',db'',d'',eb'',e'',f'',gb'',g'',ab'',a'',bb'',b'',c''',db''',d''',eb''',e''',f''',gb''',g''',ab''',a''',bb''',b''',c'''',db'''',d'''',eb'''',e'''',f'''',gb'''',g'''',ab'''',a'''',bb'''',b'''',c''''',db''''',d''''',eb''''',e''''',f''''',gb''''',g''''',ab''''',a''''',bb''''',b''''',c'''''',db'''''',d'''''',eb'''''',e'''''',f'''''',gb'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,C-diesis-5,D-5,D-diesis-5,E-5,F-5,F-diesis-5,G-5,G-diesis-5,A-5,A-diesis-5,B-5,C-4,C-diesis-4,D-4,D-diesis-4,E-4,F-4,F-diesis-4,G-4,G-diesis-4,A-4,A-diesis-4,B-4,C-3,C-diesis-3,D-3,D-diesis-3,E-3,F-3,F-diesis-3,G-3,G-diesis-3,A-3,A-diesis-3,B-3,C-2,C-diesis-2,D-2,D-diesis-2,E-2,F-2,F-diesis-2,G-2,G-diesis-2,A-2,A-diesis-2,B-2,C-,C-diesis-,D-,D-diesis-,E-,F-,F-diesis-,G-,G-diesis-,A-,A-diesis-,B-,C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,A-diesis,B,C+,C-diesis+,D+,D-diesis+,E+,F+,F-diesis+,G+,G-diesis+,A+,A-diesis+,B+,C+2,C-diesis+2,D+2,D-diesis+2,E+2,F+2,F-diesis+2,G+2,G-diesis+2,A+2,A-diesis+2,B+2,C+3,C-diesis+3,D+3,D-diesis+3,E+3,F+3,F-diesis+3,G+3,G-diesis+3,A+3,A-diesis+3,B+3,C+4,C-diesis+4,D+4,D-diesis+4,E+4,F+4,F-diesis+4,G+4,G-diesis+4,A+4,A-diesis+4,B+4,C+5,C-diesis+5,D+5,D-diesis+5,E+5,F+5,F-diesis+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,C-diesis-----,D-----,D-diesis-----,E-----,F-----,F-diesis-----,G-----,G-diesis-----,A-----,A-diesis-----,B-----,C----,C-diesis----,D----,D-diesis----,E----,F----,F-diesis----,G----,G-diesis----,A----,A-diesis----,B----,C---,C-diesis---,D---,D-diesis---,E---,F---,F-diesis---,G---,G-diesis---,A---,A-diesis---,B---,C--,C-diesis--,D--,D-diesis--,E--,F--,F-diesis--,G--,G-diesis--,A--,A-diesis--,B--,C-,C-diesis-,D-,D-diesis-,E-,F-,F-diesis-,G-,G-diesis-,A-,A-diesis-,B-,C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,A-diesis,B,C+,C-diesis+,D+,D-diesis+,E+,F+,F-diesis+,G+,G-diesis+,A+,A-diesis+,B+,C++,C-diesis++,D++,D-diesis++,E++,F++,F-diesis++,G++,G-diesis++,A++,A-diesis++,B++,C+++,C-diesis+++,D+++,D-diesis+++,E+++,F+++,F-diesis+++,G+++,G-diesis+++,A+++,A-diesis+++,B+++,C++++,C-diesis++++,D++++,D-diesis++++,E++++,F++++,F-diesis++++,G++++,G-diesis++++,A++++,A-diesis++++,B++++,C+++++,C-diesis+++++,D+++++,D-diesis+++++,E+++++,F+++++,F-diesis+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,C-diesis-1,D-1,D-diesis-1,E-1,F-1,F-diesis-1,G-1,G-diesis-1,A-1,A-diesis-1,B-1,C0,C-diesis0,D0,D-diesis0,E0,F0,F-diesis0,G0,G-diesis0,A0,A-diesis0,B0,C1,C-diesis1,D1,D-diesis1,E1,F1,F-diesis1,G1,G-diesis1,A1,A-diesis1,B1,C2,C-diesis2,D2,D-diesis2,E2,F2,F-diesis2,G2,G-diesis2,A2,A-diesis2,B2,C3,C-diesis3,D3,D-diesis3,E3,F3,F-diesis3,G3,G-diesis3,A3,A-diesis3,B3,C4,C-diesis4,D4,D-diesis4,E4,F4,F-diesis4,G4,G-diesis4,A4,A-diesis4,B4,C5,C-diesis5,D5,D-diesis5,E5,F5,F-diesis5,G5,G-diesis5,A5,A-diesis5,B5,C6,C-diesis6,D6,D-diesis6,E6,F6,F-diesis6,G6,G-diesis6,A6,A-diesis6,B6,C7,C-diesis7,D7,D-diesis7,E7,F7,F-diesis7,G7,G-diesis7,A7,A-diesis7,B7,C8,C-diesis8,D8,D-diesis8,E8,F8,F-diesis8,G8,G-diesis8,A8,A-diesis8,B8,C9,C-diesis9,D9,D-diesis9,E9,F9,F-diesis9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C-diesis''',D''',D-diesis''',E''',F''',F-diesis''',G''',G-diesis''',A''',A-diesis''',B''',C'',C-diesis'',D'',D-diesis'',E'',F'',F-diesis'',G'',G-diesis'',A'',A-diesis'',B'',C',C-diesis',D',D-diesis',E',F',F-diesis',G',G-diesis',A',A-diesis',B',C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,A-diesis,B,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,a-diesis,b,c',c-diesis',d',d-diesis',e',f',f-diesis',g',g-diesis',a',a-diesis',b',c'',c-diesis'',d'',d-diesis'',e'',f'',f-diesis'',g'',g-diesis'',a'',a-diesis'',b'',c''',c-diesis''',d''',d-diesis''',e''',f''',f-diesis''',g''',g-diesis''',a''',a-diesis''',b''',c'''',c-diesis'''',d'''',d-diesis'''',e'''',f'''',f-diesis'''',g'''',g-diesis'''',a'''',a-diesis'''',b'''',c''''',c-diesis''''',d''''',d-diesis''''',e''''',f''''',f-diesis''''',g''''',g-diesis''''',a''''',a-diesis''''',b''''',c'''''',c-diesis'''''',d'''''',d-diesis'''''',e'''''',f'''''',f-diesis'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,D-bemolle-5,D-5,E-bemolle-5,E-5,F-5,G-bemolle-5,G-5,A-bemolle-5,A-5,B-bemolle-5,B-5,C-4,D-bemolle-4,D-4,E-bemolle-4,E-4,F-4,G-bemolle-4,G-4,A-bemolle-4,A-4,B-bemolle-4,B-4,C-3,D-bemolle-3,D-3,E-bemolle-3,E-3,F-3,G-bemolle-3,G-3,A-bemolle-3,A-3,B-bemolle-3,B-3,C-2,D-bemolle-2,D-2,E-bemolle-2,E-2,F-2,G-bemolle-2,G-2,A-bemolle-2,A-2,B-bemolle-2,B-2,C-,D-bemolle-,D-,E-bemolle-,E-,F-,G-bemolle-,G-,A-bemolle-,A-,B-bemolle-,B-,C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B-bemolle,B,C+,D-bemolle+,D+,E-bemolle+,E+,F+,G-bemolle+,G+,A-bemolle+,A+,B-bemolle+,B+,C+2,D-bemolle+2,D+2,E-bemolle+2,E+2,F+2,G-bemolle+2,G+2,A-bemolle+2,A+2,B-bemolle+2,B+2,C+3,D-bemolle+3,D+3,E-bemolle+3,E+3,F+3,G-bemolle+3,G+3,A-bemolle+3,A+3,B-bemolle+3,B+3,C+4,D-bemolle+4,D+4,E-bemolle+4,E+4,F+4,G-bemolle+4,G+4,A-bemolle+4,A+4,B-bemolle+4,B+4,C+5,D-bemolle+5,D+5,E-bemolle+5,E+5,F+5,G-bemolle+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,D-bemolle-----,D-----,E-bemolle-----,E-----,F-----,G-bemolle-----,G-----,A-bemolle-----,A-----,B-bemolle-----,B-----,C----,D-bemolle----,D----,E-bemolle----,E----,F----,G-bemolle----,G----,A-bemolle----,A----,B-bemolle----,B----,C---,D-bemolle---,D---,E-bemolle---,E---,F---,G-bemolle---,G---,A-bemolle---,A---,B-bemolle---,B---,C--,D-bemolle--,D--,E-bemolle--,E--,F--,G-bemolle--,G--,A-bemolle--,A--,B-bemolle--,B--,C-,D-bemolle-,D-,E-bemolle-,E-,F-,G-bemolle-,G-,A-bemolle-,A-,B-bemolle-,B-,C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B-bemolle,B,C+,D-bemolle+,D+,E-bemolle+,E+,F+,G-bemolle+,G+,A-bemolle+,A+,B-bemolle+,B+,C++,D-bemolle++,D++,E-bemolle++,E++,F++,G-bemolle++,G++,A-bemolle++,A++,B-bemolle++,B++,C+++,D-bemolle+++,D+++,E-bemolle+++,E+++,F+++,G-bemolle+++,G+++,A-bemolle+++,A+++,B-bemolle+++,B+++,C++++,D-bemolle++++,D++++,E-bemolle++++,E++++,F++++,G-bemolle++++,G++++,A-bemolle++++,A++++,B-bemolle++++,B++++,C+++++,D-bemolle+++++,D+++++,E-bemolle+++++,E+++++,F+++++,G-bemolle+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,D-bemolle-1,D-1,E-bemolle-1,E-1,F-1,G-bemolle-1,G-1,A-bemolle-1,A-1,B-bemolle-1,B-1,C0,D-bemolle0,D0,E-bemolle0,E0,F0,G-bemolle0,G0,A-bemolle0,A0,B-bemolle0,B0,C1,D-bemolle1,D1,E-bemolle1,E1,F1,G-bemolle1,G1,A-bemolle1,A1,B-bemolle1,B1,C2,D-bemolle2,D2,E-bemolle2,E2,F2,G-bemolle2,G2,A-bemolle2,A2,B-bemolle2,B2,C3,D-bemolle3,D3,E-bemolle3,E3,F3,G-bemolle3,G3,A-bemolle3,A3,B-bemolle3,B3,C4,D-bemolle4,D4,E-bemolle4,E4,F4,G-bemolle4,G4,A-bemolle4,A4,B-bemolle4,B4,C5,D-bemolle5,D5,E-bemolle5,E5,F5,G-bemolle5,G5,A-bemolle5,A5,B-bemolle5,B5,C6,D-bemolle6,D6,E-bemolle6,E6,F6,G-bemolle6,G6,A-bemolle6,A6,B-bemolle6,B6,C7,D-bemolle7,D7,E-bemolle7,E7,F7,G-bemolle7,G7,A-bemolle7,A7,B-bemolle7,B7,C8,D-bemolle8,D8,E-bemolle8,E8,F8,G-bemolle8,G8,A-bemolle8,A8,B-bemolle8,B8,C9,D-bemolle9,D9,E-bemolle9,E9,F9,G-bemolle9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',D-bemolle''',D''',E-bemolle''',E''',F''',G-bemolle''',G''',A-bemolle''',A''',B-bemolle''',B''',C'',D-bemolle'',D'',E-bemolle'',E'',F'',G-bemolle'',G'',A-bemolle'',A'',B-bemolle'',B'',C',D-bemolle',D',E-bemolle',E',F',G-bemolle',G',A-bemolle',A',B-bemolle',B',C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B-bemolle,B,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b-bemolle,b,c',d-bemolle',d',e-bemolle',e',f',g-bemolle',g',a-bemolle',a',b-bemolle',b',c'',d-bemolle'',d'',e-bemolle'',e'',f'',g-bemolle'',g'',a-bemolle'',a'',b-bemolle'',b'',c''',d-bemolle''',d''',e-bemolle''',e''',f''',g-bemolle''',g''',a-bemolle''',a''',b-bemolle''',b''',c'''',d-bemolle'''',d'''',e-bemolle'''',e'''',f'''',g-bemolle'''',g'''',a-bemolle'''',a'''',b-bemolle'''',b'''',c''''',d-bemolle''''',d''''',e-bemolle''''',e''''',f''''',g-bemolle''''',g''''',a-bemolle''''',a''''',b-bemolle''''',b''''',c'''''',d-bemolle'''''',d'''''',e-bemolle'''''',e'''''',f'''''',g-bemolle'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,Cis-5,D-5,Dis-5,E-5,F-5,Fis-5,G-5,Gis-5,A-5,Ais-5,B-5,C-4,Cis-4,D-4,Dis-4,E-4,F-4,Fis-4,G-4,Gis-4,A-4,Ais-4,B-4,C-3,Cis-3,D-3,Dis-3,E-3,F-3,Fis-3,G-3,Gis-3,A-3,Ais-3,B-3,C-2,Cis-2,D-2,Dis-2,E-2,F-2,Fis-2,G-2,Gis-2,A-2,Ais-2,B-2,C-,Cis-,D-,Dis-,E-,F-,Fis-,G-,Gis-,A-,Ais-,B-,C,Cis,D,Dis,E,F,Fis,G,Gis,A,Ais,B,C+,Cis+,D+,Dis+,E+,F+,Fis+,G+,Gis+,A+,Ais+,B+,C+2,Cis+2,D+2,Dis+2,E+2,F+2,Fis+2,G+2,Gis+2,A+2,Ais+2,B+2,C+3,Cis+3,D+3,Dis+3,E+3,F+3,Fis+3,G+3,Gis+3,A+3,Ais+3,B+3,C+4,Cis+4,D+4,Dis+4,E+4,F+4,Fis+4,G+4,Gis+4,A+4,Ais+4,B+4,C+5,Cis+5,D+5,Dis+5,E+5,F+5,Fis+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,Cis-----,D-----,Dis-----,E-----,F-----,Fis-----,G-----,Gis-----,A-----,Ais-----,B-----,C----,Cis----,D----,Dis----,E----,F----,Fis----,G----,Gis----,A----,Ais----,B----,C---,Cis---,D---,Dis---,E---,F---,Fis---,G---,Gis---,A---,Ais---,B---,C--,Cis--,D--,Dis--,E--,F--,Fis--,G--,Gis--,A--,Ais--,B--,C-,Cis-,D-,Dis-,E-,F-,Fis-,G-,Gis-,A-,Ais-,B-,C,Cis,D,Dis,E,F,Fis,G,Gis,A,Ais,B,C+,Cis+,D+,Dis+,E+,F+,Fis+,G+,Gis+,A+,Ais+,B+,C++,Cis++,D++,Dis++,E++,F++,Fis++,G++,Gis++,A++,Ais++,B++,C+++,Cis+++,D+++,Dis+++,E+++,F+++,Fis+++,G+++,Gis+++,A+++,Ais+++,B+++,C++++,Cis++++,D++++,Dis++++,E++++,F++++,Fis++++,G++++,Gis++++,A++++,Ais++++,B++++,C+++++,Cis+++++,D+++++,Dis+++++,E+++++,F+++++,Fis+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,Cis-1,D-1,Dis-1,E-1,F-1,Fis-1,G-1,Gis-1,A-1,Ais-1,B-1,C0,Cis0,D0,Dis0,E0,F0,Fis0,G0,Gis0,A0,Ais0,B0,C1,Cis1,D1,Dis1,E1,F1,Fis1,G1,Gis1,A1,Ais1,B1,C2,Cis2,D2,Dis2,E2,F2,Fis2,G2,Gis2,A2,Ais2,B2,C3,Cis3,D3,Dis3,E3,F3,Fis3,G3,Gis3,A3,Ais3,B3,C4,Cis4,D4,Dis4,E4,F4,Fis4,G4,Gis4,A4,Ais4,B4,C5,Cis5,D5,Dis5,E5,F5,Fis5,G5,Gis5,A5,Ais5,B5,C6,Cis6,D6,Dis6,E6,F6,Fis6,G6,Gis6,A6,Ais6,B6,C7,Cis7,D7,Dis7,E7,F7,Fis7,G7,Gis7,A7,Ais7,B7,C8,Cis8,D8,Dis8,E8,F8,Fis8,G8,Gis8,A8,Ais8,B8,C9,Cis9,D9,Dis9,E9,F9,Fis9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',Cis''',D''',Dis''',E''',F''',Fis''',G''',Gis''',A''',Ais''',B''',C'',Cis'',D'',Dis'',E'',F'',Fis'',G'',Gis'',A'',Ais'',B'',C',Cis',D',Dis',E',F',Fis',G',Gis',A',Ais',B',C,Cis,D,Dis,E,F,Fis,G,Gis,A,Ais,B,c,cis,d,dis,e,f,fis,g,gis,a,ais,b,c',cis',d',dis',e',f',fis',g',gis',a',ais',b',c'',cis'',d'',dis'',e'',f'',fis'',g'',gis'',a'',ais'',b'',c''',cis''',d''',dis''',e''',f''',fis''',g''',gis''',a''',ais''',b''',c'''',cis'''',d'''',dis'''',e'''',f'''',fis'''',g'''',gis'''',a'''',ais'''',b'''',c''''',cis''''',d''''',dis''''',e''''',f''''',fis''''',g''''',gis''''',a''''',ais''''',b''''',c'''''',cis'''''',d'''''',dis'''''',e'''''',f'''''',fis'''''',g''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,Des-5,D-5,Es-5,E-5,F-5,Ges-5,G-5,As-5,A-5,Bes-5,B-5,C-4,Des-4,D-4,Es-4,E-4,F-4,Ges-4,G-4,As-4,A-4,Bes-4,B-4,C-3,Des-3,D-3,Es-3,E-3,F-3,Ges-3,G-3,As-3,A-3,Bes-3,B-3,C-2,Des-2,D-2,Es-2,E-2,F-2,Ges-2,G-2,As-2,A-2,Bes-2,B-2,C-,Des-,D-,Es-,E-,F-,Ges-,G-,As-,A-,Bes-,B-,C,Des,D,Es,E,F,Ges,G,As,A,Bes,B,C+,Des+,D+,Es+,E+,F+,Ges+,G+,As+,A+,Bes+,B+,C+2,Des+2,D+2,Es+2,E+2,F+2,Ges+2,G+2,As+2,A+2,Bes+2,B+2,C+3,Des+3,D+3,Es+3,E+3,F+3,Ges+3,G+3,As+3,A+3,Bes+3,B+3,C+4,Des+4,D+4,Es+4,E+4,F+4,Ges+4,G+4,As+4,A+4,Bes+4,B+4,C+5,Des+5,D+5,Es+5,E+5,F+5,Ges+5,G+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,Des-----,D-----,Es-----,E-----,F-----,Ges-----,G-----,As-----,A-----,Bes-----,B-----,C----,Des----,D----,Es----,E----,F----,Ges----,G----,As----,A----,Bes----,B----,C---,Des---,D---,Es---,E---,F---,Ges---,G---,As---,A---,Bes---,B---,C--,Des--,D--,Es--,E--,F--,Ges--,G--,As--,A--,Bes--,B--,C-,Des-,D-,Es-,E-,F-,Ges-,G-,As-,A-,Bes-,B-,C,Des,D,Es,E,F,Ges,G,As,A,Bes,B,C+,Des+,D+,Es+,E+,F+,Ges+,G+,As+,A+,Bes+,B+,C++,Des++,D++,Es++,E++,F++,Ges++,G++,As++,A++,Bes++,B++,C+++,Des+++,D+++,Es+++,E+++,F+++,Ges+++,G+++,As+++,A+++,Bes+++,B+++,C++++,Des++++,D++++,Es++++,E++++,F++++,Ges++++,G++++,As++++,A++++,Bes++++,B++++,C+++++,Des+++++,D+++++,Es+++++,E+++++,F+++++,Ges+++++,G+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,Des-1,D-1,Es-1,E-1,F-1,Ges-1,G-1,As-1,A-1,Bes-1,B-1,C0,Des0,D0,Es0,E0,F0,Ges0,G0,As0,A0,Bes0,B0,C1,Des1,D1,Es1,E1,F1,Ges1,G1,As1,A1,Bes1,B1,C2,Des2,D2,Es2,E2,F2,Ges2,G2,As2,A2,Bes2,B2,C3,Des3,D3,Es3,E3,F3,Ges3,G3,As3,A3,Bes3,B3,C4,Des4,D4,Es4,E4,F4,Ges4,G4,As4,A4,Bes4,B4,C5,Des5,D5,Es5,E5,F5,Ges5,G5,As5,A5,Bes5,B5,C6,Des6,D6,Es6,E6,F6,Ges6,G6,As6,A6,Bes6,B6,C7,Des7,D7,Es7,E7,F7,Ges7,G7,As7,A7,Bes7,B7,C8,Des8,D8,Es8,E8,F8,Ges8,G8,As8,A8,Bes8,B8,C9,Des9,D9,Es9,E9,F9,Ges9,G9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Des''',D''',Es''',E''',F''',Ges''',G''',As''',A''',Bes''',B''',C'',Des'',D'',Es'',E'',F'',Ges'',G'',As'',A'',Bes'',B'',C',Des',D',Es',E',F',Ges',G',As',A',Bes',B',C,Des,D,Es,E,F,Ges,G,As,A,Bes,B,c,des,d,es,e,f,ges,g,as,a,bes,b,c',des',d',es',e',f',ges',g',as',a',bes',b',c'',des'',d'',es'',e'',f'',ges'',g'',as'',a'',bes'',b'',c''',des''',d''',es''',e''',f''',ges''',g''',as''',a''',bes''',b''',c'''',des'''',d'''',es'''',e'''',f'''',ges'''',g'''',as'''',a'''',bes'''',b'''',c''''',des''''',d''''',es''''',e''''',f''''',ges''''',g''''',as''''',a''''',bes''''',b''''',c'''''',des'''''',d'''''',es'''''',e'''''',f'''''',ges'''''',g''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "do-5,do#-5,re-5,re#-5,mi-5,fa-5,fa#-5,sol-5,sol#-5,la-5,la#-5,si-5,do-4,do#-4,re-4,re#-4,mi-4,fa-4,fa#-4,sol-4,sol#-4,la-4,la#-4,si-4,do-3,do#-3,re-3,re#-3,mi-3,fa-3,fa#-3,sol-3,sol#-3,la-3,la#-3,si-3,do-2,do#-2,re-2,re#-2,mi-2,fa-2,fa#-2,sol-2,sol#-2,la-2,la#-2,si-2,do-,do#-,re-,re#-,mi-,fa-,fa#-,sol-,sol#-,la-,la#-,si-,do,do#,re,re#,mi,fa,fa#,sol,sol#,la,la#,si,do+,do#+,re+,re#+,mi+,fa+,fa#+,sol+,sol#+,la+,la#+,si+,do+2,do#+2,re+2,re#+2,mi+2,fa+2,fa#+2,sol+2,sol#+2,la+2,la#+2,si+2,do+3,do#+3,re+3,re#+3,mi+3,fa+3,fa#+3,sol+3,sol#+3,la+3,la#+3,si+3,do+4,do#+4,re+4,re#+4,mi+4,fa+4,fa#+4,sol+4,sol#+4,la+4,la#+4,si+4,do+5,do#+5,re+5,re#+5,mi+5,fa+5,fa#+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "do-----,do#-----,re-----,re#-----,mi-----,fa-----,fa#-----,sol-----,sol#-----,la-----,la#-----,si-----,do----,do#----,re----,re#----,mi----,fa----,fa#----,sol----,sol#----,la----,la#----,si----,do---,do#---,re---,re#---,mi---,fa---,fa#---,sol---,sol#---,la---,la#---,si---,do--,do#--,re--,re#--,mi--,fa--,fa#--,sol--,sol#--,la--,la#--,si--,do-,do#-,re-,re#-,mi-,fa-,fa#-,sol-,sol#-,la-,la#-,si-,do,do#,re,re#,mi,fa,fa#,sol,sol#,la,la#,si,do+,do#+,re+,re#+,mi+,fa+,fa#+,sol+,sol#+,la+,la#+,si+,do++,do#++,re++,re#++,mi++,fa++,fa#++,sol++,sol#++,la++,la#++,si++,do+++,do#+++,re+++,re#+++,mi+++,fa+++,fa#+++,sol+++,sol#+++,la+++,la#+++,si+++,do++++,do#++++,re++++,re#++++,mi++++,fa++++,fa#++++,sol++++,sol#++++,la++++,la#++++,si++++,do+++++,do#+++++,re+++++,re#+++++,mi+++++,fa+++++,fa#+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "do-1,do#-1,re-1,re#-1,mi-1,fa-1,fa#-1,sol-1,sol#-1,la-1,la#-1,si-1,do0,do#0,re0,re#0,mi0,fa0,fa#0,sol0,sol#0,la0,la#0,si0,do1,do#1,re1,re#1,mi1,fa1,fa#1,sol1,sol#1,la1,la#1,si1,do2,do#2,re2,re#2,mi2,fa2,fa#2,sol2,sol#2,la2,la#2,si2,do3,do#3,re3,re#3,mi3,fa3,fa#3,sol3,sol#3,la3,la#3,si3,do4,do#4,re4,re#4,mi4,fa4,fa#4,sol4,sol#4,la4,la#4,si4,do5,do#5,re5,re#5,mi5,fa5,fa#5,sol5,sol#5,la5,la#5,si5,do6,do#6,re6,re#6,mi6,fa6,fa#6,sol6,sol#6,la6,la#6,si6,do7,do#7,re7,re#7,mi7,fa7,fa#7,sol7,sol#7,la7,la#7,si7,do8,do#8,re8,re#8,mi8,fa8,fa#8,sol8,sol#8,la8,la#8,si8,do9,do#9,re9,re#9,mi9,fa9,fa#9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Do#''',Re''',Re#''',Mi''',Fa''',Fa#''',Sol''',Sol#''',La''',La#''',Si''',Do'',Do#'',Re'',Re#'',Mi'',Fa'',Fa#'',Sol'',Sol#'',La'',La#'',Si'',Do',Do#',Re',Re#',Mi',Fa',Fa#',Sol',Sol#',La',La#',Si',Do,Do#,Re,Re#,Mi,Fa,Fa#,Sol,Sol#,La,La#,Si,do,do#,re,re#,mi,fa,fa#,sol,sol#,la,la#,si,do',do#',re',re#',mi',fa',fa#',sol',sol#',la',la#',si',do'',do#'',re'',re#'',mi'',fa'',fa#'',sol'',sol#'',la'',la#'',si'',do''',do#''',re''',re#''',mi''',fa''',fa#''',sol''',sol#''',la''',la#''',si''',do'''',do#'''',re'''',re#'''',mi'''',fa'''',fa#'''',sol'''',sol#'''',la'''',la#'''',si'''',do''''',do#''''',re''''',re#''''',mi''''',fa''''',fa#''''',sol''''',sol#''''',la''''',la#''''',si''''',do'''''',do#'''''',re'''''',re#'''''',mi'''''',fa'''''',fa#'''''',sol''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "do-5,reb-5,re-5,mib-5,mi-5,fa-5,solb-5,sol-5,lab-5,la-5,sib-5,si-5,do-4,reb-4,re-4,mib-4,mi-4,fa-4,solb-4,sol-4,lab-4,la-4,sib-4,si-4,do-3,reb-3,re-3,mib-3,mi-3,fa-3,solb-3,sol-3,lab-3,la-3,sib-3,si-3,do-2,reb-2,re-2,mib-2,mi-2,fa-2,solb-2,sol-2,lab-2,la-2,sib-2,si-2,do-,reb-,re-,mib-,mi-,fa-,solb-,sol-,lab-,la-,sib-,si-,do,reb,re,mib,mi,fa,solb,sol,lab,la,sib,si,do+,reb+,re+,mib+,mi+,fa+,solb+,sol+,lab+,la+,sib+,si+,do+2,reb+2,re+2,mib+2,mi+2,fa+2,solb+2,sol+2,lab+2,la+2,sib+2,si+2,do+3,reb+3,re+3,mib+3,mi+3,fa+3,solb+3,sol+3,lab+3,la+3,sib+3,si+3,do+4,reb+4,re+4,mib+4,mi+4,fa+4,solb+4,sol+4,lab+4,la+4,sib+4,si+4,do+5,reb+5,re+5,mib+5,mi+5,fa+5,solb+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "do-----,reb-----,re-----,mib-----,mi-----,fa-----,solb-----,sol-----,lab-----,la-----,sib-----,si-----,do----,reb----,re----,mib----,mi----,fa----,solb----,sol----,lab----,la----,sib----,si----,do---,reb---,re---,mib---,mi---,fa---,solb---,sol---,lab---,la---,sib---,si---,do--,reb--,re--,mib--,mi--,fa--,solb--,sol--,lab--,la--,sib--,si--,do-,reb-,re-,mib-,mi-,fa-,solb-,sol-,lab-,la-,sib-,si-,do,reb,re,mib,mi,fa,solb,sol,lab,la,sib,si,do+,reb+,re+,mib+,mi+,fa+,solb+,sol+,lab+,la+,sib+,si+,do++,reb++,re++,mib++,mi++,fa++,solb++,sol++,lab++,la++,sib++,si++,do+++,reb+++,re+++,mib+++,mi+++,fa+++,solb+++,sol+++,lab+++,la+++,sib+++,si+++,do++++,reb++++,re++++,mib++++,mi++++,fa++++,solb++++,sol++++,lab++++,la++++,sib++++,si++++,do+++++,reb+++++,re+++++,mib+++++,mi+++++,fa+++++,solb+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "do-1,reb-1,re-1,mib-1,mi-1,fa-1,solb-1,sol-1,lab-1,la-1,sib-1,si-1,do0,reb0,re0,mib0,mi0,fa0,solb0,sol0,lab0,la0,sib0,si0,do1,reb1,re1,mib1,mi1,fa1,solb1,sol1,lab1,la1,sib1,si1,do2,reb2,re2,mib2,mi2,fa2,solb2,sol2,lab2,la2,sib2,si2,do3,reb3,re3,mib3,mi3,fa3,solb3,sol3,lab3,la3,sib3,si3,do4,reb4,re4,mib4,mi4,fa4,solb4,sol4,lab4,la4,sib4,si4,do5,reb5,re5,mib5,mi5,fa5,solb5,sol5,lab5,la5,sib5,si5,do6,reb6,re6,mib6,mi6,fa6,solb6,sol6,lab6,la6,sib6,si6,do7,reb7,re7,mib7,mi7,fa7,solb7,sol7,lab7,la7,sib7,si7,do8,reb8,re8,mib8,mi8,fa8,solb8,sol8,lab8,la8,sib8,si8,do9,reb9,re9,mib9,mi9,fa9,solb9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Reb''',Re''',Mib''',Mi''',Fa''',Solb''',Sol''',Lab''',La''',Sib''',Si''',Do'',Reb'',Re'',Mib'',Mi'',Fa'',Solb'',Sol'',Lab'',La'',Sib'',Si'',Do',Reb',Re',Mib',Mi',Fa',Solb',Sol',Lab',La',Sib',Si',Do,Reb,Re,Mib,Mi,Fa,Solb,Sol,Lab,La,Sib,Si,do,reb,re,mib,mi,fa,solb,sol,lab,la,sib,si,do',reb',re',mib',mi',fa',solb',sol',lab',la',sib',si',do'',reb'',re'',mib'',mi'',fa'',solb'',sol'',lab'',la'',sib'',si'',do''',reb''',re''',mib''',mi''',fa''',solb''',sol''',lab''',la''',sib''',si''',do'''',reb'''',re'''',mib'''',mi'''',fa'''',solb'''',sol'''',lab'''',la'''',sib'''',si'''',do''''',reb''''',re''''',mib''''',mi''''',fa''''',solb''''',sol''''',lab''''',la''''',sib''''',si''''',do'''''',reb'''''',re'''''',mib'''''',mi'''''',fa'''''',solb'''''',sol''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "do-5,do-diesis-5,re-5,re-diesis-5,mi-5,fa-5,fa-diesis-5,sol-5,sol-diesis-5,la-5,la-diesis-5,si-5,do-4,do-diesis-4,re-4,re-diesis-4,mi-4,fa-4,fa-diesis-4,sol-4,sol-diesis-4,la-4,la-diesis-4,si-4,do-3,do-diesis-3,re-3,re-diesis-3,mi-3,fa-3,fa-diesis-3,sol-3,sol-diesis-3,la-3,la-diesis-3,si-3,do-2,do-diesis-2,re-2,re-diesis-2,mi-2,fa-2,fa-diesis-2,sol-2,sol-diesis-2,la-2,la-diesis-2,si-2,do-,do-diesis-,re-,re-diesis-,mi-,fa-,fa-diesis-,sol-,sol-diesis-,la-,la-diesis-,si-,do,do-diesis,re,re-diesis,mi,fa,fa-diesis,sol,sol-diesis,la,la-diesis,si,do+,do-diesis+,re+,re-diesis+,mi+,fa+,fa-diesis+,sol+,sol-diesis+,la+,la-diesis+,si+,do+2,do-diesis+2,re+2,re-diesis+2,mi+2,fa+2,fa-diesis+2,sol+2,sol-diesis+2,la+2,la-diesis+2,si+2,do+3,do-diesis+3,re+3,re-diesis+3,mi+3,fa+3,fa-diesis+3,sol+3,sol-diesis+3,la+3,la-diesis+3,si+3,do+4,do-diesis+4,re+4,re-diesis+4,mi+4,fa+4,fa-diesis+4,sol+4,sol-diesis+4,la+4,la-diesis+4,si+4,do+5,do-diesis+5,re+5,re-diesis+5,mi+5,fa+5,fa-diesis+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "do-----,do-diesis-----,re-----,re-diesis-----,mi-----,fa-----,fa-diesis-----,sol-----,sol-diesis-----,la-----,la-diesis-----,si-----,do----,do-diesis----,re----,re-diesis----,mi----,fa----,fa-diesis----,sol----,sol-diesis----,la----,la-diesis----,si----,do---,do-diesis---,re---,re-diesis---,mi---,fa---,fa-diesis---,sol---,sol-diesis---,la---,la-diesis---,si---,do--,do-diesis--,re--,re-diesis--,mi--,fa--,fa-diesis--,sol--,sol-diesis--,la--,la-diesis--,si--,do-,do-diesis-,re-,re-diesis-,mi-,fa-,fa-diesis-,sol-,sol-diesis-,la-,la-diesis-,si-,do,do-diesis,re,re-diesis,mi,fa,fa-diesis,sol,sol-diesis,la,la-diesis,si,do+,do-diesis+,re+,re-diesis+,mi+,fa+,fa-diesis+,sol+,sol-diesis+,la+,la-diesis+,si+,do++,do-diesis++,re++,re-diesis++,mi++,fa++,fa-diesis++,sol++,sol-diesis++,la++,la-diesis++,si++,do+++,do-diesis+++,re+++,re-diesis+++,mi+++,fa+++,fa-diesis+++,sol+++,sol-diesis+++,la+++,la-diesis+++,si+++,do++++,do-diesis++++,re++++,re-diesis++++,mi++++,fa++++,fa-diesis++++,sol++++,sol-diesis++++,la++++,la-diesis++++,si++++,do+++++,do-diesis+++++,re+++++,re-diesis+++++,mi+++++,fa+++++,fa-diesis+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "do-1,do-diesis-1,re-1,re-diesis-1,mi-1,fa-1,fa-diesis-1,sol-1,sol-diesis-1,la-1,la-diesis-1,si-1,do0,do-diesis0,re0,re-diesis0,mi0,fa0,fa-diesis0,sol0,sol-diesis0,la0,la-diesis0,si0,do1,do-diesis1,re1,re-diesis1,mi1,fa1,fa-diesis1,sol1,sol-diesis1,la1,la-diesis1,si1,do2,do-diesis2,re2,re-diesis2,mi2,fa2,fa-diesis2,sol2,sol-diesis2,la2,la-diesis2,si2,do3,do-diesis3,re3,re-diesis3,mi3,fa3,fa-diesis3,sol3,sol-diesis3,la3,la-diesis3,si3,do4,do-diesis4,re4,re-diesis4,mi4,fa4,fa-diesis4,sol4,sol-diesis4,la4,la-diesis4,si4,do5,do-diesis5,re5,re-diesis5,mi5,fa5,fa-diesis5,sol5,sol-diesis5,la5,la-diesis5,si5,do6,do-diesis6,re6,re-diesis6,mi6,fa6,fa-diesis6,sol6,sol-diesis6,la6,la-diesis6,si6,do7,do-diesis7,re7,re-diesis7,mi7,fa7,fa-diesis7,sol7,sol-diesis7,la7,la-diesis7,si7,do8,do-diesis8,re8,re-diesis8,mi8,fa8,fa-diesis8,sol8,sol-diesis8,la8,la-diesis8,si8,do9,do-diesis9,re9,re-diesis9,mi9,fa9,fa-diesis9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Do-diesis''',Re''',Re-diesis''',Mi''',Fa''',Fa-diesis''',Sol''',Sol-diesis''',La''',La-diesis''',Si''',Do'',Do-diesis'',Re'',Re-diesis'',Mi'',Fa'',Fa-diesis'',Sol'',Sol-diesis'',La'',La-diesis'',Si'',Do',Do-diesis',Re',Re-diesis',Mi',Fa',Fa-diesis',Sol',Sol-diesis',La',La-diesis',Si',Do,Do-diesis,Re,Re-diesis,Mi,Fa,Fa-diesis,Sol,Sol-diesis,La,La-diesis,Si,do,do-diesis,re,re-diesis,mi,fa,fa-diesis,sol,sol-diesis,la,la-diesis,si,do',do-diesis',re',re-diesis',mi',fa',fa-diesis',sol',sol-diesis',la',la-diesis',si',do'',do-diesis'',re'',re-diesis'',mi'',fa'',fa-diesis'',sol'',sol-diesis'',la'',la-diesis'',si'',do''',do-diesis''',re''',re-diesis''',mi''',fa''',fa-diesis''',sol''',sol-diesis''',la''',la-diesis''',si''',do'''',do-diesis'''',re'''',re-diesis'''',mi'''',fa'''',fa-diesis'''',sol'''',sol-diesis'''',la'''',la-diesis'''',si'''',do''''',do-diesis''''',re''''',re-diesis''''',mi''''',fa''''',fa-diesis''''',sol''''',sol-diesis''''',la''''',la-diesis''''',si''''',do'''''',do-diesis'''''',re'''''',re-diesis'''''',mi'''''',fa'''''',fa-diesis'''''',sol''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "do-5,re-bemolle-5,re-5,mi-bemolle-5,mi-5,fa-5,sol-bemolle-5,sol-5,la-bemolle-5,la-5,si-bemolle-5,si-5,do-4,re-bemolle-4,re-4,mi-bemolle-4,mi-4,fa-4,sol-bemolle-4,sol-4,la-bemolle-4,la-4,si-bemolle-4,si-4,do-3,re-bemolle-3,re-3,mi-bemolle-3,mi-3,fa-3,sol-bemolle-3,sol-3,la-bemolle-3,la-3,si-bemolle-3,si-3,do-2,re-bemolle-2,re-2,mi-bemolle-2,mi-2,fa-2,sol-bemolle-2,sol-2,la-bemolle-2,la-2,si-bemolle-2,si-2,do-,re-bemolle-,re-,mi-bemolle-,mi-,fa-,sol-bemolle-,sol-,la-bemolle-,la-,si-bemolle-,si-,do,re-bemolle,re,mi-bemolle,mi,fa,sol-bemolle,sol,la-bemolle,la,si-bemolle,si,do+,re-bemolle+,re+,mi-bemolle+,mi+,fa+,sol-bemolle+,sol+,la-bemolle+,la+,si-bemolle+,si+,do+2,re-bemolle+2,re+2,mi-bemolle+2,mi+2,fa+2,sol-bemolle+2,sol+2,la-bemolle+2,la+2,si-bemolle+2,si+2,do+3,re-bemolle+3,re+3,mi-bemolle+3,mi+3,fa+3,sol-bemolle+3,sol+3,la-bemolle+3,la+3,si-bemolle+3,si+3,do+4,re-bemolle+4,re+4,mi-bemolle+4,mi+4,fa+4,sol-bemolle+4,sol+4,la-bemolle+4,la+4,si-bemolle+4,si+4,do+5,re-bemolle+5,re+5,mi-bemolle+5,mi+5,fa+5,sol-bemolle+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "do-----,re-bemolle-----,re-----,mi-bemolle-----,mi-----,fa-----,sol-bemolle-----,sol-----,la-bemolle-----,la-----,si-bemolle-----,si-----,do----,re-bemolle----,re----,mi-bemolle----,mi----,fa----,sol-bemolle----,sol----,la-bemolle----,la----,si-bemolle----,si----,do---,re-bemolle---,re---,mi-bemolle---,mi---,fa---,sol-bemolle---,sol---,la-bemolle---,la---,si-bemolle---,si---,do--,re-bemolle--,re--,mi-bemolle--,mi--,fa--,sol-bemolle--,sol--,la-bemolle--,la--,si-bemolle--,si--,do-,re-bemolle-,re-,mi-bemolle-,mi-,fa-,sol-bemolle-,sol-,la-bemolle-,la-,si-bemolle-,si-,do,re-bemolle,re,mi-bemolle,mi,fa,sol-bemolle,sol,la-bemolle,la,si-bemolle,si,do+,re-bemolle+,re+,mi-bemolle+,mi+,fa+,sol-bemolle+,sol+,la-bemolle+,la+,si-bemolle+,si+,do++,re-bemolle++,re++,mi-bemolle++,mi++,fa++,sol-bemolle++,sol++,la-bemolle++,la++,si-bemolle++,si++,do+++,re-bemolle+++,re+++,mi-bemolle+++,mi+++,fa+++,sol-bemolle+++,sol+++,la-bemolle+++,la+++,si-bemolle+++,si+++,do++++,re-bemolle++++,re++++,mi-bemolle++++,mi++++,fa++++,sol-bemolle++++,sol++++,la-bemolle++++,la++++,si-bemolle++++,si++++,do+++++,re-bemolle+++++,re+++++,mi-bemolle+++++,mi+++++,fa+++++,sol-bemolle+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "do-1,re-bemolle-1,re-1,mi-bemolle-1,mi-1,fa-1,sol-bemolle-1,sol-1,la-bemolle-1,la-1,si-bemolle-1,si-1,do0,re-bemolle0,re0,mi-bemolle0,mi0,fa0,sol-bemolle0,sol0,la-bemolle0,la0,si-bemolle0,si0,do1,re-bemolle1,re1,mi-bemolle1,mi1,fa1,sol-bemolle1,sol1,la-bemolle1,la1,si-bemolle1,si1,do2,re-bemolle2,re2,mi-bemolle2,mi2,fa2,sol-bemolle2,sol2,la-bemolle2,la2,si-bemolle2,si2,do3,re-bemolle3,re3,mi-bemolle3,mi3,fa3,sol-bemolle3,sol3,la-bemolle3,la3,si-bemolle3,si3,do4,re-bemolle4,re4,mi-bemolle4,mi4,fa4,sol-bemolle4,sol4,la-bemolle4,la4,si-bemolle4,si4,do5,re-bemolle5,re5,mi-bemolle5,mi5,fa5,sol-bemolle5,sol5,la-bemolle5,la5,si-bemolle5,si5,do6,re-bemolle6,re6,mi-bemolle6,mi6,fa6,sol-bemolle6,sol6,la-bemolle6,la6,si-bemolle6,si6,do7,re-bemolle7,re7,mi-bemolle7,mi7,fa7,sol-bemolle7,sol7,la-bemolle7,la7,si-bemolle7,si7,do8,re-bemolle8,re8,mi-bemolle8,mi8,fa8,sol-bemolle8,sol8,la-bemolle8,la8,si-bemolle8,si8,do9,re-bemolle9,re9,mi-bemolle9,mi9,fa9,sol-bemolle9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Re-bemolle''',Re''',Mi-bemolle''',Mi''',Fa''',Sol-bemolle''',Sol''',La-bemolle''',La''',Si-bemolle''',Si''',Do'',Re-bemolle'',Re'',Mi-bemolle'',Mi'',Fa'',Sol-bemolle'',Sol'',La-bemolle'',La'',Si-bemolle'',Si'',Do',Re-bemolle',Re',Mi-bemolle',Mi',Fa',Sol-bemolle',Sol',La-bemolle',La',Si-bemolle',Si',Do,Re-bemolle,Re,Mi-bemolle,Mi,Fa,Sol-bemolle,Sol,La-bemolle,La,Si-bemolle,Si,do,re-bemolle,re,mi-bemolle,mi,fa,sol-bemolle,sol,la-bemolle,la,si-bemolle,si,do',re-bemolle',re',mi-bemolle',mi',fa',sol-bemolle',sol',la-bemolle',la',si-bemolle',si',do'',re-bemolle'',re'',mi-bemolle'',mi'',fa'',sol-bemolle'',sol'',la-bemolle'',la'',si-bemolle'',si'',do''',re-bemolle''',re''',mi-bemolle''',mi''',fa''',sol-bemolle''',sol''',la-bemolle''',la''',si-bemolle''',si''',do'''',re-bemolle'''',re'''',mi-bemolle'''',mi'''',fa'''',sol-bemolle'''',sol'''',la-bemolle'''',la'''',si-bemolle'''',si'''',do''''',re-bemolle''''',re''''',mi-bemolle''''',mi''''',fa''''',sol-bemolle''''',sol''''',la-bemolle''''',la''''',si-bemolle''''',si''''',do'''''',re-bemolle'''''',re'''''',mi-bemolle'''''',mi'''''',fa'''''',sol-bemolle'''''',sol''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "do-5,dois-5,re-5,reis-5,mi-5,fa-5,fais-5,sol-5,solis-5,la-5,lais-5,si-5,do-4,dois-4,re-4,reis-4,mi-4,fa-4,fais-4,sol-4,solis-4,la-4,lais-4,si-4,do-3,dois-3,re-3,reis-3,mi-3,fa-3,fais-3,sol-3,solis-3,la-3,lais-3,si-3,do-2,dois-2,re-2,reis-2,mi-2,fa-2,fais-2,sol-2,solis-2,la-2,lais-2,si-2,do-,dois-,re-,reis-,mi-,fa-,fais-,sol-,solis-,la-,lais-,si-,do,dois,re,reis,mi,fa,fais,sol,solis,la,lais,si,do+,dois+,re+,reis+,mi+,fa+,fais+,sol+,solis+,la+,lais+,si+,do+2,dois+2,re+2,reis+2,mi+2,fa+2,fais+2,sol+2,solis+2,la+2,lais+2,si+2,do+3,dois+3,re+3,reis+3,mi+3,fa+3,fais+3,sol+3,solis+3,la+3,lais+3,si+3,do+4,dois+4,re+4,reis+4,mi+4,fa+4,fais+4,sol+4,solis+4,la+4,lais+4,si+4,do+5,dois+5,re+5,reis+5,mi+5,fa+5,fais+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "do-----,dois-----,re-----,reis-----,mi-----,fa-----,fais-----,sol-----,solis-----,la-----,lais-----,si-----,do----,dois----,re----,reis----,mi----,fa----,fais----,sol----,solis----,la----,lais----,si----,do---,dois---,re---,reis---,mi---,fa---,fais---,sol---,solis---,la---,lais---,si---,do--,dois--,re--,reis--,mi--,fa--,fais--,sol--,solis--,la--,lais--,si--,do-,dois-,re-,reis-,mi-,fa-,fais-,sol-,solis-,la-,lais-,si-,do,dois,re,reis,mi,fa,fais,sol,solis,la,lais,si,do+,dois+,re+,reis+,mi+,fa+,fais+,sol+,solis+,la+,lais+,si+,do++,dois++,re++,reis++,mi++,fa++,fais++,sol++,solis++,la++,lais++,si++,do+++,dois+++,re+++,reis+++,mi+++,fa+++,fais+++,sol+++,solis+++,la+++,lais+++,si+++,do++++,dois++++,re++++,reis++++,mi++++,fa++++,fais++++,sol++++,solis++++,la++++,lais++++,si++++,do+++++,dois+++++,re+++++,reis+++++,mi+++++,fa+++++,fais+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "do-1,dois-1,re-1,reis-1,mi-1,fa-1,fais-1,sol-1,solis-1,la-1,lais-1,si-1,do0,dois0,re0,reis0,mi0,fa0,fais0,sol0,solis0,la0,lais0,si0,do1,dois1,re1,reis1,mi1,fa1,fais1,sol1,solis1,la1,lais1,si1,do2,dois2,re2,reis2,mi2,fa2,fais2,sol2,solis2,la2,lais2,si2,do3,dois3,re3,reis3,mi3,fa3,fais3,sol3,solis3,la3,lais3,si3,do4,dois4,re4,reis4,mi4,fa4,fais4,sol4,solis4,la4,lais4,si4,do5,dois5,re5,reis5,mi5,fa5,fais5,sol5,solis5,la5,lais5,si5,do6,dois6,re6,reis6,mi6,fa6,fais6,sol6,solis6,la6,lais6,si6,do7,dois7,re7,reis7,mi7,fa7,fais7,sol7,solis7,la7,lais7,si7,do8,dois8,re8,reis8,mi8,fa8,fais8,sol8,solis8,la8,lais8,si8,do9,dois9,re9,reis9,mi9,fa9,fais9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Dois''',Re''',Reis''',Mi''',Fa''',Fais''',Sol''',Solis''',La''',Lais''',Si''',Do'',Dois'',Re'',Reis'',Mi'',Fa'',Fais'',Sol'',Solis'',La'',Lais'',Si'',Do',Dois',Re',Reis',Mi',Fa',Fais',Sol',Solis',La',Lais',Si',Do,Dois,Re,Reis,Mi,Fa,Fais,Sol,Solis,La,Lais,Si,do,dois,re,reis,mi,fa,fais,sol,solis,la,lais,si,do',dois',re',reis',mi',fa',fais',sol',solis',la',lais',si',do'',dois'',re'',reis'',mi'',fa'',fais'',sol'',solis'',la'',lais'',si'',do''',dois''',re''',reis''',mi''',fa''',fais''',sol''',solis''',la''',lais''',si''',do'''',dois'''',re'''',reis'''',mi'''',fa'''',fais'''',sol'''',solis'''',la'''',lais'''',si'''',do''''',dois''''',re''''',reis''''',mi''''',fa''''',fais''''',sol''''',solis''''',la''''',lais''''',si''''',do'''''',dois'''''',re'''''',reis'''''',mi'''''',fa'''''',fais'''''',sol''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "do-5,rees-5,re-5,mies-5,mi-5,fa-5,soles-5,sol-5,laes-5,la-5,sies-5,si-5,do-4,rees-4,re-4,mies-4,mi-4,fa-4,soles-4,sol-4,laes-4,la-4,sies-4,si-4,do-3,rees-3,re-3,mies-3,mi-3,fa-3,soles-3,sol-3,laes-3,la-3,sies-3,si-3,do-2,rees-2,re-2,mies-2,mi-2,fa-2,soles-2,sol-2,laes-2,la-2,sies-2,si-2,do-,rees-,re-,mies-,mi-,fa-,soles-,sol-,laes-,la-,sies-,si-,do,rees,re,mies,mi,fa,soles,sol,laes,la,sies,si,do+,rees+,re+,mies+,mi+,fa+,soles+,sol+,laes+,la+,sies+,si+,do+2,rees+2,re+2,mies+2,mi+2,fa+2,soles+2,sol+2,laes+2,la+2,sies+2,si+2,do+3,rees+3,re+3,mies+3,mi+3,fa+3,soles+3,sol+3,laes+3,la+3,sies+3,si+3,do+4,rees+4,re+4,mies+4,mi+4,fa+4,soles+4,sol+4,laes+4,la+4,sies+4,si+4,do+5,rees+5,re+5,mies+5,mi+5,fa+5,soles+5,sol+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "do-----,rees-----,re-----,mies-----,mi-----,fa-----,soles-----,sol-----,laes-----,la-----,sies-----,si-----,do----,rees----,re----,mies----,mi----,fa----,soles----,sol----,laes----,la----,sies----,si----,do---,rees---,re---,mies---,mi---,fa---,soles---,sol---,laes---,la---,sies---,si---,do--,rees--,re--,mies--,mi--,fa--,soles--,sol--,laes--,la--,sies--,si--,do-,rees-,re-,mies-,mi-,fa-,soles-,sol-,laes-,la-,sies-,si-,do,rees,re,mies,mi,fa,soles,sol,laes,la,sies,si,do+,rees+,re+,mies+,mi+,fa+,soles+,sol+,laes+,la+,sies+,si+,do++,rees++,re++,mies++,mi++,fa++,soles++,sol++,laes++,la++,sies++,si++,do+++,rees+++,re+++,mies+++,mi+++,fa+++,soles+++,sol+++,laes+++,la+++,sies+++,si+++,do++++,rees++++,re++++,mies++++,mi++++,fa++++,soles++++,sol++++,laes++++,la++++,sies++++,si++++,do+++++,rees+++++,re+++++,mies+++++,mi+++++,fa+++++,soles+++++,sol+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "do-1,rees-1,re-1,mies-1,mi-1,fa-1,soles-1,sol-1,laes-1,la-1,sies-1,si-1,do0,rees0,re0,mies0,mi0,fa0,soles0,sol0,laes0,la0,sies0,si0,do1,rees1,re1,mies1,mi1,fa1,soles1,sol1,laes1,la1,sies1,si1,do2,rees2,re2,mies2,mi2,fa2,soles2,sol2,laes2,la2,sies2,si2,do3,rees3,re3,mies3,mi3,fa3,soles3,sol3,laes3,la3,sies3,si3,do4,rees4,re4,mies4,mi4,fa4,soles4,sol4,laes4,la4,sies4,si4,do5,rees5,re5,mies5,mi5,fa5,soles5,sol5,laes5,la5,sies5,si5,do6,rees6,re6,mies6,mi6,fa6,soles6,sol6,laes6,la6,sies6,si6,do7,rees7,re7,mies7,mi7,fa7,soles7,sol7,laes7,la7,sies7,si7,do8,rees8,re8,mies8,mi8,fa8,soles8,sol8,laes8,la8,sies8,si8,do9,rees9,re9,mies9,mi9,fa9,soles9,sol9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Rees''',Re''',Mies''',Mi''',Fa''',Soles''',Sol''',Laes''',La''',Sies''',Si''',Do'',Rees'',Re'',Mies'',Mi'',Fa'',Soles'',Sol'',Laes'',La'',Sies'',Si'',Do',Rees',Re',Mies',Mi',Fa',Soles',Sol',Laes',La',Sies',Si',Do,Rees,Re,Mies,Mi,Fa,Soles,Sol,Laes,La,Sies,Si,do,rees,re,mies,mi,fa,soles,sol,laes,la,sies,si,do',rees',re',mies',mi',fa',soles',sol',laes',la',sies',si',do'',rees'',re'',mies'',mi'',fa'',soles'',sol'',laes'',la'',sies'',si'',do''',rees''',re''',mies''',mi''',fa''',soles''',sol''',laes''',la''',sies''',si''',do'''',rees'''',re'''',mies'''',mi'''',fa'''',soles'''',sol'''',laes'''',la'''',sies'''',si'''',do''''',rees''''',re''''',mies''''',mi''''',fa''''',soles''''',sol''''',laes''''',la''''',sies''''',si''''',do'''''',rees'''''',re'''''',mies'''''',mi'''''',fa'''''',soles'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Do#-5,Re-5,Re#-5,Mi-5,Fa-5,Fa#-5,Sol-5,Sol#-5,La-5,La#-5,Si-5,Do-4,Do#-4,Re-4,Re#-4,Mi-4,Fa-4,Fa#-4,Sol-4,Sol#-4,La-4,La#-4,Si-4,Do-3,Do#-3,Re-3,Re#-3,Mi-3,Fa-3,Fa#-3,Sol-3,Sol#-3,La-3,La#-3,Si-3,Do-2,Do#-2,Re-2,Re#-2,Mi-2,Fa-2,Fa#-2,Sol-2,Sol#-2,La-2,La#-2,Si-2,Do-,Do#-,Re-,Re#-,Mi-,Fa-,Fa#-,Sol-,Sol#-,La-,La#-,Si-,Do,Do#,Re,Re#,Mi,Fa,Fa#,Sol,Sol#,La,La#,Si,Do+,Do#+,Re+,Re#+,Mi+,Fa+,Fa#+,Sol+,Sol#+,La+,La#+,Si+,Do+2,Do#+2,Re+2,Re#+2,Mi+2,Fa+2,Fa#+2,Sol+2,Sol#+2,La+2,La#+2,Si+2,Do+3,Do#+3,Re+3,Re#+3,Mi+3,Fa+3,Fa#+3,Sol+3,Sol#+3,La+3,La#+3,Si+3,Do+4,Do#+4,Re+4,Re#+4,Mi+4,Fa+4,Fa#+4,Sol+4,Sol#+4,La+4,La#+4,Si+4,Do+5,Do#+5,Re+5,Re#+5,Mi+5,Fa+5,Fa#+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Do-----,Do#-----,Re-----,Re#-----,Mi-----,Fa-----,Fa#-----,Sol-----,Sol#-----,La-----,La#-----,Si-----,Do----,Do#----,Re----,Re#----,Mi----,Fa----,Fa#----,Sol----,Sol#----,La----,La#----,Si----,Do---,Do#---,Re---,Re#---,Mi---,Fa---,Fa#---,Sol---,Sol#---,La---,La#---,Si---,Do--,Do#--,Re--,Re#--,Mi--,Fa--,Fa#--,Sol--,Sol#--,La--,La#--,Si--,Do-,Do#-,Re-,Re#-,Mi-,Fa-,Fa#-,Sol-,Sol#-,La-,La#-,Si-,Do,Do#,Re,Re#,Mi,Fa,Fa#,Sol,Sol#,La,La#,Si,Do+,Do#+,Re+,Re#+,Mi+,Fa+,Fa#+,Sol+,Sol#+,La+,La#+,Si+,Do++,Do#++,Re++,Re#++,Mi++,Fa++,Fa#++,Sol++,Sol#++,La++,La#++,Si++,Do+++,Do#+++,Re+++,Re#+++,Mi+++,Fa+++,Fa#+++,Sol+++,Sol#+++,La+++,La#+++,Si+++,Do++++,Do#++++,Re++++,Re#++++,Mi++++,Fa++++,Fa#++++,Sol++++,Sol#++++,La++++,La#++++,Si++++,Do+++++,Do#+++++,Re+++++,Re#+++++,Mi+++++,Fa+++++,Fa#+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Do-1,Do#-1,Re-1,Re#-1,Mi-1,Fa-1,Fa#-1,Sol-1,Sol#-1,La-1,La#-1,Si-1,Do0,Do#0,Re0,Re#0,Mi0,Fa0,Fa#0,Sol0,Sol#0,La0,La#0,Si0,Do1,Do#1,Re1,Re#1,Mi1,Fa1,Fa#1,Sol1,Sol#1,La1,La#1,Si1,Do2,Do#2,Re2,Re#2,Mi2,Fa2,Fa#2,Sol2,Sol#2,La2,La#2,Si2,Do3,Do#3,Re3,Re#3,Mi3,Fa3,Fa#3,Sol3,Sol#3,La3,La#3,Si3,Do4,Do#4,Re4,Re#4,Mi4,Fa4,Fa#4,Sol4,Sol#4,La4,La#4,Si4,Do5,Do#5,Re5,Re#5,Mi5,Fa5,Fa#5,Sol5,Sol#5,La5,La#5,Si5,Do6,Do#6,Re6,Re#6,Mi6,Fa6,Fa#6,Sol6,Sol#6,La6,La#6,Si6,Do7,Do#7,Re7,Re#7,Mi7,Fa7,Fa#7,Sol7,Sol#7,La7,La#7,Si7,Do8,Do#8,Re8,Re#8,Mi8,Fa8,Fa#8,Sol8,Sol#8,La8,La#8,Si8,Do9,Do#9,Re9,Re#9,Mi9,Fa9,Fa#9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Do#''',Re''',Re#''',Mi''',Fa''',Fa#''',Sol''',Sol#''',La''',La#''',Si''',Do'',Do#'',Re'',Re#'',Mi'',Fa'',Fa#'',Sol'',Sol#'',La'',La#'',Si'',Do',Do#',Re',Re#',Mi',Fa',Fa#',Sol',Sol#',La',La#',Si',Do,Do#,Re,Re#,Mi,Fa,Fa#,Sol,Sol#,La,La#,Si,do,do#,re,re#,mi,fa,fa#,sol,sol#,la,la#,si,do',do#',re',re#',mi',fa',fa#',sol',sol#',la',la#',si',do'',do#'',re'',re#'',mi'',fa'',fa#'',sol'',sol#'',la'',la#'',si'',do''',do#''',re''',re#''',mi''',fa''',fa#''',sol''',sol#''',la''',la#''',si''',do'''',do#'''',re'''',re#'''',mi'''',fa'''',fa#'''',sol'''',sol#'''',la'''',la#'''',si'''',do''''',do#''''',re''''',re#''''',mi''''',fa''''',fa#''''',sol''''',sol#''''',la''''',la#''''',si''''',do'''''',do#'''''',re'''''',re#'''''',mi'''''',fa'''''',fa#'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Reb-5,Re-5,Mib-5,Mi-5,Fa-5,Solb-5,Sol-5,Lab-5,La-5,Sib-5,Si-5,Do-4,Reb-4,Re-4,Mib-4,Mi-4,Fa-4,Solb-4,Sol-4,Lab-4,La-4,Sib-4,Si-4,Do-3,Reb-3,Re-3,Mib-3,Mi-3,Fa-3,Solb-3,Sol-3,Lab-3,La-3,Sib-3,Si-3,Do-2,Reb-2,Re-2,Mib-2,Mi-2,Fa-2,Solb-2,Sol-2,Lab-2,La-2,Sib-2,Si-2,Do-,Reb-,Re-,Mib-,Mi-,Fa-,Solb-,Sol-,Lab-,La-,Sib-,Si-,Do,Reb,Re,Mib,Mi,Fa,Solb,Sol,Lab,La,Sib,Si,Do+,Reb+,Re+,Mib+,Mi+,Fa+,Solb+,Sol+,Lab+,La+,Sib+,Si+,Do+2,Reb+2,Re+2,Mib+2,Mi+2,Fa+2,Solb+2,Sol+2,Lab+2,La+2,Sib+2,Si+2,Do+3,Reb+3,Re+3,Mib+3,Mi+3,Fa+3,Solb+3,Sol+3,Lab+3,La+3,Sib+3,Si+3,Do+4,Reb+4,Re+4,Mib+4,Mi+4,Fa+4,Solb+4,Sol+4,Lab+4,La+4,Sib+4,Si+4,Do+5,Reb+5,Re+5,Mib+5,Mi+5,Fa+5,Solb+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Do-----,Reb-----,Re-----,Mib-----,Mi-----,Fa-----,Solb-----,Sol-----,Lab-----,La-----,Sib-----,Si-----,Do----,Reb----,Re----,Mib----,Mi----,Fa----,Solb----,Sol----,Lab----,La----,Sib----,Si----,Do---,Reb---,Re---,Mib---,Mi---,Fa---,Solb---,Sol---,Lab---,La---,Sib---,Si---,Do--,Reb--,Re--,Mib--,Mi--,Fa--,Solb--,Sol--,Lab--,La--,Sib--,Si--,Do-,Reb-,Re-,Mib-,Mi-,Fa-,Solb-,Sol-,Lab-,La-,Sib-,Si-,Do,Reb,Re,Mib,Mi,Fa,Solb,Sol,Lab,La,Sib,Si,Do+,Reb+,Re+,Mib+,Mi+,Fa+,Solb+,Sol+,Lab+,La+,Sib+,Si+,Do++,Reb++,Re++,Mib++,Mi++,Fa++,Solb++,Sol++,Lab++,La++,Sib++,Si++,Do+++,Reb+++,Re+++,Mib+++,Mi+++,Fa+++,Solb+++,Sol+++,Lab+++,La+++,Sib+++,Si+++,Do++++,Reb++++,Re++++,Mib++++,Mi++++,Fa++++,Solb++++,Sol++++,Lab++++,La++++,Sib++++,Si++++,Do+++++,Reb+++++,Re+++++,Mib+++++,Mi+++++,Fa+++++,Solb+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Do-1,Reb-1,Re-1,Mib-1,Mi-1,Fa-1,Solb-1,Sol-1,Lab-1,La-1,Sib-1,Si-1,Do0,Reb0,Re0,Mib0,Mi0,Fa0,Solb0,Sol0,Lab0,La0,Sib0,Si0,Do1,Reb1,Re1,Mib1,Mi1,Fa1,Solb1,Sol1,Lab1,La1,Sib1,Si1,Do2,Reb2,Re2,Mib2,Mi2,Fa2,Solb2,Sol2,Lab2,La2,Sib2,Si2,Do3,Reb3,Re3,Mib3,Mi3,Fa3,Solb3,Sol3,Lab3,La3,Sib3,Si3,Do4,Reb4,Re4,Mib4,Mi4,Fa4,Solb4,Sol4,Lab4,La4,Sib4,Si4,Do5,Reb5,Re5,Mib5,Mi5,Fa5,Solb5,Sol5,Lab5,La5,Sib5,Si5,Do6,Reb6,Re6,Mib6,Mi6,Fa6,Solb6,Sol6,Lab6,La6,Sib6,Si6,Do7,Reb7,Re7,Mib7,Mi7,Fa7,Solb7,Sol7,Lab7,La7,Sib7,Si7,Do8,Reb8,Re8,Mib8,Mi8,Fa8,Solb8,Sol8,Lab8,La8,Sib8,Si8,Do9,Reb9,Re9,Mib9,Mi9,Fa9,Solb9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Reb''',Re''',Mib''',Mi''',Fa''',Solb''',Sol''',Lab''',La''',Sib''',Si''',Do'',Reb'',Re'',Mib'',Mi'',Fa'',Solb'',Sol'',Lab'',La'',Sib'',Si'',Do',Reb',Re',Mib',Mi',Fa',Solb',Sol',Lab',La',Sib',Si',Do,Reb,Re,Mib,Mi,Fa,Solb,Sol,Lab,La,Sib,Si,do,reb,re,mib,mi,fa,solb,sol,lab,la,sib,si,do',reb',re',mib',mi',fa',solb',sol',lab',la',sib',si',do'',reb'',re'',mib'',mi'',fa'',solb'',sol'',lab'',la'',sib'',si'',do''',reb''',re''',mib''',mi''',fa''',solb''',sol''',lab''',la''',sib''',si''',do'''',reb'''',re'''',mib'''',mi'''',fa'''',solb'''',sol'''',lab'''',la'''',sib'''',si'''',do''''',reb''''',re''''',mib''''',mi''''',fa''''',solb''''',sol''''',lab''''',la''''',sib''''',si''''',do'''''',reb'''''',re'''''',mib'''''',mi'''''',fa'''''',solb'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Do-diesis-5,Re-5,Re-diesis-5,Mi-5,Fa-5,Fa-diesis-5,Sol-5,Sol-diesis-5,La-5,La-diesis-5,Si-5,Do-4,Do-diesis-4,Re-4,Re-diesis-4,Mi-4,Fa-4,Fa-diesis-4,Sol-4,Sol-diesis-4,La-4,La-diesis-4,Si-4,Do-3,Do-diesis-3,Re-3,Re-diesis-3,Mi-3,Fa-3,Fa-diesis-3,Sol-3,Sol-diesis-3,La-3,La-diesis-3,Si-3,Do-2,Do-diesis-2,Re-2,Re-diesis-2,Mi-2,Fa-2,Fa-diesis-2,Sol-2,Sol-diesis-2,La-2,La-diesis-2,Si-2,Do-,Do-diesis-,Re-,Re-diesis-,Mi-,Fa-,Fa-diesis-,Sol-,Sol-diesis-,La-,La-diesis-,Si-,Do,Do-diesis,Re,Re-diesis,Mi,Fa,Fa-diesis,Sol,Sol-diesis,La,La-diesis,Si,Do+,Do-diesis+,Re+,Re-diesis+,Mi+,Fa+,Fa-diesis+,Sol+,Sol-diesis+,La+,La-diesis+,Si+,Do+2,Do-diesis+2,Re+2,Re-diesis+2,Mi+2,Fa+2,Fa-diesis+2,Sol+2,Sol-diesis+2,La+2,La-diesis+2,Si+2,Do+3,Do-diesis+3,Re+3,Re-diesis+3,Mi+3,Fa+3,Fa-diesis+3,Sol+3,Sol-diesis+3,La+3,La-diesis+3,Si+3,Do+4,Do-diesis+4,Re+4,Re-diesis+4,Mi+4,Fa+4,Fa-diesis+4,Sol+4,Sol-diesis+4,La+4,La-diesis+4,Si+4,Do+5,Do-diesis+5,Re+5,Re-diesis+5,Mi+5,Fa+5,Fa-diesis+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Do-----,Do-diesis-----,Re-----,Re-diesis-----,Mi-----,Fa-----,Fa-diesis-----,Sol-----,Sol-diesis-----,La-----,La-diesis-----,Si-----,Do----,Do-diesis----,Re----,Re-diesis----,Mi----,Fa----,Fa-diesis----,Sol----,Sol-diesis----,La----,La-diesis----,Si----,Do---,Do-diesis---,Re---,Re-diesis---,Mi---,Fa---,Fa-diesis---,Sol---,Sol-diesis---,La---,La-diesis---,Si---,Do--,Do-diesis--,Re--,Re-diesis--,Mi--,Fa--,Fa-diesis--,Sol--,Sol-diesis--,La--,La-diesis--,Si--,Do-,Do-diesis-,Re-,Re-diesis-,Mi-,Fa-,Fa-diesis-,Sol-,Sol-diesis-,La-,La-diesis-,Si-,Do,Do-diesis,Re,Re-diesis,Mi,Fa,Fa-diesis,Sol,Sol-diesis,La,La-diesis,Si,Do+,Do-diesis+,Re+,Re-diesis+,Mi+,Fa+,Fa-diesis+,Sol+,Sol-diesis+,La+,La-diesis+,Si+,Do++,Do-diesis++,Re++,Re-diesis++,Mi++,Fa++,Fa-diesis++,Sol++,Sol-diesis++,La++,La-diesis++,Si++,Do+++,Do-diesis+++,Re+++,Re-diesis+++,Mi+++,Fa+++,Fa-diesis+++,Sol+++,Sol-diesis+++,La+++,La-diesis+++,Si+++,Do++++,Do-diesis++++,Re++++,Re-diesis++++,Mi++++,Fa++++,Fa-diesis++++,Sol++++,Sol-diesis++++,La++++,La-diesis++++,Si++++,Do+++++,Do-diesis+++++,Re+++++,Re-diesis+++++,Mi+++++,Fa+++++,Fa-diesis+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Do-1,Do-diesis-1,Re-1,Re-diesis-1,Mi-1,Fa-1,Fa-diesis-1,Sol-1,Sol-diesis-1,La-1,La-diesis-1,Si-1,Do0,Do-diesis0,Re0,Re-diesis0,Mi0,Fa0,Fa-diesis0,Sol0,Sol-diesis0,La0,La-diesis0,Si0,Do1,Do-diesis1,Re1,Re-diesis1,Mi1,Fa1,Fa-diesis1,Sol1,Sol-diesis1,La1,La-diesis1,Si1,Do2,Do-diesis2,Re2,Re-diesis2,Mi2,Fa2,Fa-diesis2,Sol2,Sol-diesis2,La2,La-diesis2,Si2,Do3,Do-diesis3,Re3,Re-diesis3,Mi3,Fa3,Fa-diesis3,Sol3,Sol-diesis3,La3,La-diesis3,Si3,Do4,Do-diesis4,Re4,Re-diesis4,Mi4,Fa4,Fa-diesis4,Sol4,Sol-diesis4,La4,La-diesis4,Si4,Do5,Do-diesis5,Re5,Re-diesis5,Mi5,Fa5,Fa-diesis5,Sol5,Sol-diesis5,La5,La-diesis5,Si5,Do6,Do-diesis6,Re6,Re-diesis6,Mi6,Fa6,Fa-diesis6,Sol6,Sol-diesis6,La6,La-diesis6,Si6,Do7,Do-diesis7,Re7,Re-diesis7,Mi7,Fa7,Fa-diesis7,Sol7,Sol-diesis7,La7,La-diesis7,Si7,Do8,Do-diesis8,Re8,Re-diesis8,Mi8,Fa8,Fa-diesis8,Sol8,Sol-diesis8,La8,La-diesis8,Si8,Do9,Do-diesis9,Re9,Re-diesis9,Mi9,Fa9,Fa-diesis9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Do-diesis''',Re''',Re-diesis''',Mi''',Fa''',Fa-diesis''',Sol''',Sol-diesis''',La''',La-diesis''',Si''',Do'',Do-diesis'',Re'',Re-diesis'',Mi'',Fa'',Fa-diesis'',Sol'',Sol-diesis'',La'',La-diesis'',Si'',Do',Do-diesis',Re',Re-diesis',Mi',Fa',Fa-diesis',Sol',Sol-diesis',La',La-diesis',Si',Do,Do-diesis,Re,Re-diesis,Mi,Fa,Fa-diesis,Sol,Sol-diesis,La,La-diesis,Si,do,do-diesis,re,re-diesis,mi,fa,fa-diesis,sol,sol-diesis,la,la-diesis,si,do',do-diesis',re',re-diesis',mi',fa',fa-diesis',sol',sol-diesis',la',la-diesis',si',do'',do-diesis'',re'',re-diesis'',mi'',fa'',fa-diesis'',sol'',sol-diesis'',la'',la-diesis'',si'',do''',do-diesis''',re''',re-diesis''',mi''',fa''',fa-diesis''',sol''',sol-diesis''',la''',la-diesis''',si''',do'''',do-diesis'''',re'''',re-diesis'''',mi'''',fa'''',fa-diesis'''',sol'''',sol-diesis'''',la'''',la-diesis'''',si'''',do''''',do-diesis''''',re''''',re-diesis''''',mi''''',fa''''',fa-diesis''''',sol''''',sol-diesis''''',la''''',la-diesis''''',si''''',do'''''',do-diesis'''''',re'''''',re-diesis'''''',mi'''''',fa'''''',fa-diesis'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Re-bemolle-5,Re-5,Mi-bemolle-5,Mi-5,Fa-5,Sol-bemolle-5,Sol-5,La-bemolle-5,La-5,Si-bemolle-5,Si-5,Do-4,Re-bemolle-4,Re-4,Mi-bemolle-4,Mi-4,Fa-4,Sol-bemolle-4,Sol-4,La-bemolle-4,La-4,Si-bemolle-4,Si-4,Do-3,Re-bemolle-3,Re-3,Mi-bemolle-3,Mi-3,Fa-3,Sol-bemolle-3,Sol-3,La-bemolle-3,La-3,Si-bemolle-3,Si-3,Do-2,Re-bemolle-2,Re-2,Mi-bemolle-2,Mi-2,Fa-2,Sol-bemolle-2,Sol-2,La-bemolle-2,La-2,Si-bemolle-2,Si-2,Do-,Re-bemolle-,Re-,Mi-bemolle-,Mi-,Fa-,Sol-bemolle-,Sol-,La-bemolle-,La-,Si-bemolle-,Si-,Do,Re-bemolle,Re,Mi-bemolle,Mi,Fa,Sol-bemolle,Sol,La-bemolle,La,Si-bemolle,Si,Do+,Re-bemolle+,Re+,Mi-bemolle+,Mi+,Fa+,Sol-bemolle+,Sol+,La-bemolle+,La+,Si-bemolle+,Si+,Do+2,Re-bemolle+2,Re+2,Mi-bemolle+2,Mi+2,Fa+2,Sol-bemolle+2,Sol+2,La-bemolle+2,La+2,Si-bemolle+2,Si+2,Do+3,Re-bemolle+3,Re+3,Mi-bemolle+3,Mi+3,Fa+3,Sol-bemolle+3,Sol+3,La-bemolle+3,La+3,Si-bemolle+3,Si+3,Do+4,Re-bemolle+4,Re+4,Mi-bemolle+4,Mi+4,Fa+4,Sol-bemolle+4,Sol+4,La-bemolle+4,La+4,Si-bemolle+4,Si+4,Do+5,Re-bemolle+5,Re+5,Mi-bemolle+5,Mi+5,Fa+5,Sol-bemolle+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Do-----,Re-bemolle-----,Re-----,Mi-bemolle-----,Mi-----,Fa-----,Sol-bemolle-----,Sol-----,La-bemolle-----,La-----,Si-bemolle-----,Si-----,Do----,Re-bemolle----,Re----,Mi-bemolle----,Mi----,Fa----,Sol-bemolle----,Sol----,La-bemolle----,La----,Si-bemolle----,Si----,Do---,Re-bemolle---,Re---,Mi-bemolle---,Mi---,Fa---,Sol-bemolle---,Sol---,La-bemolle---,La---,Si-bemolle---,Si---,Do--,Re-bemolle--,Re--,Mi-bemolle--,Mi--,Fa--,Sol-bemolle--,Sol--,La-bemolle--,La--,Si-bemolle--,Si--,Do-,Re-bemolle-,Re-,Mi-bemolle-,Mi-,Fa-,Sol-bemolle-,Sol-,La-bemolle-,La-,Si-bemolle-,Si-,Do,Re-bemolle,Re,Mi-bemolle,Mi,Fa,Sol-bemolle,Sol,La-bemolle,La,Si-bemolle,Si,Do+,Re-bemolle+,Re+,Mi-bemolle+,Mi+,Fa+,Sol-bemolle+,Sol+,La-bemolle+,La+,Si-bemolle+,Si+,Do++,Re-bemolle++,Re++,Mi-bemolle++,Mi++,Fa++,Sol-bemolle++,Sol++,La-bemolle++,La++,Si-bemolle++,Si++,Do+++,Re-bemolle+++,Re+++,Mi-bemolle+++,Mi+++,Fa+++,Sol-bemolle+++,Sol+++,La-bemolle+++,La+++,Si-bemolle+++,Si+++,Do++++,Re-bemolle++++,Re++++,Mi-bemolle++++,Mi++++,Fa++++,Sol-bemolle++++,Sol++++,La-bemolle++++,La++++,Si-bemolle++++,Si++++,Do+++++,Re-bemolle+++++,Re+++++,Mi-bemolle+++++,Mi+++++,Fa+++++,Sol-bemolle+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Do-1,Re-bemolle-1,Re-1,Mi-bemolle-1,Mi-1,Fa-1,Sol-bemolle-1,Sol-1,La-bemolle-1,La-1,Si-bemolle-1,Si-1,Do0,Re-bemolle0,Re0,Mi-bemolle0,Mi0,Fa0,Sol-bemolle0,Sol0,La-bemolle0,La0,Si-bemolle0,Si0,Do1,Re-bemolle1,Re1,Mi-bemolle1,Mi1,Fa1,Sol-bemolle1,Sol1,La-bemolle1,La1,Si-bemolle1,Si1,Do2,Re-bemolle2,Re2,Mi-bemolle2,Mi2,Fa2,Sol-bemolle2,Sol2,La-bemolle2,La2,Si-bemolle2,Si2,Do3,Re-bemolle3,Re3,Mi-bemolle3,Mi3,Fa3,Sol-bemolle3,Sol3,La-bemolle3,La3,Si-bemolle3,Si3,Do4,Re-bemolle4,Re4,Mi-bemolle4,Mi4,Fa4,Sol-bemolle4,Sol4,La-bemolle4,La4,Si-bemolle4,Si4,Do5,Re-bemolle5,Re5,Mi-bemolle5,Mi5,Fa5,Sol-bemolle5,Sol5,La-bemolle5,La5,Si-bemolle5,Si5,Do6,Re-bemolle6,Re6,Mi-bemolle6,Mi6,Fa6,Sol-bemolle6,Sol6,La-bemolle6,La6,Si-bemolle6,Si6,Do7,Re-bemolle7,Re7,Mi-bemolle7,Mi7,Fa7,Sol-bemolle7,Sol7,La-bemolle7,La7,Si-bemolle7,Si7,Do8,Re-bemolle8,Re8,Mi-bemolle8,Mi8,Fa8,Sol-bemolle8,Sol8,La-bemolle8,La8,Si-bemolle8,Si8,Do9,Re-bemolle9,Re9,Mi-bemolle9,Mi9,Fa9,Sol-bemolle9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Re-bemolle''',Re''',Mi-bemolle''',Mi''',Fa''',Sol-bemolle''',Sol''',La-bemolle''',La''',Si-bemolle''',Si''',Do'',Re-bemolle'',Re'',Mi-bemolle'',Mi'',Fa'',Sol-bemolle'',Sol'',La-bemolle'',La'',Si-bemolle'',Si'',Do',Re-bemolle',Re',Mi-bemolle',Mi',Fa',Sol-bemolle',Sol',La-bemolle',La',Si-bemolle',Si',Do,Re-bemolle,Re,Mi-bemolle,Mi,Fa,Sol-bemolle,Sol,La-bemolle,La,Si-bemolle,Si,do,re-bemolle,re,mi-bemolle,mi,fa,sol-bemolle,sol,la-bemolle,la,si-bemolle,si,do',re-bemolle',re',mi-bemolle',mi',fa',sol-bemolle',sol',la-bemolle',la',si-bemolle',si',do'',re-bemolle'',re'',mi-bemolle'',mi'',fa'',sol-bemolle'',sol'',la-bemolle'',la'',si-bemolle'',si'',do''',re-bemolle''',re''',mi-bemolle''',mi''',fa''',sol-bemolle''',sol''',la-bemolle''',la''',si-bemolle''',si''',do'''',re-bemolle'''',re'''',mi-bemolle'''',mi'''',fa'''',sol-bemolle'''',sol'''',la-bemolle'''',la'''',si-bemolle'''',si'''',do''''',re-bemolle''''',re''''',mi-bemolle''''',mi''''',fa''''',sol-bemolle''''',sol''''',la-bemolle''''',la''''',si-bemolle''''',si''''',do'''''',re-bemolle'''''',re'''''',mi-bemolle'''''',mi'''''',fa'''''',sol-bemolle'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Dois-5,Re-5,Reis-5,Mi-5,Fa-5,Fais-5,Sol-5,Solis-5,La-5,Lais-5,Si-5,Do-4,Dois-4,Re-4,Reis-4,Mi-4,Fa-4,Fais-4,Sol-4,Solis-4,La-4,Lais-4,Si-4,Do-3,Dois-3,Re-3,Reis-3,Mi-3,Fa-3,Fais-3,Sol-3,Solis-3,La-3,Lais-3,Si-3,Do-2,Dois-2,Re-2,Reis-2,Mi-2,Fa-2,Fais-2,Sol-2,Solis-2,La-2,Lais-2,Si-2,Do-,Dois-,Re-,Reis-,Mi-,Fa-,Fais-,Sol-,Solis-,La-,Lais-,Si-,Do,Dois,Re,Reis,Mi,Fa,Fais,Sol,Solis,La,Lais,Si,Do+,Dois+,Re+,Reis+,Mi+,Fa+,Fais+,Sol+,Solis+,La+,Lais+,Si+,Do+2,Dois+2,Re+2,Reis+2,Mi+2,Fa+2,Fais+2,Sol+2,Solis+2,La+2,Lais+2,Si+2,Do+3,Dois+3,Re+3,Reis+3,Mi+3,Fa+3,Fais+3,Sol+3,Solis+3,La+3,Lais+3,Si+3,Do+4,Dois+4,Re+4,Reis+4,Mi+4,Fa+4,Fais+4,Sol+4,Solis+4,La+4,Lais+4,Si+4,Do+5,Dois+5,Re+5,Reis+5,Mi+5,Fa+5,Fais+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Do-----,Dois-----,Re-----,Reis-----,Mi-----,Fa-----,Fais-----,Sol-----,Solis-----,La-----,Lais-----,Si-----,Do----,Dois----,Re----,Reis----,Mi----,Fa----,Fais----,Sol----,Solis----,La----,Lais----,Si----,Do---,Dois---,Re---,Reis---,Mi---,Fa---,Fais---,Sol---,Solis---,La---,Lais---,Si---,Do--,Dois--,Re--,Reis--,Mi--,Fa--,Fais--,Sol--,Solis--,La--,Lais--,Si--,Do-,Dois-,Re-,Reis-,Mi-,Fa-,Fais-,Sol-,Solis-,La-,Lais-,Si-,Do,Dois,Re,Reis,Mi,Fa,Fais,Sol,Solis,La,Lais,Si,Do+,Dois+,Re+,Reis+,Mi+,Fa+,Fais+,Sol+,Solis+,La+,Lais+,Si+,Do++,Dois++,Re++,Reis++,Mi++,Fa++,Fais++,Sol++,Solis++,La++,Lais++,Si++,Do+++,Dois+++,Re+++,Reis+++,Mi+++,Fa+++,Fais+++,Sol+++,Solis+++,La+++,Lais+++,Si+++,Do++++,Dois++++,Re++++,Reis++++,Mi++++,Fa++++,Fais++++,Sol++++,Solis++++,La++++,Lais++++,Si++++,Do+++++,Dois+++++,Re+++++,Reis+++++,Mi+++++,Fa+++++,Fais+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Do-1,Dois-1,Re-1,Reis-1,Mi-1,Fa-1,Fais-1,Sol-1,Solis-1,La-1,Lais-1,Si-1,Do0,Dois0,Re0,Reis0,Mi0,Fa0,Fais0,Sol0,Solis0,La0,Lais0,Si0,Do1,Dois1,Re1,Reis1,Mi1,Fa1,Fais1,Sol1,Solis1,La1,Lais1,Si1,Do2,Dois2,Re2,Reis2,Mi2,Fa2,Fais2,Sol2,Solis2,La2,Lais2,Si2,Do3,Dois3,Re3,Reis3,Mi3,Fa3,Fais3,Sol3,Solis3,La3,Lais3,Si3,Do4,Dois4,Re4,Reis4,Mi4,Fa4,Fais4,Sol4,Solis4,La4,Lais4,Si4,Do5,Dois5,Re5,Reis5,Mi5,Fa5,Fais5,Sol5,Solis5,La5,Lais5,Si5,Do6,Dois6,Re6,Reis6,Mi6,Fa6,Fais6,Sol6,Solis6,La6,Lais6,Si6,Do7,Dois7,Re7,Reis7,Mi7,Fa7,Fais7,Sol7,Solis7,La7,Lais7,Si7,Do8,Dois8,Re8,Reis8,Mi8,Fa8,Fais8,Sol8,Solis8,La8,Lais8,Si8,Do9,Dois9,Re9,Reis9,Mi9,Fa9,Fais9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Do''',Dois''',Re''',Reis''',Mi''',Fa''',Fais''',Sol''',Solis''',La''',Lais''',Si''',Do'',Dois'',Re'',Reis'',Mi'',Fa'',Fais'',Sol'',Solis'',La'',Lais'',Si'',Do',Dois',Re',Reis',Mi',Fa',Fais',Sol',Solis',La',Lais',Si',Do,Dois,Re,Reis,Mi,Fa,Fais,Sol,Solis,La,Lais,Si,do,dois,re,reis,mi,fa,fais,sol,solis,la,lais,si,do',dois',re',reis',mi',fa',fais',sol',solis',la',lais',si',do'',dois'',re'',reis'',mi'',fa'',fais'',sol'',solis'',la'',lais'',si'',do''',dois''',re''',reis''',mi''',fa''',fais''',sol''',solis''',la''',lais''',si''',do'''',dois'''',re'''',reis'''',mi'''',fa'''',fais'''',sol'''',solis'''',la'''',lais'''',si'''',do''''',dois''''',re''''',reis''''',mi''''',fa''''',fais''''',sol''''',solis''''',la''''',lais''''',si''''',do'''''',dois'''''',re'''''',reis'''''',mi'''''',fa'''''',fais'''''',sol''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Do-5,Rees-5,Re-5,Mies-5,Mi-5,Fa-5,Soles-5,Sol-5,Laes-5,La-5,Sies-5,Si-5,Do-4,Rees-4,Re-4,Mies-4,Mi-4,Fa-4,Soles-4,Sol-4,Laes-4,La-4,Sies-4,Si-4,Do-3,Rees-3,Re-3,Mies-3,Mi-3,Fa-3,Soles-3,Sol-3,Laes-3,La-3,Sies-3,Si-3,Do-2,Rees-2,Re-2,Mies-2,Mi-2,Fa-2,Soles-2,Sol-2,Laes-2,La-2,Sies-2,Si-2,Do-,Rees-,Re-,Mies-,Mi-,Fa-,Soles-,Sol-,Laes-,La-,Sies-,Si-,Do,Rees,Re,Mies,Mi,Fa,Soles,Sol,Laes,La,Sies,Si,Do+,Rees+,Re+,Mies+,Mi+,Fa+,Soles+,Sol+,Laes+,La+,Sies+,Si+,Do+2,Rees+2,Re+2,Mies+2,Mi+2,Fa+2,Soles+2,Sol+2,Laes+2,La+2,Sies+2,Si+2,Do+3,Rees+3,Re+3,Mies+3,Mi+3,Fa+3,Soles+3,Sol+3,Laes+3,La+3,Sies+3,Si+3,Do+4,Rees+4,Re+4,Mies+4,Mi+4,Fa+4,Soles+4,Sol+4,Laes+4,La+4,Sies+4,Si+4,Do+5,Rees+5,Re+5,Mies+5,Mi+5,Fa+5,Soles+5,Sol+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Do-----,Rees-----,Re-----,Mies-----,Mi-----,Fa-----,Soles-----,Sol-----,Laes-----,La-----,Sies-----,Si-----,Do----,Rees----,Re----,Mies----,Mi----,Fa----,Soles----,Sol----,Laes----,La----,Sies----,Si----,Do---,Rees---,Re---,Mies---,Mi---,Fa---,Soles---,Sol---,Laes---,La---,Sies---,Si---,Do--,Rees--,Re--,Mies--,Mi--,Fa--,Soles--,Sol--,Laes--,La--,Sies--,Si--,Do-,Rees-,Re-,Mies-,Mi-,Fa-,Soles-,Sol-,Laes-,La-,Sies-,Si-,Do,Rees,Re,Mies,Mi,Fa,Soles,Sol,Laes,La,Sies,Si,Do+,Rees+,Re+,Mies+,Mi+,Fa+,Soles+,Sol+,Laes+,La+,Sies+,Si+,Do++,Rees++,Re++,Mies++,Mi++,Fa++,Soles++,Sol++,Laes++,La++,Sies++,Si++,Do+++,Rees+++,Re+++,Mies+++,Mi+++,Fa+++,Soles+++,Sol+++,Laes+++,La+++,Sies+++,Si+++,Do++++,Rees++++,Re++++,Mies++++,Mi++++,Fa++++,Soles++++,Sol++++,Laes++++,La++++,Sies++++,Si++++,Do+++++,Rees+++++,Re+++++,Mies+++++,Mi+++++,Fa+++++,Soles+++++,Sol+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Do-1,Rees-1,Re-1,Mies-1,Mi-1,Fa-1,Soles-1,Sol-1,Laes-1,La-1,Sies-1,Si-1,Do0,Rees0,Re0,Mies0,Mi0,Fa0,Soles0,Sol0,Laes0,La0,Sies0,Si0,Do1,Rees1,Re1,Mies1,Mi1,Fa1,Soles1,Sol1,Laes1,La1,Sies1,Si1,Do2,Rees2,Re2,Mies2,Mi2,Fa2,Soles2,Sol2,Laes2,La2,Sies2,Si2,Do3,Rees3,Re3,Mies3,Mi3,Fa3,Soles3,Sol3,Laes3,La3,Sies3,Si3,Do4,Rees4,Re4,Mies4,Mi4,Fa4,Soles4,Sol4,Laes4,La4,Sies4,Si4,Do5,Rees5,Re5,Mies5,Mi5,Fa5,Soles5,Sol5,Laes5,La5,Sies5,Si5,Do6,Rees6,Re6,Mies6,Mi6,Fa6,Soles6,Sol6,Laes6,La6,Sies6,Si6,Do7,Rees7,Re7,Mies7,Mi7,Fa7,Soles7,Sol7,Laes7,La7,Sies7,Si7,Do8,Rees8,Re8,Mies8,Mi8,Fa8,Soles8,Sol8,Laes8,La8,Sies8,Si8,Do9,Rees9,Re9,Mies9,Mi9,Fa9,Soles9,Sol9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Do''',Rees''',Re''',Mies''',Mi''',Fa''',Soles''',Sol''',Laes''',La''',Sies''',Si''',Do'',Rees'',Re'',Mies'',Mi'',Fa'',Soles'',Sol'',Laes'',La'',Sies'',Si'',Do',Rees',Re',Mies',Mi',Fa',Soles',Sol',Laes',La',Sies',Si',Do,Rees,Re,Mies,Mi,Fa,Soles,Sol,Laes,La,Sies,Si,do,rees,re,mies,mi,fa,soles,sol,laes,la,sies,si,do',rees',re',mies',mi',fa',soles',sol',laes',la',sies',si',do'',rees'',re'',mies'',mi'',fa'',soles'',sol'',laes'',la'',sies'',si'',do''',rees''',re''',mies''',mi''',fa''',soles''',sol''',laes''',la''',sies''',si''',do'''',rees'''',re'''',mies'''',mi'''',fa'''',soles'''',sol'''',laes'''',la'''',sies'''',si'''',do''''',rees''''',re''''',mies''''',mi''''',fa''''',soles''''',sol''''',laes''''',la''''',sies''''',si''''',do'''''',rees'''''',re'''''',mies'''''',mi'''''',fa'''''',soles'''''',sol''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,c#-5,d-5,d#-5,e-5,f-5,f#-5,g-5,g#-5,a-5,b-5,h-5,c-4,c#-4,d-4,d#-4,e-4,f-4,f#-4,g-4,g#-4,a-4,b-4,h-4,c-3,c#-3,d-3,d#-3,e-3,f-3,f#-3,g-3,g#-3,a-3,b-3,h-3,c-2,c#-2,d-2,d#-2,e-2,f-2,f#-2,g-2,g#-2,a-2,b-2,h-2,c-,c#-,d-,d#-,e-,f-,f#-,g-,g#-,a-,b-,h-,c,c#,d,d#,e,f,f#,g,g#,a,b,h,c+,c#+,d+,d#+,e+,f+,f#+,g+,g#+,a+,b+,h+,c+2,c#+2,d+2,d#+2,e+2,f+2,f#+2,g+2,g#+2,a+2,b+2,h+2,c+3,c#+3,d+3,d#+3,e+3,f+3,f#+3,g+3,g#+3,a+3,b+3,h+3,c+4,c#+4,d+4,d#+4,e+4,f+4,f#+4,g+4,g#+4,a+4,b+4,h+4,c+5,c#+5,d+5,d#+5,e+5,f+5,f#+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,c#-----,d-----,d#-----,e-----,f-----,f#-----,g-----,g#-----,a-----,b-----,h-----,c----,c#----,d----,d#----,e----,f----,f#----,g----,g#----,a----,b----,h----,c---,c#---,d---,d#---,e---,f---,f#---,g---,g#---,a---,b---,h---,c--,c#--,d--,d#--,e--,f--,f#--,g--,g#--,a--,b--,h--,c-,c#-,d-,d#-,e-,f-,f#-,g-,g#-,a-,b-,h-,c,c#,d,d#,e,f,f#,g,g#,a,b,h,c+,c#+,d+,d#+,e+,f+,f#+,g+,g#+,a+,b+,h+,c++,c#++,d++,d#++,e++,f++,f#++,g++,g#++,a++,b++,h++,c+++,c#+++,d+++,d#+++,e+++,f+++,f#+++,g+++,g#+++,a+++,b+++,h+++,c++++,c#++++,d++++,d#++++,e++++,f++++,f#++++,g++++,g#++++,a++++,b++++,h++++,c+++++,c#+++++,d+++++,d#+++++,e+++++,f+++++,f#+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,c#-1,d-1,d#-1,e-1,f-1,f#-1,g-1,g#-1,a-1,b-1,h-1,c0,c#0,d0,d#0,e0,f0,f#0,g0,g#0,a0,b0,h0,c1,c#1,d1,d#1,e1,f1,f#1,g1,g#1,a1,b1,h1,c2,c#2,d2,d#2,e2,f2,f#2,g2,g#2,a2,b2,h2,c3,c#3,d3,d#3,e3,f3,f#3,g3,g#3,a3,b3,h3,c4,c#4,d4,d#4,e4,f4,f#4,g4,g#4,a4,b4,h4,c5,c#5,d5,d#5,e5,f5,f#5,g5,g#5,a5,b5,h5,c6,c#6,d6,d#6,e6,f6,f#6,g6,g#6,a6,b6,h6,c7,c#7,d7,d#7,e7,f7,f#7,g7,g#7,a7,b7,h7,c8,c#8,d8,d#8,e8,f8,f#8,g8,g#8,a8,b8,h8,c9,c#9,d9,d#9,e9,f9,f#9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C#''',D''',D#''',E''',F''',F#''',G''',G#''',A''',B''',H''',C'',C#'',D'',D#'',E'',F'',F#'',G'',G#'',A'',B'',H'',C',C#',D',D#',E',F',F#',G',G#',A',B',H',C,C#,D,D#,E,F,F#,G,G#,A,B,H,c,c#,d,d#,e,f,f#,g,g#,a,b,h,c',c#',d',d#',e',f',f#',g',g#',a',b',h',c'',c#'',d'',d#'',e'',f'',f#'',g'',g#'',a'',b'',h'',c''',c#''',d''',d#''',e''',f''',f#''',g''',g#''',a''',b''',h''',c'''',c#'''',d'''',d#'''',e'''',f'''',f#'''',g'''',g#'''',a'''',b'''',h'''',c''''',c#''''',d''''',d#''''',e''''',f''''',f#''''',g''''',g#''''',a''''',b''''',h''''',c'''''',c#'''''',d'''''',d#'''''',e'''''',f'''''',f#'''''',g''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,db-5,d-5,eb-5,e-5,f-5,gb-5,g-5,ab-5,a-5,b-5,h-5,c-4,db-4,d-4,eb-4,e-4,f-4,gb-4,g-4,ab-4,a-4,b-4,h-4,c-3,db-3,d-3,eb-3,e-3,f-3,gb-3,g-3,ab-3,a-3,b-3,h-3,c-2,db-2,d-2,eb-2,e-2,f-2,gb-2,g-2,ab-2,a-2,b-2,h-2,c-,db-,d-,eb-,e-,f-,gb-,g-,ab-,a-,b-,h-,c,db,d,eb,e,f,gb,g,ab,a,b,h,c+,db+,d+,eb+,e+,f+,gb+,g+,ab+,a+,b+,h+,c+2,db+2,d+2,eb+2,e+2,f+2,gb+2,g+2,ab+2,a+2,b+2,h+2,c+3,db+3,d+3,eb+3,e+3,f+3,gb+3,g+3,ab+3,a+3,b+3,h+3,c+4,db+4,d+4,eb+4,e+4,f+4,gb+4,g+4,ab+4,a+4,b+4,h+4,c+5,db+5,d+5,eb+5,e+5,f+5,gb+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,db-----,d-----,eb-----,e-----,f-----,gb-----,g-----,ab-----,a-----,b-----,h-----,c----,db----,d----,eb----,e----,f----,gb----,g----,ab----,a----,b----,h----,c---,db---,d---,eb---,e---,f---,gb---,g---,ab---,a---,b---,h---,c--,db--,d--,eb--,e--,f--,gb--,g--,ab--,a--,b--,h--,c-,db-,d-,eb-,e-,f-,gb-,g-,ab-,a-,b-,h-,c,db,d,eb,e,f,gb,g,ab,a,b,h,c+,db+,d+,eb+,e+,f+,gb+,g+,ab+,a+,b+,h+,c++,db++,d++,eb++,e++,f++,gb++,g++,ab++,a++,b++,h++,c+++,db+++,d+++,eb+++,e+++,f+++,gb+++,g+++,ab+++,a+++,b+++,h+++,c++++,db++++,d++++,eb++++,e++++,f++++,gb++++,g++++,ab++++,a++++,b++++,h++++,c+++++,db+++++,d+++++,eb+++++,e+++++,f+++++,gb+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,db-1,d-1,eb-1,e-1,f-1,gb-1,g-1,ab-1,a-1,b-1,h-1,c0,db0,d0,eb0,e0,f0,gb0,g0,ab0,a0,b0,h0,c1,db1,d1,eb1,e1,f1,gb1,g1,ab1,a1,b1,h1,c2,db2,d2,eb2,e2,f2,gb2,g2,ab2,a2,b2,h2,c3,db3,d3,eb3,e3,f3,gb3,g3,ab3,a3,b3,h3,c4,db4,d4,eb4,e4,f4,gb4,g4,ab4,a4,b4,h4,c5,db5,d5,eb5,e5,f5,gb5,g5,ab5,a5,b5,h5,c6,db6,d6,eb6,e6,f6,gb6,g6,ab6,a6,b6,h6,c7,db7,d7,eb7,e7,f7,gb7,g7,ab7,a7,b7,h7,c8,db8,d8,eb8,e8,f8,gb8,g8,ab8,a8,b8,h8,c9,db9,d9,eb9,e9,f9,gb9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Db''',D''',Eb''',E''',F''',Gb''',G''',Ab''',A''',B''',H''',C'',Db'',D'',Eb'',E'',F'',Gb'',G'',Ab'',A'',B'',H'',C',Db',D',Eb',E',F',Gb',G',Ab',A',B',H',C,Db,D,Eb,E,F,Gb,G,Ab,A,B,H,c,db,d,eb,e,f,gb,g,ab,a,b,h,c',db',d',eb',e',f',gb',g',ab',a',b',h',c'',db'',d'',eb'',e'',f'',gb'',g'',ab'',a'',b'',h'',c''',db''',d''',eb''',e''',f''',gb''',g''',ab''',a''',b''',h''',c'''',db'''',d'''',eb'''',e'''',f'''',gb'''',g'''',ab'''',a'''',b'''',h'''',c''''',db''''',d''''',eb''''',e''''',f''''',gb''''',g''''',ab''''',a''''',b''''',h''''',c'''''',db'''''',d'''''',eb'''''',e'''''',f'''''',gb'''''',g''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,c-diesis-5,d-5,d-diesis-5,e-5,f-5,f-diesis-5,g-5,g-diesis-5,a-5,b-5,h-5,c-4,c-diesis-4,d-4,d-diesis-4,e-4,f-4,f-diesis-4,g-4,g-diesis-4,a-4,b-4,h-4,c-3,c-diesis-3,d-3,d-diesis-3,e-3,f-3,f-diesis-3,g-3,g-diesis-3,a-3,b-3,h-3,c-2,c-diesis-2,d-2,d-diesis-2,e-2,f-2,f-diesis-2,g-2,g-diesis-2,a-2,b-2,h-2,c-,c-diesis-,d-,d-diesis-,e-,f-,f-diesis-,g-,g-diesis-,a-,b-,h-,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,b,h,c+,c-diesis+,d+,d-diesis+,e+,f+,f-diesis+,g+,g-diesis+,a+,b+,h+,c+2,c-diesis+2,d+2,d-diesis+2,e+2,f+2,f-diesis+2,g+2,g-diesis+2,a+2,b+2,h+2,c+3,c-diesis+3,d+3,d-diesis+3,e+3,f+3,f-diesis+3,g+3,g-diesis+3,a+3,b+3,h+3,c+4,c-diesis+4,d+4,d-diesis+4,e+4,f+4,f-diesis+4,g+4,g-diesis+4,a+4,b+4,h+4,c+5,c-diesis+5,d+5,d-diesis+5,e+5,f+5,f-diesis+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,c-diesis-----,d-----,d-diesis-----,e-----,f-----,f-diesis-----,g-----,g-diesis-----,a-----,b-----,h-----,c----,c-diesis----,d----,d-diesis----,e----,f----,f-diesis----,g----,g-diesis----,a----,b----,h----,c---,c-diesis---,d---,d-diesis---,e---,f---,f-diesis---,g---,g-diesis---,a---,b---,h---,c--,c-diesis--,d--,d-diesis--,e--,f--,f-diesis--,g--,g-diesis--,a--,b--,h--,c-,c-diesis-,d-,d-diesis-,e-,f-,f-diesis-,g-,g-diesis-,a-,b-,h-,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,b,h,c+,c-diesis+,d+,d-diesis+,e+,f+,f-diesis+,g+,g-diesis+,a+,b+,h+,c++,c-diesis++,d++,d-diesis++,e++,f++,f-diesis++,g++,g-diesis++,a++,b++,h++,c+++,c-diesis+++,d+++,d-diesis+++,e+++,f+++,f-diesis+++,g+++,g-diesis+++,a+++,b+++,h+++,c++++,c-diesis++++,d++++,d-diesis++++,e++++,f++++,f-diesis++++,g++++,g-diesis++++,a++++,b++++,h++++,c+++++,c-diesis+++++,d+++++,d-diesis+++++,e+++++,f+++++,f-diesis+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,c-diesis-1,d-1,d-diesis-1,e-1,f-1,f-diesis-1,g-1,g-diesis-1,a-1,b-1,h-1,c0,c-diesis0,d0,d-diesis0,e0,f0,f-diesis0,g0,g-diesis0,a0,b0,h0,c1,c-diesis1,d1,d-diesis1,e1,f1,f-diesis1,g1,g-diesis1,a1,b1,h1,c2,c-diesis2,d2,d-diesis2,e2,f2,f-diesis2,g2,g-diesis2,a2,b2,h2,c3,c-diesis3,d3,d-diesis3,e3,f3,f-diesis3,g3,g-diesis3,a3,b3,h3,c4,c-diesis4,d4,d-diesis4,e4,f4,f-diesis4,g4,g-diesis4,a4,b4,h4,c5,c-diesis5,d5,d-diesis5,e5,f5,f-diesis5,g5,g-diesis5,a5,b5,h5,c6,c-diesis6,d6,d-diesis6,e6,f6,f-diesis6,g6,g-diesis6,a6,b6,h6,c7,c-diesis7,d7,d-diesis7,e7,f7,f-diesis7,g7,g-diesis7,a7,b7,h7,c8,c-diesis8,d8,d-diesis8,e8,f8,f-diesis8,g8,g-diesis8,a8,b8,h8,c9,c-diesis9,d9,d-diesis9,e9,f9,f-diesis9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C-diesis''',D''',D-diesis''',E''',F''',F-diesis''',G''',G-diesis''',A''',B''',H''',C'',C-diesis'',D'',D-diesis'',E'',F'',F-diesis'',G'',G-diesis'',A'',B'',H'',C',C-diesis',D',D-diesis',E',F',F-diesis',G',G-diesis',A',B',H',C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,B,H,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,b,h,c',c-diesis',d',d-diesis',e',f',f-diesis',g',g-diesis',a',b',h',c'',c-diesis'',d'',d-diesis'',e'',f'',f-diesis'',g'',g-diesis'',a'',b'',h'',c''',c-diesis''',d''',d-diesis''',e''',f''',f-diesis''',g''',g-diesis''',a''',b''',h''',c'''',c-diesis'''',d'''',d-diesis'''',e'''',f'''',f-diesis'''',g'''',g-diesis'''',a'''',b'''',h'''',c''''',c-diesis''''',d''''',d-diesis''''',e''''',f''''',f-diesis''''',g''''',g-diesis''''',a''''',b''''',h''''',c'''''',c-diesis'''''',d'''''',d-diesis'''''',e'''''',f'''''',f-diesis'''''',g''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,d-bemolle-5,d-5,e-bemolle-5,e-5,f-5,g-bemolle-5,g-5,a-bemolle-5,a-5,b-5,h-5,c-4,d-bemolle-4,d-4,e-bemolle-4,e-4,f-4,g-bemolle-4,g-4,a-bemolle-4,a-4,b-4,h-4,c-3,d-bemolle-3,d-3,e-bemolle-3,e-3,f-3,g-bemolle-3,g-3,a-bemolle-3,a-3,b-3,h-3,c-2,d-bemolle-2,d-2,e-bemolle-2,e-2,f-2,g-bemolle-2,g-2,a-bemolle-2,a-2,b-2,h-2,c-,d-bemolle-,d-,e-bemolle-,e-,f-,g-bemolle-,g-,a-bemolle-,a-,b-,h-,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b,h,c+,d-bemolle+,d+,e-bemolle+,e+,f+,g-bemolle+,g+,a-bemolle+,a+,b+,h+,c+2,d-bemolle+2,d+2,e-bemolle+2,e+2,f+2,g-bemolle+2,g+2,a-bemolle+2,a+2,b+2,h+2,c+3,d-bemolle+3,d+3,e-bemolle+3,e+3,f+3,g-bemolle+3,g+3,a-bemolle+3,a+3,b+3,h+3,c+4,d-bemolle+4,d+4,e-bemolle+4,e+4,f+4,g-bemolle+4,g+4,a-bemolle+4,a+4,b+4,h+4,c+5,d-bemolle+5,d+5,e-bemolle+5,e+5,f+5,g-bemolle+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,d-bemolle-----,d-----,e-bemolle-----,e-----,f-----,g-bemolle-----,g-----,a-bemolle-----,a-----,b-----,h-----,c----,d-bemolle----,d----,e-bemolle----,e----,f----,g-bemolle----,g----,a-bemolle----,a----,b----,h----,c---,d-bemolle---,d---,e-bemolle---,e---,f---,g-bemolle---,g---,a-bemolle---,a---,b---,h---,c--,d-bemolle--,d--,e-bemolle--,e--,f--,g-bemolle--,g--,a-bemolle--,a--,b--,h--,c-,d-bemolle-,d-,e-bemolle-,e-,f-,g-bemolle-,g-,a-bemolle-,a-,b-,h-,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b,h,c+,d-bemolle+,d+,e-bemolle+,e+,f+,g-bemolle+,g+,a-bemolle+,a+,b+,h+,c++,d-bemolle++,d++,e-bemolle++,e++,f++,g-bemolle++,g++,a-bemolle++,a++,b++,h++,c+++,d-bemolle+++,d+++,e-bemolle+++,e+++,f+++,g-bemolle+++,g+++,a-bemolle+++,a+++,b+++,h+++,c++++,d-bemolle++++,d++++,e-bemolle++++,e++++,f++++,g-bemolle++++,g++++,a-bemolle++++,a++++,b++++,h++++,c+++++,d-bemolle+++++,d+++++,e-bemolle+++++,e+++++,f+++++,g-bemolle+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,d-bemolle-1,d-1,e-bemolle-1,e-1,f-1,g-bemolle-1,g-1,a-bemolle-1,a-1,b-1,h-1,c0,d-bemolle0,d0,e-bemolle0,e0,f0,g-bemolle0,g0,a-bemolle0,a0,b0,h0,c1,d-bemolle1,d1,e-bemolle1,e1,f1,g-bemolle1,g1,a-bemolle1,a1,b1,h1,c2,d-bemolle2,d2,e-bemolle2,e2,f2,g-bemolle2,g2,a-bemolle2,a2,b2,h2,c3,d-bemolle3,d3,e-bemolle3,e3,f3,g-bemolle3,g3,a-bemolle3,a3,b3,h3,c4,d-bemolle4,d4,e-bemolle4,e4,f4,g-bemolle4,g4,a-bemolle4,a4,b4,h4,c5,d-bemolle5,d5,e-bemolle5,e5,f5,g-bemolle5,g5,a-bemolle5,a5,b5,h5,c6,d-bemolle6,d6,e-bemolle6,e6,f6,g-bemolle6,g6,a-bemolle6,a6,b6,h6,c7,d-bemolle7,d7,e-bemolle7,e7,f7,g-bemolle7,g7,a-bemolle7,a7,b7,h7,c8,d-bemolle8,d8,e-bemolle8,e8,f8,g-bemolle8,g8,a-bemolle8,a8,b8,h8,c9,d-bemolle9,d9,e-bemolle9,e9,f9,g-bemolle9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',D-bemolle''',D''',E-bemolle''',E''',F''',G-bemolle''',G''',A-bemolle''',A''',B''',H''',C'',D-bemolle'',D'',E-bemolle'',E'',F'',G-bemolle'',G'',A-bemolle'',A'',B'',H'',C',D-bemolle',D',E-bemolle',E',F',G-bemolle',G',A-bemolle',A',B',H',C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B,H,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b,h,c',d-bemolle',d',e-bemolle',e',f',g-bemolle',g',a-bemolle',a',b',h',c'',d-bemolle'',d'',e-bemolle'',e'',f'',g-bemolle'',g'',a-bemolle'',a'',b'',h'',c''',d-bemolle''',d''',e-bemolle''',e''',f''',g-bemolle''',g''',a-bemolle''',a''',b''',h''',c'''',d-bemolle'''',d'''',e-bemolle'''',e'''',f'''',g-bemolle'''',g'''',a-bemolle'''',a'''',b'''',h'''',c''''',d-bemolle''''',d''''',e-bemolle''''',e''''',f''''',g-bemolle''''',g''''',a-bemolle''''',a''''',b''''',h''''',c'''''',d-bemolle'''''',d'''''',e-bemolle'''''',e'''''',f'''''',g-bemolle'''''',g''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "c-5,cis-5,d-5,dis-5,e-5,f-5,fis-5,g-5,gis-5,a-5,b-5,h-5,c-4,cis-4,d-4,dis-4,e-4,f-4,fis-4,g-4,gis-4,a-4,b-4,h-4,c-3,cis-3,d-3,dis-3,e-3,f-3,fis-3,g-3,gis-3,a-3,b-3,h-3,c-2,cis-2,d-2,dis-2,e-2,f-2,fis-2,g-2,gis-2,a-2,b-2,h-2,c-,cis-,d-,dis-,e-,f-,fis-,g-,gis-,a-,b-,h-,c,cis,d,dis,e,f,fis,g,gis,a,b,h,c+,cis+,d+,dis+,e+,f+,fis+,g+,gis+,a+,b+,h+,c+2,cis+2,d+2,dis+2,e+2,f+2,fis+2,g+2,gis+2,a+2,b+2,h+2,c+3,cis+3,d+3,dis+3,e+3,f+3,fis+3,g+3,gis+3,a+3,b+3,h+3,c+4,cis+4,d+4,dis+4,e+4,f+4,fis+4,g+4,gis+4,a+4,b+4,h+4,c+5,cis+5,d+5,dis+5,e+5,f+5,fis+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "c-----,cis-----,d-----,dis-----,e-----,f-----,fis-----,g-----,gis-----,a-----,b-----,h-----,c----,cis----,d----,dis----,e----,f----,fis----,g----,gis----,a----,b----,h----,c---,cis---,d---,dis---,e---,f---,fis---,g---,gis---,a---,b---,h---,c--,cis--,d--,dis--,e--,f--,fis--,g--,gis--,a--,b--,h--,c-,cis-,d-,dis-,e-,f-,fis-,g-,gis-,a-,b-,h-,c,cis,d,dis,e,f,fis,g,gis,a,b,h,c+,cis+,d+,dis+,e+,f+,fis+,g+,gis+,a+,b+,h+,c++,cis++,d++,dis++,e++,f++,fis++,g++,gis++,a++,b++,h++,c+++,cis+++,d+++,dis+++,e+++,f+++,fis+++,g+++,gis+++,a+++,b+++,h+++,c++++,cis++++,d++++,dis++++,e++++,f++++,fis++++,g++++,gis++++,a++++,b++++,h++++,c+++++,cis+++++,d+++++,dis+++++,e+++++,f+++++,fis+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "c-1,cis-1,d-1,dis-1,e-1,f-1,fis-1,g-1,gis-1,a-1,b-1,h-1,c0,cis0,d0,dis0,e0,f0,fis0,g0,gis0,a0,b0,h0,c1,cis1,d1,dis1,e1,f1,fis1,g1,gis1,a1,b1,h1,c2,cis2,d2,dis2,e2,f2,fis2,g2,gis2,a2,b2,h2,c3,cis3,d3,dis3,e3,f3,fis3,g3,gis3,a3,b3,h3,c4,cis4,d4,dis4,e4,f4,fis4,g4,gis4,a4,b4,h4,c5,cis5,d5,dis5,e5,f5,fis5,g5,gis5,a5,b5,h5,c6,cis6,d6,dis6,e6,f6,fis6,g6,gis6,a6,b6,h6,c7,cis7,d7,dis7,e7,f7,fis7,g7,gis7,a7,b7,h7,c8,cis8,d8,dis8,e8,f8,fis8,g8,gis8,a8,b8,h8,c9,cis9,d9,dis9,e9,f9,fis9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',Cis''',D''',Dis''',E''',F''',Fis''',G''',Gis''',A''',B''',H''',C'',Cis'',D'',Dis'',E'',F'',Fis'',G'',Gis'',A'',B'',H'',C',Cis',D',Dis',E',F',Fis',G',Gis',A',B',H',C,Cis,D,Dis,E,F,Fis,G,Gis,A,B,H,c,cis,d,dis,e,f,fis,g,gis,a,b,h,c',cis',d',dis',e',f',fis',g',gis',a',b',h',c'',cis'',d'',dis'',e'',f'',fis'',g'',gis'',a'',b'',h'',c''',cis''',d''',dis''',e''',f''',fis''',g''',gis''',a''',b''',h''',c'''',cis'''',d'''',dis'''',e'''',f'''',fis'''',g'''',gis'''',a'''',b'''',h'''',c''''',cis''''',d''''',dis''''',e''''',f''''',fis''''',g''''',gis''''',a''''',b''''',h''''',c'''''',cis'''''',d'''''',dis'''''',e'''''',f'''''',fis'''''',g''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "c-5,des-5,d-5,es-5,e-5,f-5,ges-5,g-5,as-5,a-5,b-5,h-5,c-4,des-4,d-4,es-4,e-4,f-4,ges-4,g-4,as-4,a-4,b-4,h-4,c-3,des-3,d-3,es-3,e-3,f-3,ges-3,g-3,as-3,a-3,b-3,h-3,c-2,des-2,d-2,es-2,e-2,f-2,ges-2,g-2,as-2,a-2,b-2,h-2,c-,des-,d-,es-,e-,f-,ges-,g-,as-,a-,b-,h-,c,des,d,es,e,f,ges,g,as,a,b,h,c+,des+,d+,es+,e+,f+,ges+,g+,as+,a+,b+,h+,c+2,des+2,d+2,es+2,e+2,f+2,ges+2,g+2,as+2,a+2,b+2,h+2,c+3,des+3,d+3,es+3,e+3,f+3,ges+3,g+3,as+3,a+3,b+3,h+3,c+4,des+4,d+4,es+4,e+4,f+4,ges+4,g+4,as+4,a+4,b+4,h+4,c+5,des+5,d+5,es+5,e+5,f+5,ges+5,g+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "c-----,des-----,d-----,es-----,e-----,f-----,ges-----,g-----,as-----,a-----,b-----,h-----,c----,des----,d----,es----,e----,f----,ges----,g----,as----,a----,b----,h----,c---,des---,d---,es---,e---,f---,ges---,g---,as---,a---,b---,h---,c--,des--,d--,es--,e--,f--,ges--,g--,as--,a--,b--,h--,c-,des-,d-,es-,e-,f-,ges-,g-,as-,a-,b-,h-,c,des,d,es,e,f,ges,g,as,a,b,h,c+,des+,d+,es+,e+,f+,ges+,g+,as+,a+,b+,h+,c++,des++,d++,es++,e++,f++,ges++,g++,as++,a++,b++,h++,c+++,des+++,d+++,es+++,e+++,f+++,ges+++,g+++,as+++,a+++,b+++,h+++,c++++,des++++,d++++,es++++,e++++,f++++,ges++++,g++++,as++++,a++++,b++++,h++++,c+++++,des+++++,d+++++,es+++++,e+++++,f+++++,ges+++++,g+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "c-1,des-1,d-1,es-1,e-1,f-1,ges-1,g-1,as-1,a-1,b-1,h-1,c0,des0,d0,es0,e0,f0,ges0,g0,as0,a0,b0,h0,c1,des1,d1,es1,e1,f1,ges1,g1,as1,a1,b1,h1,c2,des2,d2,es2,e2,f2,ges2,g2,as2,a2,b2,h2,c3,des3,d3,es3,e3,f3,ges3,g3,as3,a3,b3,h3,c4,des4,d4,es4,e4,f4,ges4,g4,as4,a4,b4,h4,c5,des5,d5,es5,e5,f5,ges5,g5,as5,a5,b5,h5,c6,des6,d6,es6,e6,f6,ges6,g6,as6,a6,b6,h6,c7,des7,d7,es7,e7,f7,ges7,g7,as7,a7,b7,h7,c8,des8,d8,es8,e8,f8,ges8,g8,as8,a8,b8,h8,c9,des9,d9,es9,e9,f9,ges9,g9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Des''',D''',Es''',E''',F''',Ges''',G''',As''',A''',B''',H''',C'',Des'',D'',Es'',E'',F'',Ges'',G'',As'',A'',B'',H'',C',Des',D',Es',E',F',Ges',G',As',A',B',H',C,Des,D,Es,E,F,Ges,G,As,A,B,H,c,des,d,es,e,f,ges,g,as,a,b,h,c',des',d',es',e',f',ges',g',as',a',b',h',c'',des'',d'',es'',e'',f'',ges'',g'',as'',a'',b'',h'',c''',des''',d''',es''',e''',f''',ges''',g''',as''',a''',b''',h''',c'''',des'''',d'''',es'''',e'''',f'''',ges'''',g'''',as'''',a'''',b'''',h'''',c''''',des''''',d''''',es''''',e''''',f''''',ges''''',g''''',as''''',a''''',b''''',h''''',c'''''',des'''''',d'''''',es'''''',e'''''',f'''''',ges'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,C#-5,D-5,D#-5,E-5,F-5,F#-5,G-5,G#-5,A-5,B-5,H-5,C-4,C#-4,D-4,D#-4,E-4,F-4,F#-4,G-4,G#-4,A-4,B-4,H-4,C-3,C#-3,D-3,D#-3,E-3,F-3,F#-3,G-3,G#-3,A-3,B-3,H-3,C-2,C#-2,D-2,D#-2,E-2,F-2,F#-2,G-2,G#-2,A-2,B-2,H-2,C-,C#-,D-,D#-,E-,F-,F#-,G-,G#-,A-,B-,H-,C,C#,D,D#,E,F,F#,G,G#,A,B,H,C+,C#+,D+,D#+,E+,F+,F#+,G+,G#+,A+,B+,H+,C+2,C#+2,D+2,D#+2,E+2,F+2,F#+2,G+2,G#+2,A+2,B+2,H+2,C+3,C#+3,D+3,D#+3,E+3,F+3,F#+3,G+3,G#+3,A+3,B+3,H+3,C+4,C#+4,D+4,D#+4,E+4,F+4,F#+4,G+4,G#+4,A+4,B+4,H+4,C+5,C#+5,D+5,D#+5,E+5,F+5,F#+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,C#-----,D-----,D#-----,E-----,F-----,F#-----,G-----,G#-----,A-----,B-----,H-----,C----,C#----,D----,D#----,E----,F----,F#----,G----,G#----,A----,B----,H----,C---,C#---,D---,D#---,E---,F---,F#---,G---,G#---,A---,B---,H---,C--,C#--,D--,D#--,E--,F--,F#--,G--,G#--,A--,B--,H--,C-,C#-,D-,D#-,E-,F-,F#-,G-,G#-,A-,B-,H-,C,C#,D,D#,E,F,F#,G,G#,A,B,H,C+,C#+,D+,D#+,E+,F+,F#+,G+,G#+,A+,B+,H+,C++,C#++,D++,D#++,E++,F++,F#++,G++,G#++,A++,B++,H++,C+++,C#+++,D+++,D#+++,E+++,F+++,F#+++,G+++,G#+++,A+++,B+++,H+++,C++++,C#++++,D++++,D#++++,E++++,F++++,F#++++,G++++,G#++++,A++++,B++++,H++++,C+++++,C#+++++,D+++++,D#+++++,E+++++,F+++++,F#+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,C#-1,D-1,D#-1,E-1,F-1,F#-1,G-1,G#-1,A-1,B-1,H-1,C0,C#0,D0,D#0,E0,F0,F#0,G0,G#0,A0,B0,H0,C1,C#1,D1,D#1,E1,F1,F#1,G1,G#1,A1,B1,H1,C2,C#2,D2,D#2,E2,F2,F#2,G2,G#2,A2,B2,H2,C3,C#3,D3,D#3,E3,F3,F#3,G3,G#3,A3,B3,H3,C4,C#4,D4,D#4,E4,F4,F#4,G4,G#4,A4,B4,H4,C5,C#5,D5,D#5,E5,F5,F#5,G5,G#5,A5,B5,H5,C6,C#6,D6,D#6,E6,F6,F#6,G6,G#6,A6,B6,H6,C7,C#7,D7,D#7,E7,F7,F#7,G7,G#7,A7,B7,H7,C8,C#8,D8,D#8,E8,F8,F#8,G8,G#8,A8,B8,H8,C9,C#9,D9,D#9,E9,F9,F#9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C#''',D''',D#''',E''',F''',F#''',G''',G#''',A''',B''',H''',C'',C#'',D'',D#'',E'',F'',F#'',G'',G#'',A'',B'',H'',C',C#',D',D#',E',F',F#',G',G#',A',B',H',C,C#,D,D#,E,F,F#,G,G#,A,B,H,c,c#,d,d#,e,f,f#,g,g#,a,b,h,c',c#',d',d#',e',f',f#',g',g#',a',b',h',c'',c#'',d'',d#'',e'',f'',f#'',g'',g#'',a'',b'',h'',c''',c#''',d''',d#''',e''',f''',f#''',g''',g#''',a''',b''',h''',c'''',c#'''',d'''',d#'''',e'''',f'''',f#'''',g'''',g#'''',a'''',b'''',h'''',c''''',c#''''',d''''',d#''''',e''''',f''''',f#''''',g''''',g#''''',a''''',b''''',h''''',c'''''',c#'''''',d'''''',d#'''''',e'''''',f'''''',f#'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,Db-5,D-5,Eb-5,E-5,F-5,Gb-5,G-5,Ab-5,A-5,B-5,H-5,C-4,Db-4,D-4,Eb-4,E-4,F-4,Gb-4,G-4,Ab-4,A-4,B-4,H-4,C-3,Db-3,D-3,Eb-3,E-3,F-3,Gb-3,G-3,Ab-3,A-3,B-3,H-3,C-2,Db-2,D-2,Eb-2,E-2,F-2,Gb-2,G-2,Ab-2,A-2,B-2,H-2,C-,Db-,D-,Eb-,E-,F-,Gb-,G-,Ab-,A-,B-,H-,C,Db,D,Eb,E,F,Gb,G,Ab,A,B,H,C+,Db+,D+,Eb+,E+,F+,Gb+,G+,Ab+,A+,B+,H+,C+2,Db+2,D+2,Eb+2,E+2,F+2,Gb+2,G+2,Ab+2,A+2,B+2,H+2,C+3,Db+3,D+3,Eb+3,E+3,F+3,Gb+3,G+3,Ab+3,A+3,B+3,H+3,C+4,Db+4,D+4,Eb+4,E+4,F+4,Gb+4,G+4,Ab+4,A+4,B+4,H+4,C+5,Db+5,D+5,Eb+5,E+5,F+5,Gb+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,Db-----,D-----,Eb-----,E-----,F-----,Gb-----,G-----,Ab-----,A-----,B-----,H-----,C----,Db----,D----,Eb----,E----,F----,Gb----,G----,Ab----,A----,B----,H----,C---,Db---,D---,Eb---,E---,F---,Gb---,G---,Ab---,A---,B---,H---,C--,Db--,D--,Eb--,E--,F--,Gb--,G--,Ab--,A--,B--,H--,C-,Db-,D-,Eb-,E-,F-,Gb-,G-,Ab-,A-,B-,H-,C,Db,D,Eb,E,F,Gb,G,Ab,A,B,H,C+,Db+,D+,Eb+,E+,F+,Gb+,G+,Ab+,A+,B+,H+,C++,Db++,D++,Eb++,E++,F++,Gb++,G++,Ab++,A++,B++,H++,C+++,Db+++,D+++,Eb+++,E+++,F+++,Gb+++,G+++,Ab+++,A+++,B+++,H+++,C++++,Db++++,D++++,Eb++++,E++++,F++++,Gb++++,G++++,Ab++++,A++++,B++++,H++++,C+++++,Db+++++,D+++++,Eb+++++,E+++++,F+++++,Gb+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,Db-1,D-1,Eb-1,E-1,F-1,Gb-1,G-1,Ab-1,A-1,B-1,H-1,C0,Db0,D0,Eb0,E0,F0,Gb0,G0,Ab0,A0,B0,H0,C1,Db1,D1,Eb1,E1,F1,Gb1,G1,Ab1,A1,B1,H1,C2,Db2,D2,Eb2,E2,F2,Gb2,G2,Ab2,A2,B2,H2,C3,Db3,D3,Eb3,E3,F3,Gb3,G3,Ab3,A3,B3,H3,C4,Db4,D4,Eb4,E4,F4,Gb4,G4,Ab4,A4,B4,H4,C5,Db5,D5,Eb5,E5,F5,Gb5,G5,Ab5,A5,B5,H5,C6,Db6,D6,Eb6,E6,F6,Gb6,G6,Ab6,A6,B6,H6,C7,Db7,D7,Eb7,E7,F7,Gb7,G7,Ab7,A7,B7,H7,C8,Db8,D8,Eb8,E8,F8,Gb8,G8,Ab8,A8,B8,H8,C9,Db9,D9,Eb9,E9,F9,Gb9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Db''',D''',Eb''',E''',F''',Gb''',G''',Ab''',A''',B''',H''',C'',Db'',D'',Eb'',E'',F'',Gb'',G'',Ab'',A'',B'',H'',C',Db',D',Eb',E',F',Gb',G',Ab',A',B',H',C,Db,D,Eb,E,F,Gb,G,Ab,A,B,H,c,db,d,eb,e,f,gb,g,ab,a,b,h,c',db',d',eb',e',f',gb',g',ab',a',b',h',c'',db'',d'',eb'',e'',f'',gb'',g'',ab'',a'',b'',h'',c''',db''',d''',eb''',e''',f''',gb''',g''',ab''',a''',b''',h''',c'''',db'''',d'''',eb'''',e'''',f'''',gb'''',g'''',ab'''',a'''',b'''',h'''',c''''',db''''',d''''',eb''''',e''''',f''''',gb''''',g''''',ab''''',a''''',b''''',h''''',c'''''',db'''''',d'''''',eb'''''',e'''''',f'''''',gb'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,C-diesis-5,D-5,D-diesis-5,E-5,F-5,F-diesis-5,G-5,G-diesis-5,A-5,B-5,H-5,C-4,C-diesis-4,D-4,D-diesis-4,E-4,F-4,F-diesis-4,G-4,G-diesis-4,A-4,B-4,H-4,C-3,C-diesis-3,D-3,D-diesis-3,E-3,F-3,F-diesis-3,G-3,G-diesis-3,A-3,B-3,H-3,C-2,C-diesis-2,D-2,D-diesis-2,E-2,F-2,F-diesis-2,G-2,G-diesis-2,A-2,B-2,H-2,C-,C-diesis-,D-,D-diesis-,E-,F-,F-diesis-,G-,G-diesis-,A-,B-,H-,C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,B,H,C+,C-diesis+,D+,D-diesis+,E+,F+,F-diesis+,G+,G-diesis+,A+,B+,H+,C+2,C-diesis+2,D+2,D-diesis+2,E+2,F+2,F-diesis+2,G+2,G-diesis+2,A+2,B+2,H+2,C+3,C-diesis+3,D+3,D-diesis+3,E+3,F+3,F-diesis+3,G+3,G-diesis+3,A+3,B+3,H+3,C+4,C-diesis+4,D+4,D-diesis+4,E+4,F+4,F-diesis+4,G+4,G-diesis+4,A+4,B+4,H+4,C+5,C-diesis+5,D+5,D-diesis+5,E+5,F+5,F-diesis+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,C-diesis-----,D-----,D-diesis-----,E-----,F-----,F-diesis-----,G-----,G-diesis-----,A-----,B-----,H-----,C----,C-diesis----,D----,D-diesis----,E----,F----,F-diesis----,G----,G-diesis----,A----,B----,H----,C---,C-diesis---,D---,D-diesis---,E---,F---,F-diesis---,G---,G-diesis---,A---,B---,H---,C--,C-diesis--,D--,D-diesis--,E--,F--,F-diesis--,G--,G-diesis--,A--,B--,H--,C-,C-diesis-,D-,D-diesis-,E-,F-,F-diesis-,G-,G-diesis-,A-,B-,H-,C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,B,H,C+,C-diesis+,D+,D-diesis+,E+,F+,F-diesis+,G+,G-diesis+,A+,B+,H+,C++,C-diesis++,D++,D-diesis++,E++,F++,F-diesis++,G++,G-diesis++,A++,B++,H++,C+++,C-diesis+++,D+++,D-diesis+++,E+++,F+++,F-diesis+++,G+++,G-diesis+++,A+++,B+++,H+++,C++++,C-diesis++++,D++++,D-diesis++++,E++++,F++++,F-diesis++++,G++++,G-diesis++++,A++++,B++++,H++++,C+++++,C-diesis+++++,D+++++,D-diesis+++++,E+++++,F+++++,F-diesis+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,C-diesis-1,D-1,D-diesis-1,E-1,F-1,F-diesis-1,G-1,G-diesis-1,A-1,B-1,H-1,C0,C-diesis0,D0,D-diesis0,E0,F0,F-diesis0,G0,G-diesis0,A0,B0,H0,C1,C-diesis1,D1,D-diesis1,E1,F1,F-diesis1,G1,G-diesis1,A1,B1,H1,C2,C-diesis2,D2,D-diesis2,E2,F2,F-diesis2,G2,G-diesis2,A2,B2,H2,C3,C-diesis3,D3,D-diesis3,E3,F3,F-diesis3,G3,G-diesis3,A3,B3,H3,C4,C-diesis4,D4,D-diesis4,E4,F4,F-diesis4,G4,G-diesis4,A4,B4,H4,C5,C-diesis5,D5,D-diesis5,E5,F5,F-diesis5,G5,G-diesis5,A5,B5,H5,C6,C-diesis6,D6,D-diesis6,E6,F6,F-diesis6,G6,G-diesis6,A6,B6,H6,C7,C-diesis7,D7,D-diesis7,E7,F7,F-diesis7,G7,G-diesis7,A7,B7,H7,C8,C-diesis8,D8,D-diesis8,E8,F8,F-diesis8,G8,G-diesis8,A8,B8,H8,C9,C-diesis9,D9,D-diesis9,E9,F9,F-diesis9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',C-diesis''',D''',D-diesis''',E''',F''',F-diesis''',G''',G-diesis''',A''',B''',H''',C'',C-diesis'',D'',D-diesis'',E'',F'',F-diesis'',G'',G-diesis'',A'',B'',H'',C',C-diesis',D',D-diesis',E',F',F-diesis',G',G-diesis',A',B',H',C,C-diesis,D,D-diesis,E,F,F-diesis,G,G-diesis,A,B,H,c,c-diesis,d,d-diesis,e,f,f-diesis,g,g-diesis,a,b,h,c',c-diesis',d',d-diesis',e',f',f-diesis',g',g-diesis',a',b',h',c'',c-diesis'',d'',d-diesis'',e'',f'',f-diesis'',g'',g-diesis'',a'',b'',h'',c''',c-diesis''',d''',d-diesis''',e''',f''',f-diesis''',g''',g-diesis''',a''',b''',h''',c'''',c-diesis'''',d'''',d-diesis'''',e'''',f'''',f-diesis'''',g'''',g-diesis'''',a'''',b'''',h'''',c''''',c-diesis''''',d''''',d-diesis''''',e''''',f''''',f-diesis''''',g''''',g-diesis''''',a''''',b''''',h''''',c'''''',c-diesis'''''',d'''''',d-diesis'''''',e'''''',f'''''',f-diesis'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,D-bemolle-5,D-5,E-bemolle-5,E-5,F-5,G-bemolle-5,G-5,A-bemolle-5,A-5,B-5,H-5,C-4,D-bemolle-4,D-4,E-bemolle-4,E-4,F-4,G-bemolle-4,G-4,A-bemolle-4,A-4,B-4,H-4,C-3,D-bemolle-3,D-3,E-bemolle-3,E-3,F-3,G-bemolle-3,G-3,A-bemolle-3,A-3,B-3,H-3,C-2,D-bemolle-2,D-2,E-bemolle-2,E-2,F-2,G-bemolle-2,G-2,A-bemolle-2,A-2,B-2,H-2,C-,D-bemolle-,D-,E-bemolle-,E-,F-,G-bemolle-,G-,A-bemolle-,A-,B-,H-,C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B,H,C+,D-bemolle+,D+,E-bemolle+,E+,F+,G-bemolle+,G+,A-bemolle+,A+,B+,H+,C+2,D-bemolle+2,D+2,E-bemolle+2,E+2,F+2,G-bemolle+2,G+2,A-bemolle+2,A+2,B+2,H+2,C+3,D-bemolle+3,D+3,E-bemolle+3,E+3,F+3,G-bemolle+3,G+3,A-bemolle+3,A+3,B+3,H+3,C+4,D-bemolle+4,D+4,E-bemolle+4,E+4,F+4,G-bemolle+4,G+4,A-bemolle+4,A+4,B+4,H+4,C+5,D-bemolle+5,D+5,E-bemolle+5,E+5,F+5,G-bemolle+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,D-bemolle-----,D-----,E-bemolle-----,E-----,F-----,G-bemolle-----,G-----,A-bemolle-----,A-----,B-----,H-----,C----,D-bemolle----,D----,E-bemolle----,E----,F----,G-bemolle----,G----,A-bemolle----,A----,B----,H----,C---,D-bemolle---,D---,E-bemolle---,E---,F---,G-bemolle---,G---,A-bemolle---,A---,B---,H---,C--,D-bemolle--,D--,E-bemolle--,E--,F--,G-bemolle--,G--,A-bemolle--,A--,B--,H--,C-,D-bemolle-,D-,E-bemolle-,E-,F-,G-bemolle-,G-,A-bemolle-,A-,B-,H-,C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B,H,C+,D-bemolle+,D+,E-bemolle+,E+,F+,G-bemolle+,G+,A-bemolle+,A+,B+,H+,C++,D-bemolle++,D++,E-bemolle++,E++,F++,G-bemolle++,G++,A-bemolle++,A++,B++,H++,C+++,D-bemolle+++,D+++,E-bemolle+++,E+++,F+++,G-bemolle+++,G+++,A-bemolle+++,A+++,B+++,H+++,C++++,D-bemolle++++,D++++,E-bemolle++++,E++++,F++++,G-bemolle++++,G++++,A-bemolle++++,A++++,B++++,H++++,C+++++,D-bemolle+++++,D+++++,E-bemolle+++++,E+++++,F+++++,G-bemolle+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,D-bemolle-1,D-1,E-bemolle-1,E-1,F-1,G-bemolle-1,G-1,A-bemolle-1,A-1,B-1,H-1,C0,D-bemolle0,D0,E-bemolle0,E0,F0,G-bemolle0,G0,A-bemolle0,A0,B0,H0,C1,D-bemolle1,D1,E-bemolle1,E1,F1,G-bemolle1,G1,A-bemolle1,A1,B1,H1,C2,D-bemolle2,D2,E-bemolle2,E2,F2,G-bemolle2,G2,A-bemolle2,A2,B2,H2,C3,D-bemolle3,D3,E-bemolle3,E3,F3,G-bemolle3,G3,A-bemolle3,A3,B3,H3,C4,D-bemolle4,D4,E-bemolle4,E4,F4,G-bemolle4,G4,A-bemolle4,A4,B4,H4,C5,D-bemolle5,D5,E-bemolle5,E5,F5,G-bemolle5,G5,A-bemolle5,A5,B5,H5,C6,D-bemolle6,D6,E-bemolle6,E6,F6,G-bemolle6,G6,A-bemolle6,A6,B6,H6,C7,D-bemolle7,D7,E-bemolle7,E7,F7,G-bemolle7,G7,A-bemolle7,A7,B7,H7,C8,D-bemolle8,D8,E-bemolle8,E8,F8,G-bemolle8,G8,A-bemolle8,A8,B8,H8,C9,D-bemolle9,D9,E-bemolle9,E9,F9,G-bemolle9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',D-bemolle''',D''',E-bemolle''',E''',F''',G-bemolle''',G''',A-bemolle''',A''',B''',H''',C'',D-bemolle'',D'',E-bemolle'',E'',F'',G-bemolle'',G'',A-bemolle'',A'',B'',H'',C',D-bemolle',D',E-bemolle',E',F',G-bemolle',G',A-bemolle',A',B',H',C,D-bemolle,D,E-bemolle,E,F,G-bemolle,G,A-bemolle,A,B,H,c,d-bemolle,d,e-bemolle,e,f,g-bemolle,g,a-bemolle,a,b,h,c',d-bemolle',d',e-bemolle',e',f',g-bemolle',g',a-bemolle',a',b',h',c'',d-bemolle'',d'',e-bemolle'',e'',f'',g-bemolle'',g'',a-bemolle'',a'',b'',h'',c''',d-bemolle''',d''',e-bemolle''',e''',f''',g-bemolle''',g''',a-bemolle''',a''',b''',h''',c'''',d-bemolle'''',d'''',e-bemolle'''',e'''',f'''',g-bemolle'''',g'''',a-bemolle'''',a'''',b'''',h'''',c''''',d-bemolle''''',d''''',e-bemolle''''',e''''',f''''',g-bemolle''''',g''''',a-bemolle''''',a''''',b''''',h''''',c'''''',d-bemolle'''''',d'''''',e-bemolle'''''',e'''''',f'''''',g-bemolle'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "C-5,Cis-5,D-5,Dis-5,E-5,F-5,Fis-5,G-5,Gis-5,A-5,B-5,H-5,C-4,Cis-4,D-4,Dis-4,E-4,F-4,Fis-4,G-4,Gis-4,A-4,B-4,H-4,C-3,Cis-3,D-3,Dis-3,E-3,F-3,Fis-3,G-3,Gis-3,A-3,B-3,H-3,C-2,Cis-2,D-2,Dis-2,E-2,F-2,Fis-2,G-2,Gis-2,A-2,B-2,H-2,C-,Cis-,D-,Dis-,E-,F-,Fis-,G-,Gis-,A-,B-,H-,C,Cis,D,Dis,E,F,Fis,G,Gis,A,B,H,C+,Cis+,D+,Dis+,E+,F+,Fis+,G+,Gis+,A+,B+,H+,C+2,Cis+2,D+2,Dis+2,E+2,F+2,Fis+2,G+2,Gis+2,A+2,B+2,H+2,C+3,Cis+3,D+3,Dis+3,E+3,F+3,Fis+3,G+3,Gis+3,A+3,B+3,H+3,C+4,Cis+4,D+4,Dis+4,E+4,F+4,Fis+4,G+4,Gis+4,A+4,B+4,H+4,C+5,Cis+5,D+5,Dis+5,E+5,F+5,Fis+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "C-----,Cis-----,D-----,Dis-----,E-----,F-----,Fis-----,G-----,Gis-----,A-----,B-----,H-----,C----,Cis----,D----,Dis----,E----,F----,Fis----,G----,Gis----,A----,B----,H----,C---,Cis---,D---,Dis---,E---,F---,Fis---,G---,Gis---,A---,B---,H---,C--,Cis--,D--,Dis--,E--,F--,Fis--,G--,Gis--,A--,B--,H--,C-,Cis-,D-,Dis-,E-,F-,Fis-,G-,Gis-,A-,B-,H-,C,Cis,D,Dis,E,F,Fis,G,Gis,A,B,H,C+,Cis+,D+,Dis+,E+,F+,Fis+,G+,Gis+,A+,B+,H+,C++,Cis++,D++,Dis++,E++,F++,Fis++,G++,Gis++,A++,B++,H++,C+++,Cis+++,D+++,Dis+++,E+++,F+++,Fis+++,G+++,Gis+++,A+++,B+++,H+++,C++++,Cis++++,D++++,Dis++++,E++++,F++++,Fis++++,G++++,Gis++++,A++++,B++++,H++++,C+++++,Cis+++++,D+++++,Dis+++++,E+++++,F+++++,Fis+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "C-1,Cis-1,D-1,Dis-1,E-1,F-1,Fis-1,G-1,Gis-1,A-1,B-1,H-1,C0,Cis0,D0,Dis0,E0,F0,Fis0,G0,Gis0,A0,B0,H0,C1,Cis1,D1,Dis1,E1,F1,Fis1,G1,Gis1,A1,B1,H1,C2,Cis2,D2,Dis2,E2,F2,Fis2,G2,Gis2,A2,B2,H2,C3,Cis3,D3,Dis3,E3,F3,Fis3,G3,Gis3,A3,B3,H3,C4,Cis4,D4,Dis4,E4,F4,Fis4,G4,Gis4,A4,B4,H4,C5,Cis5,D5,Dis5,E5,F5,Fis5,G5,Gis5,A5,B5,H5,C6,Cis6,D6,Dis6,E6,F6,Fis6,G6,Gis6,A6,B6,H6,C7,Cis7,D7,Dis7,E7,F7,Fis7,G7,Gis7,A7,B7,H7,C8,Cis8,D8,Dis8,E8,F8,Fis8,G8,Gis8,A8,B8,H8,C9,Cis9,D9,Dis9,E9,F9,Fis9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "C''',Cis''',D''',Dis''',E''',F''',Fis''',G''',Gis''',A''',B''',H''',C'',Cis'',D'',Dis'',E'',F'',Fis'',G'',Gis'',A'',B'',H'',C',Cis',D',Dis',E',F',Fis',G',Gis',A',B',H',C,Cis,D,Dis,E,F,Fis,G,Gis,A,B,H,c,cis,d,dis,e,f,fis,g,gis,a,b,h,c',cis',d',dis',e',f',fis',g',gis',a',b',h',c'',cis'',d'',dis'',e'',f'',fis'',g'',gis'',a'',b'',h'',c''',cis''',d''',dis''',e''',f''',fis''',g''',gis''',a''',b''',h''',c'''',cis'''',d'''',dis'''',e'''',f'''',fis'''',g'''',gis'''',a'''',b'''',h'''',c''''',cis''''',d''''',dis''''',e''''',f''''',fis''''',g''''',gis''''',a''''',b''''',h''''',c'''''',cis'''''',d'''''',dis'''''',e'''''',f'''''',fis'''''',g''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "C-5,Des-5,D-5,Es-5,E-5,F-5,Ges-5,G-5,As-5,A-5,B-5,H-5,C-4,Des-4,D-4,Es-4,E-4,F-4,Ges-4,G-4,As-4,A-4,B-4,H-4,C-3,Des-3,D-3,Es-3,E-3,F-3,Ges-3,G-3,As-3,A-3,B-3,H-3,C-2,Des-2,D-2,Es-2,E-2,F-2,Ges-2,G-2,As-2,A-2,B-2,H-2,C-,Des-,D-,Es-,E-,F-,Ges-,G-,As-,A-,B-,H-,C,Des,D,Es,E,F,Ges,G,As,A,B,H,C+,Des+,D+,Es+,E+,F+,Ges+,G+,As+,A+,B+,H+,C+2,Des+2,D+2,Es+2,E+2,F+2,Ges+2,G+2,As+2,A+2,B+2,H+2,C+3,Des+3,D+3,Es+3,E+3,F+3,Ges+3,G+3,As+3,A+3,B+3,H+3,C+4,Des+4,D+4,Es+4,E+4,F+4,Ges+4,G+4,As+4,A+4,B+4,H+4,C+5,Des+5,D+5,Es+5,E+5,F+5,Ges+5,G+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "C-----,Des-----,D-----,Es-----,E-----,F-----,Ges-----,G-----,As-----,A-----,B-----,H-----,C----,Des----,D----,Es----,E----,F----,Ges----,G----,As----,A----,B----,H----,C---,Des---,D---,Es---,E---,F---,Ges---,G---,As---,A---,B---,H---,C--,Des--,D--,Es--,E--,F--,Ges--,G--,As--,A--,B--,H--,C-,Des-,D-,Es-,E-,F-,Ges-,G-,As-,A-,B-,H-,C,Des,D,Es,E,F,Ges,G,As,A,B,H,C+,Des+,D+,Es+,E+,F+,Ges+,G+,As+,A+,B+,H+,C++,Des++,D++,Es++,E++,F++,Ges++,G++,As++,A++,B++,H++,C+++,Des+++,D+++,Es+++,E+++,F+++,Ges+++,G+++,As+++,A+++,B+++,H+++,C++++,Des++++,D++++,Es++++,E++++,F++++,Ges++++,G++++,As++++,A++++,B++++,H++++,C+++++,Des+++++,D+++++,Es+++++,E+++++,F+++++,Ges+++++,G+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "C-1,Des-1,D-1,Es-1,E-1,F-1,Ges-1,G-1,As-1,A-1,B-1,H-1,C0,Des0,D0,Es0,E0,F0,Ges0,G0,As0,A0,B0,H0,C1,Des1,D1,Es1,E1,F1,Ges1,G1,As1,A1,B1,H1,C2,Des2,D2,Es2,E2,F2,Ges2,G2,As2,A2,B2,H2,C3,Des3,D3,Es3,E3,F3,Ges3,G3,As3,A3,B3,H3,C4,Des4,D4,Es4,E4,F4,Ges4,G4,As4,A4,B4,H4,C5,Des5,D5,Es5,E5,F5,Ges5,G5,As5,A5,B5,H5,C6,Des6,D6,Es6,E6,F6,Ges6,G6,As6,A6,B6,H6,C7,Des7,D7,Es7,E7,F7,Ges7,G7,As7,A7,B7,H7,C8,Des8,D8,Es8,E8,F8,Ges8,G8,As8,A8,B8,H8,C9,Des9,D9,Es9,E9,F9,Ges9,G9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "C''',Des''',D''',Es''',E''',F''',Ges''',G''',As''',A''',B''',H''',C'',Des'',D'',Es'',E'',F'',Ges'',G'',As'',A'',B'',H'',C',Des',D',Es',E',F',Ges',G',As',A',B',H',C,Des,D,Es,E,F,Ges,G,As,A,B,H,c,des,d,es,e,f,ges,g,as,a,b,h,c',des',d',es',e',f',ges',g',as',a',b',h',c'',des'',d'',es'',e'',f'',ges'',g'',as'',a'',b'',h'',c''',des''',d''',es''',e''',f''',ges''',g''',as''',a''',b''',h''',c'''',des'''',d'''',es'''',e'''',f'''',ges'''',g'''',as'''',a'''',b'''',h'''',c''''',des''''',d''''',es''''',e''''',f''''',ges''''',g''''',as''''',a''''',b''''',h''''',c'''''',des'''''',d'''''',es'''''',e'''''',f'''''',ges'''''',g''''''\n",
			noteNames.toString()
		);
		
		assertEquals(
			"cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "a###-6, b#-6, dbb-5,a####-6, b##-6, db-5, ebbb-5,b###-6, c##-5, ebb-5, fbbb-5,c###-5, eb-5, fbb-5,c####-5, d##-5, fb-5, gbbb-5,d###-5, e#-5, gbb-5,abbb-5, d####-5, e##-5, gb-5,abb-5, e###-5, f##-5,ab-5, bbbb-5, f###-5,bbb-5, cbbb-4, f####-5, g##-5,bb-5, cbb-4, g###-5,a##-5, cb-4, dbbb-4, g####-5,a###-5, b#-5, dbb-4,a####-5, b##-5, db-4, ebbb-4,b###-5, c##-4, ebb-4, fbbb-4,c###-4, eb-4, fbb-4,c####-4, d##-4, fb-4, gbbb-4,d###-4, e#-4, gbb-4,abbb-4, d####-4, e##-4, gb-4,abb-4, e###-4, f##-4,ab-4, bbbb-4, f###-4,bbb-4, cbbb-3, f####-4, g##-4,bb-4, cbb-3, g###-4,a##-4, cb-3, dbbb-3, g####-4,a###-4, b#-4, dbb-3,a####-4, b##-4, db-3, ebbb-3,b###-4, c##-3, ebb-3, fbbb-3,c###-3, eb-3, fbb-3,c####-3, d##-3, fb-3, gbbb-3,d###-3, e#-3, gbb-3,abbb-3, d####-3, e##-3, gb-3,abb-3, e###-3, f##-3,ab-3, bbbb-3, f###-3,bbb-3, cbbb-2, f####-3, g##-3,bb-3, cbb-2, g###-3,a##-3, cb-2, dbbb-2, g####-3,a###-3, b#-3, dbb-2,a####-3, b##-3, db-2, ebbb-2,b###-3, c##-2, ebb-2, fbbb-2,c###-2, eb-2, fbb-2,c####-2, d##-2, fb-2, gbbb-2,d###-2, e#-2, gbb-2,abbb-2, d####-2, e##-2, gb-2,abb-2, e###-2, f##-2,ab-2, bbbb-2, f###-2,bbb-2, cbbb-, f####-2, g##-2,bb-2, cbb-, g###-2,a##-2, cb-, dbbb-, g####-2,a###-2, b#-2, dbb-,a####-2, b##-2, db-, ebbb-,b###-2, c##-, ebb-, fbbb-,c###-, eb-, fbb-,c####-, d##-, fb-, gbbb-,d###-, e#-, gbb-,abbb-, d####-, e##-, gb-,abb-, e###-, f##-,ab-, bbbb-, f###-,bbb-, cbbb, f####-, g##-,bb-, cbb, g###-,a##-, cb, dbbb, g####-,a###-, b#-, dbb,a####-, b##-, db, ebbb,b###-, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, e###, f##,ab, bbbb, f###,bbb, cbbb+, f####, g##,bb, cbb+, g###,a##, cb+, dbbb+, g####,a###, b#, dbb+,a####, b##, db+, ebbb+,b###, c##+, ebb+, fbbb+,c###+, eb+, fbb+,c####+, d##+, fb+, gbbb+,d###+, e#+, gbb+,abbb+, d####+, e##+, gb+,abb+, e###+, f##+,ab+, bbbb+, f###+,bbb+, cbbb+2, f####+, g##+,bb+, cbb+2, g###+,a##+, cb+2, dbbb+2, g####+,a###+, b#+, dbb+2,a####+, b##+, db+2, ebbb+2,b###+, c##+2, ebb+2, fbbb+2,c###+2, eb+2, fbb+2,c####+2, d##+2, fb+2, gbbb+2,d###+2, e#+2, gbb+2,abbb+2, d####+2, e##+2, gb+2,abb+2, e###+2, f##+2,ab+2, bbbb+2, f###+2,bbb+2, cbbb+3, f####+2, g##+2,bb+2, cbb+3, g###+2,a##+2, cb+3, dbbb+3, g####+2,a###+2, b#+2, dbb+3,a####+2, b##+2, db+3, ebbb+3,b###+2, c##+3, ebb+3, fbbb+3,c###+3, eb+3, fbb+3,c####+3, d##+3, fb+3, gbbb+3,d###+3, e#+3, gbb+3,abbb+3, d####+3, e##+3, gb+3,abb+3, e###+3, f##+3,ab+3, bbbb+3, f###+3,bbb+3, cbbb+4, f####+3, g##+3,bb+3, cbb+4, g###+3,a##+3, cb+4, dbbb+4, g####+3,a###+3, b#+3, dbb+4,a####+3, b##+3, db+4, ebbb+4,b###+3, c##+4, ebb+4, fbbb+4,c###+4, eb+4, fbb+4,c####+4, d##+4, fb+4, gbbb+4,d###+4, e#+4, gbb+4,abbb+4, d####+4, e##+4, gb+4,abb+4, e###+4, f##+4,ab+4, bbbb+4, f###+4,bbb+4, cbbb+5, f####+4, g##+4,bb+4, cbb+5, g###+4,a##+4, cb+5, dbbb+5, g####+4,a###+4, b#+4, dbb+5,a####+4, b##+4, db+5, ebbb+5,b###+4, c##+5, ebb+5, fbbb+5,c###+5, eb+5, fbb+5,c####+5, d##+5, fb+5, gbbb+5,d###+5, e#+5, gbb+5,abbb+5, d####+5, e##+5, gb+5,abb+5, e###+5, f##+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "a###------, b#------, dbb-----,a####------, b##------, db-----, ebbb-----,b###------, c##-----, ebb-----, fbbb-----,c###-----, eb-----, fbb-----,c####-----, d##-----, fb-----, gbbb-----,d###-----, e#-----, gbb-----,abbb-----, d####-----, e##-----, gb-----,abb-----, e###-----, f##-----,ab-----, bbbb-----, f###-----,bbb-----, cbbb----, f####-----, g##-----,bb-----, cbb----, g###-----,a##-----, cb----, dbbb----, g####-----,a###-----, b#-----, dbb----,a####-----, b##-----, db----, ebbb----,b###-----, c##----, ebb----, fbbb----,c###----, eb----, fbb----,c####----, d##----, fb----, gbbb----,d###----, e#----, gbb----,abbb----, d####----, e##----, gb----,abb----, e###----, f##----,ab----, bbbb----, f###----,bbb----, cbbb---, f####----, g##----,bb----, cbb---, g###----,a##----, cb---, dbbb---, g####----,a###----, b#----, dbb---,a####----, b##----, db---, ebbb---,b###----, c##---, ebb---, fbbb---,c###---, eb---, fbb---,c####---, d##---, fb---, gbbb---,d###---, e#---, gbb---,abbb---, d####---, e##---, gb---,abb---, e###---, f##---,ab---, bbbb---, f###---,bbb---, cbbb--, f####---, g##---,bb---, cbb--, g###---,a##---, cb--, dbbb--, g####---,a###---, b#---, dbb--,a####---, b##---, db--, ebbb--,b###---, c##--, ebb--, fbbb--,c###--, eb--, fbb--,c####--, d##--, fb--, gbbb--,d###--, e#--, gbb--,abbb--, d####--, e##--, gb--,abb--, e###--, f##--,ab--, bbbb--, f###--,bbb--, cbbb-, f####--, g##--,bb--, cbb-, g###--,a##--, cb-, dbbb-, g####--,a###--, b#--, dbb-,a####--, b##--, db-, ebbb-,b###--, c##-, ebb-, fbbb-,c###-, eb-, fbb-,c####-, d##-, fb-, gbbb-,d###-, e#-, gbb-,abbb-, d####-, e##-, gb-,abb-, e###-, f##-,ab-, bbbb-, f###-,bbb-, cbbb, f####-, g##-,bb-, cbb, g###-,a##-, cb, dbbb, g####-,a###-, b#-, dbb,a####-, b##-, db, ebbb,b###-, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, e###, f##,ab, bbbb, f###,bbb, cbbb+, f####, g##,bb, cbb+, g###,a##, cb+, dbbb+, g####,a###, b#, dbb+,a####, b##, db+, ebbb+,b###, c##+, ebb+, fbbb+,c###+, eb+, fbb+,c####+, d##+, fb+, gbbb+,d###+, e#+, gbb+,abbb+, d####+, e##+, gb+,abb+, e###+, f##+,ab+, bbbb+, f###+,bbb+, cbbb++, f####+, g##+,bb+, cbb++, g###+,a##+, cb++, dbbb++, g####+,a###+, b#+, dbb++,a####+, b##+, db++, ebbb++,b###+, c##++, ebb++, fbbb++,c###++, eb++, fbb++,c####++, d##++, fb++, gbbb++,d###++, e#++, gbb++,abbb++, d####++, e##++, gb++,abb++, e###++, f##++,ab++, bbbb++, f###++,bbb++, cbbb+++, f####++, g##++,bb++, cbb+++, g###++,a##++, cb+++, dbbb+++, g####++,a###++, b#++, dbb+++,a####++, b##++, db+++, ebbb+++,b###++, c##+++, ebb+++, fbbb+++,c###+++, eb+++, fbb+++,c####+++, d##+++, fb+++, gbbb+++,d###+++, e#+++, gbb+++,abbb+++, d####+++, e##+++, gb+++,abb+++, e###+++, f##+++,ab+++, bbbb+++, f###+++,bbb+++, cbbb++++, f####+++, g##+++,bb+++, cbb++++, g###+++,a##+++, cb++++, dbbb++++, g####+++,a###+++, b#+++, dbb++++,a####+++, b##+++, db++++, ebbb++++,b###+++, c##++++, ebb++++, fbbb++++,c###++++, eb++++, fbb++++,c####++++, d##++++, fb++++, gbbb++++,d###++++, e#++++, gbb++++,abbb++++, d####++++, e##++++, gb++++,abb++++, e###++++, f##++++,ab++++, bbbb++++, f###++++,bbb++++, cbbb+++++, f####++++, g##++++,bb++++, cbb+++++, g###++++,a##++++, cb+++++, dbbb+++++, g####++++,a###++++, b#++++, dbb+++++,a####++++, b##++++, db+++++, ebbb+++++,b###++++, c##+++++, ebb+++++, fbbb+++++,c###+++++, eb+++++, fbb+++++,c####+++++, d##+++++, fb+++++, gbbb+++++,d###+++++, e#+++++, gbb+++++,abbb+++++, d####+++++, e##+++++, gb+++++,abb+++++, e###+++++, f##+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "a###-2, b#-2, dbb-1,a####-2, b##-2, db-1, ebbb-1,b###-2, c##-1, ebb-1, fbbb-1,c###-1, eb-1, fbb-1,c####-1, d##-1, fb-1, gbbb-1,d###-1, e#-1, gbb-1,abbb-1, d####-1, e##-1, gb-1,abb-1, e###-1, f##-1,ab-1, bbbb-1, f###-1,bbb-1, cbbb0, f####-1, g##-1,bb-1, cbb0, g###-1,a##-1, cb0, dbbb0, g####-1,a###-1, b#-1, dbb0,a####-1, b##-1, db0, ebbb0,b###-1, c##0, ebb0, fbbb0,c###0, eb0, fbb0,c####0, d##0, fb0, gbbb0,d###0, e#0, gbb0,abbb0, d####0, e##0, gb0,abb0, e###0, f##0,ab0, bbbb0, f###0,bbb0, cbbb1, f####0, g##0,bb0, cbb1, g###0,a##0, cb1, dbbb1, g####0,a###0, b#0, dbb1,a####0, b##0, db1, ebbb1,b###0, c##1, ebb1, fbbb1,c###1, eb1, fbb1,c####1, d##1, fb1, gbbb1,d###1, e#1, gbb1,abbb1, d####1, e##1, gb1,abb1, e###1, f##1,ab1, bbbb1, f###1,bbb1, cbbb2, f####1, g##1,bb1, cbb2, g###1,a##1, cb2, dbbb2, g####1,a###1, b#1, dbb2,a####1, b##1, db2, ebbb2,b###1, c##2, ebb2, fbbb2,c###2, eb2, fbb2,c####2, d##2, fb2, gbbb2,d###2, e#2, gbb2,abbb2, d####2, e##2, gb2,abb2, e###2, f##2,ab2, bbbb2, f###2,bbb2, cbbb3, f####2, g##2,bb2, cbb3, g###2,a##2, cb3, dbbb3, g####2,a###2, b#2, dbb3,a####2, b##2, db3, ebbb3,b###2, c##3, ebb3, fbbb3,c###3, eb3, fbb3,c####3, d##3, fb3, gbbb3,d###3, e#3, gbb3,abbb3, d####3, e##3, gb3,abb3, e###3, f##3,ab3, bbbb3, f###3,bbb3, cbbb4, f####3, g##3,bb3, cbb4, g###3,a##3, cb4, dbbb4, g####3,a###3, b#3, dbb4,a####3, b##3, db4, ebbb4,b###3, c##4, ebb4, fbbb4,c###4, eb4, fbb4,c####4, d##4, fb4, gbbb4,d###4, e#4, gbb4,abbb4, d####4, e##4, gb4,abb4, e###4, f##4,ab4, bbbb4, f###4,bbb4, cbbb5, f####4, g##4,bb4, cbb5, g###4,a##4, cb5, dbbb5, g####4,a###4, b#4, dbb5,a####4, b##4, db5, ebbb5,b###4, c##5, ebb5, fbbb5,c###5, eb5, fbb5,c####5, d##5, fb5, gbbb5,d###5, e#5, gbb5,abbb5, d####5, e##5, gb5,abb5, e###5, f##5,ab5, bbbb5, f###5,bbb5, cbbb6, f####5, g##5,bb5, cbb6, g###5,a##5, cb6, dbbb6, g####5,a###5, b#5, dbb6,a####5, b##5, db6, ebbb6,b###5, c##6, ebb6, fbbb6,c###6, eb6, fbb6,c####6, d##6, fb6, gbbb6,d###6, e#6, gbb6,abbb6, d####6, e##6, gb6,abb6, e###6, f##6,ab6, bbbb6, f###6,bbb6, cbbb7, f####6, g##6,bb6, cbb7, g###6,a##6, cb7, dbbb7, g####6,a###6, b#6, dbb7,a####6, b##6, db7, ebbb7,b###6, c##7, ebb7, fbbb7,c###7, eb7, fbb7,c####7, d##7, fb7, gbbb7,d###7, e#7, gbb7,abbb7, d####7, e##7, gb7,abb7, e###7, f##7,ab7, bbbb7, f###7,bbb7, cbbb8, f####7, g##7,bb7, cbb8, g###7,a##7, cb8, dbbb8, g####7,a###7, b#7, dbb8,a####7, b##7, db8, ebbb8,b###7, c##8, ebb8, fbbb8,c###8, eb8, fbb8,c####8, d##8, fb8, gbbb8,d###8, e#8, gbb8,abbb8, d####8, e##8, gb8,abb8, e###8, f##8,ab8, bbbb8, f###8,bbb8, cbbb9, f####8, g##8,bb8, cbb9, g###8,a##8, cb9, dbbb9, g####8,a###8, b#8, dbb9,a####8, b##8, db9, ebbb9,b###8, c##9, ebb9, fbbb9,c###9, eb9, fbb9,c####9, d##9, fb9, gbbb9,d###9, e#9, gbb9,abbb9, d####9, e##9, gb9,abb9, e###9, f##9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A###'''', B#'''', Dbb''',A####'''', B##'''', Db''', Ebbb''',B###'''', C##''', Ebb''', Fbbb''',C###''', Eb''', Fbb''',C####''', D##''', Fb''', Gbbb''',D###''', E#''', Gbb''',Abbb''', D####''', E##''', Gb''',Abb''', E###''', F##''',Ab''', Bbbb''', F###''',Bbb''', Cbbb'', F####''', G##''',Bb''', Cbb'', G###''',A##''', Cb'', Dbbb'', G####''',A###''', B#''', Dbb'',A####''', B##''', Db'', Ebbb'',B###''', C##'', Ebb'', Fbbb'',C###'', Eb'', Fbb'',C####'', D##'', Fb'', Gbbb'',D###'', E#'', Gbb'',Abbb'', D####'', E##'', Gb'',Abb'', E###'', F##'',Ab'', Bbbb'', F###'',Bbb'', Cbbb', F####'', G##'',Bb'', Cbb', G###'',A##'', Cb', Dbbb', G####'',A###'', B#'', Dbb',A####'', B##'', Db', Ebbb',B###'', C##', Ebb', Fbbb',C###', Eb', Fbb',C####', D##', Fb', Gbbb',D###', E#', Gbb',Abbb', D####', E##', Gb',Abb', E###', F##',Ab', Bbbb', F###',Bbb', Cbbb, F####', G##',Bb', Cbb, G###',A##', Cb, Dbbb, G####',A###', B#', Dbb,A####', B##', Db, Ebbb,B###', C##, Ebb, Fbbb,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, E###, F##,Ab, Bbbb, F###,Bbb, F####, G##, cbbb,Bb, G###, cbb,A##, G####, cb, dbbb,A###, B#, dbb,A####, B##, db, ebbb,B###, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, e###, f##,ab, bbbb, f###,bbb, cbbb', f####, g##,bb, cbb', g###,a##, cb', dbbb', g####,a###, b#, dbb',a####, b##, db', ebbb',b###, c##', ebb', fbbb',c###', eb', fbb',c####', d##', fb', gbbb',d###', e#', gbb',abbb', d####', e##', gb',abb', e###', f##',ab', bbbb', f###',bbb', cbbb'', f####', g##',bb', cbb'', g###',a##', cb'', dbbb'', g####',a###', b#', dbb'',a####', b##', db'', ebbb'',b###', c##'', ebb'', fbbb'',c###'', eb'', fbb'',c####'', d##'', fb'', gbbb'',d###'', e#'', gbb'',abbb'', d####'', e##'', gb'',abb'', e###'', f##'',ab'', bbbb'', f###'',bbb'', cbbb''', f####'', g##'',bb'', cbb''', g###'',a##'', cb''', dbbb''', g####'',a###'', b#'', dbb''',a####'', b##'', db''', ebbb''',b###'', c##''', ebb''', fbbb''',c###''', eb''', fbb''',c####''', d##''', fb''', gbbb''',d###''', e#''', gbb''',abbb''', d####''', e##''', gb''',abb''', e###''', f##''',ab''', bbbb''', f###''',bbb''', cbbb'''', f####''', g##''',bb''', cbb'''', g###''',a##''', cb'''', dbbb'''', g####''',a###''', b#''', dbb'''',a####''', b##''', db'''', ebbb'''',b###''', c##'''', ebb'''', fbbb'''',c###'''', eb'''', fbb'''',c####'''', d##'''', fb'''', gbbb'''',d###'''', e#'''', gbb'''',abbb'''', d####'''', e##'''', gb'''',abb'''', e###'''', f##'''',ab'''', bbbb'''', f###'''',bbb'''', cbbb''''', f####'''', g##'''',bb'''', cbb''''', g###'''',a##'''', cb''''', dbbb''''', g####'''',a###'''', b#'''', dbb''''',a####'''', b##'''', db''''', ebbb''''',b###'''', c##''''', ebb''''', fbbb''''',c###''''', eb''''', fbb''''',c####''''', d##''''', fb''''', gbbb''''',d###''''', e#''''', gbb''''',abbb''''', d####''''', e##''''', gb''''',abb''''', e###''''', f##''''',ab''''', bbbb''''', f###''''',bbb''''', cbbb'''''', f####''''', g##''''',bb''''', cbb'''''', g###''''',a##''''', cb'''''', dbbb'''''', g####''''',a###''''', b#''''', dbb'''''',a####''''', b##''''', db'''''', ebbb'''''',b###''''', c##'''''', ebb'''''', fbbb'''''',c###'''''', eb'''''', fbb'''''',c####'''''', d##'''''', fb'''''', gbbb'''''',d###'''''', e#'''''', gbb'''''',abbb'''''', d####'''''', e##'''''', gb'''''',abb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "a###-6, b#-6, dbb-5, ebbbb-5,b##-6, c#-5, ebbb-5,b###-6, c##-5, ebb-5, fbbb-5,c###-5, d#-5, fbb-5, gbbbb-5,d##-5, fb-5, gbbb-5,abbbb-5, d###-5, e#-5, gbb-5,abbb-5, e##-5, f#-5,abb-5, bbbbb-5, e###-5, f##-5,bbbb-5, f###-5, g#-5,bbb-5, cbbb-4, g##-5,a#-5, cbb-4, dbbbb-4, g###-5,a##-5, cb-4, dbbb-4,a###-5, b#-5, dbb-4, ebbbb-4,b##-5, c#-4, ebbb-4,b###-5, c##-4, ebb-4, fbbb-4,c###-4, d#-4, fbb-4, gbbbb-4,d##-4, fb-4, gbbb-4,abbbb-4, d###-4, e#-4, gbb-4,abbb-4, e##-4, f#-4,abb-4, bbbbb-4, e###-4, f##-4,bbbb-4, f###-4, g#-4,bbb-4, cbbb-3, g##-4,a#-4, cbb-3, dbbbb-3, g###-4,a##-4, cb-3, dbbb-3,a###-4, b#-4, dbb-3, ebbbb-3,b##-4, c#-3, ebbb-3,b###-4, c##-3, ebb-3, fbbb-3,c###-3, d#-3, fbb-3, gbbbb-3,d##-3, fb-3, gbbb-3,abbbb-3, d###-3, e#-3, gbb-3,abbb-3, e##-3, f#-3,abb-3, bbbbb-3, e###-3, f##-3,bbbb-3, f###-3, g#-3,bbb-3, cbbb-2, g##-3,a#-3, cbb-2, dbbbb-2, g###-3,a##-3, cb-2, dbbb-2,a###-3, b#-3, dbb-2, ebbbb-2,b##-3, c#-2, ebbb-2,b###-3, c##-2, ebb-2, fbbb-2,c###-2, d#-2, fbb-2, gbbbb-2,d##-2, fb-2, gbbb-2,abbbb-2, d###-2, e#-2, gbb-2,abbb-2, e##-2, f#-2,abb-2, bbbbb-2, e###-2, f##-2,bbbb-2, f###-2, g#-2,bbb-2, cbbb-, g##-2,a#-2, cbb-, dbbbb-, g###-2,a##-2, cb-, dbbb-,a###-2, b#-2, dbb-, ebbbb-,b##-2, c#-, ebbb-,b###-2, c##-, ebb-, fbbb-,c###-, d#-, fbb-, gbbbb-,d##-, fb-, gbbb-,abbbb-, d###-, e#-, gbb-,abbb-, e##-, f#-,abb-, bbbbb-, e###-, f##-,bbbb-, f###-, g#-,bbb-, cbbb, g##-,a#-, cbb, dbbbb, g###-,a##-, cb, dbbb,a###-, b#-, dbb, ebbbb,b##-, c#, ebbb,b###-, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbbb, e###, f##,bbbb, f###, g#,bbb, cbbb+, g##,a#, cbb+, dbbbb+, g###,a##, cb+, dbbb+,a###, b#, dbb+, ebbbb+,b##, c#+, ebbb+,b###, c##+, ebb+, fbbb+,c###+, d#+, fbb+, gbbbb+,d##+, fb+, gbbb+,abbbb+, d###+, e#+, gbb+,abbb+, e##+, f#+,abb+, bbbbb+, e###+, f##+,bbbb+, f###+, g#+,bbb+, cbbb+2, g##+,a#+, cbb+2, dbbbb+2, g###+,a##+, cb+2, dbbb+2,a###+, b#+, dbb+2, ebbbb+2,b##+, c#+2, ebbb+2,b###+, c##+2, ebb+2, fbbb+2,c###+2, d#+2, fbb+2, gbbbb+2,d##+2, fb+2, gbbb+2,abbbb+2, d###+2, e#+2, gbb+2,abbb+2, e##+2, f#+2,abb+2, bbbbb+2, e###+2, f##+2,bbbb+2, f###+2, g#+2,bbb+2, cbbb+3, g##+2,a#+2, cbb+3, dbbbb+3, g###+2,a##+2, cb+3, dbbb+3,a###+2, b#+2, dbb+3, ebbbb+3,b##+2, c#+3, ebbb+3,b###+2, c##+3, ebb+3, fbbb+3,c###+3, d#+3, fbb+3, gbbbb+3,d##+3, fb+3, gbbb+3,abbbb+3, d###+3, e#+3, gbb+3,abbb+3, e##+3, f#+3,abb+3, bbbbb+3, e###+3, f##+3,bbbb+3, f###+3, g#+3,bbb+3, cbbb+4, g##+3,a#+3, cbb+4, dbbbb+4, g###+3,a##+3, cb+4, dbbb+4,a###+3, b#+3, dbb+4, ebbbb+4,b##+3, c#+4, ebbb+4,b###+3, c##+4, ebb+4, fbbb+4,c###+4, d#+4, fbb+4, gbbbb+4,d##+4, fb+4, gbbb+4,abbbb+4, d###+4, e#+4, gbb+4,abbb+4, e##+4, f#+4,abb+4, bbbbb+4, e###+4, f##+4,bbbb+4, f###+4, g#+4,bbb+4, cbbb+5, g##+4,a#+4, cbb+5, dbbbb+5, g###+4,a##+4, cb+5, dbbb+5,a###+4, b#+4, dbb+5, ebbbb+5,b##+4, c#+5, ebbb+5,b###+4, c##+5, ebb+5, fbbb+5,c###+5, d#+5, fbb+5, gbbbb+5,d##+5, fb+5, gbbb+5,abbbb+5, d###+5, e#+5, gbb+5,abbb+5, e##+5, f#+5,abb+5, bbbbb+5, e###+5, f##+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "a###------, b#------, dbb-----, ebbbb-----,b##------, c#-----, ebbb-----,b###------, c##-----, ebb-----, fbbb-----,c###-----, d#-----, fbb-----, gbbbb-----,d##-----, fb-----, gbbb-----,abbbb-----, d###-----, e#-----, gbb-----,abbb-----, e##-----, f#-----,abb-----, bbbbb-----, e###-----, f##-----,bbbb-----, f###-----, g#-----,bbb-----, cbbb----, g##-----,a#-----, cbb----, dbbbb----, g###-----,a##-----, cb----, dbbb----,a###-----, b#-----, dbb----, ebbbb----,b##-----, c#----, ebbb----,b###-----, c##----, ebb----, fbbb----,c###----, d#----, fbb----, gbbbb----,d##----, fb----, gbbb----,abbbb----, d###----, e#----, gbb----,abbb----, e##----, f#----,abb----, bbbbb----, e###----, f##----,bbbb----, f###----, g#----,bbb----, cbbb---, g##----,a#----, cbb---, dbbbb---, g###----,a##----, cb---, dbbb---,a###----, b#----, dbb---, ebbbb---,b##----, c#---, ebbb---,b###----, c##---, ebb---, fbbb---,c###---, d#---, fbb---, gbbbb---,d##---, fb---, gbbb---,abbbb---, d###---, e#---, gbb---,abbb---, e##---, f#---,abb---, bbbbb---, e###---, f##---,bbbb---, f###---, g#---,bbb---, cbbb--, g##---,a#---, cbb--, dbbbb--, g###---,a##---, cb--, dbbb--,a###---, b#---, dbb--, ebbbb--,b##---, c#--, ebbb--,b###---, c##--, ebb--, fbbb--,c###--, d#--, fbb--, gbbbb--,d##--, fb--, gbbb--,abbbb--, d###--, e#--, gbb--,abbb--, e##--, f#--,abb--, bbbbb--, e###--, f##--,bbbb--, f###--, g#--,bbb--, cbbb-, g##--,a#--, cbb-, dbbbb-, g###--,a##--, cb-, dbbb-,a###--, b#--, dbb-, ebbbb-,b##--, c#-, ebbb-,b###--, c##-, ebb-, fbbb-,c###-, d#-, fbb-, gbbbb-,d##-, fb-, gbbb-,abbbb-, d###-, e#-, gbb-,abbb-, e##-, f#-,abb-, bbbbb-, e###-, f##-,bbbb-, f###-, g#-,bbb-, cbbb, g##-,a#-, cbb, dbbbb, g###-,a##-, cb, dbbb,a###-, b#-, dbb, ebbbb,b##-, c#, ebbb,b###-, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbbb, e###, f##,bbbb, f###, g#,bbb, cbbb+, g##,a#, cbb+, dbbbb+, g###,a##, cb+, dbbb+,a###, b#, dbb+, ebbbb+,b##, c#+, ebbb+,b###, c##+, ebb+, fbbb+,c###+, d#+, fbb+, gbbbb+,d##+, fb+, gbbb+,abbbb+, d###+, e#+, gbb+,abbb+, e##+, f#+,abb+, bbbbb+, e###+, f##+,bbbb+, f###+, g#+,bbb+, cbbb++, g##+,a#+, cbb++, dbbbb++, g###+,a##+, cb++, dbbb++,a###+, b#+, dbb++, ebbbb++,b##+, c#++, ebbb++,b###+, c##++, ebb++, fbbb++,c###++, d#++, fbb++, gbbbb++,d##++, fb++, gbbb++,abbbb++, d###++, e#++, gbb++,abbb++, e##++, f#++,abb++, bbbbb++, e###++, f##++,bbbb++, f###++, g#++,bbb++, cbbb+++, g##++,a#++, cbb+++, dbbbb+++, g###++,a##++, cb+++, dbbb+++,a###++, b#++, dbb+++, ebbbb+++,b##++, c#+++, ebbb+++,b###++, c##+++, ebb+++, fbbb+++,c###+++, d#+++, fbb+++, gbbbb+++,d##+++, fb+++, gbbb+++,abbbb+++, d###+++, e#+++, gbb+++,abbb+++, e##+++, f#+++,abb+++, bbbbb+++, e###+++, f##+++,bbbb+++, f###+++, g#+++,bbb+++, cbbb++++, g##+++,a#+++, cbb++++, dbbbb++++, g###+++,a##+++, cb++++, dbbb++++,a###+++, b#+++, dbb++++, ebbbb++++,b##+++, c#++++, ebbb++++,b###+++, c##++++, ebb++++, fbbb++++,c###++++, d#++++, fbb++++, gbbbb++++,d##++++, fb++++, gbbb++++,abbbb++++, d###++++, e#++++, gbb++++,abbb++++, e##++++, f#++++,abb++++, bbbbb++++, e###++++, f##++++,bbbb++++, f###++++, g#++++,bbb++++, cbbb+++++, g##++++,a#++++, cbb+++++, dbbbb+++++, g###++++,a##++++, cb+++++, dbbb+++++,a###++++, b#++++, dbb+++++, ebbbb+++++,b##++++, c#+++++, ebbb+++++,b###++++, c##+++++, ebb+++++, fbbb+++++,c###+++++, d#+++++, fbb+++++, gbbbb+++++,d##+++++, fb+++++, gbbb+++++,abbbb+++++, d###+++++, e#+++++, gbb+++++,abbb+++++, e##+++++, f#+++++,abb+++++, bbbbb+++++, e###+++++, f##+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "a###-2, b#-2, dbb-1, ebbbb-1,b##-2, c#-1, ebbb-1,b###-2, c##-1, ebb-1, fbbb-1,c###-1, d#-1, fbb-1, gbbbb-1,d##-1, fb-1, gbbb-1,abbbb-1, d###-1, e#-1, gbb-1,abbb-1, e##-1, f#-1,abb-1, bbbbb-1, e###-1, f##-1,bbbb-1, f###-1, g#-1,bbb-1, cbbb0, g##-1,a#-1, cbb0, dbbbb0, g###-1,a##-1, cb0, dbbb0,a###-1, b#-1, dbb0, ebbbb0,b##-1, c#0, ebbb0,b###-1, c##0, ebb0, fbbb0,c###0, d#0, fbb0, gbbbb0,d##0, fb0, gbbb0,abbbb0, d###0, e#0, gbb0,abbb0, e##0, f#0,abb0, bbbbb0, e###0, f##0,bbbb0, f###0, g#0,bbb0, cbbb1, g##0,a#0, cbb1, dbbbb1, g###0,a##0, cb1, dbbb1,a###0, b#0, dbb1, ebbbb1,b##0, c#1, ebbb1,b###0, c##1, ebb1, fbbb1,c###1, d#1, fbb1, gbbbb1,d##1, fb1, gbbb1,abbbb1, d###1, e#1, gbb1,abbb1, e##1, f#1,abb1, bbbbb1, e###1, f##1,bbbb1, f###1, g#1,bbb1, cbbb2, g##1,a#1, cbb2, dbbbb2, g###1,a##1, cb2, dbbb2,a###1, b#1, dbb2, ebbbb2,b##1, c#2, ebbb2,b###1, c##2, ebb2, fbbb2,c###2, d#2, fbb2, gbbbb2,d##2, fb2, gbbb2,abbbb2, d###2, e#2, gbb2,abbb2, e##2, f#2,abb2, bbbbb2, e###2, f##2,bbbb2, f###2, g#2,bbb2, cbbb3, g##2,a#2, cbb3, dbbbb3, g###2,a##2, cb3, dbbb3,a###2, b#2, dbb3, ebbbb3,b##2, c#3, ebbb3,b###2, c##3, ebb3, fbbb3,c###3, d#3, fbb3, gbbbb3,d##3, fb3, gbbb3,abbbb3, d###3, e#3, gbb3,abbb3, e##3, f#3,abb3, bbbbb3, e###3, f##3,bbbb3, f###3, g#3,bbb3, cbbb4, g##3,a#3, cbb4, dbbbb4, g###3,a##3, cb4, dbbb4,a###3, b#3, dbb4, ebbbb4,b##3, c#4, ebbb4,b###3, c##4, ebb4, fbbb4,c###4, d#4, fbb4, gbbbb4,d##4, fb4, gbbb4,abbbb4, d###4, e#4, gbb4,abbb4, e##4, f#4,abb4, bbbbb4, e###4, f##4,bbbb4, f###4, g#4,bbb4, cbbb5, g##4,a#4, cbb5, dbbbb5, g###4,a##4, cb5, dbbb5,a###4, b#4, dbb5, ebbbb5,b##4, c#5, ebbb5,b###4, c##5, ebb5, fbbb5,c###5, d#5, fbb5, gbbbb5,d##5, fb5, gbbb5,abbbb5, d###5, e#5, gbb5,abbb5, e##5, f#5,abb5, bbbbb5, e###5, f##5,bbbb5, f###5, g#5,bbb5, cbbb6, g##5,a#5, cbb6, dbbbb6, g###5,a##5, cb6, dbbb6,a###5, b#5, dbb6, ebbbb6,b##5, c#6, ebbb6,b###5, c##6, ebb6, fbbb6,c###6, d#6, fbb6, gbbbb6,d##6, fb6, gbbb6,abbbb6, d###6, e#6, gbb6,abbb6, e##6, f#6,abb6, bbbbb6, e###6, f##6,bbbb6, f###6, g#6,bbb6, cbbb7, g##6,a#6, cbb7, dbbbb7, g###6,a##6, cb7, dbbb7,a###6, b#6, dbb7, ebbbb7,b##6, c#7, ebbb7,b###6, c##7, ebb7, fbbb7,c###7, d#7, fbb7, gbbbb7,d##7, fb7, gbbb7,abbbb7, d###7, e#7, gbb7,abbb7, e##7, f#7,abb7, bbbbb7, e###7, f##7,bbbb7, f###7, g#7,bbb7, cbbb8, g##7,a#7, cbb8, dbbbb8, g###7,a##7, cb8, dbbb8,a###7, b#7, dbb8, ebbbb8,b##7, c#8, ebbb8,b###7, c##8, ebb8, fbbb8,c###8, d#8, fbb8, gbbbb8,d##8, fb8, gbbb8,abbbb8, d###8, e#8, gbb8,abbb8, e##8, f#8,abb8, bbbbb8, e###8, f##8,bbbb8, f###8, g#8,bbb8, cbbb9, g##8,a#8, cbb9, dbbbb9, g###8,a##8, cb9, dbbb9,a###8, b#8, dbb9, ebbbb9,b##8, c#9, ebbb9,b###8, c##9, ebb9, fbbb9,c###9, d#9, fbb9, gbbbb9,d##9, fb9, gbbb9,abbbb9, d###9, e#9, gbb9,abbb9, e##9, f#9,abb9, bbbbb9, e###9, f##9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A###'''', B#'''', Dbb''', Ebbbb''',B##'''', C#''', Ebbb''',B###'''', C##''', Ebb''', Fbbb''',C###''', D#''', Fbb''', Gbbbb''',D##''', Fb''', Gbbb''',Abbbb''', D###''', E#''', Gbb''',Abbb''', E##''', F#''',Abb''', Bbbbb''', E###''', F##''',Bbbb''', F###''', G#''',Bbb''', Cbbb'', G##''',A#''', Cbb'', Dbbbb'', G###''',A##''', Cb'', Dbbb'',A###''', B#''', Dbb'', Ebbbb'',B##''', C#'', Ebbb'',B###''', C##'', Ebb'', Fbbb'',C###'', D#'', Fbb'', Gbbbb'',D##'', Fb'', Gbbb'',Abbbb'', D###'', E#'', Gbb'',Abbb'', E##'', F#'',Abb'', Bbbbb'', E###'', F##'',Bbbb'', F###'', G#'',Bbb'', Cbbb', G##'',A#'', Cbb', Dbbbb', G###'',A##'', Cb', Dbbb',A###'', B#'', Dbb', Ebbbb',B##'', C#', Ebbb',B###'', C##', Ebb', Fbbb',C###', D#', Fbb', Gbbbb',D##', Fb', Gbbb',Abbbb', D###', E#', Gbb',Abbb', E##', F#',Abb', Bbbbb', E###', F##',Bbbb', F###', G#',Bbb', Cbbb, G##',A#', Cbb, Dbbbb, G###',A##', Cb, Dbbb,A###', B#', Dbb, Ebbbb,B##', C#, Ebbb,B###', C##, Ebb, Fbbb,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbbb, E###, F##,Bbbb, F###, G#,Bbb, G##, cbbb,A#, G###, cbb, dbbbb,A##, cb, dbbb,A###, B#, dbb, ebbbb,B##, c#, ebbb,B###, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbbb, e###, f##,bbbb, f###, g#,bbb, cbbb', g##,a#, cbb', dbbbb', g###,a##, cb', dbbb',a###, b#, dbb', ebbbb',b##, c#', ebbb',b###, c##', ebb', fbbb',c###', d#', fbb', gbbbb',d##', fb', gbbb',abbbb', d###', e#', gbb',abbb', e##', f#',abb', bbbbb', e###', f##',bbbb', f###', g#',bbb', cbbb'', g##',a#', cbb'', dbbbb'', g###',a##', cb'', dbbb'',a###', b#', dbb'', ebbbb'',b##', c#'', ebbb'',b###', c##'', ebb'', fbbb'',c###'', d#'', fbb'', gbbbb'',d##'', fb'', gbbb'',abbbb'', d###'', e#'', gbb'',abbb'', e##'', f#'',abb'', bbbbb'', e###'', f##'',bbbb'', f###'', g#'',bbb'', cbbb''', g##'',a#'', cbb''', dbbbb''', g###'',a##'', cb''', dbbb''',a###'', b#'', dbb''', ebbbb''',b##'', c#''', ebbb''',b###'', c##''', ebb''', fbbb''',c###''', d#''', fbb''', gbbbb''',d##''', fb''', gbbb''',abbbb''', d###''', e#''', gbb''',abbb''', e##''', f#''',abb''', bbbbb''', e###''', f##''',bbbb''', f###''', g#''',bbb''', cbbb'''', g##''',a#''', cbb'''', dbbbb'''', g###''',a##''', cb'''', dbbb'''',a###''', b#''', dbb'''', ebbbb'''',b##''', c#'''', ebbb'''',b###''', c##'''', ebb'''', fbbb'''',c###'''', d#'''', fbb'''', gbbbb'''',d##'''', fb'''', gbbb'''',abbbb'''', d###'''', e#'''', gbb'''',abbb'''', e##'''', f#'''',abb'''', bbbbb'''', e###'''', f##'''',bbbb'''', f###'''', g#'''',bbb'''', cbbb''''', g##'''',a#'''', cbb''''', dbbbb''''', g###'''',a##'''', cb''''', dbbb''''',a###'''', b#'''', dbb''''', ebbbb''''',b##'''', c#''''', ebbb''''',b###'''', c##''''', ebb''''', fbbb''''',c###''''', d#''''', fbb''''', gbbbb''''',d##''''', fb''''', gbbb''''',abbbb''''', d###''''', e#''''', gbb''''',abbb''''', e##''''', f#''''',abb''''', bbbbb''''', e###''''', f##''''',bbbb''''', f###''''', g#''''',bbb''''', cbbb'''''', g##''''',a#''''', cbb'''''', dbbbb'''''', g###''''',a##''''', cb'''''', dbbb'''''',a###''''', b#''''', dbb'''''', ebbbb'''''',b##''''', c#'''''', ebbb'''''',b###''''', c##'''''', ebb'''''', fbbb'''''',c###'''''', d#'''''', fbb'''''', gbbbb'''''',d##'''''', fb'''''', gbbb'''''',abbbb'''''', d###'''''', e#'''''', gbb'''''',abbb'''''', e##'''''', f#'''''',abb'''''', bbbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "a-diesis-diesis-diesis-6, b-diesis-6, d-bemolle-bemolle-5,a-diesis-diesis-diesis-diesis-6, b-diesis-diesis-6, d-bemolle-5, e-bemolle-bemolle-bemolle-5,b-diesis-diesis-diesis-6, c-diesis-diesis-5, e-bemolle-bemolle-5, f-bemolle-bemolle-bemolle-5,c-diesis-diesis-diesis-5, e-bemolle-5, f-bemolle-bemolle-5,c-diesis-diesis-diesis-diesis-5, d-diesis-diesis-5, f-bemolle-5, g-bemolle-bemolle-bemolle-5,d-diesis-diesis-diesis-5, e-diesis-5, g-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-5, d-diesis-diesis-diesis-diesis-5, e-diesis-diesis-5, g-bemolle-5,a-bemolle-bemolle-5, e-diesis-diesis-diesis-5, f-diesis-diesis-5,a-bemolle-5, b-bemolle-bemolle-bemolle-5, f-diesis-diesis-diesis-5,b-bemolle-bemolle-5, c-bemolle-bemolle-bemolle-4, f-diesis-diesis-diesis-diesis-5, g-diesis-diesis-5,b-bemolle-5, c-bemolle-bemolle-4, g-diesis-diesis-diesis-5,a-diesis-diesis-5, c-bemolle-4, d-bemolle-bemolle-bemolle-4, g-diesis-diesis-diesis-diesis-5,a-diesis-diesis-diesis-5, b-diesis-5, d-bemolle-bemolle-4,a-diesis-diesis-diesis-diesis-5, b-diesis-diesis-5, d-bemolle-4, e-bemolle-bemolle-bemolle-4,b-diesis-diesis-diesis-5, c-diesis-diesis-4, e-bemolle-bemolle-4, f-bemolle-bemolle-bemolle-4,c-diesis-diesis-diesis-4, e-bemolle-4, f-bemolle-bemolle-4,c-diesis-diesis-diesis-diesis-4, d-diesis-diesis-4, f-bemolle-4, g-bemolle-bemolle-bemolle-4,d-diesis-diesis-diesis-4, e-diesis-4, g-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-4, d-diesis-diesis-diesis-diesis-4, e-diesis-diesis-4, g-bemolle-4,a-bemolle-bemolle-4, e-diesis-diesis-diesis-4, f-diesis-diesis-4,a-bemolle-4, b-bemolle-bemolle-bemolle-4, f-diesis-diesis-diesis-4,b-bemolle-bemolle-4, c-bemolle-bemolle-bemolle-3, f-diesis-diesis-diesis-diesis-4, g-diesis-diesis-4,b-bemolle-4, c-bemolle-bemolle-3, g-diesis-diesis-diesis-4,a-diesis-diesis-4, c-bemolle-3, d-bemolle-bemolle-bemolle-3, g-diesis-diesis-diesis-diesis-4,a-diesis-diesis-diesis-4, b-diesis-4, d-bemolle-bemolle-3,a-diesis-diesis-diesis-diesis-4, b-diesis-diesis-4, d-bemolle-3, e-bemolle-bemolle-bemolle-3,b-diesis-diesis-diesis-4, c-diesis-diesis-3, e-bemolle-bemolle-3, f-bemolle-bemolle-bemolle-3,c-diesis-diesis-diesis-3, e-bemolle-3, f-bemolle-bemolle-3,c-diesis-diesis-diesis-diesis-3, d-diesis-diesis-3, f-bemolle-3, g-bemolle-bemolle-bemolle-3,d-diesis-diesis-diesis-3, e-diesis-3, g-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-3, d-diesis-diesis-diesis-diesis-3, e-diesis-diesis-3, g-bemolle-3,a-bemolle-bemolle-3, e-diesis-diesis-diesis-3, f-diesis-diesis-3,a-bemolle-3, b-bemolle-bemolle-bemolle-3, f-diesis-diesis-diesis-3,b-bemolle-bemolle-3, c-bemolle-bemolle-bemolle-2, f-diesis-diesis-diesis-diesis-3, g-diesis-diesis-3,b-bemolle-3, c-bemolle-bemolle-2, g-diesis-diesis-diesis-3,a-diesis-diesis-3, c-bemolle-2, d-bemolle-bemolle-bemolle-2, g-diesis-diesis-diesis-diesis-3,a-diesis-diesis-diesis-3, b-diesis-3, d-bemolle-bemolle-2,a-diesis-diesis-diesis-diesis-3, b-diesis-diesis-3, d-bemolle-2, e-bemolle-bemolle-bemolle-2,b-diesis-diesis-diesis-3, c-diesis-diesis-2, e-bemolle-bemolle-2, f-bemolle-bemolle-bemolle-2,c-diesis-diesis-diesis-2, e-bemolle-2, f-bemolle-bemolle-2,c-diesis-diesis-diesis-diesis-2, d-diesis-diesis-2, f-bemolle-2, g-bemolle-bemolle-bemolle-2,d-diesis-diesis-diesis-2, e-diesis-2, g-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-2, d-diesis-diesis-diesis-diesis-2, e-diesis-diesis-2, g-bemolle-2,a-bemolle-bemolle-2, e-diesis-diesis-diesis-2, f-diesis-diesis-2,a-bemolle-2, b-bemolle-bemolle-bemolle-2, f-diesis-diesis-diesis-2,b-bemolle-bemolle-2, c-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-diesis-2, g-diesis-diesis-2,b-bemolle-2, c-bemolle-bemolle-, g-diesis-diesis-diesis-2,a-diesis-diesis-2, c-bemolle-, d-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-diesis-2,a-diesis-diesis-diesis-2, b-diesis-2, d-bemolle-bemolle-,a-diesis-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-, e-bemolle-bemolle-bemolle-,b-diesis-diesis-diesis-2, c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-,c-diesis-diesis-diesis-, e-bemolle-, f-bemolle-bemolle-,c-diesis-diesis-diesis-diesis-, d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-diesis-, e-diesis-diesis-, g-bemolle-,a-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,a-bemolle-, b-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-,b-bemolle-bemolle-, c-bemolle-bemolle-bemolle, f-diesis-diesis-diesis-diesis-, g-diesis-diesis-,b-bemolle-, c-bemolle-bemolle, g-diesis-diesis-diesis-,a-diesis-diesis-, c-bemolle, d-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-diesis-,a-diesis-diesis-diesis-, b-diesis-, d-bemolle-bemolle,a-diesis-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle, e-bemolle-bemolle-bemolle,b-diesis-diesis-diesis-, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis-diesis, g-diesis-diesis,b-bemolle, c-bemolle-bemolle+, g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle+,a-diesis-diesis-diesis-diesis, b-diesis-diesis, d-bemolle+, e-bemolle-bemolle-bemolle+,b-diesis-diesis-diesis, c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+,c-diesis-diesis-diesis+, e-bemolle+, f-bemolle-bemolle+,c-diesis-diesis-diesis-diesis+, d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis-diesis+, e-diesis-diesis+, g-bemolle+,a-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,a-bemolle+, b-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis+,b-bemolle-bemolle+, c-bemolle-bemolle-bemolle+2, f-diesis-diesis-diesis-diesis+, g-diesis-diesis+,b-bemolle+, c-bemolle-bemolle+2, g-diesis-diesis-diesis+,a-diesis-diesis+, c-bemolle+2, d-bemolle-bemolle-bemolle+2, g-diesis-diesis-diesis-diesis+,a-diesis-diesis-diesis+, b-diesis+, d-bemolle-bemolle+2,a-diesis-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle+2, e-bemolle-bemolle-bemolle+2,b-diesis-diesis-diesis+, c-diesis-diesis+2, e-bemolle-bemolle+2, f-bemolle-bemolle-bemolle+2,c-diesis-diesis-diesis+2, e-bemolle+2, f-bemolle-bemolle+2,c-diesis-diesis-diesis-diesis+2, d-diesis-diesis+2, f-bemolle+2, g-bemolle-bemolle-bemolle+2,d-diesis-diesis-diesis+2, e-diesis+2, g-bemolle-bemolle+2,a-bemolle-bemolle-bemolle+2, d-diesis-diesis-diesis-diesis+2, e-diesis-diesis+2, g-bemolle+2,a-bemolle-bemolle+2, e-diesis-diesis-diesis+2, f-diesis-diesis+2,a-bemolle+2, b-bemolle-bemolle-bemolle+2, f-diesis-diesis-diesis+2,b-bemolle-bemolle+2, c-bemolle-bemolle-bemolle+3, f-diesis-diesis-diesis-diesis+2, g-diesis-diesis+2,b-bemolle+2, c-bemolle-bemolle+3, g-diesis-diesis-diesis+2,a-diesis-diesis+2, c-bemolle+3, d-bemolle-bemolle-bemolle+3, g-diesis-diesis-diesis-diesis+2,a-diesis-diesis-diesis+2, b-diesis+2, d-bemolle-bemolle+3,a-diesis-diesis-diesis-diesis+2, b-diesis-diesis+2, d-bemolle+3, e-bemolle-bemolle-bemolle+3,b-diesis-diesis-diesis+2, c-diesis-diesis+3, e-bemolle-bemolle+3, f-bemolle-bemolle-bemolle+3,c-diesis-diesis-diesis+3, e-bemolle+3, f-bemolle-bemolle+3,c-diesis-diesis-diesis-diesis+3, d-diesis-diesis+3, f-bemolle+3, g-bemolle-bemolle-bemolle+3,d-diesis-diesis-diesis+3, e-diesis+3, g-bemolle-bemolle+3,a-bemolle-bemolle-bemolle+3, d-diesis-diesis-diesis-diesis+3, e-diesis-diesis+3, g-bemolle+3,a-bemolle-bemolle+3, e-diesis-diesis-diesis+3, f-diesis-diesis+3,a-bemolle+3, b-bemolle-bemolle-bemolle+3, f-diesis-diesis-diesis+3,b-bemolle-bemolle+3, c-bemolle-bemolle-bemolle+4, f-diesis-diesis-diesis-diesis+3, g-diesis-diesis+3,b-bemolle+3, c-bemolle-bemolle+4, g-diesis-diesis-diesis+3,a-diesis-diesis+3, c-bemolle+4, d-bemolle-bemolle-bemolle+4, g-diesis-diesis-diesis-diesis+3,a-diesis-diesis-diesis+3, b-diesis+3, d-bemolle-bemolle+4,a-diesis-diesis-diesis-diesis+3, b-diesis-diesis+3, d-bemolle+4, e-bemolle-bemolle-bemolle+4,b-diesis-diesis-diesis+3, c-diesis-diesis+4, e-bemolle-bemolle+4, f-bemolle-bemolle-bemolle+4,c-diesis-diesis-diesis+4, e-bemolle+4, f-bemolle-bemolle+4,c-diesis-diesis-diesis-diesis+4, d-diesis-diesis+4, f-bemolle+4, g-bemolle-bemolle-bemolle+4,d-diesis-diesis-diesis+4, e-diesis+4, g-bemolle-bemolle+4,a-bemolle-bemolle-bemolle+4, d-diesis-diesis-diesis-diesis+4, e-diesis-diesis+4, g-bemolle+4,a-bemolle-bemolle+4, e-diesis-diesis-diesis+4, f-diesis-diesis+4,a-bemolle+4, b-bemolle-bemolle-bemolle+4, f-diesis-diesis-diesis+4,b-bemolle-bemolle+4, c-bemolle-bemolle-bemolle+5, f-diesis-diesis-diesis-diesis+4, g-diesis-diesis+4,b-bemolle+4, c-bemolle-bemolle+5, g-diesis-diesis-diesis+4,a-diesis-diesis+4, c-bemolle+5, d-bemolle-bemolle-bemolle+5, g-diesis-diesis-diesis-diesis+4,a-diesis-diesis-diesis+4, b-diesis+4, d-bemolle-bemolle+5,a-diesis-diesis-diesis-diesis+4, b-diesis-diesis+4, d-bemolle+5, e-bemolle-bemolle-bemolle+5,b-diesis-diesis-diesis+4, c-diesis-diesis+5, e-bemolle-bemolle+5, f-bemolle-bemolle-bemolle+5,c-diesis-diesis-diesis+5, e-bemolle+5, f-bemolle-bemolle+5,c-diesis-diesis-diesis-diesis+5, d-diesis-diesis+5, f-bemolle+5, g-bemolle-bemolle-bemolle+5,d-diesis-diesis-diesis+5, e-diesis+5, g-bemolle-bemolle+5,a-bemolle-bemolle-bemolle+5, d-diesis-diesis-diesis-diesis+5, e-diesis-diesis+5, g-bemolle+5,a-bemolle-bemolle+5, e-diesis-diesis-diesis+5, f-diesis-diesis+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "a-diesis-diesis-diesis------, b-diesis------, d-bemolle-bemolle-----,a-diesis-diesis-diesis-diesis------, b-diesis-diesis------, d-bemolle-----, e-bemolle-bemolle-bemolle-----,b-diesis-diesis-diesis------, c-diesis-diesis-----, e-bemolle-bemolle-----, f-bemolle-bemolle-bemolle-----,c-diesis-diesis-diesis-----, e-bemolle-----, f-bemolle-bemolle-----,c-diesis-diesis-diesis-diesis-----, d-diesis-diesis-----, f-bemolle-----, g-bemolle-bemolle-bemolle-----,d-diesis-diesis-diesis-----, e-diesis-----, g-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-----, d-diesis-diesis-diesis-diesis-----, e-diesis-diesis-----, g-bemolle-----,a-bemolle-bemolle-----, e-diesis-diesis-diesis-----, f-diesis-diesis-----,a-bemolle-----, b-bemolle-bemolle-bemolle-----, f-diesis-diesis-diesis-----,b-bemolle-bemolle-----, c-bemolle-bemolle-bemolle----, f-diesis-diesis-diesis-diesis-----, g-diesis-diesis-----,b-bemolle-----, c-bemolle-bemolle----, g-diesis-diesis-diesis-----,a-diesis-diesis-----, c-bemolle----, d-bemolle-bemolle-bemolle----, g-diesis-diesis-diesis-diesis-----,a-diesis-diesis-diesis-----, b-diesis-----, d-bemolle-bemolle----,a-diesis-diesis-diesis-diesis-----, b-diesis-diesis-----, d-bemolle----, e-bemolle-bemolle-bemolle----,b-diesis-diesis-diesis-----, c-diesis-diesis----, e-bemolle-bemolle----, f-bemolle-bemolle-bemolle----,c-diesis-diesis-diesis----, e-bemolle----, f-bemolle-bemolle----,c-diesis-diesis-diesis-diesis----, d-diesis-diesis----, f-bemolle----, g-bemolle-bemolle-bemolle----,d-diesis-diesis-diesis----, e-diesis----, g-bemolle-bemolle----,a-bemolle-bemolle-bemolle----, d-diesis-diesis-diesis-diesis----, e-diesis-diesis----, g-bemolle----,a-bemolle-bemolle----, e-diesis-diesis-diesis----, f-diesis-diesis----,a-bemolle----, b-bemolle-bemolle-bemolle----, f-diesis-diesis-diesis----,b-bemolle-bemolle----, c-bemolle-bemolle-bemolle---, f-diesis-diesis-diesis-diesis----, g-diesis-diesis----,b-bemolle----, c-bemolle-bemolle---, g-diesis-diesis-diesis----,a-diesis-diesis----, c-bemolle---, d-bemolle-bemolle-bemolle---, g-diesis-diesis-diesis-diesis----,a-diesis-diesis-diesis----, b-diesis----, d-bemolle-bemolle---,a-diesis-diesis-diesis-diesis----, b-diesis-diesis----, d-bemolle---, e-bemolle-bemolle-bemolle---,b-diesis-diesis-diesis----, c-diesis-diesis---, e-bemolle-bemolle---, f-bemolle-bemolle-bemolle---,c-diesis-diesis-diesis---, e-bemolle---, f-bemolle-bemolle---,c-diesis-diesis-diesis-diesis---, d-diesis-diesis---, f-bemolle---, g-bemolle-bemolle-bemolle---,d-diesis-diesis-diesis---, e-diesis---, g-bemolle-bemolle---,a-bemolle-bemolle-bemolle---, d-diesis-diesis-diesis-diesis---, e-diesis-diesis---, g-bemolle---,a-bemolle-bemolle---, e-diesis-diesis-diesis---, f-diesis-diesis---,a-bemolle---, b-bemolle-bemolle-bemolle---, f-diesis-diesis-diesis---,b-bemolle-bemolle---, c-bemolle-bemolle-bemolle--, f-diesis-diesis-diesis-diesis---, g-diesis-diesis---,b-bemolle---, c-bemolle-bemolle--, g-diesis-diesis-diesis---,a-diesis-diesis---, c-bemolle--, d-bemolle-bemolle-bemolle--, g-diesis-diesis-diesis-diesis---,a-diesis-diesis-diesis---, b-diesis---, d-bemolle-bemolle--,a-diesis-diesis-diesis-diesis---, b-diesis-diesis---, d-bemolle--, e-bemolle-bemolle-bemolle--,b-diesis-diesis-diesis---, c-diesis-diesis--, e-bemolle-bemolle--, f-bemolle-bemolle-bemolle--,c-diesis-diesis-diesis--, e-bemolle--, f-bemolle-bemolle--,c-diesis-diesis-diesis-diesis--, d-diesis-diesis--, f-bemolle--, g-bemolle-bemolle-bemolle--,d-diesis-diesis-diesis--, e-diesis--, g-bemolle-bemolle--,a-bemolle-bemolle-bemolle--, d-diesis-diesis-diesis-diesis--, e-diesis-diesis--, g-bemolle--,a-bemolle-bemolle--, e-diesis-diesis-diesis--, f-diesis-diesis--,a-bemolle--, b-bemolle-bemolle-bemolle--, f-diesis-diesis-diesis--,b-bemolle-bemolle--, c-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-diesis--, g-diesis-diesis--,b-bemolle--, c-bemolle-bemolle-, g-diesis-diesis-diesis--,a-diesis-diesis--, c-bemolle-, d-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-diesis--,a-diesis-diesis-diesis--, b-diesis--, d-bemolle-bemolle-,a-diesis-diesis-diesis-diesis--, b-diesis-diesis--, d-bemolle-, e-bemolle-bemolle-bemolle-,b-diesis-diesis-diesis--, c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-,c-diesis-diesis-diesis-, e-bemolle-, f-bemolle-bemolle-,c-diesis-diesis-diesis-diesis-, d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-diesis-, e-diesis-diesis-, g-bemolle-,a-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,a-bemolle-, b-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-,b-bemolle-bemolle-, c-bemolle-bemolle-bemolle, f-diesis-diesis-diesis-diesis-, g-diesis-diesis-,b-bemolle-, c-bemolle-bemolle, g-diesis-diesis-diesis-,a-diesis-diesis-, c-bemolle, d-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-diesis-,a-diesis-diesis-diesis-, b-diesis-, d-bemolle-bemolle,a-diesis-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle, e-bemolle-bemolle-bemolle,b-diesis-diesis-diesis-, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis-diesis, g-diesis-diesis,b-bemolle, c-bemolle-bemolle+, g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle+,a-diesis-diesis-diesis-diesis, b-diesis-diesis, d-bemolle+, e-bemolle-bemolle-bemolle+,b-diesis-diesis-diesis, c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+,c-diesis-diesis-diesis+, e-bemolle+, f-bemolle-bemolle+,c-diesis-diesis-diesis-diesis+, d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis-diesis+, e-diesis-diesis+, g-bemolle+,a-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,a-bemolle+, b-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis+,b-bemolle-bemolle+, c-bemolle-bemolle-bemolle++, f-diesis-diesis-diesis-diesis+, g-diesis-diesis+,b-bemolle+, c-bemolle-bemolle++, g-diesis-diesis-diesis+,a-diesis-diesis+, c-bemolle++, d-bemolle-bemolle-bemolle++, g-diesis-diesis-diesis-diesis+,a-diesis-diesis-diesis+, b-diesis+, d-bemolle-bemolle++,a-diesis-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle++, e-bemolle-bemolle-bemolle++,b-diesis-diesis-diesis+, c-diesis-diesis++, e-bemolle-bemolle++, f-bemolle-bemolle-bemolle++,c-diesis-diesis-diesis++, e-bemolle++, f-bemolle-bemolle++,c-diesis-diesis-diesis-diesis++, d-diesis-diesis++, f-bemolle++, g-bemolle-bemolle-bemolle++,d-diesis-diesis-diesis++, e-diesis++, g-bemolle-bemolle++,a-bemolle-bemolle-bemolle++, d-diesis-diesis-diesis-diesis++, e-diesis-diesis++, g-bemolle++,a-bemolle-bemolle++, e-diesis-diesis-diesis++, f-diesis-diesis++,a-bemolle++, b-bemolle-bemolle-bemolle++, f-diesis-diesis-diesis++,b-bemolle-bemolle++, c-bemolle-bemolle-bemolle+++, f-diesis-diesis-diesis-diesis++, g-diesis-diesis++,b-bemolle++, c-bemolle-bemolle+++, g-diesis-diesis-diesis++,a-diesis-diesis++, c-bemolle+++, d-bemolle-bemolle-bemolle+++, g-diesis-diesis-diesis-diesis++,a-diesis-diesis-diesis++, b-diesis++, d-bemolle-bemolle+++,a-diesis-diesis-diesis-diesis++, b-diesis-diesis++, d-bemolle+++, e-bemolle-bemolle-bemolle+++,b-diesis-diesis-diesis++, c-diesis-diesis+++, e-bemolle-bemolle+++, f-bemolle-bemolle-bemolle+++,c-diesis-diesis-diesis+++, e-bemolle+++, f-bemolle-bemolle+++,c-diesis-diesis-diesis-diesis+++, d-diesis-diesis+++, f-bemolle+++, g-bemolle-bemolle-bemolle+++,d-diesis-diesis-diesis+++, e-diesis+++, g-bemolle-bemolle+++,a-bemolle-bemolle-bemolle+++, d-diesis-diesis-diesis-diesis+++, e-diesis-diesis+++, g-bemolle+++,a-bemolle-bemolle+++, e-diesis-diesis-diesis+++, f-diesis-diesis+++,a-bemolle+++, b-bemolle-bemolle-bemolle+++, f-diesis-diesis-diesis+++,b-bemolle-bemolle+++, c-bemolle-bemolle-bemolle++++, f-diesis-diesis-diesis-diesis+++, g-diesis-diesis+++,b-bemolle+++, c-bemolle-bemolle++++, g-diesis-diesis-diesis+++,a-diesis-diesis+++, c-bemolle++++, d-bemolle-bemolle-bemolle++++, g-diesis-diesis-diesis-diesis+++,a-diesis-diesis-diesis+++, b-diesis+++, d-bemolle-bemolle++++,a-diesis-diesis-diesis-diesis+++, b-diesis-diesis+++, d-bemolle++++, e-bemolle-bemolle-bemolle++++,b-diesis-diesis-diesis+++, c-diesis-diesis++++, e-bemolle-bemolle++++, f-bemolle-bemolle-bemolle++++,c-diesis-diesis-diesis++++, e-bemolle++++, f-bemolle-bemolle++++,c-diesis-diesis-diesis-diesis++++, d-diesis-diesis++++, f-bemolle++++, g-bemolle-bemolle-bemolle++++,d-diesis-diesis-diesis++++, e-diesis++++, g-bemolle-bemolle++++,a-bemolle-bemolle-bemolle++++, d-diesis-diesis-diesis-diesis++++, e-diesis-diesis++++, g-bemolle++++,a-bemolle-bemolle++++, e-diesis-diesis-diesis++++, f-diesis-diesis++++,a-bemolle++++, b-bemolle-bemolle-bemolle++++, f-diesis-diesis-diesis++++,b-bemolle-bemolle++++, c-bemolle-bemolle-bemolle+++++, f-diesis-diesis-diesis-diesis++++, g-diesis-diesis++++,b-bemolle++++, c-bemolle-bemolle+++++, g-diesis-diesis-diesis++++,a-diesis-diesis++++, c-bemolle+++++, d-bemolle-bemolle-bemolle+++++, g-diesis-diesis-diesis-diesis++++,a-diesis-diesis-diesis++++, b-diesis++++, d-bemolle-bemolle+++++,a-diesis-diesis-diesis-diesis++++, b-diesis-diesis++++, d-bemolle+++++, e-bemolle-bemolle-bemolle+++++,b-diesis-diesis-diesis++++, c-diesis-diesis+++++, e-bemolle-bemolle+++++, f-bemolle-bemolle-bemolle+++++,c-diesis-diesis-diesis+++++, e-bemolle+++++, f-bemolle-bemolle+++++,c-diesis-diesis-diesis-diesis+++++, d-diesis-diesis+++++, f-bemolle+++++, g-bemolle-bemolle-bemolle+++++,d-diesis-diesis-diesis+++++, e-diesis+++++, g-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle+++++, d-diesis-diesis-diesis-diesis+++++, e-diesis-diesis+++++, g-bemolle+++++,a-bemolle-bemolle+++++, e-diesis-diesis-diesis+++++, f-diesis-diesis+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "a-diesis-diesis-diesis-2, b-diesis-2, d-bemolle-bemolle-1,a-diesis-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-1, e-bemolle-bemolle-bemolle-1,b-diesis-diesis-diesis-2, c-diesis-diesis-1, e-bemolle-bemolle-1, f-bemolle-bemolle-bemolle-1,c-diesis-diesis-diesis-1, e-bemolle-1, f-bemolle-bemolle-1,c-diesis-diesis-diesis-diesis-1, d-diesis-diesis-1, f-bemolle-1, g-bemolle-bemolle-bemolle-1,d-diesis-diesis-diesis-1, e-diesis-1, g-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-1, d-diesis-diesis-diesis-diesis-1, e-diesis-diesis-1, g-bemolle-1,a-bemolle-bemolle-1, e-diesis-diesis-diesis-1, f-diesis-diesis-1,a-bemolle-1, b-bemolle-bemolle-bemolle-1, f-diesis-diesis-diesis-1,b-bemolle-bemolle-1, c-bemolle-bemolle-bemolle0, f-diesis-diesis-diesis-diesis-1, g-diesis-diesis-1,b-bemolle-1, c-bemolle-bemolle0, g-diesis-diesis-diesis-1,a-diesis-diesis-1, c-bemolle0, d-bemolle-bemolle-bemolle0, g-diesis-diesis-diesis-diesis-1,a-diesis-diesis-diesis-1, b-diesis-1, d-bemolle-bemolle0,a-diesis-diesis-diesis-diesis-1, b-diesis-diesis-1, d-bemolle0, e-bemolle-bemolle-bemolle0,b-diesis-diesis-diesis-1, c-diesis-diesis0, e-bemolle-bemolle0, f-bemolle-bemolle-bemolle0,c-diesis-diesis-diesis0, e-bemolle0, f-bemolle-bemolle0,c-diesis-diesis-diesis-diesis0, d-diesis-diesis0, f-bemolle0, g-bemolle-bemolle-bemolle0,d-diesis-diesis-diesis0, e-diesis0, g-bemolle-bemolle0,a-bemolle-bemolle-bemolle0, d-diesis-diesis-diesis-diesis0, e-diesis-diesis0, g-bemolle0,a-bemolle-bemolle0, e-diesis-diesis-diesis0, f-diesis-diesis0,a-bemolle0, b-bemolle-bemolle-bemolle0, f-diesis-diesis-diesis0,b-bemolle-bemolle0, c-bemolle-bemolle-bemolle1, f-diesis-diesis-diesis-diesis0, g-diesis-diesis0,b-bemolle0, c-bemolle-bemolle1, g-diesis-diesis-diesis0,a-diesis-diesis0, c-bemolle1, d-bemolle-bemolle-bemolle1, g-diesis-diesis-diesis-diesis0,a-diesis-diesis-diesis0, b-diesis0, d-bemolle-bemolle1,a-diesis-diesis-diesis-diesis0, b-diesis-diesis0, d-bemolle1, e-bemolle-bemolle-bemolle1,b-diesis-diesis-diesis0, c-diesis-diesis1, e-bemolle-bemolle1, f-bemolle-bemolle-bemolle1,c-diesis-diesis-diesis1, e-bemolle1, f-bemolle-bemolle1,c-diesis-diesis-diesis-diesis1, d-diesis-diesis1, f-bemolle1, g-bemolle-bemolle-bemolle1,d-diesis-diesis-diesis1, e-diesis1, g-bemolle-bemolle1,a-bemolle-bemolle-bemolle1, d-diesis-diesis-diesis-diesis1, e-diesis-diesis1, g-bemolle1,a-bemolle-bemolle1, e-diesis-diesis-diesis1, f-diesis-diesis1,a-bemolle1, b-bemolle-bemolle-bemolle1, f-diesis-diesis-diesis1,b-bemolle-bemolle1, c-bemolle-bemolle-bemolle2, f-diesis-diesis-diesis-diesis1, g-diesis-diesis1,b-bemolle1, c-bemolle-bemolle2, g-diesis-diesis-diesis1,a-diesis-diesis1, c-bemolle2, d-bemolle-bemolle-bemolle2, g-diesis-diesis-diesis-diesis1,a-diesis-diesis-diesis1, b-diesis1, d-bemolle-bemolle2,a-diesis-diesis-diesis-diesis1, b-diesis-diesis1, d-bemolle2, e-bemolle-bemolle-bemolle2,b-diesis-diesis-diesis1, c-diesis-diesis2, e-bemolle-bemolle2, f-bemolle-bemolle-bemolle2,c-diesis-diesis-diesis2, e-bemolle2, f-bemolle-bemolle2,c-diesis-diesis-diesis-diesis2, d-diesis-diesis2, f-bemolle2, g-bemolle-bemolle-bemolle2,d-diesis-diesis-diesis2, e-diesis2, g-bemolle-bemolle2,a-bemolle-bemolle-bemolle2, d-diesis-diesis-diesis-diesis2, e-diesis-diesis2, g-bemolle2,a-bemolle-bemolle2, e-diesis-diesis-diesis2, f-diesis-diesis2,a-bemolle2, b-bemolle-bemolle-bemolle2, f-diesis-diesis-diesis2,b-bemolle-bemolle2, c-bemolle-bemolle-bemolle3, f-diesis-diesis-diesis-diesis2, g-diesis-diesis2,b-bemolle2, c-bemolle-bemolle3, g-diesis-diesis-diesis2,a-diesis-diesis2, c-bemolle3, d-bemolle-bemolle-bemolle3, g-diesis-diesis-diesis-diesis2,a-diesis-diesis-diesis2, b-diesis2, d-bemolle-bemolle3,a-diesis-diesis-diesis-diesis2, b-diesis-diesis2, d-bemolle3, e-bemolle-bemolle-bemolle3,b-diesis-diesis-diesis2, c-diesis-diesis3, e-bemolle-bemolle3, f-bemolle-bemolle-bemolle3,c-diesis-diesis-diesis3, e-bemolle3, f-bemolle-bemolle3,c-diesis-diesis-diesis-diesis3, d-diesis-diesis3, f-bemolle3, g-bemolle-bemolle-bemolle3,d-diesis-diesis-diesis3, e-diesis3, g-bemolle-bemolle3,a-bemolle-bemolle-bemolle3, d-diesis-diesis-diesis-diesis3, e-diesis-diesis3, g-bemolle3,a-bemolle-bemolle3, e-diesis-diesis-diesis3, f-diesis-diesis3,a-bemolle3, b-bemolle-bemolle-bemolle3, f-diesis-diesis-diesis3,b-bemolle-bemolle3, c-bemolle-bemolle-bemolle4, f-diesis-diesis-diesis-diesis3, g-diesis-diesis3,b-bemolle3, c-bemolle-bemolle4, g-diesis-diesis-diesis3,a-diesis-diesis3, c-bemolle4, d-bemolle-bemolle-bemolle4, g-diesis-diesis-diesis-diesis3,a-diesis-diesis-diesis3, b-diesis3, d-bemolle-bemolle4,a-diesis-diesis-diesis-diesis3, b-diesis-diesis3, d-bemolle4, e-bemolle-bemolle-bemolle4,b-diesis-diesis-diesis3, c-diesis-diesis4, e-bemolle-bemolle4, f-bemolle-bemolle-bemolle4,c-diesis-diesis-diesis4, e-bemolle4, f-bemolle-bemolle4,c-diesis-diesis-diesis-diesis4, d-diesis-diesis4, f-bemolle4, g-bemolle-bemolle-bemolle4,d-diesis-diesis-diesis4, e-diesis4, g-bemolle-bemolle4,a-bemolle-bemolle-bemolle4, d-diesis-diesis-diesis-diesis4, e-diesis-diesis4, g-bemolle4,a-bemolle-bemolle4, e-diesis-diesis-diesis4, f-diesis-diesis4,a-bemolle4, b-bemolle-bemolle-bemolle4, f-diesis-diesis-diesis4,b-bemolle-bemolle4, c-bemolle-bemolle-bemolle5, f-diesis-diesis-diesis-diesis4, g-diesis-diesis4,b-bemolle4, c-bemolle-bemolle5, g-diesis-diesis-diesis4,a-diesis-diesis4, c-bemolle5, d-bemolle-bemolle-bemolle5, g-diesis-diesis-diesis-diesis4,a-diesis-diesis-diesis4, b-diesis4, d-bemolle-bemolle5,a-diesis-diesis-diesis-diesis4, b-diesis-diesis4, d-bemolle5, e-bemolle-bemolle-bemolle5,b-diesis-diesis-diesis4, c-diesis-diesis5, e-bemolle-bemolle5, f-bemolle-bemolle-bemolle5,c-diesis-diesis-diesis5, e-bemolle5, f-bemolle-bemolle5,c-diesis-diesis-diesis-diesis5, d-diesis-diesis5, f-bemolle5, g-bemolle-bemolle-bemolle5,d-diesis-diesis-diesis5, e-diesis5, g-bemolle-bemolle5,a-bemolle-bemolle-bemolle5, d-diesis-diesis-diesis-diesis5, e-diesis-diesis5, g-bemolle5,a-bemolle-bemolle5, e-diesis-diesis-diesis5, f-diesis-diesis5,a-bemolle5, b-bemolle-bemolle-bemolle5, f-diesis-diesis-diesis5,b-bemolle-bemolle5, c-bemolle-bemolle-bemolle6, f-diesis-diesis-diesis-diesis5, g-diesis-diesis5,b-bemolle5, c-bemolle-bemolle6, g-diesis-diesis-diesis5,a-diesis-diesis5, c-bemolle6, d-bemolle-bemolle-bemolle6, g-diesis-diesis-diesis-diesis5,a-diesis-diesis-diesis5, b-diesis5, d-bemolle-bemolle6,a-diesis-diesis-diesis-diesis5, b-diesis-diesis5, d-bemolle6, e-bemolle-bemolle-bemolle6,b-diesis-diesis-diesis5, c-diesis-diesis6, e-bemolle-bemolle6, f-bemolle-bemolle-bemolle6,c-diesis-diesis-diesis6, e-bemolle6, f-bemolle-bemolle6,c-diesis-diesis-diesis-diesis6, d-diesis-diesis6, f-bemolle6, g-bemolle-bemolle-bemolle6,d-diesis-diesis-diesis6, e-diesis6, g-bemolle-bemolle6,a-bemolle-bemolle-bemolle6, d-diesis-diesis-diesis-diesis6, e-diesis-diesis6, g-bemolle6,a-bemolle-bemolle6, e-diesis-diesis-diesis6, f-diesis-diesis6,a-bemolle6, b-bemolle-bemolle-bemolle6, f-diesis-diesis-diesis6,b-bemolle-bemolle6, c-bemolle-bemolle-bemolle7, f-diesis-diesis-diesis-diesis6, g-diesis-diesis6,b-bemolle6, c-bemolle-bemolle7, g-diesis-diesis-diesis6,a-diesis-diesis6, c-bemolle7, d-bemolle-bemolle-bemolle7, g-diesis-diesis-diesis-diesis6,a-diesis-diesis-diesis6, b-diesis6, d-bemolle-bemolle7,a-diesis-diesis-diesis-diesis6, b-diesis-diesis6, d-bemolle7, e-bemolle-bemolle-bemolle7,b-diesis-diesis-diesis6, c-diesis-diesis7, e-bemolle-bemolle7, f-bemolle-bemolle-bemolle7,c-diesis-diesis-diesis7, e-bemolle7, f-bemolle-bemolle7,c-diesis-diesis-diesis-diesis7, d-diesis-diesis7, f-bemolle7, g-bemolle-bemolle-bemolle7,d-diesis-diesis-diesis7, e-diesis7, g-bemolle-bemolle7,a-bemolle-bemolle-bemolle7, d-diesis-diesis-diesis-diesis7, e-diesis-diesis7, g-bemolle7,a-bemolle-bemolle7, e-diesis-diesis-diesis7, f-diesis-diesis7,a-bemolle7, b-bemolle-bemolle-bemolle7, f-diesis-diesis-diesis7,b-bemolle-bemolle7, c-bemolle-bemolle-bemolle8, f-diesis-diesis-diesis-diesis7, g-diesis-diesis7,b-bemolle7, c-bemolle-bemolle8, g-diesis-diesis-diesis7,a-diesis-diesis7, c-bemolle8, d-bemolle-bemolle-bemolle8, g-diesis-diesis-diesis-diesis7,a-diesis-diesis-diesis7, b-diesis7, d-bemolle-bemolle8,a-diesis-diesis-diesis-diesis7, b-diesis-diesis7, d-bemolle8, e-bemolle-bemolle-bemolle8,b-diesis-diesis-diesis7, c-diesis-diesis8, e-bemolle-bemolle8, f-bemolle-bemolle-bemolle8,c-diesis-diesis-diesis8, e-bemolle8, f-bemolle-bemolle8,c-diesis-diesis-diesis-diesis8, d-diesis-diesis8, f-bemolle8, g-bemolle-bemolle-bemolle8,d-diesis-diesis-diesis8, e-diesis8, g-bemolle-bemolle8,a-bemolle-bemolle-bemolle8, d-diesis-diesis-diesis-diesis8, e-diesis-diesis8, g-bemolle8,a-bemolle-bemolle8, e-diesis-diesis-diesis8, f-diesis-diesis8,a-bemolle8, b-bemolle-bemolle-bemolle8, f-diesis-diesis-diesis8,b-bemolle-bemolle8, c-bemolle-bemolle-bemolle9, f-diesis-diesis-diesis-diesis8, g-diesis-diesis8,b-bemolle8, c-bemolle-bemolle9, g-diesis-diesis-diesis8,a-diesis-diesis8, c-bemolle9, d-bemolle-bemolle-bemolle9, g-diesis-diesis-diesis-diesis8,a-diesis-diesis-diesis8, b-diesis8, d-bemolle-bemolle9,a-diesis-diesis-diesis-diesis8, b-diesis-diesis8, d-bemolle9, e-bemolle-bemolle-bemolle9,b-diesis-diesis-diesis8, c-diesis-diesis9, e-bemolle-bemolle9, f-bemolle-bemolle-bemolle9,c-diesis-diesis-diesis9, e-bemolle9, f-bemolle-bemolle9,c-diesis-diesis-diesis-diesis9, d-diesis-diesis9, f-bemolle9, g-bemolle-bemolle-bemolle9,d-diesis-diesis-diesis9, e-diesis9, g-bemolle-bemolle9,a-bemolle-bemolle-bemolle9, d-diesis-diesis-diesis-diesis9, e-diesis-diesis9, g-bemolle9,a-bemolle-bemolle9, e-diesis-diesis-diesis9, f-diesis-diesis9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis'''', D-bemolle-bemolle''',A-diesis-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle''', E-bemolle-bemolle-bemolle''',B-diesis-diesis-diesis'''', C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''',C-diesis-diesis-diesis''', E-bemolle''', F-bemolle-bemolle''',C-diesis-diesis-diesis-diesis''', D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis-diesis''', E-diesis-diesis''', G-bemolle''',A-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',A-bemolle''', B-bemolle-bemolle-bemolle''', F-diesis-diesis-diesis''',B-bemolle-bemolle''', C-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis-diesis''', G-diesis-diesis''',B-bemolle''', C-bemolle-bemolle'', G-diesis-diesis-diesis''',A-diesis-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis-diesis''',A-diesis-diesis-diesis''', B-diesis''', D-bemolle-bemolle'',A-diesis-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle'', E-bemolle-bemolle-bemolle'',B-diesis-diesis-diesis''', C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'',C-diesis-diesis-diesis'', E-bemolle'', F-bemolle-bemolle'',C-diesis-diesis-diesis-diesis'', D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis-diesis'', E-diesis-diesis'', G-bemolle'',A-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',A-bemolle'', B-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis'',B-bemolle-bemolle'', C-bemolle-bemolle-bemolle', F-diesis-diesis-diesis-diesis'', G-diesis-diesis'',B-bemolle'', C-bemolle-bemolle', G-diesis-diesis-diesis'',A-diesis-diesis'', C-bemolle', D-bemolle-bemolle-bemolle', G-diesis-diesis-diesis-diesis'',A-diesis-diesis-diesis'', B-diesis'', D-bemolle-bemolle',A-diesis-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle', E-bemolle-bemolle-bemolle',B-diesis-diesis-diesis'', C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle',C-diesis-diesis-diesis', E-bemolle', F-bemolle-bemolle',C-diesis-diesis-diesis-diesis', D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', D-diesis-diesis-diesis-diesis', E-diesis-diesis', G-bemolle',A-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',A-bemolle', B-bemolle-bemolle-bemolle', F-diesis-diesis-diesis',B-bemolle-bemolle', C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis', G-diesis-diesis',B-bemolle', C-bemolle-bemolle, G-diesis-diesis-diesis',A-diesis-diesis', C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis',A-diesis-diesis-diesis', B-diesis', D-bemolle-bemolle,A-diesis-diesis-diesis-diesis', B-diesis-diesis', D-bemolle, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis', C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis-diesis, G-diesis-diesis, c-bemolle-bemolle-bemolle,B-bemolle, G-diesis-diesis-diesis, c-bemolle-bemolle,A-diesis-diesis, G-diesis-diesis-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis, d-bemolle-bemolle,A-diesis-diesis-diesis-diesis, B-diesis-diesis, d-bemolle, e-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle', f-diesis-diesis-diesis-diesis, g-diesis-diesis,b-bemolle, c-bemolle-bemolle', g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle', d-bemolle-bemolle-bemolle', g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle',a-diesis-diesis-diesis-diesis, b-diesis-diesis, d-bemolle', e-bemolle-bemolle-bemolle',b-diesis-diesis-diesis, c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle',c-diesis-diesis-diesis', e-bemolle', f-bemolle-bemolle',c-diesis-diesis-diesis-diesis', d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', d-diesis-diesis-diesis-diesis', e-diesis-diesis', g-bemolle',a-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',a-bemolle', b-bemolle-bemolle-bemolle', f-diesis-diesis-diesis',b-bemolle-bemolle', c-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis-diesis', g-diesis-diesis',b-bemolle', c-bemolle-bemolle'', g-diesis-diesis-diesis',a-diesis-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis-diesis',a-diesis-diesis-diesis', b-diesis', d-bemolle-bemolle'',a-diesis-diesis-diesis-diesis', b-diesis-diesis', d-bemolle'', e-bemolle-bemolle-bemolle'',b-diesis-diesis-diesis', c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'',c-diesis-diesis-diesis'', e-bemolle'', f-bemolle-bemolle'',c-diesis-diesis-diesis-diesis'', d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis-diesis'', e-diesis-diesis'', g-bemolle'',a-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',a-bemolle'', b-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis'',b-bemolle-bemolle'', c-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis-diesis'', g-diesis-diesis'',b-bemolle'', c-bemolle-bemolle''', g-diesis-diesis-diesis'',a-diesis-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis-diesis'',a-diesis-diesis-diesis'', b-diesis'', d-bemolle-bemolle''',a-diesis-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle''', e-bemolle-bemolle-bemolle''',b-diesis-diesis-diesis'', c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''',c-diesis-diesis-diesis''', e-bemolle''', f-bemolle-bemolle''',c-diesis-diesis-diesis-diesis''', d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis-diesis''', e-diesis-diesis''', g-bemolle''',a-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',a-bemolle''', b-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis''',b-bemolle-bemolle''', c-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis-diesis''', g-diesis-diesis''',b-bemolle''', c-bemolle-bemolle'''', g-diesis-diesis-diesis''',a-diesis-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis-diesis''',a-diesis-diesis-diesis''', b-diesis''', d-bemolle-bemolle'''',a-diesis-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle'''', e-bemolle-bemolle-bemolle'''',b-diesis-diesis-diesis''', c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''',c-diesis-diesis-diesis'''', e-bemolle'''', f-bemolle-bemolle'''',c-diesis-diesis-diesis-diesis'''', d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis-diesis'''', e-diesis-diesis'''', g-bemolle'''',a-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',a-bemolle'''', b-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis'''',b-bemolle-bemolle'''', c-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis-diesis'''', g-diesis-diesis'''',b-bemolle'''', c-bemolle-bemolle''''', g-diesis-diesis-diesis'''',a-diesis-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis-diesis'''',a-diesis-diesis-diesis'''', b-diesis'''', d-bemolle-bemolle''''',a-diesis-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle''''', e-bemolle-bemolle-bemolle''''',b-diesis-diesis-diesis'''', c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''',c-diesis-diesis-diesis''''', e-bemolle''''', f-bemolle-bemolle''''',c-diesis-diesis-diesis-diesis''''', d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis-diesis''''', e-diesis-diesis''''', g-bemolle''''',a-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',a-bemolle''''', b-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis''''',b-bemolle-bemolle''''', c-bemolle-bemolle-bemolle'''''', f-diesis-diesis-diesis-diesis''''', g-diesis-diesis''''',b-bemolle''''', c-bemolle-bemolle'''''', g-diesis-diesis-diesis''''',a-diesis-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis-diesis''''',a-diesis-diesis-diesis''''', b-diesis''''', d-bemolle-bemolle'''''',a-diesis-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle'''''', e-bemolle-bemolle-bemolle'''''',b-diesis-diesis-diesis''''', c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''',c-diesis-diesis-diesis'''''', e-bemolle'''''', f-bemolle-bemolle'''''',c-diesis-diesis-diesis-diesis'''''', d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis-diesis'''''', e-diesis-diesis'''''', g-bemolle'''''',a-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "a-diesis-diesis-diesis-6, b-diesis-6, d-bemolle-bemolle-5, e-bemolle-bemolle-bemolle-bemolle-5,b-diesis-diesis-6, c-diesis-5, e-bemolle-bemolle-bemolle-5,b-diesis-diesis-diesis-6, c-diesis-diesis-5, e-bemolle-bemolle-5, f-bemolle-bemolle-bemolle-5,c-diesis-diesis-diesis-5, d-diesis-5, f-bemolle-bemolle-5, g-bemolle-bemolle-bemolle-bemolle-5,d-diesis-diesis-5, f-bemolle-5, g-bemolle-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-bemolle-5, d-diesis-diesis-diesis-5, e-diesis-5, g-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-5, e-diesis-diesis-5, f-diesis-5,a-bemolle-bemolle-5, b-bemolle-bemolle-bemolle-bemolle-5, e-diesis-diesis-diesis-5, f-diesis-diesis-5,b-bemolle-bemolle-bemolle-5, f-diesis-diesis-diesis-5, g-diesis-5,b-bemolle-bemolle-5, c-bemolle-bemolle-bemolle-4, g-diesis-diesis-5,a-diesis-5, c-bemolle-bemolle-4, d-bemolle-bemolle-bemolle-bemolle-4, g-diesis-diesis-diesis-5,a-diesis-diesis-5, c-bemolle-4, d-bemolle-bemolle-bemolle-4,a-diesis-diesis-diesis-5, b-diesis-5, d-bemolle-bemolle-4, e-bemolle-bemolle-bemolle-bemolle-4,b-diesis-diesis-5, c-diesis-4, e-bemolle-bemolle-bemolle-4,b-diesis-diesis-diesis-5, c-diesis-diesis-4, e-bemolle-bemolle-4, f-bemolle-bemolle-bemolle-4,c-diesis-diesis-diesis-4, d-diesis-4, f-bemolle-bemolle-4, g-bemolle-bemolle-bemolle-bemolle-4,d-diesis-diesis-4, f-bemolle-4, g-bemolle-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-bemolle-4, d-diesis-diesis-diesis-4, e-diesis-4, g-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-4, e-diesis-diesis-4, f-diesis-4,a-bemolle-bemolle-4, b-bemolle-bemolle-bemolle-bemolle-4, e-diesis-diesis-diesis-4, f-diesis-diesis-4,b-bemolle-bemolle-bemolle-4, f-diesis-diesis-diesis-4, g-diesis-4,b-bemolle-bemolle-4, c-bemolle-bemolle-bemolle-3, g-diesis-diesis-4,a-diesis-4, c-bemolle-bemolle-3, d-bemolle-bemolle-bemolle-bemolle-3, g-diesis-diesis-diesis-4,a-diesis-diesis-4, c-bemolle-3, d-bemolle-bemolle-bemolle-3,a-diesis-diesis-diesis-4, b-diesis-4, d-bemolle-bemolle-3, e-bemolle-bemolle-bemolle-bemolle-3,b-diesis-diesis-4, c-diesis-3, e-bemolle-bemolle-bemolle-3,b-diesis-diesis-diesis-4, c-diesis-diesis-3, e-bemolle-bemolle-3, f-bemolle-bemolle-bemolle-3,c-diesis-diesis-diesis-3, d-diesis-3, f-bemolle-bemolle-3, g-bemolle-bemolle-bemolle-bemolle-3,d-diesis-diesis-3, f-bemolle-3, g-bemolle-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-bemolle-3, d-diesis-diesis-diesis-3, e-diesis-3, g-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-3, e-diesis-diesis-3, f-diesis-3,a-bemolle-bemolle-3, b-bemolle-bemolle-bemolle-bemolle-3, e-diesis-diesis-diesis-3, f-diesis-diesis-3,b-bemolle-bemolle-bemolle-3, f-diesis-diesis-diesis-3, g-diesis-3,b-bemolle-bemolle-3, c-bemolle-bemolle-bemolle-2, g-diesis-diesis-3,a-diesis-3, c-bemolle-bemolle-2, d-bemolle-bemolle-bemolle-bemolle-2, g-diesis-diesis-diesis-3,a-diesis-diesis-3, c-bemolle-2, d-bemolle-bemolle-bemolle-2,a-diesis-diesis-diesis-3, b-diesis-3, d-bemolle-bemolle-2, e-bemolle-bemolle-bemolle-bemolle-2,b-diesis-diesis-3, c-diesis-2, e-bemolle-bemolle-bemolle-2,b-diesis-diesis-diesis-3, c-diesis-diesis-2, e-bemolle-bemolle-2, f-bemolle-bemolle-bemolle-2,c-diesis-diesis-diesis-2, d-diesis-2, f-bemolle-bemolle-2, g-bemolle-bemolle-bemolle-bemolle-2,d-diesis-diesis-2, f-bemolle-2, g-bemolle-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-bemolle-2, d-diesis-diesis-diesis-2, e-diesis-2, g-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-2, e-diesis-diesis-2, f-diesis-2,a-bemolle-bemolle-2, b-bemolle-bemolle-bemolle-bemolle-2, e-diesis-diesis-diesis-2, f-diesis-diesis-2,b-bemolle-bemolle-bemolle-2, f-diesis-diesis-diesis-2, g-diesis-2,b-bemolle-bemolle-2, c-bemolle-bemolle-bemolle-, g-diesis-diesis-2,a-diesis-2, c-bemolle-bemolle-, d-bemolle-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-2,a-diesis-diesis-2, c-bemolle-, d-bemolle-bemolle-bemolle-,a-diesis-diesis-diesis-2, b-diesis-2, d-bemolle-bemolle-, e-bemolle-bemolle-bemolle-bemolle-,b-diesis-diesis-2, c-diesis-, e-bemolle-bemolle-bemolle-,b-diesis-diesis-diesis-2, c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-,c-diesis-diesis-diesis-, d-diesis-, f-bemolle-bemolle-, g-bemolle-bemolle-bemolle-bemolle-,d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,a-bemolle-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, e-diesis-diesis-, f-diesis-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,b-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-, g-diesis-,b-bemolle-bemolle-, c-bemolle-bemolle-bemolle, g-diesis-diesis-,a-diesis-, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-,a-diesis-diesis-, c-bemolle, d-bemolle-bemolle-bemolle,a-diesis-diesis-diesis-, b-diesis-, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,b-diesis-diesis-, c-diesis, e-bemolle-bemolle-bemolle,b-diesis-diesis-diesis-, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle+, g-diesis-diesis,a-diesis, c-bemolle-bemolle+, d-bemolle-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle+, e-bemolle-bemolle-bemolle-bemolle+,b-diesis-diesis, c-diesis+, e-bemolle-bemolle-bemolle+,b-diesis-diesis-diesis, c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+,c-diesis-diesis-diesis+, d-diesis+, f-bemolle-bemolle+, g-bemolle-bemolle-bemolle-bemolle+,d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,a-bemolle-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, e-diesis-diesis+, f-diesis+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,b-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis+, g-diesis+,b-bemolle-bemolle+, c-bemolle-bemolle-bemolle+2, g-diesis-diesis+,a-diesis+, c-bemolle-bemolle+2, d-bemolle-bemolle-bemolle-bemolle+2, g-diesis-diesis-diesis+,a-diesis-diesis+, c-bemolle+2, d-bemolle-bemolle-bemolle+2,a-diesis-diesis-diesis+, b-diesis+, d-bemolle-bemolle+2, e-bemolle-bemolle-bemolle-bemolle+2,b-diesis-diesis+, c-diesis+2, e-bemolle-bemolle-bemolle+2,b-diesis-diesis-diesis+, c-diesis-diesis+2, e-bemolle-bemolle+2, f-bemolle-bemolle-bemolle+2,c-diesis-diesis-diesis+2, d-diesis+2, f-bemolle-bemolle+2, g-bemolle-bemolle-bemolle-bemolle+2,d-diesis-diesis+2, f-bemolle+2, g-bemolle-bemolle-bemolle+2,a-bemolle-bemolle-bemolle-bemolle+2, d-diesis-diesis-diesis+2, e-diesis+2, g-bemolle-bemolle+2,a-bemolle-bemolle-bemolle+2, e-diesis-diesis+2, f-diesis+2,a-bemolle-bemolle+2, b-bemolle-bemolle-bemolle-bemolle+2, e-diesis-diesis-diesis+2, f-diesis-diesis+2,b-bemolle-bemolle-bemolle+2, f-diesis-diesis-diesis+2, g-diesis+2,b-bemolle-bemolle+2, c-bemolle-bemolle-bemolle+3, g-diesis-diesis+2,a-diesis+2, c-bemolle-bemolle+3, d-bemolle-bemolle-bemolle-bemolle+3, g-diesis-diesis-diesis+2,a-diesis-diesis+2, c-bemolle+3, d-bemolle-bemolle-bemolle+3,a-diesis-diesis-diesis+2, b-diesis+2, d-bemolle-bemolle+3, e-bemolle-bemolle-bemolle-bemolle+3,b-diesis-diesis+2, c-diesis+3, e-bemolle-bemolle-bemolle+3,b-diesis-diesis-diesis+2, c-diesis-diesis+3, e-bemolle-bemolle+3, f-bemolle-bemolle-bemolle+3,c-diesis-diesis-diesis+3, d-diesis+3, f-bemolle-bemolle+3, g-bemolle-bemolle-bemolle-bemolle+3,d-diesis-diesis+3, f-bemolle+3, g-bemolle-bemolle-bemolle+3,a-bemolle-bemolle-bemolle-bemolle+3, d-diesis-diesis-diesis+3, e-diesis+3, g-bemolle-bemolle+3,a-bemolle-bemolle-bemolle+3, e-diesis-diesis+3, f-diesis+3,a-bemolle-bemolle+3, b-bemolle-bemolle-bemolle-bemolle+3, e-diesis-diesis-diesis+3, f-diesis-diesis+3,b-bemolle-bemolle-bemolle+3, f-diesis-diesis-diesis+3, g-diesis+3,b-bemolle-bemolle+3, c-bemolle-bemolle-bemolle+4, g-diesis-diesis+3,a-diesis+3, c-bemolle-bemolle+4, d-bemolle-bemolle-bemolle-bemolle+4, g-diesis-diesis-diesis+3,a-diesis-diesis+3, c-bemolle+4, d-bemolle-bemolle-bemolle+4,a-diesis-diesis-diesis+3, b-diesis+3, d-bemolle-bemolle+4, e-bemolle-bemolle-bemolle-bemolle+4,b-diesis-diesis+3, c-diesis+4, e-bemolle-bemolle-bemolle+4,b-diesis-diesis-diesis+3, c-diesis-diesis+4, e-bemolle-bemolle+4, f-bemolle-bemolle-bemolle+4,c-diesis-diesis-diesis+4, d-diesis+4, f-bemolle-bemolle+4, g-bemolle-bemolle-bemolle-bemolle+4,d-diesis-diesis+4, f-bemolle+4, g-bemolle-bemolle-bemolle+4,a-bemolle-bemolle-bemolle-bemolle+4, d-diesis-diesis-diesis+4, e-diesis+4, g-bemolle-bemolle+4,a-bemolle-bemolle-bemolle+4, e-diesis-diesis+4, f-diesis+4,a-bemolle-bemolle+4, b-bemolle-bemolle-bemolle-bemolle+4, e-diesis-diesis-diesis+4, f-diesis-diesis+4,b-bemolle-bemolle-bemolle+4, f-diesis-diesis-diesis+4, g-diesis+4,b-bemolle-bemolle+4, c-bemolle-bemolle-bemolle+5, g-diesis-diesis+4,a-diesis+4, c-bemolle-bemolle+5, d-bemolle-bemolle-bemolle-bemolle+5, g-diesis-diesis-diesis+4,a-diesis-diesis+4, c-bemolle+5, d-bemolle-bemolle-bemolle+5,a-diesis-diesis-diesis+4, b-diesis+4, d-bemolle-bemolle+5, e-bemolle-bemolle-bemolle-bemolle+5,b-diesis-diesis+4, c-diesis+5, e-bemolle-bemolle-bemolle+5,b-diesis-diesis-diesis+4, c-diesis-diesis+5, e-bemolle-bemolle+5, f-bemolle-bemolle-bemolle+5,c-diesis-diesis-diesis+5, d-diesis+5, f-bemolle-bemolle+5, g-bemolle-bemolle-bemolle-bemolle+5,d-diesis-diesis+5, f-bemolle+5, g-bemolle-bemolle-bemolle+5,a-bemolle-bemolle-bemolle-bemolle+5, d-diesis-diesis-diesis+5, e-diesis+5, g-bemolle-bemolle+5,a-bemolle-bemolle-bemolle+5, e-diesis-diesis+5, f-diesis+5,a-bemolle-bemolle+5, b-bemolle-bemolle-bemolle-bemolle+5, e-diesis-diesis-diesis+5, f-diesis-diesis+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "a-diesis-diesis-diesis------, b-diesis------, d-bemolle-bemolle-----, e-bemolle-bemolle-bemolle-bemolle-----,b-diesis-diesis------, c-diesis-----, e-bemolle-bemolle-bemolle-----,b-diesis-diesis-diesis------, c-diesis-diesis-----, e-bemolle-bemolle-----, f-bemolle-bemolle-bemolle-----,c-diesis-diesis-diesis-----, d-diesis-----, f-bemolle-bemolle-----, g-bemolle-bemolle-bemolle-bemolle-----,d-diesis-diesis-----, f-bemolle-----, g-bemolle-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-bemolle-----, d-diesis-diesis-diesis-----, e-diesis-----, g-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-----, e-diesis-diesis-----, f-diesis-----,a-bemolle-bemolle-----, b-bemolle-bemolle-bemolle-bemolle-----, e-diesis-diesis-diesis-----, f-diesis-diesis-----,b-bemolle-bemolle-bemolle-----, f-diesis-diesis-diesis-----, g-diesis-----,b-bemolle-bemolle-----, c-bemolle-bemolle-bemolle----, g-diesis-diesis-----,a-diesis-----, c-bemolle-bemolle----, d-bemolle-bemolle-bemolle-bemolle----, g-diesis-diesis-diesis-----,a-diesis-diesis-----, c-bemolle----, d-bemolle-bemolle-bemolle----,a-diesis-diesis-diesis-----, b-diesis-----, d-bemolle-bemolle----, e-bemolle-bemolle-bemolle-bemolle----,b-diesis-diesis-----, c-diesis----, e-bemolle-bemolle-bemolle----,b-diesis-diesis-diesis-----, c-diesis-diesis----, e-bemolle-bemolle----, f-bemolle-bemolle-bemolle----,c-diesis-diesis-diesis----, d-diesis----, f-bemolle-bemolle----, g-bemolle-bemolle-bemolle-bemolle----,d-diesis-diesis----, f-bemolle----, g-bemolle-bemolle-bemolle----,a-bemolle-bemolle-bemolle-bemolle----, d-diesis-diesis-diesis----, e-diesis----, g-bemolle-bemolle----,a-bemolle-bemolle-bemolle----, e-diesis-diesis----, f-diesis----,a-bemolle-bemolle----, b-bemolle-bemolle-bemolle-bemolle----, e-diesis-diesis-diesis----, f-diesis-diesis----,b-bemolle-bemolle-bemolle----, f-diesis-diesis-diesis----, g-diesis----,b-bemolle-bemolle----, c-bemolle-bemolle-bemolle---, g-diesis-diesis----,a-diesis----, c-bemolle-bemolle---, d-bemolle-bemolle-bemolle-bemolle---, g-diesis-diesis-diesis----,a-diesis-diesis----, c-bemolle---, d-bemolle-bemolle-bemolle---,a-diesis-diesis-diesis----, b-diesis----, d-bemolle-bemolle---, e-bemolle-bemolle-bemolle-bemolle---,b-diesis-diesis----, c-diesis---, e-bemolle-bemolle-bemolle---,b-diesis-diesis-diesis----, c-diesis-diesis---, e-bemolle-bemolle---, f-bemolle-bemolle-bemolle---,c-diesis-diesis-diesis---, d-diesis---, f-bemolle-bemolle---, g-bemolle-bemolle-bemolle-bemolle---,d-diesis-diesis---, f-bemolle---, g-bemolle-bemolle-bemolle---,a-bemolle-bemolle-bemolle-bemolle---, d-diesis-diesis-diesis---, e-diesis---, g-bemolle-bemolle---,a-bemolle-bemolle-bemolle---, e-diesis-diesis---, f-diesis---,a-bemolle-bemolle---, b-bemolle-bemolle-bemolle-bemolle---, e-diesis-diesis-diesis---, f-diesis-diesis---,b-bemolle-bemolle-bemolle---, f-diesis-diesis-diesis---, g-diesis---,b-bemolle-bemolle---, c-bemolle-bemolle-bemolle--, g-diesis-diesis---,a-diesis---, c-bemolle-bemolle--, d-bemolle-bemolle-bemolle-bemolle--, g-diesis-diesis-diesis---,a-diesis-diesis---, c-bemolle--, d-bemolle-bemolle-bemolle--,a-diesis-diesis-diesis---, b-diesis---, d-bemolle-bemolle--, e-bemolle-bemolle-bemolle-bemolle--,b-diesis-diesis---, c-diesis--, e-bemolle-bemolle-bemolle--,b-diesis-diesis-diesis---, c-diesis-diesis--, e-bemolle-bemolle--, f-bemolle-bemolle-bemolle--,c-diesis-diesis-diesis--, d-diesis--, f-bemolle-bemolle--, g-bemolle-bemolle-bemolle-bemolle--,d-diesis-diesis--, f-bemolle--, g-bemolle-bemolle-bemolle--,a-bemolle-bemolle-bemolle-bemolle--, d-diesis-diesis-diesis--, e-diesis--, g-bemolle-bemolle--,a-bemolle-bemolle-bemolle--, e-diesis-diesis--, f-diesis--,a-bemolle-bemolle--, b-bemolle-bemolle-bemolle-bemolle--, e-diesis-diesis-diesis--, f-diesis-diesis--,b-bemolle-bemolle-bemolle--, f-diesis-diesis-diesis--, g-diesis--,b-bemolle-bemolle--, c-bemolle-bemolle-bemolle-, g-diesis-diesis--,a-diesis--, c-bemolle-bemolle-, d-bemolle-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis--,a-diesis-diesis--, c-bemolle-, d-bemolle-bemolle-bemolle-,a-diesis-diesis-diesis--, b-diesis--, d-bemolle-bemolle-, e-bemolle-bemolle-bemolle-bemolle-,b-diesis-diesis--, c-diesis-, e-bemolle-bemolle-bemolle-,b-diesis-diesis-diesis--, c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-,c-diesis-diesis-diesis-, d-diesis-, f-bemolle-bemolle-, g-bemolle-bemolle-bemolle-bemolle-,d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,a-bemolle-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, e-diesis-diesis-, f-diesis-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,b-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-, g-diesis-,b-bemolle-bemolle-, c-bemolle-bemolle-bemolle, g-diesis-diesis-,a-diesis-, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-,a-diesis-diesis-, c-bemolle, d-bemolle-bemolle-bemolle,a-diesis-diesis-diesis-, b-diesis-, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,b-diesis-diesis-, c-diesis, e-bemolle-bemolle-bemolle,b-diesis-diesis-diesis-, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle+, g-diesis-diesis,a-diesis, c-bemolle-bemolle+, d-bemolle-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle+, e-bemolle-bemolle-bemolle-bemolle+,b-diesis-diesis, c-diesis+, e-bemolle-bemolle-bemolle+,b-diesis-diesis-diesis, c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+,c-diesis-diesis-diesis+, d-diesis+, f-bemolle-bemolle+, g-bemolle-bemolle-bemolle-bemolle+,d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,a-bemolle-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, e-diesis-diesis+, f-diesis+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,b-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis+, g-diesis+,b-bemolle-bemolle+, c-bemolle-bemolle-bemolle++, g-diesis-diesis+,a-diesis+, c-bemolle-bemolle++, d-bemolle-bemolle-bemolle-bemolle++, g-diesis-diesis-diesis+,a-diesis-diesis+, c-bemolle++, d-bemolle-bemolle-bemolle++,a-diesis-diesis-diesis+, b-diesis+, d-bemolle-bemolle++, e-bemolle-bemolle-bemolle-bemolle++,b-diesis-diesis+, c-diesis++, e-bemolle-bemolle-bemolle++,b-diesis-diesis-diesis+, c-diesis-diesis++, e-bemolle-bemolle++, f-bemolle-bemolle-bemolle++,c-diesis-diesis-diesis++, d-diesis++, f-bemolle-bemolle++, g-bemolle-bemolle-bemolle-bemolle++,d-diesis-diesis++, f-bemolle++, g-bemolle-bemolle-bemolle++,a-bemolle-bemolle-bemolle-bemolle++, d-diesis-diesis-diesis++, e-diesis++, g-bemolle-bemolle++,a-bemolle-bemolle-bemolle++, e-diesis-diesis++, f-diesis++,a-bemolle-bemolle++, b-bemolle-bemolle-bemolle-bemolle++, e-diesis-diesis-diesis++, f-diesis-diesis++,b-bemolle-bemolle-bemolle++, f-diesis-diesis-diesis++, g-diesis++,b-bemolle-bemolle++, c-bemolle-bemolle-bemolle+++, g-diesis-diesis++,a-diesis++, c-bemolle-bemolle+++, d-bemolle-bemolle-bemolle-bemolle+++, g-diesis-diesis-diesis++,a-diesis-diesis++, c-bemolle+++, d-bemolle-bemolle-bemolle+++,a-diesis-diesis-diesis++, b-diesis++, d-bemolle-bemolle+++, e-bemolle-bemolle-bemolle-bemolle+++,b-diesis-diesis++, c-diesis+++, e-bemolle-bemolle-bemolle+++,b-diesis-diesis-diesis++, c-diesis-diesis+++, e-bemolle-bemolle+++, f-bemolle-bemolle-bemolle+++,c-diesis-diesis-diesis+++, d-diesis+++, f-bemolle-bemolle+++, g-bemolle-bemolle-bemolle-bemolle+++,d-diesis-diesis+++, f-bemolle+++, g-bemolle-bemolle-bemolle+++,a-bemolle-bemolle-bemolle-bemolle+++, d-diesis-diesis-diesis+++, e-diesis+++, g-bemolle-bemolle+++,a-bemolle-bemolle-bemolle+++, e-diesis-diesis+++, f-diesis+++,a-bemolle-bemolle+++, b-bemolle-bemolle-bemolle-bemolle+++, e-diesis-diesis-diesis+++, f-diesis-diesis+++,b-bemolle-bemolle-bemolle+++, f-diesis-diesis-diesis+++, g-diesis+++,b-bemolle-bemolle+++, c-bemolle-bemolle-bemolle++++, g-diesis-diesis+++,a-diesis+++, c-bemolle-bemolle++++, d-bemolle-bemolle-bemolle-bemolle++++, g-diesis-diesis-diesis+++,a-diesis-diesis+++, c-bemolle++++, d-bemolle-bemolle-bemolle++++,a-diesis-diesis-diesis+++, b-diesis+++, d-bemolle-bemolle++++, e-bemolle-bemolle-bemolle-bemolle++++,b-diesis-diesis+++, c-diesis++++, e-bemolle-bemolle-bemolle++++,b-diesis-diesis-diesis+++, c-diesis-diesis++++, e-bemolle-bemolle++++, f-bemolle-bemolle-bemolle++++,c-diesis-diesis-diesis++++, d-diesis++++, f-bemolle-bemolle++++, g-bemolle-bemolle-bemolle-bemolle++++,d-diesis-diesis++++, f-bemolle++++, g-bemolle-bemolle-bemolle++++,a-bemolle-bemolle-bemolle-bemolle++++, d-diesis-diesis-diesis++++, e-diesis++++, g-bemolle-bemolle++++,a-bemolle-bemolle-bemolle++++, e-diesis-diesis++++, f-diesis++++,a-bemolle-bemolle++++, b-bemolle-bemolle-bemolle-bemolle++++, e-diesis-diesis-diesis++++, f-diesis-diesis++++,b-bemolle-bemolle-bemolle++++, f-diesis-diesis-diesis++++, g-diesis++++,b-bemolle-bemolle++++, c-bemolle-bemolle-bemolle+++++, g-diesis-diesis++++,a-diesis++++, c-bemolle-bemolle+++++, d-bemolle-bemolle-bemolle-bemolle+++++, g-diesis-diesis-diesis++++,a-diesis-diesis++++, c-bemolle+++++, d-bemolle-bemolle-bemolle+++++,a-diesis-diesis-diesis++++, b-diesis++++, d-bemolle-bemolle+++++, e-bemolle-bemolle-bemolle-bemolle+++++,b-diesis-diesis++++, c-diesis+++++, e-bemolle-bemolle-bemolle+++++,b-diesis-diesis-diesis++++, c-diesis-diesis+++++, e-bemolle-bemolle+++++, f-bemolle-bemolle-bemolle+++++,c-diesis-diesis-diesis+++++, d-diesis+++++, f-bemolle-bemolle+++++, g-bemolle-bemolle-bemolle-bemolle+++++,d-diesis-diesis+++++, f-bemolle+++++, g-bemolle-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle-bemolle+++++, d-diesis-diesis-diesis+++++, e-diesis+++++, g-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle+++++, e-diesis-diesis+++++, f-diesis+++++,a-bemolle-bemolle+++++, b-bemolle-bemolle-bemolle-bemolle+++++, e-diesis-diesis-diesis+++++, f-diesis-diesis+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "a-diesis-diesis-diesis-2, b-diesis-2, d-bemolle-bemolle-1, e-bemolle-bemolle-bemolle-bemolle-1,b-diesis-diesis-2, c-diesis-1, e-bemolle-bemolle-bemolle-1,b-diesis-diesis-diesis-2, c-diesis-diesis-1, e-bemolle-bemolle-1, f-bemolle-bemolle-bemolle-1,c-diesis-diesis-diesis-1, d-diesis-1, f-bemolle-bemolle-1, g-bemolle-bemolle-bemolle-bemolle-1,d-diesis-diesis-1, f-bemolle-1, g-bemolle-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-bemolle-1, d-diesis-diesis-diesis-1, e-diesis-1, g-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-1, e-diesis-diesis-1, f-diesis-1,a-bemolle-bemolle-1, b-bemolle-bemolle-bemolle-bemolle-1, e-diesis-diesis-diesis-1, f-diesis-diesis-1,b-bemolle-bemolle-bemolle-1, f-diesis-diesis-diesis-1, g-diesis-1,b-bemolle-bemolle-1, c-bemolle-bemolle-bemolle0, g-diesis-diesis-1,a-diesis-1, c-bemolle-bemolle0, d-bemolle-bemolle-bemolle-bemolle0, g-diesis-diesis-diesis-1,a-diesis-diesis-1, c-bemolle0, d-bemolle-bemolle-bemolle0,a-diesis-diesis-diesis-1, b-diesis-1, d-bemolle-bemolle0, e-bemolle-bemolle-bemolle-bemolle0,b-diesis-diesis-1, c-diesis0, e-bemolle-bemolle-bemolle0,b-diesis-diesis-diesis-1, c-diesis-diesis0, e-bemolle-bemolle0, f-bemolle-bemolle-bemolle0,c-diesis-diesis-diesis0, d-diesis0, f-bemolle-bemolle0, g-bemolle-bemolle-bemolle-bemolle0,d-diesis-diesis0, f-bemolle0, g-bemolle-bemolle-bemolle0,a-bemolle-bemolle-bemolle-bemolle0, d-diesis-diesis-diesis0, e-diesis0, g-bemolle-bemolle0,a-bemolle-bemolle-bemolle0, e-diesis-diesis0, f-diesis0,a-bemolle-bemolle0, b-bemolle-bemolle-bemolle-bemolle0, e-diesis-diesis-diesis0, f-diesis-diesis0,b-bemolle-bemolle-bemolle0, f-diesis-diesis-diesis0, g-diesis0,b-bemolle-bemolle0, c-bemolle-bemolle-bemolle1, g-diesis-diesis0,a-diesis0, c-bemolle-bemolle1, d-bemolle-bemolle-bemolle-bemolle1, g-diesis-diesis-diesis0,a-diesis-diesis0, c-bemolle1, d-bemolle-bemolle-bemolle1,a-diesis-diesis-diesis0, b-diesis0, d-bemolle-bemolle1, e-bemolle-bemolle-bemolle-bemolle1,b-diesis-diesis0, c-diesis1, e-bemolle-bemolle-bemolle1,b-diesis-diesis-diesis0, c-diesis-diesis1, e-bemolle-bemolle1, f-bemolle-bemolle-bemolle1,c-diesis-diesis-diesis1, d-diesis1, f-bemolle-bemolle1, g-bemolle-bemolle-bemolle-bemolle1,d-diesis-diesis1, f-bemolle1, g-bemolle-bemolle-bemolle1,a-bemolle-bemolle-bemolle-bemolle1, d-diesis-diesis-diesis1, e-diesis1, g-bemolle-bemolle1,a-bemolle-bemolle-bemolle1, e-diesis-diesis1, f-diesis1,a-bemolle-bemolle1, b-bemolle-bemolle-bemolle-bemolle1, e-diesis-diesis-diesis1, f-diesis-diesis1,b-bemolle-bemolle-bemolle1, f-diesis-diesis-diesis1, g-diesis1,b-bemolle-bemolle1, c-bemolle-bemolle-bemolle2, g-diesis-diesis1,a-diesis1, c-bemolle-bemolle2, d-bemolle-bemolle-bemolle-bemolle2, g-diesis-diesis-diesis1,a-diesis-diesis1, c-bemolle2, d-bemolle-bemolle-bemolle2,a-diesis-diesis-diesis1, b-diesis1, d-bemolle-bemolle2, e-bemolle-bemolle-bemolle-bemolle2,b-diesis-diesis1, c-diesis2, e-bemolle-bemolle-bemolle2,b-diesis-diesis-diesis1, c-diesis-diesis2, e-bemolle-bemolle2, f-bemolle-bemolle-bemolle2,c-diesis-diesis-diesis2, d-diesis2, f-bemolle-bemolle2, g-bemolle-bemolle-bemolle-bemolle2,d-diesis-diesis2, f-bemolle2, g-bemolle-bemolle-bemolle2,a-bemolle-bemolle-bemolle-bemolle2, d-diesis-diesis-diesis2, e-diesis2, g-bemolle-bemolle2,a-bemolle-bemolle-bemolle2, e-diesis-diesis2, f-diesis2,a-bemolle-bemolle2, b-bemolle-bemolle-bemolle-bemolle2, e-diesis-diesis-diesis2, f-diesis-diesis2,b-bemolle-bemolle-bemolle2, f-diesis-diesis-diesis2, g-diesis2,b-bemolle-bemolle2, c-bemolle-bemolle-bemolle3, g-diesis-diesis2,a-diesis2, c-bemolle-bemolle3, d-bemolle-bemolle-bemolle-bemolle3, g-diesis-diesis-diesis2,a-diesis-diesis2, c-bemolle3, d-bemolle-bemolle-bemolle3,a-diesis-diesis-diesis2, b-diesis2, d-bemolle-bemolle3, e-bemolle-bemolle-bemolle-bemolle3,b-diesis-diesis2, c-diesis3, e-bemolle-bemolle-bemolle3,b-diesis-diesis-diesis2, c-diesis-diesis3, e-bemolle-bemolle3, f-bemolle-bemolle-bemolle3,c-diesis-diesis-diesis3, d-diesis3, f-bemolle-bemolle3, g-bemolle-bemolle-bemolle-bemolle3,d-diesis-diesis3, f-bemolle3, g-bemolle-bemolle-bemolle3,a-bemolle-bemolle-bemolle-bemolle3, d-diesis-diesis-diesis3, e-diesis3, g-bemolle-bemolle3,a-bemolle-bemolle-bemolle3, e-diesis-diesis3, f-diesis3,a-bemolle-bemolle3, b-bemolle-bemolle-bemolle-bemolle3, e-diesis-diesis-diesis3, f-diesis-diesis3,b-bemolle-bemolle-bemolle3, f-diesis-diesis-diesis3, g-diesis3,b-bemolle-bemolle3, c-bemolle-bemolle-bemolle4, g-diesis-diesis3,a-diesis3, c-bemolle-bemolle4, d-bemolle-bemolle-bemolle-bemolle4, g-diesis-diesis-diesis3,a-diesis-diesis3, c-bemolle4, d-bemolle-bemolle-bemolle4,a-diesis-diesis-diesis3, b-diesis3, d-bemolle-bemolle4, e-bemolle-bemolle-bemolle-bemolle4,b-diesis-diesis3, c-diesis4, e-bemolle-bemolle-bemolle4,b-diesis-diesis-diesis3, c-diesis-diesis4, e-bemolle-bemolle4, f-bemolle-bemolle-bemolle4,c-diesis-diesis-diesis4, d-diesis4, f-bemolle-bemolle4, g-bemolle-bemolle-bemolle-bemolle4,d-diesis-diesis4, f-bemolle4, g-bemolle-bemolle-bemolle4,a-bemolle-bemolle-bemolle-bemolle4, d-diesis-diesis-diesis4, e-diesis4, g-bemolle-bemolle4,a-bemolle-bemolle-bemolle4, e-diesis-diesis4, f-diesis4,a-bemolle-bemolle4, b-bemolle-bemolle-bemolle-bemolle4, e-diesis-diesis-diesis4, f-diesis-diesis4,b-bemolle-bemolle-bemolle4, f-diesis-diesis-diesis4, g-diesis4,b-bemolle-bemolle4, c-bemolle-bemolle-bemolle5, g-diesis-diesis4,a-diesis4, c-bemolle-bemolle5, d-bemolle-bemolle-bemolle-bemolle5, g-diesis-diesis-diesis4,a-diesis-diesis4, c-bemolle5, d-bemolle-bemolle-bemolle5,a-diesis-diesis-diesis4, b-diesis4, d-bemolle-bemolle5, e-bemolle-bemolle-bemolle-bemolle5,b-diesis-diesis4, c-diesis5, e-bemolle-bemolle-bemolle5,b-diesis-diesis-diesis4, c-diesis-diesis5, e-bemolle-bemolle5, f-bemolle-bemolle-bemolle5,c-diesis-diesis-diesis5, d-diesis5, f-bemolle-bemolle5, g-bemolle-bemolle-bemolle-bemolle5,d-diesis-diesis5, f-bemolle5, g-bemolle-bemolle-bemolle5,a-bemolle-bemolle-bemolle-bemolle5, d-diesis-diesis-diesis5, e-diesis5, g-bemolle-bemolle5,a-bemolle-bemolle-bemolle5, e-diesis-diesis5, f-diesis5,a-bemolle-bemolle5, b-bemolle-bemolle-bemolle-bemolle5, e-diesis-diesis-diesis5, f-diesis-diesis5,b-bemolle-bemolle-bemolle5, f-diesis-diesis-diesis5, g-diesis5,b-bemolle-bemolle5, c-bemolle-bemolle-bemolle6, g-diesis-diesis5,a-diesis5, c-bemolle-bemolle6, d-bemolle-bemolle-bemolle-bemolle6, g-diesis-diesis-diesis5,a-diesis-diesis5, c-bemolle6, d-bemolle-bemolle-bemolle6,a-diesis-diesis-diesis5, b-diesis5, d-bemolle-bemolle6, e-bemolle-bemolle-bemolle-bemolle6,b-diesis-diesis5, c-diesis6, e-bemolle-bemolle-bemolle6,b-diesis-diesis-diesis5, c-diesis-diesis6, e-bemolle-bemolle6, f-bemolle-bemolle-bemolle6,c-diesis-diesis-diesis6, d-diesis6, f-bemolle-bemolle6, g-bemolle-bemolle-bemolle-bemolle6,d-diesis-diesis6, f-bemolle6, g-bemolle-bemolle-bemolle6,a-bemolle-bemolle-bemolle-bemolle6, d-diesis-diesis-diesis6, e-diesis6, g-bemolle-bemolle6,a-bemolle-bemolle-bemolle6, e-diesis-diesis6, f-diesis6,a-bemolle-bemolle6, b-bemolle-bemolle-bemolle-bemolle6, e-diesis-diesis-diesis6, f-diesis-diesis6,b-bemolle-bemolle-bemolle6, f-diesis-diesis-diesis6, g-diesis6,b-bemolle-bemolle6, c-bemolle-bemolle-bemolle7, g-diesis-diesis6,a-diesis6, c-bemolle-bemolle7, d-bemolle-bemolle-bemolle-bemolle7, g-diesis-diesis-diesis6,a-diesis-diesis6, c-bemolle7, d-bemolle-bemolle-bemolle7,a-diesis-diesis-diesis6, b-diesis6, d-bemolle-bemolle7, e-bemolle-bemolle-bemolle-bemolle7,b-diesis-diesis6, c-diesis7, e-bemolle-bemolle-bemolle7,b-diesis-diesis-diesis6, c-diesis-diesis7, e-bemolle-bemolle7, f-bemolle-bemolle-bemolle7,c-diesis-diesis-diesis7, d-diesis7, f-bemolle-bemolle7, g-bemolle-bemolle-bemolle-bemolle7,d-diesis-diesis7, f-bemolle7, g-bemolle-bemolle-bemolle7,a-bemolle-bemolle-bemolle-bemolle7, d-diesis-diesis-diesis7, e-diesis7, g-bemolle-bemolle7,a-bemolle-bemolle-bemolle7, e-diesis-diesis7, f-diesis7,a-bemolle-bemolle7, b-bemolle-bemolle-bemolle-bemolle7, e-diesis-diesis-diesis7, f-diesis-diesis7,b-bemolle-bemolle-bemolle7, f-diesis-diesis-diesis7, g-diesis7,b-bemolle-bemolle7, c-bemolle-bemolle-bemolle8, g-diesis-diesis7,a-diesis7, c-bemolle-bemolle8, d-bemolle-bemolle-bemolle-bemolle8, g-diesis-diesis-diesis7,a-diesis-diesis7, c-bemolle8, d-bemolle-bemolle-bemolle8,a-diesis-diesis-diesis7, b-diesis7, d-bemolle-bemolle8, e-bemolle-bemolle-bemolle-bemolle8,b-diesis-diesis7, c-diesis8, e-bemolle-bemolle-bemolle8,b-diesis-diesis-diesis7, c-diesis-diesis8, e-bemolle-bemolle8, f-bemolle-bemolle-bemolle8,c-diesis-diesis-diesis8, d-diesis8, f-bemolle-bemolle8, g-bemolle-bemolle-bemolle-bemolle8,d-diesis-diesis8, f-bemolle8, g-bemolle-bemolle-bemolle8,a-bemolle-bemolle-bemolle-bemolle8, d-diesis-diesis-diesis8, e-diesis8, g-bemolle-bemolle8,a-bemolle-bemolle-bemolle8, e-diesis-diesis8, f-diesis8,a-bemolle-bemolle8, b-bemolle-bemolle-bemolle-bemolle8, e-diesis-diesis-diesis8, f-diesis-diesis8,b-bemolle-bemolle-bemolle8, f-diesis-diesis-diesis8, g-diesis8,b-bemolle-bemolle8, c-bemolle-bemolle-bemolle9, g-diesis-diesis8,a-diesis8, c-bemolle-bemolle9, d-bemolle-bemolle-bemolle-bemolle9, g-diesis-diesis-diesis8,a-diesis-diesis8, c-bemolle9, d-bemolle-bemolle-bemolle9,a-diesis-diesis-diesis8, b-diesis8, d-bemolle-bemolle9, e-bemolle-bemolle-bemolle-bemolle9,b-diesis-diesis8, c-diesis9, e-bemolle-bemolle-bemolle9,b-diesis-diesis-diesis8, c-diesis-diesis9, e-bemolle-bemolle9, f-bemolle-bemolle-bemolle9,c-diesis-diesis-diesis9, d-diesis9, f-bemolle-bemolle9, g-bemolle-bemolle-bemolle-bemolle9,d-diesis-diesis9, f-bemolle9, g-bemolle-bemolle-bemolle9,a-bemolle-bemolle-bemolle-bemolle9, d-diesis-diesis-diesis9, e-diesis9, g-bemolle-bemolle9,a-bemolle-bemolle-bemolle9, e-diesis-diesis9, f-diesis9,a-bemolle-bemolle9, b-bemolle-bemolle-bemolle-bemolle9, e-diesis-diesis-diesis9, f-diesis-diesis9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis'''', D-bemolle-bemolle''', E-bemolle-bemolle-bemolle-bemolle''',B-diesis-diesis'''', C-diesis''', E-bemolle-bemolle-bemolle''',B-diesis-diesis-diesis'''', C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''',C-diesis-diesis-diesis''', D-diesis''', F-bemolle-bemolle''', G-bemolle-bemolle-bemolle-bemolle''',D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',A-bemolle-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', E-diesis-diesis''', F-diesis''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',B-bemolle-bemolle-bemolle''', F-diesis-diesis-diesis''', G-diesis''',B-bemolle-bemolle''', C-bemolle-bemolle-bemolle'', G-diesis-diesis''',A-diesis''', C-bemolle-bemolle'', D-bemolle-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis''',A-diesis-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'',A-diesis-diesis-diesis''', B-diesis''', D-bemolle-bemolle'', E-bemolle-bemolle-bemolle-bemolle'',B-diesis-diesis''', C-diesis'', E-bemolle-bemolle-bemolle'',B-diesis-diesis-diesis''', C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'',C-diesis-diesis-diesis'', D-diesis'', F-bemolle-bemolle'', G-bemolle-bemolle-bemolle-bemolle'',D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',A-bemolle-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', E-diesis-diesis'', F-diesis'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',B-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis'', G-diesis'',B-bemolle-bemolle'', C-bemolle-bemolle-bemolle', G-diesis-diesis'',A-diesis'', C-bemolle-bemolle', D-bemolle-bemolle-bemolle-bemolle', G-diesis-diesis-diesis'',A-diesis-diesis'', C-bemolle', D-bemolle-bemolle-bemolle',A-diesis-diesis-diesis'', B-diesis'', D-bemolle-bemolle', E-bemolle-bemolle-bemolle-bemolle',B-diesis-diesis'', C-diesis', E-bemolle-bemolle-bemolle',B-diesis-diesis-diesis'', C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle',C-diesis-diesis-diesis', D-diesis', F-bemolle-bemolle', G-bemolle-bemolle-bemolle-bemolle',D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',A-bemolle-bemolle-bemolle-bemolle', D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', E-diesis-diesis', F-diesis',A-bemolle-bemolle', B-bemolle-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',B-bemolle-bemolle-bemolle', F-diesis-diesis-diesis', G-diesis',B-bemolle-bemolle', C-bemolle-bemolle-bemolle, G-diesis-diesis',A-diesis', C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis',A-diesis-diesis', C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis', B-diesis', D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis', C-diesis, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis', C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis,B-bemolle-bemolle, G-diesis-diesis, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle,A-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis, c-diesis, e-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle', g-diesis-diesis,a-diesis, c-bemolle-bemolle', d-bemolle-bemolle-bemolle-bemolle', g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle', d-bemolle-bemolle-bemolle',a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle', e-bemolle-bemolle-bemolle-bemolle',b-diesis-diesis, c-diesis', e-bemolle-bemolle-bemolle',b-diesis-diesis-diesis, c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle',c-diesis-diesis-diesis', d-diesis', f-bemolle-bemolle', g-bemolle-bemolle-bemolle-bemolle',d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',a-bemolle-bemolle-bemolle-bemolle', d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', e-diesis-diesis', f-diesis',a-bemolle-bemolle', b-bemolle-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',b-bemolle-bemolle-bemolle', f-diesis-diesis-diesis', g-diesis',b-bemolle-bemolle', c-bemolle-bemolle-bemolle'', g-diesis-diesis',a-diesis', c-bemolle-bemolle'', d-bemolle-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis',a-diesis-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'',a-diesis-diesis-diesis', b-diesis', d-bemolle-bemolle'', e-bemolle-bemolle-bemolle-bemolle'',b-diesis-diesis', c-diesis'', e-bemolle-bemolle-bemolle'',b-diesis-diesis-diesis', c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'',c-diesis-diesis-diesis'', d-diesis'', f-bemolle-bemolle'', g-bemolle-bemolle-bemolle-bemolle'',d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',a-bemolle-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', e-diesis-diesis'', f-diesis'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',b-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis'', g-diesis'',b-bemolle-bemolle'', c-bemolle-bemolle-bemolle''', g-diesis-diesis'',a-diesis'', c-bemolle-bemolle''', d-bemolle-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis'',a-diesis-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''',a-diesis-diesis-diesis'', b-diesis'', d-bemolle-bemolle''', e-bemolle-bemolle-bemolle-bemolle''',b-diesis-diesis'', c-diesis''', e-bemolle-bemolle-bemolle''',b-diesis-diesis-diesis'', c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''',c-diesis-diesis-diesis''', d-diesis''', f-bemolle-bemolle''', g-bemolle-bemolle-bemolle-bemolle''',d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',a-bemolle-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', e-diesis-diesis''', f-diesis''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',b-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis''', g-diesis''',b-bemolle-bemolle''', c-bemolle-bemolle-bemolle'''', g-diesis-diesis''',a-diesis''', c-bemolle-bemolle'''', d-bemolle-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis''',a-diesis-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''',a-diesis-diesis-diesis''', b-diesis''', d-bemolle-bemolle'''', e-bemolle-bemolle-bemolle-bemolle'''',b-diesis-diesis''', c-diesis'''', e-bemolle-bemolle-bemolle'''',b-diesis-diesis-diesis''', c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''',c-diesis-diesis-diesis'''', d-diesis'''', f-bemolle-bemolle'''', g-bemolle-bemolle-bemolle-bemolle'''',d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',a-bemolle-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', e-diesis-diesis'''', f-diesis'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',b-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis'''', g-diesis'''',b-bemolle-bemolle'''', c-bemolle-bemolle-bemolle''''', g-diesis-diesis'''',a-diesis'''', c-bemolle-bemolle''''', d-bemolle-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis'''',a-diesis-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''',a-diesis-diesis-diesis'''', b-diesis'''', d-bemolle-bemolle''''', e-bemolle-bemolle-bemolle-bemolle''''',b-diesis-diesis'''', c-diesis''''', e-bemolle-bemolle-bemolle''''',b-diesis-diesis-diesis'''', c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''',c-diesis-diesis-diesis''''', d-diesis''''', f-bemolle-bemolle''''', g-bemolle-bemolle-bemolle-bemolle''''',d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',a-bemolle-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', e-diesis-diesis''''', f-diesis''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',b-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis''''', g-diesis''''',b-bemolle-bemolle''''', c-bemolle-bemolle-bemolle'''''', g-diesis-diesis''''',a-diesis''''', c-bemolle-bemolle'''''', d-bemolle-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis''''',a-diesis-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''',a-diesis-diesis-diesis''''', b-diesis''''', d-bemolle-bemolle'''''', e-bemolle-bemolle-bemolle-bemolle'''''',b-diesis-diesis''''', c-diesis'''''', e-bemolle-bemolle-bemolle'''''',b-diesis-diesis-diesis''''', c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''',c-diesis-diesis-diesis'''''', d-diesis'''''', f-bemolle-bemolle'''''', g-bemolle-bemolle-bemolle-bemolle'''''',d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', e-diesis-diesis'''''', f-diesis'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "aisisis-6, bis-6, deses-5,aisisisis-6, bisis-6, des-5, eseses-5,bisisis-6, cisis-5, eses-5, feseses-5,cisisis-5, es-5, feses-5,cisisisis-5, disis-5, fes-5, geseses-5,disisis-5, eis-5, geses-5,aseses-5, disisisis-5, eisis-5, ges-5,ases-5, eisisis-5, fisis-5,as-5, beseses-5, fisisis-5,beses-5, ceseses-4, fisisisis-5, gisis-5,bes-5, ceses-4, gisisis-5,aisis-5, ces-4, deseses-4, gisisisis-5,aisisis-5, bis-5, deses-4,aisisisis-5, bisis-5, des-4, eseses-4,bisisis-5, cisis-4, eses-4, feseses-4,cisisis-4, es-4, feses-4,cisisisis-4, disis-4, fes-4, geseses-4,disisis-4, eis-4, geses-4,aseses-4, disisisis-4, eisis-4, ges-4,ases-4, eisisis-4, fisis-4,as-4, beseses-4, fisisis-4,beses-4, ceseses-3, fisisisis-4, gisis-4,bes-4, ceses-3, gisisis-4,aisis-4, ces-3, deseses-3, gisisisis-4,aisisis-4, bis-4, deses-3,aisisisis-4, bisis-4, des-3, eseses-3,bisisis-4, cisis-3, eses-3, feseses-3,cisisis-3, es-3, feses-3,cisisisis-3, disis-3, fes-3, geseses-3,disisis-3, eis-3, geses-3,aseses-3, disisisis-3, eisis-3, ges-3,ases-3, eisisis-3, fisis-3,as-3, beseses-3, fisisis-3,beses-3, ceseses-2, fisisisis-3, gisis-3,bes-3, ceses-2, gisisis-3,aisis-3, ces-2, deseses-2, gisisisis-3,aisisis-3, bis-3, deses-2,aisisisis-3, bisis-3, des-2, eseses-2,bisisis-3, cisis-2, eses-2, feseses-2,cisisis-2, es-2, feses-2,cisisisis-2, disis-2, fes-2, geseses-2,disisis-2, eis-2, geses-2,aseses-2, disisisis-2, eisis-2, ges-2,ases-2, eisisis-2, fisis-2,as-2, beseses-2, fisisis-2,beses-2, ceseses-, fisisisis-2, gisis-2,bes-2, ceses-, gisisis-2,aisis-2, ces-, deseses-, gisisisis-2,aisisis-2, bis-2, deses-,aisisisis-2, bisis-2, des-, eseses-,bisisis-2, cisis-, eses-, feseses-,cisisis-, es-, feses-,cisisisis-, disis-, fes-, geseses-,disisis-, eis-, geses-,aseses-, disisisis-, eisis-, ges-,ases-, eisisis-, fisis-,as-, beseses-, fisisis-,beses-, ceseses, fisisisis-, gisis-,bes-, ceses, gisisis-,aisis-, ces, deseses, gisisisis-,aisisis-, bis-, deses,aisisisis-, bisis-, des, eseses,bisisis-, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, eisisis, fisis,as, beseses, fisisis,beses, ceseses+, fisisisis, gisis,bes, ceses+, gisisis,aisis, ces+, deseses+, gisisisis,aisisis, bis, deses+,aisisisis, bisis, des+, eseses+,bisisis, cisis+, eses+, feseses+,cisisis+, es+, feses+,cisisisis+, disis+, fes+, geseses+,disisis+, eis+, geses+,aseses+, disisisis+, eisis+, ges+,ases+, eisisis+, fisis+,as+, beseses+, fisisis+,beses+, ceseses+2, fisisisis+, gisis+,bes+, ceses+2, gisisis+,aisis+, ces+2, deseses+2, gisisisis+,aisisis+, bis+, deses+2,aisisisis+, bisis+, des+2, eseses+2,bisisis+, cisis+2, eses+2, feseses+2,cisisis+2, es+2, feses+2,cisisisis+2, disis+2, fes+2, geseses+2,disisis+2, eis+2, geses+2,aseses+2, disisisis+2, eisis+2, ges+2,ases+2, eisisis+2, fisis+2,as+2, beseses+2, fisisis+2,beses+2, ceseses+3, fisisisis+2, gisis+2,bes+2, ceses+3, gisisis+2,aisis+2, ces+3, deseses+3, gisisisis+2,aisisis+2, bis+2, deses+3,aisisisis+2, bisis+2, des+3, eseses+3,bisisis+2, cisis+3, eses+3, feseses+3,cisisis+3, es+3, feses+3,cisisisis+3, disis+3, fes+3, geseses+3,disisis+3, eis+3, geses+3,aseses+3, disisisis+3, eisis+3, ges+3,ases+3, eisisis+3, fisis+3,as+3, beseses+3, fisisis+3,beses+3, ceseses+4, fisisisis+3, gisis+3,bes+3, ceses+4, gisisis+3,aisis+3, ces+4, deseses+4, gisisisis+3,aisisis+3, bis+3, deses+4,aisisisis+3, bisis+3, des+4, eseses+4,bisisis+3, cisis+4, eses+4, feseses+4,cisisis+4, es+4, feses+4,cisisisis+4, disis+4, fes+4, geseses+4,disisis+4, eis+4, geses+4,aseses+4, disisisis+4, eisis+4, ges+4,ases+4, eisisis+4, fisis+4,as+4, beseses+4, fisisis+4,beses+4, ceseses+5, fisisisis+4, gisis+4,bes+4, ceses+5, gisisis+4,aisis+4, ces+5, deseses+5, gisisisis+4,aisisis+4, bis+4, deses+5,aisisisis+4, bisis+4, des+5, eseses+5,bisisis+4, cisis+5, eses+5, feseses+5,cisisis+5, es+5, feses+5,cisisisis+5, disis+5, fes+5, geseses+5,disisis+5, eis+5, geses+5,aseses+5, disisisis+5, eisis+5, ges+5,ases+5, eisisis+5, fisis+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "aisisis------, bis------, deses-----,aisisisis------, bisis------, des-----, eseses-----,bisisis------, cisis-----, eses-----, feseses-----,cisisis-----, es-----, feses-----,cisisisis-----, disis-----, fes-----, geseses-----,disisis-----, eis-----, geses-----,aseses-----, disisisis-----, eisis-----, ges-----,ases-----, eisisis-----, fisis-----,as-----, beseses-----, fisisis-----,beses-----, ceseses----, fisisisis-----, gisis-----,bes-----, ceses----, gisisis-----,aisis-----, ces----, deseses----, gisisisis-----,aisisis-----, bis-----, deses----,aisisisis-----, bisis-----, des----, eseses----,bisisis-----, cisis----, eses----, feseses----,cisisis----, es----, feses----,cisisisis----, disis----, fes----, geseses----,disisis----, eis----, geses----,aseses----, disisisis----, eisis----, ges----,ases----, eisisis----, fisis----,as----, beseses----, fisisis----,beses----, ceseses---, fisisisis----, gisis----,bes----, ceses---, gisisis----,aisis----, ces---, deseses---, gisisisis----,aisisis----, bis----, deses---,aisisisis----, bisis----, des---, eseses---,bisisis----, cisis---, eses---, feseses---,cisisis---, es---, feses---,cisisisis---, disis---, fes---, geseses---,disisis---, eis---, geses---,aseses---, disisisis---, eisis---, ges---,ases---, eisisis---, fisis---,as---, beseses---, fisisis---,beses---, ceseses--, fisisisis---, gisis---,bes---, ceses--, gisisis---,aisis---, ces--, deseses--, gisisisis---,aisisis---, bis---, deses--,aisisisis---, bisis---, des--, eseses--,bisisis---, cisis--, eses--, feseses--,cisisis--, es--, feses--,cisisisis--, disis--, fes--, geseses--,disisis--, eis--, geses--,aseses--, disisisis--, eisis--, ges--,ases--, eisisis--, fisis--,as--, beseses--, fisisis--,beses--, ceseses-, fisisisis--, gisis--,bes--, ceses-, gisisis--,aisis--, ces-, deseses-, gisisisis--,aisisis--, bis--, deses-,aisisisis--, bisis--, des-, eseses-,bisisis--, cisis-, eses-, feseses-,cisisis-, es-, feses-,cisisisis-, disis-, fes-, geseses-,disisis-, eis-, geses-,aseses-, disisisis-, eisis-, ges-,ases-, eisisis-, fisis-,as-, beseses-, fisisis-,beses-, ceseses, fisisisis-, gisis-,bes-, ceses, gisisis-,aisis-, ces, deseses, gisisisis-,aisisis-, bis-, deses,aisisisis-, bisis-, des, eseses,bisisis-, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, eisisis, fisis,as, beseses, fisisis,beses, ceseses+, fisisisis, gisis,bes, ceses+, gisisis,aisis, ces+, deseses+, gisisisis,aisisis, bis, deses+,aisisisis, bisis, des+, eseses+,bisisis, cisis+, eses+, feseses+,cisisis+, es+, feses+,cisisisis+, disis+, fes+, geseses+,disisis+, eis+, geses+,aseses+, disisisis+, eisis+, ges+,ases+, eisisis+, fisis+,as+, beseses+, fisisis+,beses+, ceseses++, fisisisis+, gisis+,bes+, ceses++, gisisis+,aisis+, ces++, deseses++, gisisisis+,aisisis+, bis+, deses++,aisisisis+, bisis+, des++, eseses++,bisisis+, cisis++, eses++, feseses++,cisisis++, es++, feses++,cisisisis++, disis++, fes++, geseses++,disisis++, eis++, geses++,aseses++, disisisis++, eisis++, ges++,ases++, eisisis++, fisis++,as++, beseses++, fisisis++,beses++, ceseses+++, fisisisis++, gisis++,bes++, ceses+++, gisisis++,aisis++, ces+++, deseses+++, gisisisis++,aisisis++, bis++, deses+++,aisisisis++, bisis++, des+++, eseses+++,bisisis++, cisis+++, eses+++, feseses+++,cisisis+++, es+++, feses+++,cisisisis+++, disis+++, fes+++, geseses+++,disisis+++, eis+++, geses+++,aseses+++, disisisis+++, eisis+++, ges+++,ases+++, eisisis+++, fisis+++,as+++, beseses+++, fisisis+++,beses+++, ceseses++++, fisisisis+++, gisis+++,bes+++, ceses++++, gisisis+++,aisis+++, ces++++, deseses++++, gisisisis+++,aisisis+++, bis+++, deses++++,aisisisis+++, bisis+++, des++++, eseses++++,bisisis+++, cisis++++, eses++++, feseses++++,cisisis++++, es++++, feses++++,cisisisis++++, disis++++, fes++++, geseses++++,disisis++++, eis++++, geses++++,aseses++++, disisisis++++, eisis++++, ges++++,ases++++, eisisis++++, fisis++++,as++++, beseses++++, fisisis++++,beses++++, ceseses+++++, fisisisis++++, gisis++++,bes++++, ceses+++++, gisisis++++,aisis++++, ces+++++, deseses+++++, gisisisis++++,aisisis++++, bis++++, deses+++++,aisisisis++++, bisis++++, des+++++, eseses+++++,bisisis++++, cisis+++++, eses+++++, feseses+++++,cisisis+++++, es+++++, feses+++++,cisisisis+++++, disis+++++, fes+++++, geseses+++++,disisis+++++, eis+++++, geses+++++,aseses+++++, disisisis+++++, eisis+++++, ges+++++,ases+++++, eisisis+++++, fisis+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "aisisis-2, bis-2, deses-1,aisisisis-2, bisis-2, des-1, eseses-1,bisisis-2, cisis-1, eses-1, feseses-1,cisisis-1, es-1, feses-1,cisisisis-1, disis-1, fes-1, geseses-1,disisis-1, eis-1, geses-1,aseses-1, disisisis-1, eisis-1, ges-1,ases-1, eisisis-1, fisis-1,as-1, beseses-1, fisisis-1,beses-1, ceseses0, fisisisis-1, gisis-1,bes-1, ceses0, gisisis-1,aisis-1, ces0, deseses0, gisisisis-1,aisisis-1, bis-1, deses0,aisisisis-1, bisis-1, des0, eseses0,bisisis-1, cisis0, eses0, feseses0,cisisis0, es0, feses0,cisisisis0, disis0, fes0, geseses0,disisis0, eis0, geses0,aseses0, disisisis0, eisis0, ges0,ases0, eisisis0, fisis0,as0, beseses0, fisisis0,beses0, ceseses1, fisisisis0, gisis0,bes0, ceses1, gisisis0,aisis0, ces1, deseses1, gisisisis0,aisisis0, bis0, deses1,aisisisis0, bisis0, des1, eseses1,bisisis0, cisis1, eses1, feseses1,cisisis1, es1, feses1,cisisisis1, disis1, fes1, geseses1,disisis1, eis1, geses1,aseses1, disisisis1, eisis1, ges1,ases1, eisisis1, fisis1,as1, beseses1, fisisis1,beses1, ceseses2, fisisisis1, gisis1,bes1, ceses2, gisisis1,aisis1, ces2, deseses2, gisisisis1,aisisis1, bis1, deses2,aisisisis1, bisis1, des2, eseses2,bisisis1, cisis2, eses2, feseses2,cisisis2, es2, feses2,cisisisis2, disis2, fes2, geseses2,disisis2, eis2, geses2,aseses2, disisisis2, eisis2, ges2,ases2, eisisis2, fisis2,as2, beseses2, fisisis2,beses2, ceseses3, fisisisis2, gisis2,bes2, ceses3, gisisis2,aisis2, ces3, deseses3, gisisisis2,aisisis2, bis2, deses3,aisisisis2, bisis2, des3, eseses3,bisisis2, cisis3, eses3, feseses3,cisisis3, es3, feses3,cisisisis3, disis3, fes3, geseses3,disisis3, eis3, geses3,aseses3, disisisis3, eisis3, ges3,ases3, eisisis3, fisis3,as3, beseses3, fisisis3,beses3, ceseses4, fisisisis3, gisis3,bes3, ceses4, gisisis3,aisis3, ces4, deseses4, gisisisis3,aisisis3, bis3, deses4,aisisisis3, bisis3, des4, eseses4,bisisis3, cisis4, eses4, feseses4,cisisis4, es4, feses4,cisisisis4, disis4, fes4, geseses4,disisis4, eis4, geses4,aseses4, disisisis4, eisis4, ges4,ases4, eisisis4, fisis4,as4, beseses4, fisisis4,beses4, ceseses5, fisisisis4, gisis4,bes4, ceses5, gisisis4,aisis4, ces5, deseses5, gisisisis4,aisisis4, bis4, deses5,aisisisis4, bisis4, des5, eseses5,bisisis4, cisis5, eses5, feseses5,cisisis5, es5, feses5,cisisisis5, disis5, fes5, geseses5,disisis5, eis5, geses5,aseses5, disisisis5, eisis5, ges5,ases5, eisisis5, fisis5,as5, beseses5, fisisis5,beses5, ceseses6, fisisisis5, gisis5,bes5, ceses6, gisisis5,aisis5, ces6, deseses6, gisisisis5,aisisis5, bis5, deses6,aisisisis5, bisis5, des6, eseses6,bisisis5, cisis6, eses6, feseses6,cisisis6, es6, feses6,cisisisis6, disis6, fes6, geseses6,disisis6, eis6, geses6,aseses6, disisisis6, eisis6, ges6,ases6, eisisis6, fisis6,as6, beseses6, fisisis6,beses6, ceseses7, fisisisis6, gisis6,bes6, ceses7, gisisis6,aisis6, ces7, deseses7, gisisisis6,aisisis6, bis6, deses7,aisisisis6, bisis6, des7, eseses7,bisisis6, cisis7, eses7, feseses7,cisisis7, es7, feses7,cisisisis7, disis7, fes7, geseses7,disisis7, eis7, geses7,aseses7, disisisis7, eisis7, ges7,ases7, eisisis7, fisis7,as7, beseses7, fisisis7,beses7, ceseses8, fisisisis7, gisis7,bes7, ceses8, gisisis7,aisis7, ces8, deseses8, gisisisis7,aisisis7, bis7, deses8,aisisisis7, bisis7, des8, eseses8,bisisis7, cisis8, eses8, feseses8,cisisis8, es8, feses8,cisisisis8, disis8, fes8, geseses8,disisis8, eis8, geses8,aseses8, disisisis8, eisis8, ges8,ases8, eisisis8, fisis8,as8, beseses8, fisisis8,beses8, ceseses9, fisisisis8, gisis8,bes8, ceses9, gisisis8,aisis8, ces9, deseses9, gisisisis8,aisisis8, bis8, deses9,aisisisis8, bisis8, des9, eseses9,bisisis8, cisis9, eses9, feseses9,cisisis9, es9, feses9,cisisisis9, disis9, fes9, geseses9,disisis9, eis9, geses9,aseses9, disisisis9, eisis9, ges9,ases9, eisisis9, fisis9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Aisisis'''', Bis'''', Deses''',Aisisisis'''', Bisis'''', Des''', Eseses''',Bisisis'''', Cisis''', Eses''', Feseses''',Cisisis''', Es''', Feses''',Cisisisis''', Disis''', Fes''', Geseses''',Disisis''', Eis''', Geses''',Aseses''', Disisisis''', Eisis''', Ges''',Ases''', Eisisis''', Fisis''',As''', Beseses''', Fisisis''',Beses''', Ceseses'', Fisisisis''', Gisis''',Bes''', Ceses'', Gisisis''',Aisis''', Ces'', Deseses'', Gisisisis''',Aisisis''', Bis''', Deses'',Aisisisis''', Bisis''', Des'', Eseses'',Bisisis''', Cisis'', Eses'', Feseses'',Cisisis'', Es'', Feses'',Cisisisis'', Disis'', Fes'', Geseses'',Disisis'', Eis'', Geses'',Aseses'', Disisisis'', Eisis'', Ges'',Ases'', Eisisis'', Fisis'',As'', Beseses'', Fisisis'',Beses'', Ceseses', Fisisisis'', Gisis'',Bes'', Ceses', Gisisis'',Aisis'', Ces', Deseses', Gisisisis'',Aisisis'', Bis'', Deses',Aisisisis'', Bisis'', Des', Eseses',Bisisis'', Cisis', Eses', Feseses',Cisisis', Es', Feses',Cisisisis', Disis', Fes', Geseses',Disisis', Eis', Geses',Aseses', Disisisis', Eisis', Ges',Ases', Eisisis', Fisis',As', Beseses', Fisisis',Beses', Ceseses, Fisisisis', Gisis',Bes', Ceses, Gisisis',Aisis', Ces, Deseses, Gisisisis',Aisisis', Bis', Deses,Aisisisis', Bisis', Des, Eseses,Bisisis', Cisis, Eses, Feseses,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Eisisis, Fisis,As, Beseses, Fisisis,Beses, Fisisisis, Gisis, ceseses,Bes, Gisisis, ceses,Aisis, Gisisisis, ces, deseses,Aisisis, Bis, deses,Aisisisis, Bisis, des, eseses,Bisisis, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, eisisis, fisis,as, beseses, fisisis,beses, ceseses', fisisisis, gisis,bes, ceses', gisisis,aisis, ces', deseses', gisisisis,aisisis, bis, deses',aisisisis, bisis, des', eseses',bisisis, cisis', eses', feseses',cisisis', es', feses',cisisisis', disis', fes', geseses',disisis', eis', geses',aseses', disisisis', eisis', ges',ases', eisisis', fisis',as', beseses', fisisis',beses', ceseses'', fisisisis', gisis',bes', ceses'', gisisis',aisis', ces'', deseses'', gisisisis',aisisis', bis', deses'',aisisisis', bisis', des'', eseses'',bisisis', cisis'', eses'', feseses'',cisisis'', es'', feses'',cisisisis'', disis'', fes'', geseses'',disisis'', eis'', geses'',aseses'', disisisis'', eisis'', ges'',ases'', eisisis'', fisis'',as'', beseses'', fisisis'',beses'', ceseses''', fisisisis'', gisis'',bes'', ceses''', gisisis'',aisis'', ces''', deseses''', gisisisis'',aisisis'', bis'', deses''',aisisisis'', bisis'', des''', eseses''',bisisis'', cisis''', eses''', feseses''',cisisis''', es''', feses''',cisisisis''', disis''', fes''', geseses''',disisis''', eis''', geses''',aseses''', disisisis''', eisis''', ges''',ases''', eisisis''', fisis''',as''', beseses''', fisisis''',beses''', ceseses'''', fisisisis''', gisis''',bes''', ceses'''', gisisis''',aisis''', ces'''', deseses'''', gisisisis''',aisisis''', bis''', deses'''',aisisisis''', bisis''', des'''', eseses'''',bisisis''', cisis'''', eses'''', feseses'''',cisisis'''', es'''', feses'''',cisisisis'''', disis'''', fes'''', geseses'''',disisis'''', eis'''', geses'''',aseses'''', disisisis'''', eisis'''', ges'''',ases'''', eisisis'''', fisis'''',as'''', beseses'''', fisisis'''',beses'''', ceseses''''', fisisisis'''', gisis'''',bes'''', ceses''''', gisisis'''',aisis'''', ces''''', deseses''''', gisisisis'''',aisisis'''', bis'''', deses''''',aisisisis'''', bisis'''', des''''', eseses''''',bisisis'''', cisis''''', eses''''', feseses''''',cisisis''''', es''''', feses''''',cisisisis''''', disis''''', fes''''', geseses''''',disisis''''', eis''''', geses''''',aseses''''', disisisis''''', eisis''''', ges''''',ases''''', eisisis''''', fisis''''',as''''', beseses''''', fisisis''''',beses''''', ceseses'''''', fisisisis''''', gisis''''',bes''''', ceses'''''', gisisis''''',aisis''''', ces'''''', deseses'''''', gisisisis''''',aisisis''''', bis''''', deses'''''',aisisisis''''', bisis''''', des'''''', eseses'''''',bisisis''''', cisis'''''', eses'''''', feseses'''''',cisisis'''''', es'''''', feses'''''',cisisisis'''''', disis'''''', fes'''''', geseses'''''',disisis'''''', eis'''''', geses'''''',aseses'''''', disisisis'''''', eisis'''''', ges'''''',ases'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "aisisis-6, bis-6, deses-5, eseseses-5,bisis-6, cis-5, eseses-5,bisisis-6, cisis-5, eses-5, feseses-5,cisisis-5, dis-5, feses-5, geseseses-5,disis-5, fes-5, geseses-5,aseseses-5, disisis-5, eis-5, geses-5,aseses-5, eisis-5, fis-5,ases-5, beseseses-5, eisisis-5, fisis-5,beseses-5, fisisis-5, gis-5,beses-5, ceseses-4, gisis-5,ais-5, ceses-4, deseseses-4, gisisis-5,aisis-5, ces-4, deseses-4,aisisis-5, bis-5, deses-4, eseseses-4,bisis-5, cis-4, eseses-4,bisisis-5, cisis-4, eses-4, feseses-4,cisisis-4, dis-4, feses-4, geseseses-4,disis-4, fes-4, geseses-4,aseseses-4, disisis-4, eis-4, geses-4,aseses-4, eisis-4, fis-4,ases-4, beseseses-4, eisisis-4, fisis-4,beseses-4, fisisis-4, gis-4,beses-4, ceseses-3, gisis-4,ais-4, ceses-3, deseseses-3, gisisis-4,aisis-4, ces-3, deseses-3,aisisis-4, bis-4, deses-3, eseseses-3,bisis-4, cis-3, eseses-3,bisisis-4, cisis-3, eses-3, feseses-3,cisisis-3, dis-3, feses-3, geseseses-3,disis-3, fes-3, geseses-3,aseseses-3, disisis-3, eis-3, geses-3,aseses-3, eisis-3, fis-3,ases-3, beseseses-3, eisisis-3, fisis-3,beseses-3, fisisis-3, gis-3,beses-3, ceseses-2, gisis-3,ais-3, ceses-2, deseseses-2, gisisis-3,aisis-3, ces-2, deseses-2,aisisis-3, bis-3, deses-2, eseseses-2,bisis-3, cis-2, eseses-2,bisisis-3, cisis-2, eses-2, feseses-2,cisisis-2, dis-2, feses-2, geseseses-2,disis-2, fes-2, geseses-2,aseseses-2, disisis-2, eis-2, geses-2,aseses-2, eisis-2, fis-2,ases-2, beseseses-2, eisisis-2, fisis-2,beseses-2, fisisis-2, gis-2,beses-2, ceseses-, gisis-2,ais-2, ceses-, deseseses-, gisisis-2,aisis-2, ces-, deseses-,aisisis-2, bis-2, deses-, eseseses-,bisis-2, cis-, eseses-,bisisis-2, cisis-, eses-, feseses-,cisisis-, dis-, feses-, geseseses-,disis-, fes-, geseses-,aseseses-, disisis-, eis-, geses-,aseses-, eisis-, fis-,ases-, beseseses-, eisisis-, fisis-,beseses-, fisisis-, gis-,beses-, ceseses, gisis-,ais-, ceses, deseseses, gisisis-,aisis-, ces, deseses,aisisis-, bis-, deses, eseseses,bisis-, cis, eseses,bisisis-, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseseses, eisisis, fisis,beseses, fisisis, gis,beses, ceseses+, gisis,ais, ceses+, deseseses+, gisisis,aisis, ces+, deseses+,aisisis, bis, deses+, eseseses+,bisis, cis+, eseses+,bisisis, cisis+, eses+, feseses+,cisisis+, dis+, feses+, geseseses+,disis+, fes+, geseses+,aseseses+, disisis+, eis+, geses+,aseses+, eisis+, fis+,ases+, beseseses+, eisisis+, fisis+,beseses+, fisisis+, gis+,beses+, ceseses+2, gisis+,ais+, ceses+2, deseseses+2, gisisis+,aisis+, ces+2, deseses+2,aisisis+, bis+, deses+2, eseseses+2,bisis+, cis+2, eseses+2,bisisis+, cisis+2, eses+2, feseses+2,cisisis+2, dis+2, feses+2, geseseses+2,disis+2, fes+2, geseses+2,aseseses+2, disisis+2, eis+2, geses+2,aseses+2, eisis+2, fis+2,ases+2, beseseses+2, eisisis+2, fisis+2,beseses+2, fisisis+2, gis+2,beses+2, ceseses+3, gisis+2,ais+2, ceses+3, deseseses+3, gisisis+2,aisis+2, ces+3, deseses+3,aisisis+2, bis+2, deses+3, eseseses+3,bisis+2, cis+3, eseses+3,bisisis+2, cisis+3, eses+3, feseses+3,cisisis+3, dis+3, feses+3, geseseses+3,disis+3, fes+3, geseses+3,aseseses+3, disisis+3, eis+3, geses+3,aseses+3, eisis+3, fis+3,ases+3, beseseses+3, eisisis+3, fisis+3,beseses+3, fisisis+3, gis+3,beses+3, ceseses+4, gisis+3,ais+3, ceses+4, deseseses+4, gisisis+3,aisis+3, ces+4, deseses+4,aisisis+3, bis+3, deses+4, eseseses+4,bisis+3, cis+4, eseses+4,bisisis+3, cisis+4, eses+4, feseses+4,cisisis+4, dis+4, feses+4, geseseses+4,disis+4, fes+4, geseses+4,aseseses+4, disisis+4, eis+4, geses+4,aseses+4, eisis+4, fis+4,ases+4, beseseses+4, eisisis+4, fisis+4,beseses+4, fisisis+4, gis+4,beses+4, ceseses+5, gisis+4,ais+4, ceses+5, deseseses+5, gisisis+4,aisis+4, ces+5, deseses+5,aisisis+4, bis+4, deses+5, eseseses+5,bisis+4, cis+5, eseses+5,bisisis+4, cisis+5, eses+5, feseses+5,cisisis+5, dis+5, feses+5, geseseses+5,disis+5, fes+5, geseses+5,aseseses+5, disisis+5, eis+5, geses+5,aseses+5, eisis+5, fis+5,ases+5, beseseses+5, eisisis+5, fisis+5\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "aisisis------, bis------, deses-----, eseseses-----,bisis------, cis-----, eseses-----,bisisis------, cisis-----, eses-----, feseses-----,cisisis-----, dis-----, feses-----, geseseses-----,disis-----, fes-----, geseses-----,aseseses-----, disisis-----, eis-----, geses-----,aseses-----, eisis-----, fis-----,ases-----, beseseses-----, eisisis-----, fisis-----,beseses-----, fisisis-----, gis-----,beses-----, ceseses----, gisis-----,ais-----, ceses----, deseseses----, gisisis-----,aisis-----, ces----, deseses----,aisisis-----, bis-----, deses----, eseseses----,bisis-----, cis----, eseses----,bisisis-----, cisis----, eses----, feseses----,cisisis----, dis----, feses----, geseseses----,disis----, fes----, geseses----,aseseses----, disisis----, eis----, geses----,aseses----, eisis----, fis----,ases----, beseseses----, eisisis----, fisis----,beseses----, fisisis----, gis----,beses----, ceseses---, gisis----,ais----, ceses---, deseseses---, gisisis----,aisis----, ces---, deseses---,aisisis----, bis----, deses---, eseseses---,bisis----, cis---, eseses---,bisisis----, cisis---, eses---, feseses---,cisisis---, dis---, feses---, geseseses---,disis---, fes---, geseses---,aseseses---, disisis---, eis---, geses---,aseses---, eisis---, fis---,ases---, beseseses---, eisisis---, fisis---,beseses---, fisisis---, gis---,beses---, ceseses--, gisis---,ais---, ceses--, deseseses--, gisisis---,aisis---, ces--, deseses--,aisisis---, bis---, deses--, eseseses--,bisis---, cis--, eseses--,bisisis---, cisis--, eses--, feseses--,cisisis--, dis--, feses--, geseseses--,disis--, fes--, geseses--,aseseses--, disisis--, eis--, geses--,aseses--, eisis--, fis--,ases--, beseseses--, eisisis--, fisis--,beseses--, fisisis--, gis--,beses--, ceseses-, gisis--,ais--, ceses-, deseseses-, gisisis--,aisis--, ces-, deseses-,aisisis--, bis--, deses-, eseseses-,bisis--, cis-, eseses-,bisisis--, cisis-, eses-, feseses-,cisisis-, dis-, feses-, geseseses-,disis-, fes-, geseses-,aseseses-, disisis-, eis-, geses-,aseses-, eisis-, fis-,ases-, beseseses-, eisisis-, fisis-,beseses-, fisisis-, gis-,beses-, ceseses, gisis-,ais-, ceses, deseseses, gisisis-,aisis-, ces, deseses,aisisis-, bis-, deses, eseseses,bisis-, cis, eseses,bisisis-, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseseses, eisisis, fisis,beseses, fisisis, gis,beses, ceseses+, gisis,ais, ceses+, deseseses+, gisisis,aisis, ces+, deseses+,aisisis, bis, deses+, eseseses+,bisis, cis+, eseses+,bisisis, cisis+, eses+, feseses+,cisisis+, dis+, feses+, geseseses+,disis+, fes+, geseses+,aseseses+, disisis+, eis+, geses+,aseses+, eisis+, fis+,ases+, beseseses+, eisisis+, fisis+,beseses+, fisisis+, gis+,beses+, ceseses++, gisis+,ais+, ceses++, deseseses++, gisisis+,aisis+, ces++, deseses++,aisisis+, bis+, deses++, eseseses++,bisis+, cis++, eseses++,bisisis+, cisis++, eses++, feseses++,cisisis++, dis++, feses++, geseseses++,disis++, fes++, geseses++,aseseses++, disisis++, eis++, geses++,aseses++, eisis++, fis++,ases++, beseseses++, eisisis++, fisis++,beseses++, fisisis++, gis++,beses++, ceseses+++, gisis++,ais++, ceses+++, deseseses+++, gisisis++,aisis++, ces+++, deseses+++,aisisis++, bis++, deses+++, eseseses+++,bisis++, cis+++, eseses+++,bisisis++, cisis+++, eses+++, feseses+++,cisisis+++, dis+++, feses+++, geseseses+++,disis+++, fes+++, geseses+++,aseseses+++, disisis+++, eis+++, geses+++,aseses+++, eisis+++, fis+++,ases+++, beseseses+++, eisisis+++, fisis+++,beseses+++, fisisis+++, gis+++,beses+++, ceseses++++, gisis+++,ais+++, ceses++++, deseseses++++, gisisis+++,aisis+++, ces++++, deseses++++,aisisis+++, bis+++, deses++++, eseseses++++,bisis+++, cis++++, eseses++++,bisisis+++, cisis++++, eses++++, feseses++++,cisisis++++, dis++++, feses++++, geseseses++++,disis++++, fes++++, geseses++++,aseseses++++, disisis++++, eis++++, geses++++,aseses++++, eisis++++, fis++++,ases++++, beseseses++++, eisisis++++, fisis++++,beseses++++, fisisis++++, gis++++,beses++++, ceseses+++++, gisis++++,ais++++, ceses+++++, deseseses+++++, gisisis++++,aisis++++, ces+++++, deseses+++++,aisisis++++, bis++++, deses+++++, eseseses+++++,bisis++++, cis+++++, eseses+++++,bisisis++++, cisis+++++, eses+++++, feseses+++++,cisisis+++++, dis+++++, feses+++++, geseseses+++++,disis+++++, fes+++++, geseses+++++,aseseses+++++, disisis+++++, eis+++++, geses+++++,aseses+++++, eisis+++++, fis+++++,ases+++++, beseseses+++++, eisisis+++++, fisis+++++\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "aisisis-2, bis-2, deses-1, eseseses-1,bisis-2, cis-1, eseses-1,bisisis-2, cisis-1, eses-1, feseses-1,cisisis-1, dis-1, feses-1, geseseses-1,disis-1, fes-1, geseses-1,aseseses-1, disisis-1, eis-1, geses-1,aseses-1, eisis-1, fis-1,ases-1, beseseses-1, eisisis-1, fisis-1,beseses-1, fisisis-1, gis-1,beses-1, ceseses0, gisis-1,ais-1, ceses0, deseseses0, gisisis-1,aisis-1, ces0, deseses0,aisisis-1, bis-1, deses0, eseseses0,bisis-1, cis0, eseses0,bisisis-1, cisis0, eses0, feseses0,cisisis0, dis0, feses0, geseseses0,disis0, fes0, geseses0,aseseses0, disisis0, eis0, geses0,aseses0, eisis0, fis0,ases0, beseseses0, eisisis0, fisis0,beseses0, fisisis0, gis0,beses0, ceseses1, gisis0,ais0, ceses1, deseseses1, gisisis0,aisis0, ces1, deseses1,aisisis0, bis0, deses1, eseseses1,bisis0, cis1, eseses1,bisisis0, cisis1, eses1, feseses1,cisisis1, dis1, feses1, geseseses1,disis1, fes1, geseses1,aseseses1, disisis1, eis1, geses1,aseses1, eisis1, fis1,ases1, beseseses1, eisisis1, fisis1,beseses1, fisisis1, gis1,beses1, ceseses2, gisis1,ais1, ceses2, deseseses2, gisisis1,aisis1, ces2, deseses2,aisisis1, bis1, deses2, eseseses2,bisis1, cis2, eseses2,bisisis1, cisis2, eses2, feseses2,cisisis2, dis2, feses2, geseseses2,disis2, fes2, geseses2,aseseses2, disisis2, eis2, geses2,aseses2, eisis2, fis2,ases2, beseseses2, eisisis2, fisis2,beseses2, fisisis2, gis2,beses2, ceseses3, gisis2,ais2, ceses3, deseseses3, gisisis2,aisis2, ces3, deseses3,aisisis2, bis2, deses3, eseseses3,bisis2, cis3, eseses3,bisisis2, cisis3, eses3, feseses3,cisisis3, dis3, feses3, geseseses3,disis3, fes3, geseses3,aseseses3, disisis3, eis3, geses3,aseses3, eisis3, fis3,ases3, beseseses3, eisisis3, fisis3,beseses3, fisisis3, gis3,beses3, ceseses4, gisis3,ais3, ceses4, deseseses4, gisisis3,aisis3, ces4, deseses4,aisisis3, bis3, deses4, eseseses4,bisis3, cis4, eseses4,bisisis3, cisis4, eses4, feseses4,cisisis4, dis4, feses4, geseseses4,disis4, fes4, geseses4,aseseses4, disisis4, eis4, geses4,aseses4, eisis4, fis4,ases4, beseseses4, eisisis4, fisis4,beseses4, fisisis4, gis4,beses4, ceseses5, gisis4,ais4, ceses5, deseseses5, gisisis4,aisis4, ces5, deseses5,aisisis4, bis4, deses5, eseseses5,bisis4, cis5, eseses5,bisisis4, cisis5, eses5, feseses5,cisisis5, dis5, feses5, geseseses5,disis5, fes5, geseses5,aseseses5, disisis5, eis5, geses5,aseses5, eisis5, fis5,ases5, beseseses5, eisisis5, fisis5,beseses5, fisisis5, gis5,beses5, ceseses6, gisis5,ais5, ceses6, deseseses6, gisisis5,aisis5, ces6, deseses6,aisisis5, bis5, deses6, eseseses6,bisis5, cis6, eseses6,bisisis5, cisis6, eses6, feseses6,cisisis6, dis6, feses6, geseseses6,disis6, fes6, geseses6,aseseses6, disisis6, eis6, geses6,aseses6, eisis6, fis6,ases6, beseseses6, eisisis6, fisis6,beseses6, fisisis6, gis6,beses6, ceseses7, gisis6,ais6, ceses7, deseseses7, gisisis6,aisis6, ces7, deseses7,aisisis6, bis6, deses7, eseseses7,bisis6, cis7, eseses7,bisisis6, cisis7, eses7, feseses7,cisisis7, dis7, feses7, geseseses7,disis7, fes7, geseses7,aseseses7, disisis7, eis7, geses7,aseses7, eisis7, fis7,ases7, beseseses7, eisisis7, fisis7,beseses7, fisisis7, gis7,beses7, ceseses8, gisis7,ais7, ceses8, deseseses8, gisisis7,aisis7, ces8, deseses8,aisisis7, bis7, deses8, eseseses8,bisis7, cis8, eseses8,bisisis7, cisis8, eses8, feseses8,cisisis8, dis8, feses8, geseseses8,disis8, fes8, geseses8,aseseses8, disisis8, eis8, geses8,aseses8, eisis8, fis8,ases8, beseseses8, eisisis8, fisis8,beseses8, fisisis8, gis8,beses8, ceseses9, gisis8,ais8, ceses9, deseseses9, gisisis8,aisis8, ces9, deseses9,aisisis8, bis8, deses9, eseseses9,bisis8, cis9, eseses9,bisisis8, cisis9, eses9, feseses9,cisisis9, dis9, feses9, geseseses9,disis9, fes9, geseses9,aseseses9, disisis9, eis9, geses9,aseses9, eisis9, fis9,ases9, beseseses9, eisisis9, fisis9\n"
			+ "cbx_note_id_international_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Aisisis'''', Bis'''', Deses''', Eseseses''',Bisis'''', Cis''', Eseses''',Bisisis'''', Cisis''', Eses''', Feseses''',Cisisis''', Dis''', Feses''', Geseseses''',Disis''', Fes''', Geseses''',Aseseses''', Disisis''', Eis''', Geses''',Aseses''', Eisis''', Fis''',Ases''', Beseseses''', Eisisis''', Fisis''',Beseses''', Fisisis''', Gis''',Beses''', Ceseses'', Gisis''',Ais''', Ceses'', Deseseses'', Gisisis''',Aisis''', Ces'', Deseses'',Aisisis''', Bis''', Deses'', Eseseses'',Bisis''', Cis'', Eseses'',Bisisis''', Cisis'', Eses'', Feseses'',Cisisis'', Dis'', Feses'', Geseseses'',Disis'', Fes'', Geseses'',Aseseses'', Disisis'', Eis'', Geses'',Aseses'', Eisis'', Fis'',Ases'', Beseseses'', Eisisis'', Fisis'',Beseses'', Fisisis'', Gis'',Beses'', Ceseses', Gisis'',Ais'', Ceses', Deseseses', Gisisis'',Aisis'', Ces', Deseses',Aisisis'', Bis'', Deses', Eseseses',Bisis'', Cis', Eseses',Bisisis'', Cisis', Eses', Feseses',Cisisis', Dis', Feses', Geseseses',Disis', Fes', Geseses',Aseseses', Disisis', Eis', Geses',Aseses', Eisis', Fis',Ases', Beseseses', Eisisis', Fisis',Beseses', Fisisis', Gis',Beses', Ceseses, Gisis',Ais', Ceses, Deseseses, Gisisis',Aisis', Ces, Deseses,Aisisis', Bis', Deses, Eseseses,Bisis', Cis, Eseses,Bisisis', Cisis, Eses, Feseses,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseseses, Eisisis, Fisis,Beseses, Fisisis, Gis,Beses, Gisis, ceseses,Ais, Gisisis, ceses, deseseses,Aisis, ces, deseses,Aisisis, Bis, deses, eseseses,Bisis, cis, eseses,Bisisis, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseseses, eisisis, fisis,beseses, fisisis, gis,beses, ceseses', gisis,ais, ceses', deseseses', gisisis,aisis, ces', deseses',aisisis, bis, deses', eseseses',bisis, cis', eseses',bisisis, cisis', eses', feseses',cisisis', dis', feses', geseseses',disis', fes', geseses',aseseses', disisis', eis', geses',aseses', eisis', fis',ases', beseseses', eisisis', fisis',beseses', fisisis', gis',beses', ceseses'', gisis',ais', ceses'', deseseses'', gisisis',aisis', ces'', deseses'',aisisis', bis', deses'', eseseses'',bisis', cis'', eseses'',bisisis', cisis'', eses'', feseses'',cisisis'', dis'', feses'', geseseses'',disis'', fes'', geseses'',aseseses'', disisis'', eis'', geses'',aseses'', eisis'', fis'',ases'', beseseses'', eisisis'', fisis'',beseses'', fisisis'', gis'',beses'', ceseses''', gisis'',ais'', ceses''', deseseses''', gisisis'',aisis'', ces''', deseses''',aisisis'', bis'', deses''', eseseses''',bisis'', cis''', eseses''',bisisis'', cisis''', eses''', feseses''',cisisis''', dis''', feses''', geseseses''',disis''', fes''', geseses''',aseseses''', disisis''', eis''', geses''',aseses''', eisis''', fis''',ases''', beseseses''', eisisis''', fisis''',beseses''', fisisis''', gis''',beses''', ceseses'''', gisis''',ais''', ceses'''', deseseses'''', gisisis''',aisis''', ces'''', deseses'''',aisisis''', bis''', deses'''', eseseses'''',bisis''', cis'''', eseses'''',bisisis''', cisis'''', eses'''', feseses'''',cisisis'''', dis'''', feses'''', geseseses'''',disis'''', fes'''', geseses'''',aseseses'''', disisis'''', eis'''', geses'''',aseses'''', eisis'''', fis'''',ases'''', beseseses'''', eisisis'''', fisis'''',beseses'''', fisisis'''', gis'''',beses'''', ceseses''''', gisis'''',ais'''', ceses''''', deseseses''''', gisisis'''',aisis'''', ces''''', deseses''''',aisisis'''', bis'''', deses''''', eseseses''''',bisis'''', cis''''', eseses''''',bisisis'''', cisis''''', eses''''', feseses''''',cisisis''''', dis''''', feses''''', geseseses''''',disis''''', fes''''', geseses''''',aseseses''''', disisis''''', eis''''', geses''''',aseses''''', eisis''''', fis''''',ases''''', beseseses''''', eisisis''''', fisis''''',beseses''''', fisisis''''', gis''''',beses''''', ceseses'''''', gisis''''',ais''''', ceses'''''', deseseses'''''', gisisis''''',aisis''''', ces'''''', deseses'''''',aisisis''''', bis''''', deses'''''', eseseses'''''',bisis''''', cis'''''', eseses'''''',bisisis''''', cisis'''''', eses'''''', feseses'''''',cisisis'''''', dis'''''', feses'''''', geseseses'''''',disis'''''', fes'''''', geseses'''''',aseseses'''''', disisis'''''', eis'''''', geses'''''',aseses'''''', eisis'''''', fis'''''',ases'''''', beseseses'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "A###-6, B#-6, Dbb-5,A####-6, B##-6, Db-5, Ebbb-5,B###-6, C##-5, Ebb-5, Fbbb-5,C###-5, Eb-5, Fbb-5,C####-5, D##-5, Fb-5, Gbbb-5,D###-5, E#-5, Gbb-5,Abbb-5, D####-5, E##-5, Gb-5,Abb-5, E###-5, F##-5,Ab-5, Bbbb-5, F###-5,Bbb-5, Cbbb-4, F####-5, G##-5,Bb-5, Cbb-4, G###-5,A##-5, Cb-4, Dbbb-4, G####-5,A###-5, B#-5, Dbb-4,A####-5, B##-5, Db-4, Ebbb-4,B###-5, C##-4, Ebb-4, Fbbb-4,C###-4, Eb-4, Fbb-4,C####-4, D##-4, Fb-4, Gbbb-4,D###-4, E#-4, Gbb-4,Abbb-4, D####-4, E##-4, Gb-4,Abb-4, E###-4, F##-4,Ab-4, Bbbb-4, F###-4,Bbb-4, Cbbb-3, F####-4, G##-4,Bb-4, Cbb-3, G###-4,A##-4, Cb-3, Dbbb-3, G####-4,A###-4, B#-4, Dbb-3,A####-4, B##-4, Db-3, Ebbb-3,B###-4, C##-3, Ebb-3, Fbbb-3,C###-3, Eb-3, Fbb-3,C####-3, D##-3, Fb-3, Gbbb-3,D###-3, E#-3, Gbb-3,Abbb-3, D####-3, E##-3, Gb-3,Abb-3, E###-3, F##-3,Ab-3, Bbbb-3, F###-3,Bbb-3, Cbbb-2, F####-3, G##-3,Bb-3, Cbb-2, G###-3,A##-3, Cb-2, Dbbb-2, G####-3,A###-3, B#-3, Dbb-2,A####-3, B##-3, Db-2, Ebbb-2,B###-3, C##-2, Ebb-2, Fbbb-2,C###-2, Eb-2, Fbb-2,C####-2, D##-2, Fb-2, Gbbb-2,D###-2, E#-2, Gbb-2,Abbb-2, D####-2, E##-2, Gb-2,Abb-2, E###-2, F##-2,Ab-2, Bbbb-2, F###-2,Bbb-2, Cbbb-, F####-2, G##-2,Bb-2, Cbb-, G###-2,A##-2, Cb-, Dbbb-, G####-2,A###-2, B#-2, Dbb-,A####-2, B##-2, Db-, Ebbb-,B###-2, C##-, Ebb-, Fbbb-,C###-, Eb-, Fbb-,C####-, D##-, Fb-, Gbbb-,D###-, E#-, Gbb-,Abbb-, D####-, E##-, Gb-,Abb-, E###-, F##-,Ab-, Bbbb-, F###-,Bbb-, Cbbb, F####-, G##-,Bb-, Cbb, G###-,A##-, Cb, Dbbb, G####-,A###-, B#-, Dbb,A####-, B##-, Db, Ebbb,B###-, C##, Ebb, Fbbb,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, E###, F##,Ab, Bbbb, F###,Bbb, Cbbb+, F####, G##,Bb, Cbb+, G###,A##, Cb+, Dbbb+, G####,A###, B#, Dbb+,A####, B##, Db+, Ebbb+,B###, C##+, Ebb+, Fbbb+,C###+, Eb+, Fbb+,C####+, D##+, Fb+, Gbbb+,D###+, E#+, Gbb+,Abbb+, D####+, E##+, Gb+,Abb+, E###+, F##+,Ab+, Bbbb+, F###+,Bbb+, Cbbb+2, F####+, G##+,Bb+, Cbb+2, G###+,A##+, Cb+2, Dbbb+2, G####+,A###+, B#+, Dbb+2,A####+, B##+, Db+2, Ebbb+2,B###+, C##+2, Ebb+2, Fbbb+2,C###+2, Eb+2, Fbb+2,C####+2, D##+2, Fb+2, Gbbb+2,D###+2, E#+2, Gbb+2,Abbb+2, D####+2, E##+2, Gb+2,Abb+2, E###+2, F##+2,Ab+2, Bbbb+2, F###+2,Bbb+2, Cbbb+3, F####+2, G##+2,Bb+2, Cbb+3, G###+2,A##+2, Cb+3, Dbbb+3, G####+2,A###+2, B#+2, Dbb+3,A####+2, B##+2, Db+3, Ebbb+3,B###+2, C##+3, Ebb+3, Fbbb+3,C###+3, Eb+3, Fbb+3,C####+3, D##+3, Fb+3, Gbbb+3,D###+3, E#+3, Gbb+3,Abbb+3, D####+3, E##+3, Gb+3,Abb+3, E###+3, F##+3,Ab+3, Bbbb+3, F###+3,Bbb+3, Cbbb+4, F####+3, G##+3,Bb+3, Cbb+4, G###+3,A##+3, Cb+4, Dbbb+4, G####+3,A###+3, B#+3, Dbb+4,A####+3, B##+3, Db+4, Ebbb+4,B###+3, C##+4, Ebb+4, Fbbb+4,C###+4, Eb+4, Fbb+4,C####+4, D##+4, Fb+4, Gbbb+4,D###+4, E#+4, Gbb+4,Abbb+4, D####+4, E##+4, Gb+4,Abb+4, E###+4, F##+4,Ab+4, Bbbb+4, F###+4,Bbb+4, Cbbb+5, F####+4, G##+4,Bb+4, Cbb+5, G###+4,A##+4, Cb+5, Dbbb+5, G####+4,A###+4, B#+4, Dbb+5,A####+4, B##+4, Db+5, Ebbb+5,B###+4, C##+5, Ebb+5, Fbbb+5,C###+5, Eb+5, Fbb+5,C####+5, D##+5, Fb+5, Gbbb+5,D###+5, E#+5, Gbb+5,Abbb+5, D####+5, E##+5, Gb+5,Abb+5, E###+5, F##+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "A###------, B#------, Dbb-----,A####------, B##------, Db-----, Ebbb-----,B###------, C##-----, Ebb-----, Fbbb-----,C###-----, Eb-----, Fbb-----,C####-----, D##-----, Fb-----, Gbbb-----,D###-----, E#-----, Gbb-----,Abbb-----, D####-----, E##-----, Gb-----,Abb-----, E###-----, F##-----,Ab-----, Bbbb-----, F###-----,Bbb-----, Cbbb----, F####-----, G##-----,Bb-----, Cbb----, G###-----,A##-----, Cb----, Dbbb----, G####-----,A###-----, B#-----, Dbb----,A####-----, B##-----, Db----, Ebbb----,B###-----, C##----, Ebb----, Fbbb----,C###----, Eb----, Fbb----,C####----, D##----, Fb----, Gbbb----,D###----, E#----, Gbb----,Abbb----, D####----, E##----, Gb----,Abb----, E###----, F##----,Ab----, Bbbb----, F###----,Bbb----, Cbbb---, F####----, G##----,Bb----, Cbb---, G###----,A##----, Cb---, Dbbb---, G####----,A###----, B#----, Dbb---,A####----, B##----, Db---, Ebbb---,B###----, C##---, Ebb---, Fbbb---,C###---, Eb---, Fbb---,C####---, D##---, Fb---, Gbbb---,D###---, E#---, Gbb---,Abbb---, D####---, E##---, Gb---,Abb---, E###---, F##---,Ab---, Bbbb---, F###---,Bbb---, Cbbb--, F####---, G##---,Bb---, Cbb--, G###---,A##---, Cb--, Dbbb--, G####---,A###---, B#---, Dbb--,A####---, B##---, Db--, Ebbb--,B###---, C##--, Ebb--, Fbbb--,C###--, Eb--, Fbb--,C####--, D##--, Fb--, Gbbb--,D###--, E#--, Gbb--,Abbb--, D####--, E##--, Gb--,Abb--, E###--, F##--,Ab--, Bbbb--, F###--,Bbb--, Cbbb-, F####--, G##--,Bb--, Cbb-, G###--,A##--, Cb-, Dbbb-, G####--,A###--, B#--, Dbb-,A####--, B##--, Db-, Ebbb-,B###--, C##-, Ebb-, Fbbb-,C###-, Eb-, Fbb-,C####-, D##-, Fb-, Gbbb-,D###-, E#-, Gbb-,Abbb-, D####-, E##-, Gb-,Abb-, E###-, F##-,Ab-, Bbbb-, F###-,Bbb-, Cbbb, F####-, G##-,Bb-, Cbb, G###-,A##-, Cb, Dbbb, G####-,A###-, B#-, Dbb,A####-, B##-, Db, Ebbb,B###-, C##, Ebb, Fbbb,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, E###, F##,Ab, Bbbb, F###,Bbb, Cbbb+, F####, G##,Bb, Cbb+, G###,A##, Cb+, Dbbb+, G####,A###, B#, Dbb+,A####, B##, Db+, Ebbb+,B###, C##+, Ebb+, Fbbb+,C###+, Eb+, Fbb+,C####+, D##+, Fb+, Gbbb+,D###+, E#+, Gbb+,Abbb+, D####+, E##+, Gb+,Abb+, E###+, F##+,Ab+, Bbbb+, F###+,Bbb+, Cbbb++, F####+, G##+,Bb+, Cbb++, G###+,A##+, Cb++, Dbbb++, G####+,A###+, B#+, Dbb++,A####+, B##+, Db++, Ebbb++,B###+, C##++, Ebb++, Fbbb++,C###++, Eb++, Fbb++,C####++, D##++, Fb++, Gbbb++,D###++, E#++, Gbb++,Abbb++, D####++, E##++, Gb++,Abb++, E###++, F##++,Ab++, Bbbb++, F###++,Bbb++, Cbbb+++, F####++, G##++,Bb++, Cbb+++, G###++,A##++, Cb+++, Dbbb+++, G####++,A###++, B#++, Dbb+++,A####++, B##++, Db+++, Ebbb+++,B###++, C##+++, Ebb+++, Fbbb+++,C###+++, Eb+++, Fbb+++,C####+++, D##+++, Fb+++, Gbbb+++,D###+++, E#+++, Gbb+++,Abbb+++, D####+++, E##+++, Gb+++,Abb+++, E###+++, F##+++,Ab+++, Bbbb+++, F###+++,Bbb+++, Cbbb++++, F####+++, G##+++,Bb+++, Cbb++++, G###+++,A##+++, Cb++++, Dbbb++++, G####+++,A###+++, B#+++, Dbb++++,A####+++, B##+++, Db++++, Ebbb++++,B###+++, C##++++, Ebb++++, Fbbb++++,C###++++, Eb++++, Fbb++++,C####++++, D##++++, Fb++++, Gbbb++++,D###++++, E#++++, Gbb++++,Abbb++++, D####++++, E##++++, Gb++++,Abb++++, E###++++, F##++++,Ab++++, Bbbb++++, F###++++,Bbb++++, Cbbb+++++, F####++++, G##++++,Bb++++, Cbb+++++, G###++++,A##++++, Cb+++++, Dbbb+++++, G####++++,A###++++, B#++++, Dbb+++++,A####++++, B##++++, Db+++++, Ebbb+++++,B###++++, C##+++++, Ebb+++++, Fbbb+++++,C###+++++, Eb+++++, Fbb+++++,C####+++++, D##+++++, Fb+++++, Gbbb+++++,D###+++++, E#+++++, Gbb+++++,Abbb+++++, D####+++++, E##+++++, Gb+++++,Abb+++++, E###+++++, F##+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "A###-2, B#-2, Dbb-1,A####-2, B##-2, Db-1, Ebbb-1,B###-2, C##-1, Ebb-1, Fbbb-1,C###-1, Eb-1, Fbb-1,C####-1, D##-1, Fb-1, Gbbb-1,D###-1, E#-1, Gbb-1,Abbb-1, D####-1, E##-1, Gb-1,Abb-1, E###-1, F##-1,Ab-1, Bbbb-1, F###-1,Bbb-1, Cbbb0, F####-1, G##-1,Bb-1, Cbb0, G###-1,A##-1, Cb0, Dbbb0, G####-1,A###-1, B#-1, Dbb0,A####-1, B##-1, Db0, Ebbb0,B###-1, C##0, Ebb0, Fbbb0,C###0, Eb0, Fbb0,C####0, D##0, Fb0, Gbbb0,D###0, E#0, Gbb0,Abbb0, D####0, E##0, Gb0,Abb0, E###0, F##0,Ab0, Bbbb0, F###0,Bbb0, Cbbb1, F####0, G##0,Bb0, Cbb1, G###0,A##0, Cb1, Dbbb1, G####0,A###0, B#0, Dbb1,A####0, B##0, Db1, Ebbb1,B###0, C##1, Ebb1, Fbbb1,C###1, Eb1, Fbb1,C####1, D##1, Fb1, Gbbb1,D###1, E#1, Gbb1,Abbb1, D####1, E##1, Gb1,Abb1, E###1, F##1,Ab1, Bbbb1, F###1,Bbb1, Cbbb2, F####1, G##1,Bb1, Cbb2, G###1,A##1, Cb2, Dbbb2, G####1,A###1, B#1, Dbb2,A####1, B##1, Db2, Ebbb2,B###1, C##2, Ebb2, Fbbb2,C###2, Eb2, Fbb2,C####2, D##2, Fb2, Gbbb2,D###2, E#2, Gbb2,Abbb2, D####2, E##2, Gb2,Abb2, E###2, F##2,Ab2, Bbbb2, F###2,Bbb2, Cbbb3, F####2, G##2,Bb2, Cbb3, G###2,A##2, Cb3, Dbbb3, G####2,A###2, B#2, Dbb3,A####2, B##2, Db3, Ebbb3,B###2, C##3, Ebb3, Fbbb3,C###3, Eb3, Fbb3,C####3, D##3, Fb3, Gbbb3,D###3, E#3, Gbb3,Abbb3, D####3, E##3, Gb3,Abb3, E###3, F##3,Ab3, Bbbb3, F###3,Bbb3, Cbbb4, F####3, G##3,Bb3, Cbb4, G###3,A##3, Cb4, Dbbb4, G####3,A###3, B#3, Dbb4,A####3, B##3, Db4, Ebbb4,B###3, C##4, Ebb4, Fbbb4,C###4, Eb4, Fbb4,C####4, D##4, Fb4, Gbbb4,D###4, E#4, Gbb4,Abbb4, D####4, E##4, Gb4,Abb4, E###4, F##4,Ab4, Bbbb4, F###4,Bbb4, Cbbb5, F####4, G##4,Bb4, Cbb5, G###4,A##4, Cb5, Dbbb5, G####4,A###4, B#4, Dbb5,A####4, B##4, Db5, Ebbb5,B###4, C##5, Ebb5, Fbbb5,C###5, Eb5, Fbb5,C####5, D##5, Fb5, Gbbb5,D###5, E#5, Gbb5,Abbb5, D####5, E##5, Gb5,Abb5, E###5, F##5,Ab5, Bbbb5, F###5,Bbb5, Cbbb6, F####5, G##5,Bb5, Cbb6, G###5,A##5, Cb6, Dbbb6, G####5,A###5, B#5, Dbb6,A####5, B##5, Db6, Ebbb6,B###5, C##6, Ebb6, Fbbb6,C###6, Eb6, Fbb6,C####6, D##6, Fb6, Gbbb6,D###6, E#6, Gbb6,Abbb6, D####6, E##6, Gb6,Abb6, E###6, F##6,Ab6, Bbbb6, F###6,Bbb6, Cbbb7, F####6, G##6,Bb6, Cbb7, G###6,A##6, Cb7, Dbbb7, G####6,A###6, B#6, Dbb7,A####6, B##6, Db7, Ebbb7,B###6, C##7, Ebb7, Fbbb7,C###7, Eb7, Fbb7,C####7, D##7, Fb7, Gbbb7,D###7, E#7, Gbb7,Abbb7, D####7, E##7, Gb7,Abb7, E###7, F##7,Ab7, Bbbb7, F###7,Bbb7, Cbbb8, F####7, G##7,Bb7, Cbb8, G###7,A##7, Cb8, Dbbb8, G####7,A###7, B#7, Dbb8,A####7, B##7, Db8, Ebbb8,B###7, C##8, Ebb8, Fbbb8,C###8, Eb8, Fbb8,C####8, D##8, Fb8, Gbbb8,D###8, E#8, Gbb8,Abbb8, D####8, E##8, Gb8,Abb8, E###8, F##8,Ab8, Bbbb8, F###8,Bbb8, Cbbb9, F####8, G##8,Bb8, Cbb9, G###8,A##8, Cb9, Dbbb9, G####8,A###8, B#8, Dbb9,A####8, B##8, Db9, Ebbb9,B###8, C##9, Ebb9, Fbbb9,C###9, Eb9, Fbb9,C####9, D##9, Fb9, Gbbb9,D###9, E#9, Gbb9,Abbb9, D####9, E##9, Gb9,Abb9, E###9, F##9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A###'''', B#'''', Dbb''',A####'''', B##'''', Db''', Ebbb''',B###'''', C##''', Ebb''', Fbbb''',C###''', Eb''', Fbb''',C####''', D##''', Fb''', Gbbb''',D###''', E#''', Gbb''',Abbb''', D####''', E##''', Gb''',Abb''', E###''', F##''',Ab''', Bbbb''', F###''',Bbb''', Cbbb'', F####''', G##''',Bb''', Cbb'', G###''',A##''', Cb'', Dbbb'', G####''',A###''', B#''', Dbb'',A####''', B##''', Db'', Ebbb'',B###''', C##'', Ebb'', Fbbb'',C###'', Eb'', Fbb'',C####'', D##'', Fb'', Gbbb'',D###'', E#'', Gbb'',Abbb'', D####'', E##'', Gb'',Abb'', E###'', F##'',Ab'', Bbbb'', F###'',Bbb'', Cbbb', F####'', G##'',Bb'', Cbb', G###'',A##'', Cb', Dbbb', G####'',A###'', B#'', Dbb',A####'', B##'', Db', Ebbb',B###'', C##', Ebb', Fbbb',C###', Eb', Fbb',C####', D##', Fb', Gbbb',D###', E#', Gbb',Abbb', D####', E##', Gb',Abb', E###', F##',Ab', Bbbb', F###',Bbb', Cbbb, F####', G##',Bb', Cbb, G###',A##', Cb, Dbbb, G####',A###', B#', Dbb,A####', B##', Db, Ebbb,B###', C##, Ebb, Fbbb,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, E###, F##,Ab, Bbbb, F###,Bbb, F####, G##, cbbb,Bb, G###, cbb,A##, G####, cb, dbbb,A###, B#, dbb,A####, B##, db, ebbb,B###, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, e###, f##,ab, bbbb, f###,bbb, cbbb', f####, g##,bb, cbb', g###,a##, cb', dbbb', g####,a###, b#, dbb',a####, b##, db', ebbb',b###, c##', ebb', fbbb',c###', eb', fbb',c####', d##', fb', gbbb',d###', e#', gbb',abbb', d####', e##', gb',abb', e###', f##',ab', bbbb', f###',bbb', cbbb'', f####', g##',bb', cbb'', g###',a##', cb'', dbbb'', g####',a###', b#', dbb'',a####', b##', db'', ebbb'',b###', c##'', ebb'', fbbb'',c###'', eb'', fbb'',c####'', d##'', fb'', gbbb'',d###'', e#'', gbb'',abbb'', d####'', e##'', gb'',abb'', e###'', f##'',ab'', bbbb'', f###'',bbb'', cbbb''', f####'', g##'',bb'', cbb''', g###'',a##'', cb''', dbbb''', g####'',a###'', b#'', dbb''',a####'', b##'', db''', ebbb''',b###'', c##''', ebb''', fbbb''',c###''', eb''', fbb''',c####''', d##''', fb''', gbbb''',d###''', e#''', gbb''',abbb''', d####''', e##''', gb''',abb''', e###''', f##''',ab''', bbbb''', f###''',bbb''', cbbb'''', f####''', g##''',bb''', cbb'''', g###''',a##''', cb'''', dbbb'''', g####''',a###''', b#''', dbb'''',a####''', b##''', db'''', ebbb'''',b###''', c##'''', ebb'''', fbbb'''',c###'''', eb'''', fbb'''',c####'''', d##'''', fb'''', gbbb'''',d###'''', e#'''', gbb'''',abbb'''', d####'''', e##'''', gb'''',abb'''', e###'''', f##'''',ab'''', bbbb'''', f###'''',bbb'''', cbbb''''', f####'''', g##'''',bb'''', cbb''''', g###'''',a##'''', cb''''', dbbb''''', g####'''',a###'''', b#'''', dbb''''',a####'''', b##'''', db''''', ebbb''''',b###'''', c##''''', ebb''''', fbbb''''',c###''''', eb''''', fbb''''',c####''''', d##''''', fb''''', gbbb''''',d###''''', e#''''', gbb''''',abbb''''', d####''''', e##''''', gb''''',abb''''', e###''''', f##''''',ab''''', bbbb''''', f###''''',bbb''''', cbbb'''''', f####''''', g##''''',bb''''', cbb'''''', g###''''',a##''''', cb'''''', dbbb'''''', g####''''',a###''''', b#''''', dbb'''''',a####''''', b##''''', db'''''', ebbb'''''',b###''''', c##'''''', ebb'''''', fbbb'''''',c###'''''', eb'''''', fbb'''''',c####'''''', d##'''''', fb'''''', gbbb'''''',d###'''''', e#'''''', gbb'''''',abbb'''''', d####'''''', e##'''''', gb'''''',abb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "A###-6, B#-6, Dbb-5, Ebbbb-5,B##-6, C#-5, Ebbb-5,B###-6, C##-5, Ebb-5, Fbbb-5,C###-5, D#-5, Fbb-5, Gbbbb-5,D##-5, Fb-5, Gbbb-5,Abbbb-5, D###-5, E#-5, Gbb-5,Abbb-5, E##-5, F#-5,Abb-5, Bbbbb-5, E###-5, F##-5,Bbbb-5, F###-5, G#-5,Bbb-5, Cbbb-4, G##-5,A#-5, Cbb-4, Dbbbb-4, G###-5,A##-5, Cb-4, Dbbb-4,A###-5, B#-5, Dbb-4, Ebbbb-4,B##-5, C#-4, Ebbb-4,B###-5, C##-4, Ebb-4, Fbbb-4,C###-4, D#-4, Fbb-4, Gbbbb-4,D##-4, Fb-4, Gbbb-4,Abbbb-4, D###-4, E#-4, Gbb-4,Abbb-4, E##-4, F#-4,Abb-4, Bbbbb-4, E###-4, F##-4,Bbbb-4, F###-4, G#-4,Bbb-4, Cbbb-3, G##-4,A#-4, Cbb-3, Dbbbb-3, G###-4,A##-4, Cb-3, Dbbb-3,A###-4, B#-4, Dbb-3, Ebbbb-3,B##-4, C#-3, Ebbb-3,B###-4, C##-3, Ebb-3, Fbbb-3,C###-3, D#-3, Fbb-3, Gbbbb-3,D##-3, Fb-3, Gbbb-3,Abbbb-3, D###-3, E#-3, Gbb-3,Abbb-3, E##-3, F#-3,Abb-3, Bbbbb-3, E###-3, F##-3,Bbbb-3, F###-3, G#-3,Bbb-3, Cbbb-2, G##-3,A#-3, Cbb-2, Dbbbb-2, G###-3,A##-3, Cb-2, Dbbb-2,A###-3, B#-3, Dbb-2, Ebbbb-2,B##-3, C#-2, Ebbb-2,B###-3, C##-2, Ebb-2, Fbbb-2,C###-2, D#-2, Fbb-2, Gbbbb-2,D##-2, Fb-2, Gbbb-2,Abbbb-2, D###-2, E#-2, Gbb-2,Abbb-2, E##-2, F#-2,Abb-2, Bbbbb-2, E###-2, F##-2,Bbbb-2, F###-2, G#-2,Bbb-2, Cbbb-, G##-2,A#-2, Cbb-, Dbbbb-, G###-2,A##-2, Cb-, Dbbb-,A###-2, B#-2, Dbb-, Ebbbb-,B##-2, C#-, Ebbb-,B###-2, C##-, Ebb-, Fbbb-,C###-, D#-, Fbb-, Gbbbb-,D##-, Fb-, Gbbb-,Abbbb-, D###-, E#-, Gbb-,Abbb-, E##-, F#-,Abb-, Bbbbb-, E###-, F##-,Bbbb-, F###-, G#-,Bbb-, Cbbb, G##-,A#-, Cbb, Dbbbb, G###-,A##-, Cb, Dbbb,A###-, B#-, Dbb, Ebbbb,B##-, C#, Ebbb,B###-, C##, Ebb, Fbbb,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbbb, E###, F##,Bbbb, F###, G#,Bbb, Cbbb+, G##,A#, Cbb+, Dbbbb+, G###,A##, Cb+, Dbbb+,A###, B#, Dbb+, Ebbbb+,B##, C#+, Ebbb+,B###, C##+, Ebb+, Fbbb+,C###+, D#+, Fbb+, Gbbbb+,D##+, Fb+, Gbbb+,Abbbb+, D###+, E#+, Gbb+,Abbb+, E##+, F#+,Abb+, Bbbbb+, E###+, F##+,Bbbb+, F###+, G#+,Bbb+, Cbbb+2, G##+,A#+, Cbb+2, Dbbbb+2, G###+,A##+, Cb+2, Dbbb+2,A###+, B#+, Dbb+2, Ebbbb+2,B##+, C#+2, Ebbb+2,B###+, C##+2, Ebb+2, Fbbb+2,C###+2, D#+2, Fbb+2, Gbbbb+2,D##+2, Fb+2, Gbbb+2,Abbbb+2, D###+2, E#+2, Gbb+2,Abbb+2, E##+2, F#+2,Abb+2, Bbbbb+2, E###+2, F##+2,Bbbb+2, F###+2, G#+2,Bbb+2, Cbbb+3, G##+2,A#+2, Cbb+3, Dbbbb+3, G###+2,A##+2, Cb+3, Dbbb+3,A###+2, B#+2, Dbb+3, Ebbbb+3,B##+2, C#+3, Ebbb+3,B###+2, C##+3, Ebb+3, Fbbb+3,C###+3, D#+3, Fbb+3, Gbbbb+3,D##+3, Fb+3, Gbbb+3,Abbbb+3, D###+3, E#+3, Gbb+3,Abbb+3, E##+3, F#+3,Abb+3, Bbbbb+3, E###+3, F##+3,Bbbb+3, F###+3, G#+3,Bbb+3, Cbbb+4, G##+3,A#+3, Cbb+4, Dbbbb+4, G###+3,A##+3, Cb+4, Dbbb+4,A###+3, B#+3, Dbb+4, Ebbbb+4,B##+3, C#+4, Ebbb+4,B###+3, C##+4, Ebb+4, Fbbb+4,C###+4, D#+4, Fbb+4, Gbbbb+4,D##+4, Fb+4, Gbbb+4,Abbbb+4, D###+4, E#+4, Gbb+4,Abbb+4, E##+4, F#+4,Abb+4, Bbbbb+4, E###+4, F##+4,Bbbb+4, F###+4, G#+4,Bbb+4, Cbbb+5, G##+4,A#+4, Cbb+5, Dbbbb+5, G###+4,A##+4, Cb+5, Dbbb+5,A###+4, B#+4, Dbb+5, Ebbbb+5,B##+4, C#+5, Ebbb+5,B###+4, C##+5, Ebb+5, Fbbb+5,C###+5, D#+5, Fbb+5, Gbbbb+5,D##+5, Fb+5, Gbbb+5,Abbbb+5, D###+5, E#+5, Gbb+5,Abbb+5, E##+5, F#+5,Abb+5, Bbbbb+5, E###+5, F##+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "A###------, B#------, Dbb-----, Ebbbb-----,B##------, C#-----, Ebbb-----,B###------, C##-----, Ebb-----, Fbbb-----,C###-----, D#-----, Fbb-----, Gbbbb-----,D##-----, Fb-----, Gbbb-----,Abbbb-----, D###-----, E#-----, Gbb-----,Abbb-----, E##-----, F#-----,Abb-----, Bbbbb-----, E###-----, F##-----,Bbbb-----, F###-----, G#-----,Bbb-----, Cbbb----, G##-----,A#-----, Cbb----, Dbbbb----, G###-----,A##-----, Cb----, Dbbb----,A###-----, B#-----, Dbb----, Ebbbb----,B##-----, C#----, Ebbb----,B###-----, C##----, Ebb----, Fbbb----,C###----, D#----, Fbb----, Gbbbb----,D##----, Fb----, Gbbb----,Abbbb----, D###----, E#----, Gbb----,Abbb----, E##----, F#----,Abb----, Bbbbb----, E###----, F##----,Bbbb----, F###----, G#----,Bbb----, Cbbb---, G##----,A#----, Cbb---, Dbbbb---, G###----,A##----, Cb---, Dbbb---,A###----, B#----, Dbb---, Ebbbb---,B##----, C#---, Ebbb---,B###----, C##---, Ebb---, Fbbb---,C###---, D#---, Fbb---, Gbbbb---,D##---, Fb---, Gbbb---,Abbbb---, D###---, E#---, Gbb---,Abbb---, E##---, F#---,Abb---, Bbbbb---, E###---, F##---,Bbbb---, F###---, G#---,Bbb---, Cbbb--, G##---,A#---, Cbb--, Dbbbb--, G###---,A##---, Cb--, Dbbb--,A###---, B#---, Dbb--, Ebbbb--,B##---, C#--, Ebbb--,B###---, C##--, Ebb--, Fbbb--,C###--, D#--, Fbb--, Gbbbb--,D##--, Fb--, Gbbb--,Abbbb--, D###--, E#--, Gbb--,Abbb--, E##--, F#--,Abb--, Bbbbb--, E###--, F##--,Bbbb--, F###--, G#--,Bbb--, Cbbb-, G##--,A#--, Cbb-, Dbbbb-, G###--,A##--, Cb-, Dbbb-,A###--, B#--, Dbb-, Ebbbb-,B##--, C#-, Ebbb-,B###--, C##-, Ebb-, Fbbb-,C###-, D#-, Fbb-, Gbbbb-,D##-, Fb-, Gbbb-,Abbbb-, D###-, E#-, Gbb-,Abbb-, E##-, F#-,Abb-, Bbbbb-, E###-, F##-,Bbbb-, F###-, G#-,Bbb-, Cbbb, G##-,A#-, Cbb, Dbbbb, G###-,A##-, Cb, Dbbb,A###-, B#-, Dbb, Ebbbb,B##-, C#, Ebbb,B###-, C##, Ebb, Fbbb,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbbb, E###, F##,Bbbb, F###, G#,Bbb, Cbbb+, G##,A#, Cbb+, Dbbbb+, G###,A##, Cb+, Dbbb+,A###, B#, Dbb+, Ebbbb+,B##, C#+, Ebbb+,B###, C##+, Ebb+, Fbbb+,C###+, D#+, Fbb+, Gbbbb+,D##+, Fb+, Gbbb+,Abbbb+, D###+, E#+, Gbb+,Abbb+, E##+, F#+,Abb+, Bbbbb+, E###+, F##+,Bbbb+, F###+, G#+,Bbb+, Cbbb++, G##+,A#+, Cbb++, Dbbbb++, G###+,A##+, Cb++, Dbbb++,A###+, B#+, Dbb++, Ebbbb++,B##+, C#++, Ebbb++,B###+, C##++, Ebb++, Fbbb++,C###++, D#++, Fbb++, Gbbbb++,D##++, Fb++, Gbbb++,Abbbb++, D###++, E#++, Gbb++,Abbb++, E##++, F#++,Abb++, Bbbbb++, E###++, F##++,Bbbb++, F###++, G#++,Bbb++, Cbbb+++, G##++,A#++, Cbb+++, Dbbbb+++, G###++,A##++, Cb+++, Dbbb+++,A###++, B#++, Dbb+++, Ebbbb+++,B##++, C#+++, Ebbb+++,B###++, C##+++, Ebb+++, Fbbb+++,C###+++, D#+++, Fbb+++, Gbbbb+++,D##+++, Fb+++, Gbbb+++,Abbbb+++, D###+++, E#+++, Gbb+++,Abbb+++, E##+++, F#+++,Abb+++, Bbbbb+++, E###+++, F##+++,Bbbb+++, F###+++, G#+++,Bbb+++, Cbbb++++, G##+++,A#+++, Cbb++++, Dbbbb++++, G###+++,A##+++, Cb++++, Dbbb++++,A###+++, B#+++, Dbb++++, Ebbbb++++,B##+++, C#++++, Ebbb++++,B###+++, C##++++, Ebb++++, Fbbb++++,C###++++, D#++++, Fbb++++, Gbbbb++++,D##++++, Fb++++, Gbbb++++,Abbbb++++, D###++++, E#++++, Gbb++++,Abbb++++, E##++++, F#++++,Abb++++, Bbbbb++++, E###++++, F##++++,Bbbb++++, F###++++, G#++++,Bbb++++, Cbbb+++++, G##++++,A#++++, Cbb+++++, Dbbbb+++++, G###++++,A##++++, Cb+++++, Dbbb+++++,A###++++, B#++++, Dbb+++++, Ebbbb+++++,B##++++, C#+++++, Ebbb+++++,B###++++, C##+++++, Ebb+++++, Fbbb+++++,C###+++++, D#+++++, Fbb+++++, Gbbbb+++++,D##+++++, Fb+++++, Gbbb+++++,Abbbb+++++, D###+++++, E#+++++, Gbb+++++,Abbb+++++, E##+++++, F#+++++,Abb+++++, Bbbbb+++++, E###+++++, F##+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "A###-2, B#-2, Dbb-1, Ebbbb-1,B##-2, C#-1, Ebbb-1,B###-2, C##-1, Ebb-1, Fbbb-1,C###-1, D#-1, Fbb-1, Gbbbb-1,D##-1, Fb-1, Gbbb-1,Abbbb-1, D###-1, E#-1, Gbb-1,Abbb-1, E##-1, F#-1,Abb-1, Bbbbb-1, E###-1, F##-1,Bbbb-1, F###-1, G#-1,Bbb-1, Cbbb0, G##-1,A#-1, Cbb0, Dbbbb0, G###-1,A##-1, Cb0, Dbbb0,A###-1, B#-1, Dbb0, Ebbbb0,B##-1, C#0, Ebbb0,B###-1, C##0, Ebb0, Fbbb0,C###0, D#0, Fbb0, Gbbbb0,D##0, Fb0, Gbbb0,Abbbb0, D###0, E#0, Gbb0,Abbb0, E##0, F#0,Abb0, Bbbbb0, E###0, F##0,Bbbb0, F###0, G#0,Bbb0, Cbbb1, G##0,A#0, Cbb1, Dbbbb1, G###0,A##0, Cb1, Dbbb1,A###0, B#0, Dbb1, Ebbbb1,B##0, C#1, Ebbb1,B###0, C##1, Ebb1, Fbbb1,C###1, D#1, Fbb1, Gbbbb1,D##1, Fb1, Gbbb1,Abbbb1, D###1, E#1, Gbb1,Abbb1, E##1, F#1,Abb1, Bbbbb1, E###1, F##1,Bbbb1, F###1, G#1,Bbb1, Cbbb2, G##1,A#1, Cbb2, Dbbbb2, G###1,A##1, Cb2, Dbbb2,A###1, B#1, Dbb2, Ebbbb2,B##1, C#2, Ebbb2,B###1, C##2, Ebb2, Fbbb2,C###2, D#2, Fbb2, Gbbbb2,D##2, Fb2, Gbbb2,Abbbb2, D###2, E#2, Gbb2,Abbb2, E##2, F#2,Abb2, Bbbbb2, E###2, F##2,Bbbb2, F###2, G#2,Bbb2, Cbbb3, G##2,A#2, Cbb3, Dbbbb3, G###2,A##2, Cb3, Dbbb3,A###2, B#2, Dbb3, Ebbbb3,B##2, C#3, Ebbb3,B###2, C##3, Ebb3, Fbbb3,C###3, D#3, Fbb3, Gbbbb3,D##3, Fb3, Gbbb3,Abbbb3, D###3, E#3, Gbb3,Abbb3, E##3, F#3,Abb3, Bbbbb3, E###3, F##3,Bbbb3, F###3, G#3,Bbb3, Cbbb4, G##3,A#3, Cbb4, Dbbbb4, G###3,A##3, Cb4, Dbbb4,A###3, B#3, Dbb4, Ebbbb4,B##3, C#4, Ebbb4,B###3, C##4, Ebb4, Fbbb4,C###4, D#4, Fbb4, Gbbbb4,D##4, Fb4, Gbbb4,Abbbb4, D###4, E#4, Gbb4,Abbb4, E##4, F#4,Abb4, Bbbbb4, E###4, F##4,Bbbb4, F###4, G#4,Bbb4, Cbbb5, G##4,A#4, Cbb5, Dbbbb5, G###4,A##4, Cb5, Dbbb5,A###4, B#4, Dbb5, Ebbbb5,B##4, C#5, Ebbb5,B###4, C##5, Ebb5, Fbbb5,C###5, D#5, Fbb5, Gbbbb5,D##5, Fb5, Gbbb5,Abbbb5, D###5, E#5, Gbb5,Abbb5, E##5, F#5,Abb5, Bbbbb5, E###5, F##5,Bbbb5, F###5, G#5,Bbb5, Cbbb6, G##5,A#5, Cbb6, Dbbbb6, G###5,A##5, Cb6, Dbbb6,A###5, B#5, Dbb6, Ebbbb6,B##5, C#6, Ebbb6,B###5, C##6, Ebb6, Fbbb6,C###6, D#6, Fbb6, Gbbbb6,D##6, Fb6, Gbbb6,Abbbb6, D###6, E#6, Gbb6,Abbb6, E##6, F#6,Abb6, Bbbbb6, E###6, F##6,Bbbb6, F###6, G#6,Bbb6, Cbbb7, G##6,A#6, Cbb7, Dbbbb7, G###6,A##6, Cb7, Dbbb7,A###6, B#6, Dbb7, Ebbbb7,B##6, C#7, Ebbb7,B###6, C##7, Ebb7, Fbbb7,C###7, D#7, Fbb7, Gbbbb7,D##7, Fb7, Gbbb7,Abbbb7, D###7, E#7, Gbb7,Abbb7, E##7, F#7,Abb7, Bbbbb7, E###7, F##7,Bbbb7, F###7, G#7,Bbb7, Cbbb8, G##7,A#7, Cbb8, Dbbbb8, G###7,A##7, Cb8, Dbbb8,A###7, B#7, Dbb8, Ebbbb8,B##7, C#8, Ebbb8,B###7, C##8, Ebb8, Fbbb8,C###8, D#8, Fbb8, Gbbbb8,D##8, Fb8, Gbbb8,Abbbb8, D###8, E#8, Gbb8,Abbb8, E##8, F#8,Abb8, Bbbbb8, E###8, F##8,Bbbb8, F###8, G#8,Bbb8, Cbbb9, G##8,A#8, Cbb9, Dbbbb9, G###8,A##8, Cb9, Dbbb9,A###8, B#8, Dbb9, Ebbbb9,B##8, C#9, Ebbb9,B###8, C##9, Ebb9, Fbbb9,C###9, D#9, Fbb9, Gbbbb9,D##9, Fb9, Gbbb9,Abbbb9, D###9, E#9, Gbb9,Abbb9, E##9, F#9,Abb9, Bbbbb9, E###9, F##9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A###'''', B#'''', Dbb''', Ebbbb''',B##'''', C#''', Ebbb''',B###'''', C##''', Ebb''', Fbbb''',C###''', D#''', Fbb''', Gbbbb''',D##''', Fb''', Gbbb''',Abbbb''', D###''', E#''', Gbb''',Abbb''', E##''', F#''',Abb''', Bbbbb''', E###''', F##''',Bbbb''', F###''', G#''',Bbb''', Cbbb'', G##''',A#''', Cbb'', Dbbbb'', G###''',A##''', Cb'', Dbbb'',A###''', B#''', Dbb'', Ebbbb'',B##''', C#'', Ebbb'',B###''', C##'', Ebb'', Fbbb'',C###'', D#'', Fbb'', Gbbbb'',D##'', Fb'', Gbbb'',Abbbb'', D###'', E#'', Gbb'',Abbb'', E##'', F#'',Abb'', Bbbbb'', E###'', F##'',Bbbb'', F###'', G#'',Bbb'', Cbbb', G##'',A#'', Cbb', Dbbbb', G###'',A##'', Cb', Dbbb',A###'', B#'', Dbb', Ebbbb',B##'', C#', Ebbb',B###'', C##', Ebb', Fbbb',C###', D#', Fbb', Gbbbb',D##', Fb', Gbbb',Abbbb', D###', E#', Gbb',Abbb', E##', F#',Abb', Bbbbb', E###', F##',Bbbb', F###', G#',Bbb', Cbbb, G##',A#', Cbb, Dbbbb, G###',A##', Cb, Dbbb,A###', B#', Dbb, Ebbbb,B##', C#, Ebbb,B###', C##, Ebb, Fbbb,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbbb, E###, F##,Bbbb, F###, G#,Bbb, G##, cbbb,A#, G###, cbb, dbbbb,A##, cb, dbbb,A###, B#, dbb, ebbbb,B##, c#, ebbb,B###, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbbb, e###, f##,bbbb, f###, g#,bbb, cbbb', g##,a#, cbb', dbbbb', g###,a##, cb', dbbb',a###, b#, dbb', ebbbb',b##, c#', ebbb',b###, c##', ebb', fbbb',c###', d#', fbb', gbbbb',d##', fb', gbbb',abbbb', d###', e#', gbb',abbb', e##', f#',abb', bbbbb', e###', f##',bbbb', f###', g#',bbb', cbbb'', g##',a#', cbb'', dbbbb'', g###',a##', cb'', dbbb'',a###', b#', dbb'', ebbbb'',b##', c#'', ebbb'',b###', c##'', ebb'', fbbb'',c###'', d#'', fbb'', gbbbb'',d##'', fb'', gbbb'',abbbb'', d###'', e#'', gbb'',abbb'', e##'', f#'',abb'', bbbbb'', e###'', f##'',bbbb'', f###'', g#'',bbb'', cbbb''', g##'',a#'', cbb''', dbbbb''', g###'',a##'', cb''', dbbb''',a###'', b#'', dbb''', ebbbb''',b##'', c#''', ebbb''',b###'', c##''', ebb''', fbbb''',c###''', d#''', fbb''', gbbbb''',d##''', fb''', gbbb''',abbbb''', d###''', e#''', gbb''',abbb''', e##''', f#''',abb''', bbbbb''', e###''', f##''',bbbb''', f###''', g#''',bbb''', cbbb'''', g##''',a#''', cbb'''', dbbbb'''', g###''',a##''', cb'''', dbbb'''',a###''', b#''', dbb'''', ebbbb'''',b##''', c#'''', ebbb'''',b###''', c##'''', ebb'''', fbbb'''',c###'''', d#'''', fbb'''', gbbbb'''',d##'''', fb'''', gbbb'''',abbbb'''', d###'''', e#'''', gbb'''',abbb'''', e##'''', f#'''',abb'''', bbbbb'''', e###'''', f##'''',bbbb'''', f###'''', g#'''',bbb'''', cbbb''''', g##'''',a#'''', cbb''''', dbbbb''''', g###'''',a##'''', cb''''', dbbb''''',a###'''', b#'''', dbb''''', ebbbb''''',b##'''', c#''''', ebbb''''',b###'''', c##''''', ebb''''', fbbb''''',c###''''', d#''''', fbb''''', gbbbb''''',d##''''', fb''''', gbbb''''',abbbb''''', d###''''', e#''''', gbb''''',abbb''''', e##''''', f#''''',abb''''', bbbbb''''', e###''''', f##''''',bbbb''''', f###''''', g#''''',bbb''''', cbbb'''''', g##''''',a#''''', cbb'''''', dbbbb'''''', g###''''',a##''''', cb'''''', dbbb'''''',a###''''', b#''''', dbb'''''', ebbbb'''''',b##''''', c#'''''', ebbb'''''',b###''''', c##'''''', ebb'''''', fbbb'''''',c###'''''', d#'''''', fbb'''''', gbbbb'''''',d##'''''', fb'''''', gbbb'''''',abbbb'''''', d###'''''', e#'''''', gbb'''''',abbb'''''', e##'''''', f#'''''',abb'''''', bbbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "A-diesis-diesis-diesis-6, B-diesis-6, D-bemolle-bemolle-5,A-diesis-diesis-diesis-diesis-6, B-diesis-diesis-6, D-bemolle-5, E-bemolle-bemolle-bemolle-5,B-diesis-diesis-diesis-6, C-diesis-diesis-5, E-bemolle-bemolle-5, F-bemolle-bemolle-bemolle-5,C-diesis-diesis-diesis-5, E-bemolle-5, F-bemolle-bemolle-5,C-diesis-diesis-diesis-diesis-5, D-diesis-diesis-5, F-bemolle-5, G-bemolle-bemolle-bemolle-5,D-diesis-diesis-diesis-5, E-diesis-5, G-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-5, D-diesis-diesis-diesis-diesis-5, E-diesis-diesis-5, G-bemolle-5,A-bemolle-bemolle-5, E-diesis-diesis-diesis-5, F-diesis-diesis-5,A-bemolle-5, B-bemolle-bemolle-bemolle-5, F-diesis-diesis-diesis-5,B-bemolle-bemolle-5, C-bemolle-bemolle-bemolle-4, F-diesis-diesis-diesis-diesis-5, G-diesis-diesis-5,B-bemolle-5, C-bemolle-bemolle-4, G-diesis-diesis-diesis-5,A-diesis-diesis-5, C-bemolle-4, D-bemolle-bemolle-bemolle-4, G-diesis-diesis-diesis-diesis-5,A-diesis-diesis-diesis-5, B-diesis-5, D-bemolle-bemolle-4,A-diesis-diesis-diesis-diesis-5, B-diesis-diesis-5, D-bemolle-4, E-bemolle-bemolle-bemolle-4,B-diesis-diesis-diesis-5, C-diesis-diesis-4, E-bemolle-bemolle-4, F-bemolle-bemolle-bemolle-4,C-diesis-diesis-diesis-4, E-bemolle-4, F-bemolle-bemolle-4,C-diesis-diesis-diesis-diesis-4, D-diesis-diesis-4, F-bemolle-4, G-bemolle-bemolle-bemolle-4,D-diesis-diesis-diesis-4, E-diesis-4, G-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-4, D-diesis-diesis-diesis-diesis-4, E-diesis-diesis-4, G-bemolle-4,A-bemolle-bemolle-4, E-diesis-diesis-diesis-4, F-diesis-diesis-4,A-bemolle-4, B-bemolle-bemolle-bemolle-4, F-diesis-diesis-diesis-4,B-bemolle-bemolle-4, C-bemolle-bemolle-bemolle-3, F-diesis-diesis-diesis-diesis-4, G-diesis-diesis-4,B-bemolle-4, C-bemolle-bemolle-3, G-diesis-diesis-diesis-4,A-diesis-diesis-4, C-bemolle-3, D-bemolle-bemolle-bemolle-3, G-diesis-diesis-diesis-diesis-4,A-diesis-diesis-diesis-4, B-diesis-4, D-bemolle-bemolle-3,A-diesis-diesis-diesis-diesis-4, B-diesis-diesis-4, D-bemolle-3, E-bemolle-bemolle-bemolle-3,B-diesis-diesis-diesis-4, C-diesis-diesis-3, E-bemolle-bemolle-3, F-bemolle-bemolle-bemolle-3,C-diesis-diesis-diesis-3, E-bemolle-3, F-bemolle-bemolle-3,C-diesis-diesis-diesis-diesis-3, D-diesis-diesis-3, F-bemolle-3, G-bemolle-bemolle-bemolle-3,D-diesis-diesis-diesis-3, E-diesis-3, G-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-3, D-diesis-diesis-diesis-diesis-3, E-diesis-diesis-3, G-bemolle-3,A-bemolle-bemolle-3, E-diesis-diesis-diesis-3, F-diesis-diesis-3,A-bemolle-3, B-bemolle-bemolle-bemolle-3, F-diesis-diesis-diesis-3,B-bemolle-bemolle-3, C-bemolle-bemolle-bemolle-2, F-diesis-diesis-diesis-diesis-3, G-diesis-diesis-3,B-bemolle-3, C-bemolle-bemolle-2, G-diesis-diesis-diesis-3,A-diesis-diesis-3, C-bemolle-2, D-bemolle-bemolle-bemolle-2, G-diesis-diesis-diesis-diesis-3,A-diesis-diesis-diesis-3, B-diesis-3, D-bemolle-bemolle-2,A-diesis-diesis-diesis-diesis-3, B-diesis-diesis-3, D-bemolle-2, E-bemolle-bemolle-bemolle-2,B-diesis-diesis-diesis-3, C-diesis-diesis-2, E-bemolle-bemolle-2, F-bemolle-bemolle-bemolle-2,C-diesis-diesis-diesis-2, E-bemolle-2, F-bemolle-bemolle-2,C-diesis-diesis-diesis-diesis-2, D-diesis-diesis-2, F-bemolle-2, G-bemolle-bemolle-bemolle-2,D-diesis-diesis-diesis-2, E-diesis-2, G-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-2, D-diesis-diesis-diesis-diesis-2, E-diesis-diesis-2, G-bemolle-2,A-bemolle-bemolle-2, E-diesis-diesis-diesis-2, F-diesis-diesis-2,A-bemolle-2, B-bemolle-bemolle-bemolle-2, F-diesis-diesis-diesis-2,B-bemolle-bemolle-2, C-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-diesis-2, G-diesis-diesis-2,B-bemolle-2, C-bemolle-bemolle-, G-diesis-diesis-diesis-2,A-diesis-diesis-2, C-bemolle-, D-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-diesis-2,A-diesis-diesis-diesis-2, B-diesis-2, D-bemolle-bemolle-,A-diesis-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-, E-bemolle-bemolle-bemolle-,B-diesis-diesis-diesis-2, C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-,C-diesis-diesis-diesis-, E-bemolle-, F-bemolle-bemolle-,C-diesis-diesis-diesis-diesis-, D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-diesis-, E-diesis-diesis-, G-bemolle-,A-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,A-bemolle-, B-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-,B-bemolle-bemolle-, C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis-, G-diesis-diesis-,B-bemolle-, C-bemolle-bemolle, G-diesis-diesis-diesis-,A-diesis-diesis-, C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis-,A-diesis-diesis-diesis-, B-diesis-, D-bemolle-bemolle,A-diesis-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis-, C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis,B-bemolle-bemolle, C-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis-diesis, G-diesis-diesis,B-bemolle, C-bemolle-bemolle+, G-diesis-diesis-diesis,A-diesis-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis-diesis,A-diesis-diesis-diesis, B-diesis, D-bemolle-bemolle+,A-diesis-diesis-diesis-diesis, B-diesis-diesis, D-bemolle+, E-bemolle-bemolle-bemolle+,B-diesis-diesis-diesis, C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+,C-diesis-diesis-diesis+, E-bemolle+, F-bemolle-bemolle+,C-diesis-diesis-diesis-diesis+, D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis-diesis+, E-diesis-diesis+, G-bemolle+,A-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,A-bemolle+, B-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis+,B-bemolle-bemolle+, C-bemolle-bemolle-bemolle+2, F-diesis-diesis-diesis-diesis+, G-diesis-diesis+,B-bemolle+, C-bemolle-bemolle+2, G-diesis-diesis-diesis+,A-diesis-diesis+, C-bemolle+2, D-bemolle-bemolle-bemolle+2, G-diesis-diesis-diesis-diesis+,A-diesis-diesis-diesis+, B-diesis+, D-bemolle-bemolle+2,A-diesis-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle+2, E-bemolle-bemolle-bemolle+2,B-diesis-diesis-diesis+, C-diesis-diesis+2, E-bemolle-bemolle+2, F-bemolle-bemolle-bemolle+2,C-diesis-diesis-diesis+2, E-bemolle+2, F-bemolle-bemolle+2,C-diesis-diesis-diesis-diesis+2, D-diesis-diesis+2, F-bemolle+2, G-bemolle-bemolle-bemolle+2,D-diesis-diesis-diesis+2, E-diesis+2, G-bemolle-bemolle+2,A-bemolle-bemolle-bemolle+2, D-diesis-diesis-diesis-diesis+2, E-diesis-diesis+2, G-bemolle+2,A-bemolle-bemolle+2, E-diesis-diesis-diesis+2, F-diesis-diesis+2,A-bemolle+2, B-bemolle-bemolle-bemolle+2, F-diesis-diesis-diesis+2,B-bemolle-bemolle+2, C-bemolle-bemolle-bemolle+3, F-diesis-diesis-diesis-diesis+2, G-diesis-diesis+2,B-bemolle+2, C-bemolle-bemolle+3, G-diesis-diesis-diesis+2,A-diesis-diesis+2, C-bemolle+3, D-bemolle-bemolle-bemolle+3, G-diesis-diesis-diesis-diesis+2,A-diesis-diesis-diesis+2, B-diesis+2, D-bemolle-bemolle+3,A-diesis-diesis-diesis-diesis+2, B-diesis-diesis+2, D-bemolle+3, E-bemolle-bemolle-bemolle+3,B-diesis-diesis-diesis+2, C-diesis-diesis+3, E-bemolle-bemolle+3, F-bemolle-bemolle-bemolle+3,C-diesis-diesis-diesis+3, E-bemolle+3, F-bemolle-bemolle+3,C-diesis-diesis-diesis-diesis+3, D-diesis-diesis+3, F-bemolle+3, G-bemolle-bemolle-bemolle+3,D-diesis-diesis-diesis+3, E-diesis+3, G-bemolle-bemolle+3,A-bemolle-bemolle-bemolle+3, D-diesis-diesis-diesis-diesis+3, E-diesis-diesis+3, G-bemolle+3,A-bemolle-bemolle+3, E-diesis-diesis-diesis+3, F-diesis-diesis+3,A-bemolle+3, B-bemolle-bemolle-bemolle+3, F-diesis-diesis-diesis+3,B-bemolle-bemolle+3, C-bemolle-bemolle-bemolle+4, F-diesis-diesis-diesis-diesis+3, G-diesis-diesis+3,B-bemolle+3, C-bemolle-bemolle+4, G-diesis-diesis-diesis+3,A-diesis-diesis+3, C-bemolle+4, D-bemolle-bemolle-bemolle+4, G-diesis-diesis-diesis-diesis+3,A-diesis-diesis-diesis+3, B-diesis+3, D-bemolle-bemolle+4,A-diesis-diesis-diesis-diesis+3, B-diesis-diesis+3, D-bemolle+4, E-bemolle-bemolle-bemolle+4,B-diesis-diesis-diesis+3, C-diesis-diesis+4, E-bemolle-bemolle+4, F-bemolle-bemolle-bemolle+4,C-diesis-diesis-diesis+4, E-bemolle+4, F-bemolle-bemolle+4,C-diesis-diesis-diesis-diesis+4, D-diesis-diesis+4, F-bemolle+4, G-bemolle-bemolle-bemolle+4,D-diesis-diesis-diesis+4, E-diesis+4, G-bemolle-bemolle+4,A-bemolle-bemolle-bemolle+4, D-diesis-diesis-diesis-diesis+4, E-diesis-diesis+4, G-bemolle+4,A-bemolle-bemolle+4, E-diesis-diesis-diesis+4, F-diesis-diesis+4,A-bemolle+4, B-bemolle-bemolle-bemolle+4, F-diesis-diesis-diesis+4,B-bemolle-bemolle+4, C-bemolle-bemolle-bemolle+5, F-diesis-diesis-diesis-diesis+4, G-diesis-diesis+4,B-bemolle+4, C-bemolle-bemolle+5, G-diesis-diesis-diesis+4,A-diesis-diesis+4, C-bemolle+5, D-bemolle-bemolle-bemolle+5, G-diesis-diesis-diesis-diesis+4,A-diesis-diesis-diesis+4, B-diesis+4, D-bemolle-bemolle+5,A-diesis-diesis-diesis-diesis+4, B-diesis-diesis+4, D-bemolle+5, E-bemolle-bemolle-bemolle+5,B-diesis-diesis-diesis+4, C-diesis-diesis+5, E-bemolle-bemolle+5, F-bemolle-bemolle-bemolle+5,C-diesis-diesis-diesis+5, E-bemolle+5, F-bemolle-bemolle+5,C-diesis-diesis-diesis-diesis+5, D-diesis-diesis+5, F-bemolle+5, G-bemolle-bemolle-bemolle+5,D-diesis-diesis-diesis+5, E-diesis+5, G-bemolle-bemolle+5,A-bemolle-bemolle-bemolle+5, D-diesis-diesis-diesis-diesis+5, E-diesis-diesis+5, G-bemolle+5,A-bemolle-bemolle+5, E-diesis-diesis-diesis+5, F-diesis-diesis+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "A-diesis-diesis-diesis------, B-diesis------, D-bemolle-bemolle-----,A-diesis-diesis-diesis-diesis------, B-diesis-diesis------, D-bemolle-----, E-bemolle-bemolle-bemolle-----,B-diesis-diesis-diesis------, C-diesis-diesis-----, E-bemolle-bemolle-----, F-bemolle-bemolle-bemolle-----,C-diesis-diesis-diesis-----, E-bemolle-----, F-bemolle-bemolle-----,C-diesis-diesis-diesis-diesis-----, D-diesis-diesis-----, F-bemolle-----, G-bemolle-bemolle-bemolle-----,D-diesis-diesis-diesis-----, E-diesis-----, G-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-----, D-diesis-diesis-diesis-diesis-----, E-diesis-diesis-----, G-bemolle-----,A-bemolle-bemolle-----, E-diesis-diesis-diesis-----, F-diesis-diesis-----,A-bemolle-----, B-bemolle-bemolle-bemolle-----, F-diesis-diesis-diesis-----,B-bemolle-bemolle-----, C-bemolle-bemolle-bemolle----, F-diesis-diesis-diesis-diesis-----, G-diesis-diesis-----,B-bemolle-----, C-bemolle-bemolle----, G-diesis-diesis-diesis-----,A-diesis-diesis-----, C-bemolle----, D-bemolle-bemolle-bemolle----, G-diesis-diesis-diesis-diesis-----,A-diesis-diesis-diesis-----, B-diesis-----, D-bemolle-bemolle----,A-diesis-diesis-diesis-diesis-----, B-diesis-diesis-----, D-bemolle----, E-bemolle-bemolle-bemolle----,B-diesis-diesis-diesis-----, C-diesis-diesis----, E-bemolle-bemolle----, F-bemolle-bemolle-bemolle----,C-diesis-diesis-diesis----, E-bemolle----, F-bemolle-bemolle----,C-diesis-diesis-diesis-diesis----, D-diesis-diesis----, F-bemolle----, G-bemolle-bemolle-bemolle----,D-diesis-diesis-diesis----, E-diesis----, G-bemolle-bemolle----,A-bemolle-bemolle-bemolle----, D-diesis-diesis-diesis-diesis----, E-diesis-diesis----, G-bemolle----,A-bemolle-bemolle----, E-diesis-diesis-diesis----, F-diesis-diesis----,A-bemolle----, B-bemolle-bemolle-bemolle----, F-diesis-diesis-diesis----,B-bemolle-bemolle----, C-bemolle-bemolle-bemolle---, F-diesis-diesis-diesis-diesis----, G-diesis-diesis----,B-bemolle----, C-bemolle-bemolle---, G-diesis-diesis-diesis----,A-diesis-diesis----, C-bemolle---, D-bemolle-bemolle-bemolle---, G-diesis-diesis-diesis-diesis----,A-diesis-diesis-diesis----, B-diesis----, D-bemolle-bemolle---,A-diesis-diesis-diesis-diesis----, B-diesis-diesis----, D-bemolle---, E-bemolle-bemolle-bemolle---,B-diesis-diesis-diesis----, C-diesis-diesis---, E-bemolle-bemolle---, F-bemolle-bemolle-bemolle---,C-diesis-diesis-diesis---, E-bemolle---, F-bemolle-bemolle---,C-diesis-diesis-diesis-diesis---, D-diesis-diesis---, F-bemolle---, G-bemolle-bemolle-bemolle---,D-diesis-diesis-diesis---, E-diesis---, G-bemolle-bemolle---,A-bemolle-bemolle-bemolle---, D-diesis-diesis-diesis-diesis---, E-diesis-diesis---, G-bemolle---,A-bemolle-bemolle---, E-diesis-diesis-diesis---, F-diesis-diesis---,A-bemolle---, B-bemolle-bemolle-bemolle---, F-diesis-diesis-diesis---,B-bemolle-bemolle---, C-bemolle-bemolle-bemolle--, F-diesis-diesis-diesis-diesis---, G-diesis-diesis---,B-bemolle---, C-bemolle-bemolle--, G-diesis-diesis-diesis---,A-diesis-diesis---, C-bemolle--, D-bemolle-bemolle-bemolle--, G-diesis-diesis-diesis-diesis---,A-diesis-diesis-diesis---, B-diesis---, D-bemolle-bemolle--,A-diesis-diesis-diesis-diesis---, B-diesis-diesis---, D-bemolle--, E-bemolle-bemolle-bemolle--,B-diesis-diesis-diesis---, C-diesis-diesis--, E-bemolle-bemolle--, F-bemolle-bemolle-bemolle--,C-diesis-diesis-diesis--, E-bemolle--, F-bemolle-bemolle--,C-diesis-diesis-diesis-diesis--, D-diesis-diesis--, F-bemolle--, G-bemolle-bemolle-bemolle--,D-diesis-diesis-diesis--, E-diesis--, G-bemolle-bemolle--,A-bemolle-bemolle-bemolle--, D-diesis-diesis-diesis-diesis--, E-diesis-diesis--, G-bemolle--,A-bemolle-bemolle--, E-diesis-diesis-diesis--, F-diesis-diesis--,A-bemolle--, B-bemolle-bemolle-bemolle--, F-diesis-diesis-diesis--,B-bemolle-bemolle--, C-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-diesis--, G-diesis-diesis--,B-bemolle--, C-bemolle-bemolle-, G-diesis-diesis-diesis--,A-diesis-diesis--, C-bemolle-, D-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-diesis--,A-diesis-diesis-diesis--, B-diesis--, D-bemolle-bemolle-,A-diesis-diesis-diesis-diesis--, B-diesis-diesis--, D-bemolle-, E-bemolle-bemolle-bemolle-,B-diesis-diesis-diesis--, C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-,C-diesis-diesis-diesis-, E-bemolle-, F-bemolle-bemolle-,C-diesis-diesis-diesis-diesis-, D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-diesis-, E-diesis-diesis-, G-bemolle-,A-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,A-bemolle-, B-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-,B-bemolle-bemolle-, C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis-, G-diesis-diesis-,B-bemolle-, C-bemolle-bemolle, G-diesis-diesis-diesis-,A-diesis-diesis-, C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis-,A-diesis-diesis-diesis-, B-diesis-, D-bemolle-bemolle,A-diesis-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis-, C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis,B-bemolle-bemolle, C-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis-diesis, G-diesis-diesis,B-bemolle, C-bemolle-bemolle+, G-diesis-diesis-diesis,A-diesis-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis-diesis,A-diesis-diesis-diesis, B-diesis, D-bemolle-bemolle+,A-diesis-diesis-diesis-diesis, B-diesis-diesis, D-bemolle+, E-bemolle-bemolle-bemolle+,B-diesis-diesis-diesis, C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+,C-diesis-diesis-diesis+, E-bemolle+, F-bemolle-bemolle+,C-diesis-diesis-diesis-diesis+, D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis-diesis+, E-diesis-diesis+, G-bemolle+,A-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,A-bemolle+, B-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis+,B-bemolle-bemolle+, C-bemolle-bemolle-bemolle++, F-diesis-diesis-diesis-diesis+, G-diesis-diesis+,B-bemolle+, C-bemolle-bemolle++, G-diesis-diesis-diesis+,A-diesis-diesis+, C-bemolle++, D-bemolle-bemolle-bemolle++, G-diesis-diesis-diesis-diesis+,A-diesis-diesis-diesis+, B-diesis+, D-bemolle-bemolle++,A-diesis-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle++, E-bemolle-bemolle-bemolle++,B-diesis-diesis-diesis+, C-diesis-diesis++, E-bemolle-bemolle++, F-bemolle-bemolle-bemolle++,C-diesis-diesis-diesis++, E-bemolle++, F-bemolle-bemolle++,C-diesis-diesis-diesis-diesis++, D-diesis-diesis++, F-bemolle++, G-bemolle-bemolle-bemolle++,D-diesis-diesis-diesis++, E-diesis++, G-bemolle-bemolle++,A-bemolle-bemolle-bemolle++, D-diesis-diesis-diesis-diesis++, E-diesis-diesis++, G-bemolle++,A-bemolle-bemolle++, E-diesis-diesis-diesis++, F-diesis-diesis++,A-bemolle++, B-bemolle-bemolle-bemolle++, F-diesis-diesis-diesis++,B-bemolle-bemolle++, C-bemolle-bemolle-bemolle+++, F-diesis-diesis-diesis-diesis++, G-diesis-diesis++,B-bemolle++, C-bemolle-bemolle+++, G-diesis-diesis-diesis++,A-diesis-diesis++, C-bemolle+++, D-bemolle-bemolle-bemolle+++, G-diesis-diesis-diesis-diesis++,A-diesis-diesis-diesis++, B-diesis++, D-bemolle-bemolle+++,A-diesis-diesis-diesis-diesis++, B-diesis-diesis++, D-bemolle+++, E-bemolle-bemolle-bemolle+++,B-diesis-diesis-diesis++, C-diesis-diesis+++, E-bemolle-bemolle+++, F-bemolle-bemolle-bemolle+++,C-diesis-diesis-diesis+++, E-bemolle+++, F-bemolle-bemolle+++,C-diesis-diesis-diesis-diesis+++, D-diesis-diesis+++, F-bemolle+++, G-bemolle-bemolle-bemolle+++,D-diesis-diesis-diesis+++, E-diesis+++, G-bemolle-bemolle+++,A-bemolle-bemolle-bemolle+++, D-diesis-diesis-diesis-diesis+++, E-diesis-diesis+++, G-bemolle+++,A-bemolle-bemolle+++, E-diesis-diesis-diesis+++, F-diesis-diesis+++,A-bemolle+++, B-bemolle-bemolle-bemolle+++, F-diesis-diesis-diesis+++,B-bemolle-bemolle+++, C-bemolle-bemolle-bemolle++++, F-diesis-diesis-diesis-diesis+++, G-diesis-diesis+++,B-bemolle+++, C-bemolle-bemolle++++, G-diesis-diesis-diesis+++,A-diesis-diesis+++, C-bemolle++++, D-bemolle-bemolle-bemolle++++, G-diesis-diesis-diesis-diesis+++,A-diesis-diesis-diesis+++, B-diesis+++, D-bemolle-bemolle++++,A-diesis-diesis-diesis-diesis+++, B-diesis-diesis+++, D-bemolle++++, E-bemolle-bemolle-bemolle++++,B-diesis-diesis-diesis+++, C-diesis-diesis++++, E-bemolle-bemolle++++, F-bemolle-bemolle-bemolle++++,C-diesis-diesis-diesis++++, E-bemolle++++, F-bemolle-bemolle++++,C-diesis-diesis-diesis-diesis++++, D-diesis-diesis++++, F-bemolle++++, G-bemolle-bemolle-bemolle++++,D-diesis-diesis-diesis++++, E-diesis++++, G-bemolle-bemolle++++,A-bemolle-bemolle-bemolle++++, D-diesis-diesis-diesis-diesis++++, E-diesis-diesis++++, G-bemolle++++,A-bemolle-bemolle++++, E-diesis-diesis-diesis++++, F-diesis-diesis++++,A-bemolle++++, B-bemolle-bemolle-bemolle++++, F-diesis-diesis-diesis++++,B-bemolle-bemolle++++, C-bemolle-bemolle-bemolle+++++, F-diesis-diesis-diesis-diesis++++, G-diesis-diesis++++,B-bemolle++++, C-bemolle-bemolle+++++, G-diesis-diesis-diesis++++,A-diesis-diesis++++, C-bemolle+++++, D-bemolle-bemolle-bemolle+++++, G-diesis-diesis-diesis-diesis++++,A-diesis-diesis-diesis++++, B-diesis++++, D-bemolle-bemolle+++++,A-diesis-diesis-diesis-diesis++++, B-diesis-diesis++++, D-bemolle+++++, E-bemolle-bemolle-bemolle+++++,B-diesis-diesis-diesis++++, C-diesis-diesis+++++, E-bemolle-bemolle+++++, F-bemolle-bemolle-bemolle+++++,C-diesis-diesis-diesis+++++, E-bemolle+++++, F-bemolle-bemolle+++++,C-diesis-diesis-diesis-diesis+++++, D-diesis-diesis+++++, F-bemolle+++++, G-bemolle-bemolle-bemolle+++++,D-diesis-diesis-diesis+++++, E-diesis+++++, G-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle+++++, D-diesis-diesis-diesis-diesis+++++, E-diesis-diesis+++++, G-bemolle+++++,A-bemolle-bemolle+++++, E-diesis-diesis-diesis+++++, F-diesis-diesis+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "A-diesis-diesis-diesis-2, B-diesis-2, D-bemolle-bemolle-1,A-diesis-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-1, E-bemolle-bemolle-bemolle-1,B-diesis-diesis-diesis-2, C-diesis-diesis-1, E-bemolle-bemolle-1, F-bemolle-bemolle-bemolle-1,C-diesis-diesis-diesis-1, E-bemolle-1, F-bemolle-bemolle-1,C-diesis-diesis-diesis-diesis-1, D-diesis-diesis-1, F-bemolle-1, G-bemolle-bemolle-bemolle-1,D-diesis-diesis-diesis-1, E-diesis-1, G-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-1, D-diesis-diesis-diesis-diesis-1, E-diesis-diesis-1, G-bemolle-1,A-bemolle-bemolle-1, E-diesis-diesis-diesis-1, F-diesis-diesis-1,A-bemolle-1, B-bemolle-bemolle-bemolle-1, F-diesis-diesis-diesis-1,B-bemolle-bemolle-1, C-bemolle-bemolle-bemolle0, F-diesis-diesis-diesis-diesis-1, G-diesis-diesis-1,B-bemolle-1, C-bemolle-bemolle0, G-diesis-diesis-diesis-1,A-diesis-diesis-1, C-bemolle0, D-bemolle-bemolle-bemolle0, G-diesis-diesis-diesis-diesis-1,A-diesis-diesis-diesis-1, B-diesis-1, D-bemolle-bemolle0,A-diesis-diesis-diesis-diesis-1, B-diesis-diesis-1, D-bemolle0, E-bemolle-bemolle-bemolle0,B-diesis-diesis-diesis-1, C-diesis-diesis0, E-bemolle-bemolle0, F-bemolle-bemolle-bemolle0,C-diesis-diesis-diesis0, E-bemolle0, F-bemolle-bemolle0,C-diesis-diesis-diesis-diesis0, D-diesis-diesis0, F-bemolle0, G-bemolle-bemolle-bemolle0,D-diesis-diesis-diesis0, E-diesis0, G-bemolle-bemolle0,A-bemolle-bemolle-bemolle0, D-diesis-diesis-diesis-diesis0, E-diesis-diesis0, G-bemolle0,A-bemolle-bemolle0, E-diesis-diesis-diesis0, F-diesis-diesis0,A-bemolle0, B-bemolle-bemolle-bemolle0, F-diesis-diesis-diesis0,B-bemolle-bemolle0, C-bemolle-bemolle-bemolle1, F-diesis-diesis-diesis-diesis0, G-diesis-diesis0,B-bemolle0, C-bemolle-bemolle1, G-diesis-diesis-diesis0,A-diesis-diesis0, C-bemolle1, D-bemolle-bemolle-bemolle1, G-diesis-diesis-diesis-diesis0,A-diesis-diesis-diesis0, B-diesis0, D-bemolle-bemolle1,A-diesis-diesis-diesis-diesis0, B-diesis-diesis0, D-bemolle1, E-bemolle-bemolle-bemolle1,B-diesis-diesis-diesis0, C-diesis-diesis1, E-bemolle-bemolle1, F-bemolle-bemolle-bemolle1,C-diesis-diesis-diesis1, E-bemolle1, F-bemolle-bemolle1,C-diesis-diesis-diesis-diesis1, D-diesis-diesis1, F-bemolle1, G-bemolle-bemolle-bemolle1,D-diesis-diesis-diesis1, E-diesis1, G-bemolle-bemolle1,A-bemolle-bemolle-bemolle1, D-diesis-diesis-diesis-diesis1, E-diesis-diesis1, G-bemolle1,A-bemolle-bemolle1, E-diesis-diesis-diesis1, F-diesis-diesis1,A-bemolle1, B-bemolle-bemolle-bemolle1, F-diesis-diesis-diesis1,B-bemolle-bemolle1, C-bemolle-bemolle-bemolle2, F-diesis-diesis-diesis-diesis1, G-diesis-diesis1,B-bemolle1, C-bemolle-bemolle2, G-diesis-diesis-diesis1,A-diesis-diesis1, C-bemolle2, D-bemolle-bemolle-bemolle2, G-diesis-diesis-diesis-diesis1,A-diesis-diesis-diesis1, B-diesis1, D-bemolle-bemolle2,A-diesis-diesis-diesis-diesis1, B-diesis-diesis1, D-bemolle2, E-bemolle-bemolle-bemolle2,B-diesis-diesis-diesis1, C-diesis-diesis2, E-bemolle-bemolle2, F-bemolle-bemolle-bemolle2,C-diesis-diesis-diesis2, E-bemolle2, F-bemolle-bemolle2,C-diesis-diesis-diesis-diesis2, D-diesis-diesis2, F-bemolle2, G-bemolle-bemolle-bemolle2,D-diesis-diesis-diesis2, E-diesis2, G-bemolle-bemolle2,A-bemolle-bemolle-bemolle2, D-diesis-diesis-diesis-diesis2, E-diesis-diesis2, G-bemolle2,A-bemolle-bemolle2, E-diesis-diesis-diesis2, F-diesis-diesis2,A-bemolle2, B-bemolle-bemolle-bemolle2, F-diesis-diesis-diesis2,B-bemolle-bemolle2, C-bemolle-bemolle-bemolle3, F-diesis-diesis-diesis-diesis2, G-diesis-diesis2,B-bemolle2, C-bemolle-bemolle3, G-diesis-diesis-diesis2,A-diesis-diesis2, C-bemolle3, D-bemolle-bemolle-bemolle3, G-diesis-diesis-diesis-diesis2,A-diesis-diesis-diesis2, B-diesis2, D-bemolle-bemolle3,A-diesis-diesis-diesis-diesis2, B-diesis-diesis2, D-bemolle3, E-bemolle-bemolle-bemolle3,B-diesis-diesis-diesis2, C-diesis-diesis3, E-bemolle-bemolle3, F-bemolle-bemolle-bemolle3,C-diesis-diesis-diesis3, E-bemolle3, F-bemolle-bemolle3,C-diesis-diesis-diesis-diesis3, D-diesis-diesis3, F-bemolle3, G-bemolle-bemolle-bemolle3,D-diesis-diesis-diesis3, E-diesis3, G-bemolle-bemolle3,A-bemolle-bemolle-bemolle3, D-diesis-diesis-diesis-diesis3, E-diesis-diesis3, G-bemolle3,A-bemolle-bemolle3, E-diesis-diesis-diesis3, F-diesis-diesis3,A-bemolle3, B-bemolle-bemolle-bemolle3, F-diesis-diesis-diesis3,B-bemolle-bemolle3, C-bemolle-bemolle-bemolle4, F-diesis-diesis-diesis-diesis3, G-diesis-diesis3,B-bemolle3, C-bemolle-bemolle4, G-diesis-diesis-diesis3,A-diesis-diesis3, C-bemolle4, D-bemolle-bemolle-bemolle4, G-diesis-diesis-diesis-diesis3,A-diesis-diesis-diesis3, B-diesis3, D-bemolle-bemolle4,A-diesis-diesis-diesis-diesis3, B-diesis-diesis3, D-bemolle4, E-bemolle-bemolle-bemolle4,B-diesis-diesis-diesis3, C-diesis-diesis4, E-bemolle-bemolle4, F-bemolle-bemolle-bemolle4,C-diesis-diesis-diesis4, E-bemolle4, F-bemolle-bemolle4,C-diesis-diesis-diesis-diesis4, D-diesis-diesis4, F-bemolle4, G-bemolle-bemolle-bemolle4,D-diesis-diesis-diesis4, E-diesis4, G-bemolle-bemolle4,A-bemolle-bemolle-bemolle4, D-diesis-diesis-diesis-diesis4, E-diesis-diesis4, G-bemolle4,A-bemolle-bemolle4, E-diesis-diesis-diesis4, F-diesis-diesis4,A-bemolle4, B-bemolle-bemolle-bemolle4, F-diesis-diesis-diesis4,B-bemolle-bemolle4, C-bemolle-bemolle-bemolle5, F-diesis-diesis-diesis-diesis4, G-diesis-diesis4,B-bemolle4, C-bemolle-bemolle5, G-diesis-diesis-diesis4,A-diesis-diesis4, C-bemolle5, D-bemolle-bemolle-bemolle5, G-diesis-diesis-diesis-diesis4,A-diesis-diesis-diesis4, B-diesis4, D-bemolle-bemolle5,A-diesis-diesis-diesis-diesis4, B-diesis-diesis4, D-bemolle5, E-bemolle-bemolle-bemolle5,B-diesis-diesis-diesis4, C-diesis-diesis5, E-bemolle-bemolle5, F-bemolle-bemolle-bemolle5,C-diesis-diesis-diesis5, E-bemolle5, F-bemolle-bemolle5,C-diesis-diesis-diesis-diesis5, D-diesis-diesis5, F-bemolle5, G-bemolle-bemolle-bemolle5,D-diesis-diesis-diesis5, E-diesis5, G-bemolle-bemolle5,A-bemolle-bemolle-bemolle5, D-diesis-diesis-diesis-diesis5, E-diesis-diesis5, G-bemolle5,A-bemolle-bemolle5, E-diesis-diesis-diesis5, F-diesis-diesis5,A-bemolle5, B-bemolle-bemolle-bemolle5, F-diesis-diesis-diesis5,B-bemolle-bemolle5, C-bemolle-bemolle-bemolle6, F-diesis-diesis-diesis-diesis5, G-diesis-diesis5,B-bemolle5, C-bemolle-bemolle6, G-diesis-diesis-diesis5,A-diesis-diesis5, C-bemolle6, D-bemolle-bemolle-bemolle6, G-diesis-diesis-diesis-diesis5,A-diesis-diesis-diesis5, B-diesis5, D-bemolle-bemolle6,A-diesis-diesis-diesis-diesis5, B-diesis-diesis5, D-bemolle6, E-bemolle-bemolle-bemolle6,B-diesis-diesis-diesis5, C-diesis-diesis6, E-bemolle-bemolle6, F-bemolle-bemolle-bemolle6,C-diesis-diesis-diesis6, E-bemolle6, F-bemolle-bemolle6,C-diesis-diesis-diesis-diesis6, D-diesis-diesis6, F-bemolle6, G-bemolle-bemolle-bemolle6,D-diesis-diesis-diesis6, E-diesis6, G-bemolle-bemolle6,A-bemolle-bemolle-bemolle6, D-diesis-diesis-diesis-diesis6, E-diesis-diesis6, G-bemolle6,A-bemolle-bemolle6, E-diesis-diesis-diesis6, F-diesis-diesis6,A-bemolle6, B-bemolle-bemolle-bemolle6, F-diesis-diesis-diesis6,B-bemolle-bemolle6, C-bemolle-bemolle-bemolle7, F-diesis-diesis-diesis-diesis6, G-diesis-diesis6,B-bemolle6, C-bemolle-bemolle7, G-diesis-diesis-diesis6,A-diesis-diesis6, C-bemolle7, D-bemolle-bemolle-bemolle7, G-diesis-diesis-diesis-diesis6,A-diesis-diesis-diesis6, B-diesis6, D-bemolle-bemolle7,A-diesis-diesis-diesis-diesis6, B-diesis-diesis6, D-bemolle7, E-bemolle-bemolle-bemolle7,B-diesis-diesis-diesis6, C-diesis-diesis7, E-bemolle-bemolle7, F-bemolle-bemolle-bemolle7,C-diesis-diesis-diesis7, E-bemolle7, F-bemolle-bemolle7,C-diesis-diesis-diesis-diesis7, D-diesis-diesis7, F-bemolle7, G-bemolle-bemolle-bemolle7,D-diesis-diesis-diesis7, E-diesis7, G-bemolle-bemolle7,A-bemolle-bemolle-bemolle7, D-diesis-diesis-diesis-diesis7, E-diesis-diesis7, G-bemolle7,A-bemolle-bemolle7, E-diesis-diesis-diesis7, F-diesis-diesis7,A-bemolle7, B-bemolle-bemolle-bemolle7, F-diesis-diesis-diesis7,B-bemolle-bemolle7, C-bemolle-bemolle-bemolle8, F-diesis-diesis-diesis-diesis7, G-diesis-diesis7,B-bemolle7, C-bemolle-bemolle8, G-diesis-diesis-diesis7,A-diesis-diesis7, C-bemolle8, D-bemolle-bemolle-bemolle8, G-diesis-diesis-diesis-diesis7,A-diesis-diesis-diesis7, B-diesis7, D-bemolle-bemolle8,A-diesis-diesis-diesis-diesis7, B-diesis-diesis7, D-bemolle8, E-bemolle-bemolle-bemolle8,B-diesis-diesis-diesis7, C-diesis-diesis8, E-bemolle-bemolle8, F-bemolle-bemolle-bemolle8,C-diesis-diesis-diesis8, E-bemolle8, F-bemolle-bemolle8,C-diesis-diesis-diesis-diesis8, D-diesis-diesis8, F-bemolle8, G-bemolle-bemolle-bemolle8,D-diesis-diesis-diesis8, E-diesis8, G-bemolle-bemolle8,A-bemolle-bemolle-bemolle8, D-diesis-diesis-diesis-diesis8, E-diesis-diesis8, G-bemolle8,A-bemolle-bemolle8, E-diesis-diesis-diesis8, F-diesis-diesis8,A-bemolle8, B-bemolle-bemolle-bemolle8, F-diesis-diesis-diesis8,B-bemolle-bemolle8, C-bemolle-bemolle-bemolle9, F-diesis-diesis-diesis-diesis8, G-diesis-diesis8,B-bemolle8, C-bemolle-bemolle9, G-diesis-diesis-diesis8,A-diesis-diesis8, C-bemolle9, D-bemolle-bemolle-bemolle9, G-diesis-diesis-diesis-diesis8,A-diesis-diesis-diesis8, B-diesis8, D-bemolle-bemolle9,A-diesis-diesis-diesis-diesis8, B-diesis-diesis8, D-bemolle9, E-bemolle-bemolle-bemolle9,B-diesis-diesis-diesis8, C-diesis-diesis9, E-bemolle-bemolle9, F-bemolle-bemolle-bemolle9,C-diesis-diesis-diesis9, E-bemolle9, F-bemolle-bemolle9,C-diesis-diesis-diesis-diesis9, D-diesis-diesis9, F-bemolle9, G-bemolle-bemolle-bemolle9,D-diesis-diesis-diesis9, E-diesis9, G-bemolle-bemolle9,A-bemolle-bemolle-bemolle9, D-diesis-diesis-diesis-diesis9, E-diesis-diesis9, G-bemolle9,A-bemolle-bemolle9, E-diesis-diesis-diesis9, F-diesis-diesis9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis'''', D-bemolle-bemolle''',A-diesis-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle''', E-bemolle-bemolle-bemolle''',B-diesis-diesis-diesis'''', C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''',C-diesis-diesis-diesis''', E-bemolle''', F-bemolle-bemolle''',C-diesis-diesis-diesis-diesis''', D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis-diesis''', E-diesis-diesis''', G-bemolle''',A-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',A-bemolle''', B-bemolle-bemolle-bemolle''', F-diesis-diesis-diesis''',B-bemolle-bemolle''', C-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis-diesis''', G-diesis-diesis''',B-bemolle''', C-bemolle-bemolle'', G-diesis-diesis-diesis''',A-diesis-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis-diesis''',A-diesis-diesis-diesis''', B-diesis''', D-bemolle-bemolle'',A-diesis-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle'', E-bemolle-bemolle-bemolle'',B-diesis-diesis-diesis''', C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'',C-diesis-diesis-diesis'', E-bemolle'', F-bemolle-bemolle'',C-diesis-diesis-diesis-diesis'', D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis-diesis'', E-diesis-diesis'', G-bemolle'',A-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',A-bemolle'', B-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis'',B-bemolle-bemolle'', C-bemolle-bemolle-bemolle', F-diesis-diesis-diesis-diesis'', G-diesis-diesis'',B-bemolle'', C-bemolle-bemolle', G-diesis-diesis-diesis'',A-diesis-diesis'', C-bemolle', D-bemolle-bemolle-bemolle', G-diesis-diesis-diesis-diesis'',A-diesis-diesis-diesis'', B-diesis'', D-bemolle-bemolle',A-diesis-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle', E-bemolle-bemolle-bemolle',B-diesis-diesis-diesis'', C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle',C-diesis-diesis-diesis', E-bemolle', F-bemolle-bemolle',C-diesis-diesis-diesis-diesis', D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', D-diesis-diesis-diesis-diesis', E-diesis-diesis', G-bemolle',A-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',A-bemolle', B-bemolle-bemolle-bemolle', F-diesis-diesis-diesis',B-bemolle-bemolle', C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis', G-diesis-diesis',B-bemolle', C-bemolle-bemolle, G-diesis-diesis-diesis',A-diesis-diesis', C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis',A-diesis-diesis-diesis', B-diesis', D-bemolle-bemolle,A-diesis-diesis-diesis-diesis', B-diesis-diesis', D-bemolle, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis', C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis-diesis, G-diesis-diesis, c-bemolle-bemolle-bemolle,B-bemolle, G-diesis-diesis-diesis, c-bemolle-bemolle,A-diesis-diesis, G-diesis-diesis-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis, d-bemolle-bemolle,A-diesis-diesis-diesis-diesis, B-diesis-diesis, d-bemolle, e-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle', f-diesis-diesis-diesis-diesis, g-diesis-diesis,b-bemolle, c-bemolle-bemolle', g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle', d-bemolle-bemolle-bemolle', g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle',a-diesis-diesis-diesis-diesis, b-diesis-diesis, d-bemolle', e-bemolle-bemolle-bemolle',b-diesis-diesis-diesis, c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle',c-diesis-diesis-diesis', e-bemolle', f-bemolle-bemolle',c-diesis-diesis-diesis-diesis', d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', d-diesis-diesis-diesis-diesis', e-diesis-diesis', g-bemolle',a-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',a-bemolle', b-bemolle-bemolle-bemolle', f-diesis-diesis-diesis',b-bemolle-bemolle', c-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis-diesis', g-diesis-diesis',b-bemolle', c-bemolle-bemolle'', g-diesis-diesis-diesis',a-diesis-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis-diesis',a-diesis-diesis-diesis', b-diesis', d-bemolle-bemolle'',a-diesis-diesis-diesis-diesis', b-diesis-diesis', d-bemolle'', e-bemolle-bemolle-bemolle'',b-diesis-diesis-diesis', c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'',c-diesis-diesis-diesis'', e-bemolle'', f-bemolle-bemolle'',c-diesis-diesis-diesis-diesis'', d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis-diesis'', e-diesis-diesis'', g-bemolle'',a-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',a-bemolle'', b-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis'',b-bemolle-bemolle'', c-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis-diesis'', g-diesis-diesis'',b-bemolle'', c-bemolle-bemolle''', g-diesis-diesis-diesis'',a-diesis-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis-diesis'',a-diesis-diesis-diesis'', b-diesis'', d-bemolle-bemolle''',a-diesis-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle''', e-bemolle-bemolle-bemolle''',b-diesis-diesis-diesis'', c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''',c-diesis-diesis-diesis''', e-bemolle''', f-bemolle-bemolle''',c-diesis-diesis-diesis-diesis''', d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis-diesis''', e-diesis-diesis''', g-bemolle''',a-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',a-bemolle''', b-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis''',b-bemolle-bemolle''', c-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis-diesis''', g-diesis-diesis''',b-bemolle''', c-bemolle-bemolle'''', g-diesis-diesis-diesis''',a-diesis-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis-diesis''',a-diesis-diesis-diesis''', b-diesis''', d-bemolle-bemolle'''',a-diesis-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle'''', e-bemolle-bemolle-bemolle'''',b-diesis-diesis-diesis''', c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''',c-diesis-diesis-diesis'''', e-bemolle'''', f-bemolle-bemolle'''',c-diesis-diesis-diesis-diesis'''', d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis-diesis'''', e-diesis-diesis'''', g-bemolle'''',a-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',a-bemolle'''', b-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis'''',b-bemolle-bemolle'''', c-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis-diesis'''', g-diesis-diesis'''',b-bemolle'''', c-bemolle-bemolle''''', g-diesis-diesis-diesis'''',a-diesis-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis-diesis'''',a-diesis-diesis-diesis'''', b-diesis'''', d-bemolle-bemolle''''',a-diesis-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle''''', e-bemolle-bemolle-bemolle''''',b-diesis-diesis-diesis'''', c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''',c-diesis-diesis-diesis''''', e-bemolle''''', f-bemolle-bemolle''''',c-diesis-diesis-diesis-diesis''''', d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis-diesis''''', e-diesis-diesis''''', g-bemolle''''',a-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',a-bemolle''''', b-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis''''',b-bemolle-bemolle''''', c-bemolle-bemolle-bemolle'''''', f-diesis-diesis-diesis-diesis''''', g-diesis-diesis''''',b-bemolle''''', c-bemolle-bemolle'''''', g-diesis-diesis-diesis''''',a-diesis-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis-diesis''''',a-diesis-diesis-diesis''''', b-diesis''''', d-bemolle-bemolle'''''',a-diesis-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle'''''', e-bemolle-bemolle-bemolle'''''',b-diesis-diesis-diesis''''', c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''',c-diesis-diesis-diesis'''''', e-bemolle'''''', f-bemolle-bemolle'''''',c-diesis-diesis-diesis-diesis'''''', d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis-diesis'''''', e-diesis-diesis'''''', g-bemolle'''''',a-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "A-diesis-diesis-diesis-6, B-diesis-6, D-bemolle-bemolle-5, E-bemolle-bemolle-bemolle-bemolle-5,B-diesis-diesis-6, C-diesis-5, E-bemolle-bemolle-bemolle-5,B-diesis-diesis-diesis-6, C-diesis-diesis-5, E-bemolle-bemolle-5, F-bemolle-bemolle-bemolle-5,C-diesis-diesis-diesis-5, D-diesis-5, F-bemolle-bemolle-5, G-bemolle-bemolle-bemolle-bemolle-5,D-diesis-diesis-5, F-bemolle-5, G-bemolle-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-bemolle-5, D-diesis-diesis-diesis-5, E-diesis-5, G-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-5, E-diesis-diesis-5, F-diesis-5,A-bemolle-bemolle-5, B-bemolle-bemolle-bemolle-bemolle-5, E-diesis-diesis-diesis-5, F-diesis-diesis-5,B-bemolle-bemolle-bemolle-5, F-diesis-diesis-diesis-5, G-diesis-5,B-bemolle-bemolle-5, C-bemolle-bemolle-bemolle-4, G-diesis-diesis-5,A-diesis-5, C-bemolle-bemolle-4, D-bemolle-bemolle-bemolle-bemolle-4, G-diesis-diesis-diesis-5,A-diesis-diesis-5, C-bemolle-4, D-bemolle-bemolle-bemolle-4,A-diesis-diesis-diesis-5, B-diesis-5, D-bemolle-bemolle-4, E-bemolle-bemolle-bemolle-bemolle-4,B-diesis-diesis-5, C-diesis-4, E-bemolle-bemolle-bemolle-4,B-diesis-diesis-diesis-5, C-diesis-diesis-4, E-bemolle-bemolle-4, F-bemolle-bemolle-bemolle-4,C-diesis-diesis-diesis-4, D-diesis-4, F-bemolle-bemolle-4, G-bemolle-bemolle-bemolle-bemolle-4,D-diesis-diesis-4, F-bemolle-4, G-bemolle-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-bemolle-4, D-diesis-diesis-diesis-4, E-diesis-4, G-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-4, E-diesis-diesis-4, F-diesis-4,A-bemolle-bemolle-4, B-bemolle-bemolle-bemolle-bemolle-4, E-diesis-diesis-diesis-4, F-diesis-diesis-4,B-bemolle-bemolle-bemolle-4, F-diesis-diesis-diesis-4, G-diesis-4,B-bemolle-bemolle-4, C-bemolle-bemolle-bemolle-3, G-diesis-diesis-4,A-diesis-4, C-bemolle-bemolle-3, D-bemolle-bemolle-bemolle-bemolle-3, G-diesis-diesis-diesis-4,A-diesis-diesis-4, C-bemolle-3, D-bemolle-bemolle-bemolle-3,A-diesis-diesis-diesis-4, B-diesis-4, D-bemolle-bemolle-3, E-bemolle-bemolle-bemolle-bemolle-3,B-diesis-diesis-4, C-diesis-3, E-bemolle-bemolle-bemolle-3,B-diesis-diesis-diesis-4, C-diesis-diesis-3, E-bemolle-bemolle-3, F-bemolle-bemolle-bemolle-3,C-diesis-diesis-diesis-3, D-diesis-3, F-bemolle-bemolle-3, G-bemolle-bemolle-bemolle-bemolle-3,D-diesis-diesis-3, F-bemolle-3, G-bemolle-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-bemolle-3, D-diesis-diesis-diesis-3, E-diesis-3, G-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-3, E-diesis-diesis-3, F-diesis-3,A-bemolle-bemolle-3, B-bemolle-bemolle-bemolle-bemolle-3, E-diesis-diesis-diesis-3, F-diesis-diesis-3,B-bemolle-bemolle-bemolle-3, F-diesis-diesis-diesis-3, G-diesis-3,B-bemolle-bemolle-3, C-bemolle-bemolle-bemolle-2, G-diesis-diesis-3,A-diesis-3, C-bemolle-bemolle-2, D-bemolle-bemolle-bemolle-bemolle-2, G-diesis-diesis-diesis-3,A-diesis-diesis-3, C-bemolle-2, D-bemolle-bemolle-bemolle-2,A-diesis-diesis-diesis-3, B-diesis-3, D-bemolle-bemolle-2, E-bemolle-bemolle-bemolle-bemolle-2,B-diesis-diesis-3, C-diesis-2, E-bemolle-bemolle-bemolle-2,B-diesis-diesis-diesis-3, C-diesis-diesis-2, E-bemolle-bemolle-2, F-bemolle-bemolle-bemolle-2,C-diesis-diesis-diesis-2, D-diesis-2, F-bemolle-bemolle-2, G-bemolle-bemolle-bemolle-bemolle-2,D-diesis-diesis-2, F-bemolle-2, G-bemolle-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-bemolle-2, D-diesis-diesis-diesis-2, E-diesis-2, G-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-2, E-diesis-diesis-2, F-diesis-2,A-bemolle-bemolle-2, B-bemolle-bemolle-bemolle-bemolle-2, E-diesis-diesis-diesis-2, F-diesis-diesis-2,B-bemolle-bemolle-bemolle-2, F-diesis-diesis-diesis-2, G-diesis-2,B-bemolle-bemolle-2, C-bemolle-bemolle-bemolle-, G-diesis-diesis-2,A-diesis-2, C-bemolle-bemolle-, D-bemolle-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-2,A-diesis-diesis-2, C-bemolle-, D-bemolle-bemolle-bemolle-,A-diesis-diesis-diesis-2, B-diesis-2, D-bemolle-bemolle-, E-bemolle-bemolle-bemolle-bemolle-,B-diesis-diesis-2, C-diesis-, E-bemolle-bemolle-bemolle-,B-diesis-diesis-diesis-2, C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-,C-diesis-diesis-diesis-, D-diesis-, F-bemolle-bemolle-, G-bemolle-bemolle-bemolle-bemolle-,D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,A-bemolle-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, E-diesis-diesis-, F-diesis-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,B-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-, G-diesis-,B-bemolle-bemolle-, C-bemolle-bemolle-bemolle, G-diesis-diesis-,A-diesis-, C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-,A-diesis-diesis-, C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis-, B-diesis-, D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis-, C-diesis, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis-, C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis,B-bemolle-bemolle, C-bemolle-bemolle-bemolle+, G-diesis-diesis,A-diesis, C-bemolle-bemolle+, D-bemolle-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis,A-diesis-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+,A-diesis-diesis-diesis, B-diesis, D-bemolle-bemolle+, E-bemolle-bemolle-bemolle-bemolle+,B-diesis-diesis, C-diesis+, E-bemolle-bemolle-bemolle+,B-diesis-diesis-diesis, C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+,C-diesis-diesis-diesis+, D-diesis+, F-bemolle-bemolle+, G-bemolle-bemolle-bemolle-bemolle+,D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,A-bemolle-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, E-diesis-diesis+, F-diesis+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,B-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis+, G-diesis+,B-bemolle-bemolle+, C-bemolle-bemolle-bemolle+2, G-diesis-diesis+,A-diesis+, C-bemolle-bemolle+2, D-bemolle-bemolle-bemolle-bemolle+2, G-diesis-diesis-diesis+,A-diesis-diesis+, C-bemolle+2, D-bemolle-bemolle-bemolle+2,A-diesis-diesis-diesis+, B-diesis+, D-bemolle-bemolle+2, E-bemolle-bemolle-bemolle-bemolle+2,B-diesis-diesis+, C-diesis+2, E-bemolle-bemolle-bemolle+2,B-diesis-diesis-diesis+, C-diesis-diesis+2, E-bemolle-bemolle+2, F-bemolle-bemolle-bemolle+2,C-diesis-diesis-diesis+2, D-diesis+2, F-bemolle-bemolle+2, G-bemolle-bemolle-bemolle-bemolle+2,D-diesis-diesis+2, F-bemolle+2, G-bemolle-bemolle-bemolle+2,A-bemolle-bemolle-bemolle-bemolle+2, D-diesis-diesis-diesis+2, E-diesis+2, G-bemolle-bemolle+2,A-bemolle-bemolle-bemolle+2, E-diesis-diesis+2, F-diesis+2,A-bemolle-bemolle+2, B-bemolle-bemolle-bemolle-bemolle+2, E-diesis-diesis-diesis+2, F-diesis-diesis+2,B-bemolle-bemolle-bemolle+2, F-diesis-diesis-diesis+2, G-diesis+2,B-bemolle-bemolle+2, C-bemolle-bemolle-bemolle+3, G-diesis-diesis+2,A-diesis+2, C-bemolle-bemolle+3, D-bemolle-bemolle-bemolle-bemolle+3, G-diesis-diesis-diesis+2,A-diesis-diesis+2, C-bemolle+3, D-bemolle-bemolle-bemolle+3,A-diesis-diesis-diesis+2, B-diesis+2, D-bemolle-bemolle+3, E-bemolle-bemolle-bemolle-bemolle+3,B-diesis-diesis+2, C-diesis+3, E-bemolle-bemolle-bemolle+3,B-diesis-diesis-diesis+2, C-diesis-diesis+3, E-bemolle-bemolle+3, F-bemolle-bemolle-bemolle+3,C-diesis-diesis-diesis+3, D-diesis+3, F-bemolle-bemolle+3, G-bemolle-bemolle-bemolle-bemolle+3,D-diesis-diesis+3, F-bemolle+3, G-bemolle-bemolle-bemolle+3,A-bemolle-bemolle-bemolle-bemolle+3, D-diesis-diesis-diesis+3, E-diesis+3, G-bemolle-bemolle+3,A-bemolle-bemolle-bemolle+3, E-diesis-diesis+3, F-diesis+3,A-bemolle-bemolle+3, B-bemolle-bemolle-bemolle-bemolle+3, E-diesis-diesis-diesis+3, F-diesis-diesis+3,B-bemolle-bemolle-bemolle+3, F-diesis-diesis-diesis+3, G-diesis+3,B-bemolle-bemolle+3, C-bemolle-bemolle-bemolle+4, G-diesis-diesis+3,A-diesis+3, C-bemolle-bemolle+4, D-bemolle-bemolle-bemolle-bemolle+4, G-diesis-diesis-diesis+3,A-diesis-diesis+3, C-bemolle+4, D-bemolle-bemolle-bemolle+4,A-diesis-diesis-diesis+3, B-diesis+3, D-bemolle-bemolle+4, E-bemolle-bemolle-bemolle-bemolle+4,B-diesis-diesis+3, C-diesis+4, E-bemolle-bemolle-bemolle+4,B-diesis-diesis-diesis+3, C-diesis-diesis+4, E-bemolle-bemolle+4, F-bemolle-bemolle-bemolle+4,C-diesis-diesis-diesis+4, D-diesis+4, F-bemolle-bemolle+4, G-bemolle-bemolle-bemolle-bemolle+4,D-diesis-diesis+4, F-bemolle+4, G-bemolle-bemolle-bemolle+4,A-bemolle-bemolle-bemolle-bemolle+4, D-diesis-diesis-diesis+4, E-diesis+4, G-bemolle-bemolle+4,A-bemolle-bemolle-bemolle+4, E-diesis-diesis+4, F-diesis+4,A-bemolle-bemolle+4, B-bemolle-bemolle-bemolle-bemolle+4, E-diesis-diesis-diesis+4, F-diesis-diesis+4,B-bemolle-bemolle-bemolle+4, F-diesis-diesis-diesis+4, G-diesis+4,B-bemolle-bemolle+4, C-bemolle-bemolle-bemolle+5, G-diesis-diesis+4,A-diesis+4, C-bemolle-bemolle+5, D-bemolle-bemolle-bemolle-bemolle+5, G-diesis-diesis-diesis+4,A-diesis-diesis+4, C-bemolle+5, D-bemolle-bemolle-bemolle+5,A-diesis-diesis-diesis+4, B-diesis+4, D-bemolle-bemolle+5, E-bemolle-bemolle-bemolle-bemolle+5,B-diesis-diesis+4, C-diesis+5, E-bemolle-bemolle-bemolle+5,B-diesis-diesis-diesis+4, C-diesis-diesis+5, E-bemolle-bemolle+5, F-bemolle-bemolle-bemolle+5,C-diesis-diesis-diesis+5, D-diesis+5, F-bemolle-bemolle+5, G-bemolle-bemolle-bemolle-bemolle+5,D-diesis-diesis+5, F-bemolle+5, G-bemolle-bemolle-bemolle+5,A-bemolle-bemolle-bemolle-bemolle+5, D-diesis-diesis-diesis+5, E-diesis+5, G-bemolle-bemolle+5,A-bemolle-bemolle-bemolle+5, E-diesis-diesis+5, F-diesis+5,A-bemolle-bemolle+5, B-bemolle-bemolle-bemolle-bemolle+5, E-diesis-diesis-diesis+5, F-diesis-diesis+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "A-diesis-diesis-diesis------, B-diesis------, D-bemolle-bemolle-----, E-bemolle-bemolle-bemolle-bemolle-----,B-diesis-diesis------, C-diesis-----, E-bemolle-bemolle-bemolle-----,B-diesis-diesis-diesis------, C-diesis-diesis-----, E-bemolle-bemolle-----, F-bemolle-bemolle-bemolle-----,C-diesis-diesis-diesis-----, D-diesis-----, F-bemolle-bemolle-----, G-bemolle-bemolle-bemolle-bemolle-----,D-diesis-diesis-----, F-bemolle-----, G-bemolle-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-bemolle-----, D-diesis-diesis-diesis-----, E-diesis-----, G-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-----, E-diesis-diesis-----, F-diesis-----,A-bemolle-bemolle-----, B-bemolle-bemolle-bemolle-bemolle-----, E-diesis-diesis-diesis-----, F-diesis-diesis-----,B-bemolle-bemolle-bemolle-----, F-diesis-diesis-diesis-----, G-diesis-----,B-bemolle-bemolle-----, C-bemolle-bemolle-bemolle----, G-diesis-diesis-----,A-diesis-----, C-bemolle-bemolle----, D-bemolle-bemolle-bemolle-bemolle----, G-diesis-diesis-diesis-----,A-diesis-diesis-----, C-bemolle----, D-bemolle-bemolle-bemolle----,A-diesis-diesis-diesis-----, B-diesis-----, D-bemolle-bemolle----, E-bemolle-bemolle-bemolle-bemolle----,B-diesis-diesis-----, C-diesis----, E-bemolle-bemolle-bemolle----,B-diesis-diesis-diesis-----, C-diesis-diesis----, E-bemolle-bemolle----, F-bemolle-bemolle-bemolle----,C-diesis-diesis-diesis----, D-diesis----, F-bemolle-bemolle----, G-bemolle-bemolle-bemolle-bemolle----,D-diesis-diesis----, F-bemolle----, G-bemolle-bemolle-bemolle----,A-bemolle-bemolle-bemolle-bemolle----, D-diesis-diesis-diesis----, E-diesis----, G-bemolle-bemolle----,A-bemolle-bemolle-bemolle----, E-diesis-diesis----, F-diesis----,A-bemolle-bemolle----, B-bemolle-bemolle-bemolle-bemolle----, E-diesis-diesis-diesis----, F-diesis-diesis----,B-bemolle-bemolle-bemolle----, F-diesis-diesis-diesis----, G-diesis----,B-bemolle-bemolle----, C-bemolle-bemolle-bemolle---, G-diesis-diesis----,A-diesis----, C-bemolle-bemolle---, D-bemolle-bemolle-bemolle-bemolle---, G-diesis-diesis-diesis----,A-diesis-diesis----, C-bemolle---, D-bemolle-bemolle-bemolle---,A-diesis-diesis-diesis----, B-diesis----, D-bemolle-bemolle---, E-bemolle-bemolle-bemolle-bemolle---,B-diesis-diesis----, C-diesis---, E-bemolle-bemolle-bemolle---,B-diesis-diesis-diesis----, C-diesis-diesis---, E-bemolle-bemolle---, F-bemolle-bemolle-bemolle---,C-diesis-diesis-diesis---, D-diesis---, F-bemolle-bemolle---, G-bemolle-bemolle-bemolle-bemolle---,D-diesis-diesis---, F-bemolle---, G-bemolle-bemolle-bemolle---,A-bemolle-bemolle-bemolle-bemolle---, D-diesis-diesis-diesis---, E-diesis---, G-bemolle-bemolle---,A-bemolle-bemolle-bemolle---, E-diesis-diesis---, F-diesis---,A-bemolle-bemolle---, B-bemolle-bemolle-bemolle-bemolle---, E-diesis-diesis-diesis---, F-diesis-diesis---,B-bemolle-bemolle-bemolle---, F-diesis-diesis-diesis---, G-diesis---,B-bemolle-bemolle---, C-bemolle-bemolle-bemolle--, G-diesis-diesis---,A-diesis---, C-bemolle-bemolle--, D-bemolle-bemolle-bemolle-bemolle--, G-diesis-diesis-diesis---,A-diesis-diesis---, C-bemolle--, D-bemolle-bemolle-bemolle--,A-diesis-diesis-diesis---, B-diesis---, D-bemolle-bemolle--, E-bemolle-bemolle-bemolle-bemolle--,B-diesis-diesis---, C-diesis--, E-bemolle-bemolle-bemolle--,B-diesis-diesis-diesis---, C-diesis-diesis--, E-bemolle-bemolle--, F-bemolle-bemolle-bemolle--,C-diesis-diesis-diesis--, D-diesis--, F-bemolle-bemolle--, G-bemolle-bemolle-bemolle-bemolle--,D-diesis-diesis--, F-bemolle--, G-bemolle-bemolle-bemolle--,A-bemolle-bemolle-bemolle-bemolle--, D-diesis-diesis-diesis--, E-diesis--, G-bemolle-bemolle--,A-bemolle-bemolle-bemolle--, E-diesis-diesis--, F-diesis--,A-bemolle-bemolle--, B-bemolle-bemolle-bemolle-bemolle--, E-diesis-diesis-diesis--, F-diesis-diesis--,B-bemolle-bemolle-bemolle--, F-diesis-diesis-diesis--, G-diesis--,B-bemolle-bemolle--, C-bemolle-bemolle-bemolle-, G-diesis-diesis--,A-diesis--, C-bemolle-bemolle-, D-bemolle-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis--,A-diesis-diesis--, C-bemolle-, D-bemolle-bemolle-bemolle-,A-diesis-diesis-diesis--, B-diesis--, D-bemolle-bemolle-, E-bemolle-bemolle-bemolle-bemolle-,B-diesis-diesis--, C-diesis-, E-bemolle-bemolle-bemolle-,B-diesis-diesis-diesis--, C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-,C-diesis-diesis-diesis-, D-diesis-, F-bemolle-bemolle-, G-bemolle-bemolle-bemolle-bemolle-,D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,A-bemolle-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, E-diesis-diesis-, F-diesis-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,B-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-, G-diesis-,B-bemolle-bemolle-, C-bemolle-bemolle-bemolle, G-diesis-diesis-,A-diesis-, C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-,A-diesis-diesis-, C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis-, B-diesis-, D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis-, C-diesis, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis-, C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis,B-bemolle-bemolle, C-bemolle-bemolle-bemolle+, G-diesis-diesis,A-diesis, C-bemolle-bemolle+, D-bemolle-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis,A-diesis-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+,A-diesis-diesis-diesis, B-diesis, D-bemolle-bemolle+, E-bemolle-bemolle-bemolle-bemolle+,B-diesis-diesis, C-diesis+, E-bemolle-bemolle-bemolle+,B-diesis-diesis-diesis, C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+,C-diesis-diesis-diesis+, D-diesis+, F-bemolle-bemolle+, G-bemolle-bemolle-bemolle-bemolle+,D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,A-bemolle-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, E-diesis-diesis+, F-diesis+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,B-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis+, G-diesis+,B-bemolle-bemolle+, C-bemolle-bemolle-bemolle++, G-diesis-diesis+,A-diesis+, C-bemolle-bemolle++, D-bemolle-bemolle-bemolle-bemolle++, G-diesis-diesis-diesis+,A-diesis-diesis+, C-bemolle++, D-bemolle-bemolle-bemolle++,A-diesis-diesis-diesis+, B-diesis+, D-bemolle-bemolle++, E-bemolle-bemolle-bemolle-bemolle++,B-diesis-diesis+, C-diesis++, E-bemolle-bemolle-bemolle++,B-diesis-diesis-diesis+, C-diesis-diesis++, E-bemolle-bemolle++, F-bemolle-bemolle-bemolle++,C-diesis-diesis-diesis++, D-diesis++, F-bemolle-bemolle++, G-bemolle-bemolle-bemolle-bemolle++,D-diesis-diesis++, F-bemolle++, G-bemolle-bemolle-bemolle++,A-bemolle-bemolle-bemolle-bemolle++, D-diesis-diesis-diesis++, E-diesis++, G-bemolle-bemolle++,A-bemolle-bemolle-bemolle++, E-diesis-diesis++, F-diesis++,A-bemolle-bemolle++, B-bemolle-bemolle-bemolle-bemolle++, E-diesis-diesis-diesis++, F-diesis-diesis++,B-bemolle-bemolle-bemolle++, F-diesis-diesis-diesis++, G-diesis++,B-bemolle-bemolle++, C-bemolle-bemolle-bemolle+++, G-diesis-diesis++,A-diesis++, C-bemolle-bemolle+++, D-bemolle-bemolle-bemolle-bemolle+++, G-diesis-diesis-diesis++,A-diesis-diesis++, C-bemolle+++, D-bemolle-bemolle-bemolle+++,A-diesis-diesis-diesis++, B-diesis++, D-bemolle-bemolle+++, E-bemolle-bemolle-bemolle-bemolle+++,B-diesis-diesis++, C-diesis+++, E-bemolle-bemolle-bemolle+++,B-diesis-diesis-diesis++, C-diesis-diesis+++, E-bemolle-bemolle+++, F-bemolle-bemolle-bemolle+++,C-diesis-diesis-diesis+++, D-diesis+++, F-bemolle-bemolle+++, G-bemolle-bemolle-bemolle-bemolle+++,D-diesis-diesis+++, F-bemolle+++, G-bemolle-bemolle-bemolle+++,A-bemolle-bemolle-bemolle-bemolle+++, D-diesis-diesis-diesis+++, E-diesis+++, G-bemolle-bemolle+++,A-bemolle-bemolle-bemolle+++, E-diesis-diesis+++, F-diesis+++,A-bemolle-bemolle+++, B-bemolle-bemolle-bemolle-bemolle+++, E-diesis-diesis-diesis+++, F-diesis-diesis+++,B-bemolle-bemolle-bemolle+++, F-diesis-diesis-diesis+++, G-diesis+++,B-bemolle-bemolle+++, C-bemolle-bemolle-bemolle++++, G-diesis-diesis+++,A-diesis+++, C-bemolle-bemolle++++, D-bemolle-bemolle-bemolle-bemolle++++, G-diesis-diesis-diesis+++,A-diesis-diesis+++, C-bemolle++++, D-bemolle-bemolle-bemolle++++,A-diesis-diesis-diesis+++, B-diesis+++, D-bemolle-bemolle++++, E-bemolle-bemolle-bemolle-bemolle++++,B-diesis-diesis+++, C-diesis++++, E-bemolle-bemolle-bemolle++++,B-diesis-diesis-diesis+++, C-diesis-diesis++++, E-bemolle-bemolle++++, F-bemolle-bemolle-bemolle++++,C-diesis-diesis-diesis++++, D-diesis++++, F-bemolle-bemolle++++, G-bemolle-bemolle-bemolle-bemolle++++,D-diesis-diesis++++, F-bemolle++++, G-bemolle-bemolle-bemolle++++,A-bemolle-bemolle-bemolle-bemolle++++, D-diesis-diesis-diesis++++, E-diesis++++, G-bemolle-bemolle++++,A-bemolle-bemolle-bemolle++++, E-diesis-diesis++++, F-diesis++++,A-bemolle-bemolle++++, B-bemolle-bemolle-bemolle-bemolle++++, E-diesis-diesis-diesis++++, F-diesis-diesis++++,B-bemolle-bemolle-bemolle++++, F-diesis-diesis-diesis++++, G-diesis++++,B-bemolle-bemolle++++, C-bemolle-bemolle-bemolle+++++, G-diesis-diesis++++,A-diesis++++, C-bemolle-bemolle+++++, D-bemolle-bemolle-bemolle-bemolle+++++, G-diesis-diesis-diesis++++,A-diesis-diesis++++, C-bemolle+++++, D-bemolle-bemolle-bemolle+++++,A-diesis-diesis-diesis++++, B-diesis++++, D-bemolle-bemolle+++++, E-bemolle-bemolle-bemolle-bemolle+++++,B-diesis-diesis++++, C-diesis+++++, E-bemolle-bemolle-bemolle+++++,B-diesis-diesis-diesis++++, C-diesis-diesis+++++, E-bemolle-bemolle+++++, F-bemolle-bemolle-bemolle+++++,C-diesis-diesis-diesis+++++, D-diesis+++++, F-bemolle-bemolle+++++, G-bemolle-bemolle-bemolle-bemolle+++++,D-diesis-diesis+++++, F-bemolle+++++, G-bemolle-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle-bemolle+++++, D-diesis-diesis-diesis+++++, E-diesis+++++, G-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle+++++, E-diesis-diesis+++++, F-diesis+++++,A-bemolle-bemolle+++++, B-bemolle-bemolle-bemolle-bemolle+++++, E-diesis-diesis-diesis+++++, F-diesis-diesis+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "A-diesis-diesis-diesis-2, B-diesis-2, D-bemolle-bemolle-1, E-bemolle-bemolle-bemolle-bemolle-1,B-diesis-diesis-2, C-diesis-1, E-bemolle-bemolle-bemolle-1,B-diesis-diesis-diesis-2, C-diesis-diesis-1, E-bemolle-bemolle-1, F-bemolle-bemolle-bemolle-1,C-diesis-diesis-diesis-1, D-diesis-1, F-bemolle-bemolle-1, G-bemolle-bemolle-bemolle-bemolle-1,D-diesis-diesis-1, F-bemolle-1, G-bemolle-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-bemolle-1, D-diesis-diesis-diesis-1, E-diesis-1, G-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-1, E-diesis-diesis-1, F-diesis-1,A-bemolle-bemolle-1, B-bemolle-bemolle-bemolle-bemolle-1, E-diesis-diesis-diesis-1, F-diesis-diesis-1,B-bemolle-bemolle-bemolle-1, F-diesis-diesis-diesis-1, G-diesis-1,B-bemolle-bemolle-1, C-bemolle-bemolle-bemolle0, G-diesis-diesis-1,A-diesis-1, C-bemolle-bemolle0, D-bemolle-bemolle-bemolle-bemolle0, G-diesis-diesis-diesis-1,A-diesis-diesis-1, C-bemolle0, D-bemolle-bemolle-bemolle0,A-diesis-diesis-diesis-1, B-diesis-1, D-bemolle-bemolle0, E-bemolle-bemolle-bemolle-bemolle0,B-diesis-diesis-1, C-diesis0, E-bemolle-bemolle-bemolle0,B-diesis-diesis-diesis-1, C-diesis-diesis0, E-bemolle-bemolle0, F-bemolle-bemolle-bemolle0,C-diesis-diesis-diesis0, D-diesis0, F-bemolle-bemolle0, G-bemolle-bemolle-bemolle-bemolle0,D-diesis-diesis0, F-bemolle0, G-bemolle-bemolle-bemolle0,A-bemolle-bemolle-bemolle-bemolle0, D-diesis-diesis-diesis0, E-diesis0, G-bemolle-bemolle0,A-bemolle-bemolle-bemolle0, E-diesis-diesis0, F-diesis0,A-bemolle-bemolle0, B-bemolle-bemolle-bemolle-bemolle0, E-diesis-diesis-diesis0, F-diesis-diesis0,B-bemolle-bemolle-bemolle0, F-diesis-diesis-diesis0, G-diesis0,B-bemolle-bemolle0, C-bemolle-bemolle-bemolle1, G-diesis-diesis0,A-diesis0, C-bemolle-bemolle1, D-bemolle-bemolle-bemolle-bemolle1, G-diesis-diesis-diesis0,A-diesis-diesis0, C-bemolle1, D-bemolle-bemolle-bemolle1,A-diesis-diesis-diesis0, B-diesis0, D-bemolle-bemolle1, E-bemolle-bemolle-bemolle-bemolle1,B-diesis-diesis0, C-diesis1, E-bemolle-bemolle-bemolle1,B-diesis-diesis-diesis0, C-diesis-diesis1, E-bemolle-bemolle1, F-bemolle-bemolle-bemolle1,C-diesis-diesis-diesis1, D-diesis1, F-bemolle-bemolle1, G-bemolle-bemolle-bemolle-bemolle1,D-diesis-diesis1, F-bemolle1, G-bemolle-bemolle-bemolle1,A-bemolle-bemolle-bemolle-bemolle1, D-diesis-diesis-diesis1, E-diesis1, G-bemolle-bemolle1,A-bemolle-bemolle-bemolle1, E-diesis-diesis1, F-diesis1,A-bemolle-bemolle1, B-bemolle-bemolle-bemolle-bemolle1, E-diesis-diesis-diesis1, F-diesis-diesis1,B-bemolle-bemolle-bemolle1, F-diesis-diesis-diesis1, G-diesis1,B-bemolle-bemolle1, C-bemolle-bemolle-bemolle2, G-diesis-diesis1,A-diesis1, C-bemolle-bemolle2, D-bemolle-bemolle-bemolle-bemolle2, G-diesis-diesis-diesis1,A-diesis-diesis1, C-bemolle2, D-bemolle-bemolle-bemolle2,A-diesis-diesis-diesis1, B-diesis1, D-bemolle-bemolle2, E-bemolle-bemolle-bemolle-bemolle2,B-diesis-diesis1, C-diesis2, E-bemolle-bemolle-bemolle2,B-diesis-diesis-diesis1, C-diesis-diesis2, E-bemolle-bemolle2, F-bemolle-bemolle-bemolle2,C-diesis-diesis-diesis2, D-diesis2, F-bemolle-bemolle2, G-bemolle-bemolle-bemolle-bemolle2,D-diesis-diesis2, F-bemolle2, G-bemolle-bemolle-bemolle2,A-bemolle-bemolle-bemolle-bemolle2, D-diesis-diesis-diesis2, E-diesis2, G-bemolle-bemolle2,A-bemolle-bemolle-bemolle2, E-diesis-diesis2, F-diesis2,A-bemolle-bemolle2, B-bemolle-bemolle-bemolle-bemolle2, E-diesis-diesis-diesis2, F-diesis-diesis2,B-bemolle-bemolle-bemolle2, F-diesis-diesis-diesis2, G-diesis2,B-bemolle-bemolle2, C-bemolle-bemolle-bemolle3, G-diesis-diesis2,A-diesis2, C-bemolle-bemolle3, D-bemolle-bemolle-bemolle-bemolle3, G-diesis-diesis-diesis2,A-diesis-diesis2, C-bemolle3, D-bemolle-bemolle-bemolle3,A-diesis-diesis-diesis2, B-diesis2, D-bemolle-bemolle3, E-bemolle-bemolle-bemolle-bemolle3,B-diesis-diesis2, C-diesis3, E-bemolle-bemolle-bemolle3,B-diesis-diesis-diesis2, C-diesis-diesis3, E-bemolle-bemolle3, F-bemolle-bemolle-bemolle3,C-diesis-diesis-diesis3, D-diesis3, F-bemolle-bemolle3, G-bemolle-bemolle-bemolle-bemolle3,D-diesis-diesis3, F-bemolle3, G-bemolle-bemolle-bemolle3,A-bemolle-bemolle-bemolle-bemolle3, D-diesis-diesis-diesis3, E-diesis3, G-bemolle-bemolle3,A-bemolle-bemolle-bemolle3, E-diesis-diesis3, F-diesis3,A-bemolle-bemolle3, B-bemolle-bemolle-bemolle-bemolle3, E-diesis-diesis-diesis3, F-diesis-diesis3,B-bemolle-bemolle-bemolle3, F-diesis-diesis-diesis3, G-diesis3,B-bemolle-bemolle3, C-bemolle-bemolle-bemolle4, G-diesis-diesis3,A-diesis3, C-bemolle-bemolle4, D-bemolle-bemolle-bemolle-bemolle4, G-diesis-diesis-diesis3,A-diesis-diesis3, C-bemolle4, D-bemolle-bemolle-bemolle4,A-diesis-diesis-diesis3, B-diesis3, D-bemolle-bemolle4, E-bemolle-bemolle-bemolle-bemolle4,B-diesis-diesis3, C-diesis4, E-bemolle-bemolle-bemolle4,B-diesis-diesis-diesis3, C-diesis-diesis4, E-bemolle-bemolle4, F-bemolle-bemolle-bemolle4,C-diesis-diesis-diesis4, D-diesis4, F-bemolle-bemolle4, G-bemolle-bemolle-bemolle-bemolle4,D-diesis-diesis4, F-bemolle4, G-bemolle-bemolle-bemolle4,A-bemolle-bemolle-bemolle-bemolle4, D-diesis-diesis-diesis4, E-diesis4, G-bemolle-bemolle4,A-bemolle-bemolle-bemolle4, E-diesis-diesis4, F-diesis4,A-bemolle-bemolle4, B-bemolle-bemolle-bemolle-bemolle4, E-diesis-diesis-diesis4, F-diesis-diesis4,B-bemolle-bemolle-bemolle4, F-diesis-diesis-diesis4, G-diesis4,B-bemolle-bemolle4, C-bemolle-bemolle-bemolle5, G-diesis-diesis4,A-diesis4, C-bemolle-bemolle5, D-bemolle-bemolle-bemolle-bemolle5, G-diesis-diesis-diesis4,A-diesis-diesis4, C-bemolle5, D-bemolle-bemolle-bemolle5,A-diesis-diesis-diesis4, B-diesis4, D-bemolle-bemolle5, E-bemolle-bemolle-bemolle-bemolle5,B-diesis-diesis4, C-diesis5, E-bemolle-bemolle-bemolle5,B-diesis-diesis-diesis4, C-diesis-diesis5, E-bemolle-bemolle5, F-bemolle-bemolle-bemolle5,C-diesis-diesis-diesis5, D-diesis5, F-bemolle-bemolle5, G-bemolle-bemolle-bemolle-bemolle5,D-diesis-diesis5, F-bemolle5, G-bemolle-bemolle-bemolle5,A-bemolle-bemolle-bemolle-bemolle5, D-diesis-diesis-diesis5, E-diesis5, G-bemolle-bemolle5,A-bemolle-bemolle-bemolle5, E-diesis-diesis5, F-diesis5,A-bemolle-bemolle5, B-bemolle-bemolle-bemolle-bemolle5, E-diesis-diesis-diesis5, F-diesis-diesis5,B-bemolle-bemolle-bemolle5, F-diesis-diesis-diesis5, G-diesis5,B-bemolle-bemolle5, C-bemolle-bemolle-bemolle6, G-diesis-diesis5,A-diesis5, C-bemolle-bemolle6, D-bemolle-bemolle-bemolle-bemolle6, G-diesis-diesis-diesis5,A-diesis-diesis5, C-bemolle6, D-bemolle-bemolle-bemolle6,A-diesis-diesis-diesis5, B-diesis5, D-bemolle-bemolle6, E-bemolle-bemolle-bemolle-bemolle6,B-diesis-diesis5, C-diesis6, E-bemolle-bemolle-bemolle6,B-diesis-diesis-diesis5, C-diesis-diesis6, E-bemolle-bemolle6, F-bemolle-bemolle-bemolle6,C-diesis-diesis-diesis6, D-diesis6, F-bemolle-bemolle6, G-bemolle-bemolle-bemolle-bemolle6,D-diesis-diesis6, F-bemolle6, G-bemolle-bemolle-bemolle6,A-bemolle-bemolle-bemolle-bemolle6, D-diesis-diesis-diesis6, E-diesis6, G-bemolle-bemolle6,A-bemolle-bemolle-bemolle6, E-diesis-diesis6, F-diesis6,A-bemolle-bemolle6, B-bemolle-bemolle-bemolle-bemolle6, E-diesis-diesis-diesis6, F-diesis-diesis6,B-bemolle-bemolle-bemolle6, F-diesis-diesis-diesis6, G-diesis6,B-bemolle-bemolle6, C-bemolle-bemolle-bemolle7, G-diesis-diesis6,A-diesis6, C-bemolle-bemolle7, D-bemolle-bemolle-bemolle-bemolle7, G-diesis-diesis-diesis6,A-diesis-diesis6, C-bemolle7, D-bemolle-bemolle-bemolle7,A-diesis-diesis-diesis6, B-diesis6, D-bemolle-bemolle7, E-bemolle-bemolle-bemolle-bemolle7,B-diesis-diesis6, C-diesis7, E-bemolle-bemolle-bemolle7,B-diesis-diesis-diesis6, C-diesis-diesis7, E-bemolle-bemolle7, F-bemolle-bemolle-bemolle7,C-diesis-diesis-diesis7, D-diesis7, F-bemolle-bemolle7, G-bemolle-bemolle-bemolle-bemolle7,D-diesis-diesis7, F-bemolle7, G-bemolle-bemolle-bemolle7,A-bemolle-bemolle-bemolle-bemolle7, D-diesis-diesis-diesis7, E-diesis7, G-bemolle-bemolle7,A-bemolle-bemolle-bemolle7, E-diesis-diesis7, F-diesis7,A-bemolle-bemolle7, B-bemolle-bemolle-bemolle-bemolle7, E-diesis-diesis-diesis7, F-diesis-diesis7,B-bemolle-bemolle-bemolle7, F-diesis-diesis-diesis7, G-diesis7,B-bemolle-bemolle7, C-bemolle-bemolle-bemolle8, G-diesis-diesis7,A-diesis7, C-bemolle-bemolle8, D-bemolle-bemolle-bemolle-bemolle8, G-diesis-diesis-diesis7,A-diesis-diesis7, C-bemolle8, D-bemolle-bemolle-bemolle8,A-diesis-diesis-diesis7, B-diesis7, D-bemolle-bemolle8, E-bemolle-bemolle-bemolle-bemolle8,B-diesis-diesis7, C-diesis8, E-bemolle-bemolle-bemolle8,B-diesis-diesis-diesis7, C-diesis-diesis8, E-bemolle-bemolle8, F-bemolle-bemolle-bemolle8,C-diesis-diesis-diesis8, D-diesis8, F-bemolle-bemolle8, G-bemolle-bemolle-bemolle-bemolle8,D-diesis-diesis8, F-bemolle8, G-bemolle-bemolle-bemolle8,A-bemolle-bemolle-bemolle-bemolle8, D-diesis-diesis-diesis8, E-diesis8, G-bemolle-bemolle8,A-bemolle-bemolle-bemolle8, E-diesis-diesis8, F-diesis8,A-bemolle-bemolle8, B-bemolle-bemolle-bemolle-bemolle8, E-diesis-diesis-diesis8, F-diesis-diesis8,B-bemolle-bemolle-bemolle8, F-diesis-diesis-diesis8, G-diesis8,B-bemolle-bemolle8, C-bemolle-bemolle-bemolle9, G-diesis-diesis8,A-diesis8, C-bemolle-bemolle9, D-bemolle-bemolle-bemolle-bemolle9, G-diesis-diesis-diesis8,A-diesis-diesis8, C-bemolle9, D-bemolle-bemolle-bemolle9,A-diesis-diesis-diesis8, B-diesis8, D-bemolle-bemolle9, E-bemolle-bemolle-bemolle-bemolle9,B-diesis-diesis8, C-diesis9, E-bemolle-bemolle-bemolle9,B-diesis-diesis-diesis8, C-diesis-diesis9, E-bemolle-bemolle9, F-bemolle-bemolle-bemolle9,C-diesis-diesis-diesis9, D-diesis9, F-bemolle-bemolle9, G-bemolle-bemolle-bemolle-bemolle9,D-diesis-diesis9, F-bemolle9, G-bemolle-bemolle-bemolle9,A-bemolle-bemolle-bemolle-bemolle9, D-diesis-diesis-diesis9, E-diesis9, G-bemolle-bemolle9,A-bemolle-bemolle-bemolle9, E-diesis-diesis9, F-diesis9,A-bemolle-bemolle9, B-bemolle-bemolle-bemolle-bemolle9, E-diesis-diesis-diesis9, F-diesis-diesis9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis'''', D-bemolle-bemolle''', E-bemolle-bemolle-bemolle-bemolle''',B-diesis-diesis'''', C-diesis''', E-bemolle-bemolle-bemolle''',B-diesis-diesis-diesis'''', C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''',C-diesis-diesis-diesis''', D-diesis''', F-bemolle-bemolle''', G-bemolle-bemolle-bemolle-bemolle''',D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',A-bemolle-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', E-diesis-diesis''', F-diesis''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',B-bemolle-bemolle-bemolle''', F-diesis-diesis-diesis''', G-diesis''',B-bemolle-bemolle''', C-bemolle-bemolle-bemolle'', G-diesis-diesis''',A-diesis''', C-bemolle-bemolle'', D-bemolle-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis''',A-diesis-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'',A-diesis-diesis-diesis''', B-diesis''', D-bemolle-bemolle'', E-bemolle-bemolle-bemolle-bemolle'',B-diesis-diesis''', C-diesis'', E-bemolle-bemolle-bemolle'',B-diesis-diesis-diesis''', C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'',C-diesis-diesis-diesis'', D-diesis'', F-bemolle-bemolle'', G-bemolle-bemolle-bemolle-bemolle'',D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',A-bemolle-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', E-diesis-diesis'', F-diesis'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',B-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis'', G-diesis'',B-bemolle-bemolle'', C-bemolle-bemolle-bemolle', G-diesis-diesis'',A-diesis'', C-bemolle-bemolle', D-bemolle-bemolle-bemolle-bemolle', G-diesis-diesis-diesis'',A-diesis-diesis'', C-bemolle', D-bemolle-bemolle-bemolle',A-diesis-diesis-diesis'', B-diesis'', D-bemolle-bemolle', E-bemolle-bemolle-bemolle-bemolle',B-diesis-diesis'', C-diesis', E-bemolle-bemolle-bemolle',B-diesis-diesis-diesis'', C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle',C-diesis-diesis-diesis', D-diesis', F-bemolle-bemolle', G-bemolle-bemolle-bemolle-bemolle',D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',A-bemolle-bemolle-bemolle-bemolle', D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', E-diesis-diesis', F-diesis',A-bemolle-bemolle', B-bemolle-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',B-bemolle-bemolle-bemolle', F-diesis-diesis-diesis', G-diesis',B-bemolle-bemolle', C-bemolle-bemolle-bemolle, G-diesis-diesis',A-diesis', C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis',A-diesis-diesis', C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis', B-diesis', D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis', C-diesis, E-bemolle-bemolle-bemolle,B-diesis-diesis-diesis', C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis,B-bemolle-bemolle, G-diesis-diesis, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle,A-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis, c-diesis, e-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis,b-bemolle-bemolle, c-bemolle-bemolle-bemolle', g-diesis-diesis,a-diesis, c-bemolle-bemolle', d-bemolle-bemolle-bemolle-bemolle', g-diesis-diesis-diesis,a-diesis-diesis, c-bemolle', d-bemolle-bemolle-bemolle',a-diesis-diesis-diesis, b-diesis, d-bemolle-bemolle', e-bemolle-bemolle-bemolle-bemolle',b-diesis-diesis, c-diesis', e-bemolle-bemolle-bemolle',b-diesis-diesis-diesis, c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle',c-diesis-diesis-diesis', d-diesis', f-bemolle-bemolle', g-bemolle-bemolle-bemolle-bemolle',d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',a-bemolle-bemolle-bemolle-bemolle', d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', e-diesis-diesis', f-diesis',a-bemolle-bemolle', b-bemolle-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',b-bemolle-bemolle-bemolle', f-diesis-diesis-diesis', g-diesis',b-bemolle-bemolle', c-bemolle-bemolle-bemolle'', g-diesis-diesis',a-diesis', c-bemolle-bemolle'', d-bemolle-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis',a-diesis-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'',a-diesis-diesis-diesis', b-diesis', d-bemolle-bemolle'', e-bemolle-bemolle-bemolle-bemolle'',b-diesis-diesis', c-diesis'', e-bemolle-bemolle-bemolle'',b-diesis-diesis-diesis', c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'',c-diesis-diesis-diesis'', d-diesis'', f-bemolle-bemolle'', g-bemolle-bemolle-bemolle-bemolle'',d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',a-bemolle-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', e-diesis-diesis'', f-diesis'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',b-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis'', g-diesis'',b-bemolle-bemolle'', c-bemolle-bemolle-bemolle''', g-diesis-diesis'',a-diesis'', c-bemolle-bemolle''', d-bemolle-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis'',a-diesis-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''',a-diesis-diesis-diesis'', b-diesis'', d-bemolle-bemolle''', e-bemolle-bemolle-bemolle-bemolle''',b-diesis-diesis'', c-diesis''', e-bemolle-bemolle-bemolle''',b-diesis-diesis-diesis'', c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''',c-diesis-diesis-diesis''', d-diesis''', f-bemolle-bemolle''', g-bemolle-bemolle-bemolle-bemolle''',d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',a-bemolle-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', e-diesis-diesis''', f-diesis''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',b-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis''', g-diesis''',b-bemolle-bemolle''', c-bemolle-bemolle-bemolle'''', g-diesis-diesis''',a-diesis''', c-bemolle-bemolle'''', d-bemolle-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis''',a-diesis-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''',a-diesis-diesis-diesis''', b-diesis''', d-bemolle-bemolle'''', e-bemolle-bemolle-bemolle-bemolle'''',b-diesis-diesis''', c-diesis'''', e-bemolle-bemolle-bemolle'''',b-diesis-diesis-diesis''', c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''',c-diesis-diesis-diesis'''', d-diesis'''', f-bemolle-bemolle'''', g-bemolle-bemolle-bemolle-bemolle'''',d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',a-bemolle-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', e-diesis-diesis'''', f-diesis'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',b-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis'''', g-diesis'''',b-bemolle-bemolle'''', c-bemolle-bemolle-bemolle''''', g-diesis-diesis'''',a-diesis'''', c-bemolle-bemolle''''', d-bemolle-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis'''',a-diesis-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''',a-diesis-diesis-diesis'''', b-diesis'''', d-bemolle-bemolle''''', e-bemolle-bemolle-bemolle-bemolle''''',b-diesis-diesis'''', c-diesis''''', e-bemolle-bemolle-bemolle''''',b-diesis-diesis-diesis'''', c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''',c-diesis-diesis-diesis''''', d-diesis''''', f-bemolle-bemolle''''', g-bemolle-bemolle-bemolle-bemolle''''',d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',a-bemolle-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', e-diesis-diesis''''', f-diesis''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',b-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis''''', g-diesis''''',b-bemolle-bemolle''''', c-bemolle-bemolle-bemolle'''''', g-diesis-diesis''''',a-diesis''''', c-bemolle-bemolle'''''', d-bemolle-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis''''',a-diesis-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''',a-diesis-diesis-diesis''''', b-diesis''''', d-bemolle-bemolle'''''', e-bemolle-bemolle-bemolle-bemolle'''''',b-diesis-diesis''''', c-diesis'''''', e-bemolle-bemolle-bemolle'''''',b-diesis-diesis-diesis''''', c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''',c-diesis-diesis-diesis'''''', d-diesis'''''', f-bemolle-bemolle'''''', g-bemolle-bemolle-bemolle-bemolle'''''',d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', e-diesis-diesis'''''', f-diesis'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Aisisis-6, Bis-6, Deses-5,Aisisisis-6, Bisis-6, Des-5, Eseses-5,Bisisis-6, Cisis-5, Eses-5, Feseses-5,Cisisis-5, Es-5, Feses-5,Cisisisis-5, Disis-5, Fes-5, Geseses-5,Disisis-5, Eis-5, Geses-5,Aseses-5, Disisisis-5, Eisis-5, Ges-5,Ases-5, Eisisis-5, Fisis-5,As-5, Beseses-5, Fisisis-5,Beses-5, Ceseses-4, Fisisisis-5, Gisis-5,Bes-5, Ceses-4, Gisisis-5,Aisis-5, Ces-4, Deseses-4, Gisisisis-5,Aisisis-5, Bis-5, Deses-4,Aisisisis-5, Bisis-5, Des-4, Eseses-4,Bisisis-5, Cisis-4, Eses-4, Feseses-4,Cisisis-4, Es-4, Feses-4,Cisisisis-4, Disis-4, Fes-4, Geseses-4,Disisis-4, Eis-4, Geses-4,Aseses-4, Disisisis-4, Eisis-4, Ges-4,Ases-4, Eisisis-4, Fisis-4,As-4, Beseses-4, Fisisis-4,Beses-4, Ceseses-3, Fisisisis-4, Gisis-4,Bes-4, Ceses-3, Gisisis-4,Aisis-4, Ces-3, Deseses-3, Gisisisis-4,Aisisis-4, Bis-4, Deses-3,Aisisisis-4, Bisis-4, Des-3, Eseses-3,Bisisis-4, Cisis-3, Eses-3, Feseses-3,Cisisis-3, Es-3, Feses-3,Cisisisis-3, Disis-3, Fes-3, Geseses-3,Disisis-3, Eis-3, Geses-3,Aseses-3, Disisisis-3, Eisis-3, Ges-3,Ases-3, Eisisis-3, Fisis-3,As-3, Beseses-3, Fisisis-3,Beses-3, Ceseses-2, Fisisisis-3, Gisis-3,Bes-3, Ceses-2, Gisisis-3,Aisis-3, Ces-2, Deseses-2, Gisisisis-3,Aisisis-3, Bis-3, Deses-2,Aisisisis-3, Bisis-3, Des-2, Eseses-2,Bisisis-3, Cisis-2, Eses-2, Feseses-2,Cisisis-2, Es-2, Feses-2,Cisisisis-2, Disis-2, Fes-2, Geseses-2,Disisis-2, Eis-2, Geses-2,Aseses-2, Disisisis-2, Eisis-2, Ges-2,Ases-2, Eisisis-2, Fisis-2,As-2, Beseses-2, Fisisis-2,Beses-2, Ceseses-, Fisisisis-2, Gisis-2,Bes-2, Ceses-, Gisisis-2,Aisis-2, Ces-, Deseses-, Gisisisis-2,Aisisis-2, Bis-2, Deses-,Aisisisis-2, Bisis-2, Des-, Eseses-,Bisisis-2, Cisis-, Eses-, Feseses-,Cisisis-, Es-, Feses-,Cisisisis-, Disis-, Fes-, Geseses-,Disisis-, Eis-, Geses-,Aseses-, Disisisis-, Eisis-, Ges-,Ases-, Eisisis-, Fisis-,As-, Beseses-, Fisisis-,Beses-, Ceseses, Fisisisis-, Gisis-,Bes-, Ceses, Gisisis-,Aisis-, Ces, Deseses, Gisisisis-,Aisisis-, Bis-, Deses,Aisisisis-, Bisis-, Des, Eseses,Bisisis-, Cisis, Eses, Feseses,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Eisisis, Fisis,As, Beseses, Fisisis,Beses, Ceseses+, Fisisisis, Gisis,Bes, Ceses+, Gisisis,Aisis, Ces+, Deseses+, Gisisisis,Aisisis, Bis, Deses+,Aisisisis, Bisis, Des+, Eseses+,Bisisis, Cisis+, Eses+, Feseses+,Cisisis+, Es+, Feses+,Cisisisis+, Disis+, Fes+, Geseses+,Disisis+, Eis+, Geses+,Aseses+, Disisisis+, Eisis+, Ges+,Ases+, Eisisis+, Fisis+,As+, Beseses+, Fisisis+,Beses+, Ceseses+2, Fisisisis+, Gisis+,Bes+, Ceses+2, Gisisis+,Aisis+, Ces+2, Deseses+2, Gisisisis+,Aisisis+, Bis+, Deses+2,Aisisisis+, Bisis+, Des+2, Eseses+2,Bisisis+, Cisis+2, Eses+2, Feseses+2,Cisisis+2, Es+2, Feses+2,Cisisisis+2, Disis+2, Fes+2, Geseses+2,Disisis+2, Eis+2, Geses+2,Aseses+2, Disisisis+2, Eisis+2, Ges+2,Ases+2, Eisisis+2, Fisis+2,As+2, Beseses+2, Fisisis+2,Beses+2, Ceseses+3, Fisisisis+2, Gisis+2,Bes+2, Ceses+3, Gisisis+2,Aisis+2, Ces+3, Deseses+3, Gisisisis+2,Aisisis+2, Bis+2, Deses+3,Aisisisis+2, Bisis+2, Des+3, Eseses+3,Bisisis+2, Cisis+3, Eses+3, Feseses+3,Cisisis+3, Es+3, Feses+3,Cisisisis+3, Disis+3, Fes+3, Geseses+3,Disisis+3, Eis+3, Geses+3,Aseses+3, Disisisis+3, Eisis+3, Ges+3,Ases+3, Eisisis+3, Fisis+3,As+3, Beseses+3, Fisisis+3,Beses+3, Ceseses+4, Fisisisis+3, Gisis+3,Bes+3, Ceses+4, Gisisis+3,Aisis+3, Ces+4, Deseses+4, Gisisisis+3,Aisisis+3, Bis+3, Deses+4,Aisisisis+3, Bisis+3, Des+4, Eseses+4,Bisisis+3, Cisis+4, Eses+4, Feseses+4,Cisisis+4, Es+4, Feses+4,Cisisisis+4, Disis+4, Fes+4, Geseses+4,Disisis+4, Eis+4, Geses+4,Aseses+4, Disisisis+4, Eisis+4, Ges+4,Ases+4, Eisisis+4, Fisis+4,As+4, Beseses+4, Fisisis+4,Beses+4, Ceseses+5, Fisisisis+4, Gisis+4,Bes+4, Ceses+5, Gisisis+4,Aisis+4, Ces+5, Deseses+5, Gisisisis+4,Aisisis+4, Bis+4, Deses+5,Aisisisis+4, Bisis+4, Des+5, Eseses+5,Bisisis+4, Cisis+5, Eses+5, Feseses+5,Cisisis+5, Es+5, Feses+5,Cisisisis+5, Disis+5, Fes+5, Geseses+5,Disisis+5, Eis+5, Geses+5,Aseses+5, Disisisis+5, Eisis+5, Ges+5,Ases+5, Eisisis+5, Fisis+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Aisisis------, Bis------, Deses-----,Aisisisis------, Bisis------, Des-----, Eseses-----,Bisisis------, Cisis-----, Eses-----, Feseses-----,Cisisis-----, Es-----, Feses-----,Cisisisis-----, Disis-----, Fes-----, Geseses-----,Disisis-----, Eis-----, Geses-----,Aseses-----, Disisisis-----, Eisis-----, Ges-----,Ases-----, Eisisis-----, Fisis-----,As-----, Beseses-----, Fisisis-----,Beses-----, Ceseses----, Fisisisis-----, Gisis-----,Bes-----, Ceses----, Gisisis-----,Aisis-----, Ces----, Deseses----, Gisisisis-----,Aisisis-----, Bis-----, Deses----,Aisisisis-----, Bisis-----, Des----, Eseses----,Bisisis-----, Cisis----, Eses----, Feseses----,Cisisis----, Es----, Feses----,Cisisisis----, Disis----, Fes----, Geseses----,Disisis----, Eis----, Geses----,Aseses----, Disisisis----, Eisis----, Ges----,Ases----, Eisisis----, Fisis----,As----, Beseses----, Fisisis----,Beses----, Ceseses---, Fisisisis----, Gisis----,Bes----, Ceses---, Gisisis----,Aisis----, Ces---, Deseses---, Gisisisis----,Aisisis----, Bis----, Deses---,Aisisisis----, Bisis----, Des---, Eseses---,Bisisis----, Cisis---, Eses---, Feseses---,Cisisis---, Es---, Feses---,Cisisisis---, Disis---, Fes---, Geseses---,Disisis---, Eis---, Geses---,Aseses---, Disisisis---, Eisis---, Ges---,Ases---, Eisisis---, Fisis---,As---, Beseses---, Fisisis---,Beses---, Ceseses--, Fisisisis---, Gisis---,Bes---, Ceses--, Gisisis---,Aisis---, Ces--, Deseses--, Gisisisis---,Aisisis---, Bis---, Deses--,Aisisisis---, Bisis---, Des--, Eseses--,Bisisis---, Cisis--, Eses--, Feseses--,Cisisis--, Es--, Feses--,Cisisisis--, Disis--, Fes--, Geseses--,Disisis--, Eis--, Geses--,Aseses--, Disisisis--, Eisis--, Ges--,Ases--, Eisisis--, Fisis--,As--, Beseses--, Fisisis--,Beses--, Ceseses-, Fisisisis--, Gisis--,Bes--, Ceses-, Gisisis--,Aisis--, Ces-, Deseses-, Gisisisis--,Aisisis--, Bis--, Deses-,Aisisisis--, Bisis--, Des-, Eseses-,Bisisis--, Cisis-, Eses-, Feseses-,Cisisis-, Es-, Feses-,Cisisisis-, Disis-, Fes-, Geseses-,Disisis-, Eis-, Geses-,Aseses-, Disisisis-, Eisis-, Ges-,Ases-, Eisisis-, Fisis-,As-, Beseses-, Fisisis-,Beses-, Ceseses, Fisisisis-, Gisis-,Bes-, Ceses, Gisisis-,Aisis-, Ces, Deseses, Gisisisis-,Aisisis-, Bis-, Deses,Aisisisis-, Bisis-, Des, Eseses,Bisisis-, Cisis, Eses, Feseses,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Eisisis, Fisis,As, Beseses, Fisisis,Beses, Ceseses+, Fisisisis, Gisis,Bes, Ceses+, Gisisis,Aisis, Ces+, Deseses+, Gisisisis,Aisisis, Bis, Deses+,Aisisisis, Bisis, Des+, Eseses+,Bisisis, Cisis+, Eses+, Feseses+,Cisisis+, Es+, Feses+,Cisisisis+, Disis+, Fes+, Geseses+,Disisis+, Eis+, Geses+,Aseses+, Disisisis+, Eisis+, Ges+,Ases+, Eisisis+, Fisis+,As+, Beseses+, Fisisis+,Beses+, Ceseses++, Fisisisis+, Gisis+,Bes+, Ceses++, Gisisis+,Aisis+, Ces++, Deseses++, Gisisisis+,Aisisis+, Bis+, Deses++,Aisisisis+, Bisis+, Des++, Eseses++,Bisisis+, Cisis++, Eses++, Feseses++,Cisisis++, Es++, Feses++,Cisisisis++, Disis++, Fes++, Geseses++,Disisis++, Eis++, Geses++,Aseses++, Disisisis++, Eisis++, Ges++,Ases++, Eisisis++, Fisis++,As++, Beseses++, Fisisis++,Beses++, Ceseses+++, Fisisisis++, Gisis++,Bes++, Ceses+++, Gisisis++,Aisis++, Ces+++, Deseses+++, Gisisisis++,Aisisis++, Bis++, Deses+++,Aisisisis++, Bisis++, Des+++, Eseses+++,Bisisis++, Cisis+++, Eses+++, Feseses+++,Cisisis+++, Es+++, Feses+++,Cisisisis+++, Disis+++, Fes+++, Geseses+++,Disisis+++, Eis+++, Geses+++,Aseses+++, Disisisis+++, Eisis+++, Ges+++,Ases+++, Eisisis+++, Fisis+++,As+++, Beseses+++, Fisisis+++,Beses+++, Ceseses++++, Fisisisis+++, Gisis+++,Bes+++, Ceses++++, Gisisis+++,Aisis+++, Ces++++, Deseses++++, Gisisisis+++,Aisisis+++, Bis+++, Deses++++,Aisisisis+++, Bisis+++, Des++++, Eseses++++,Bisisis+++, Cisis++++, Eses++++, Feseses++++,Cisisis++++, Es++++, Feses++++,Cisisisis++++, Disis++++, Fes++++, Geseses++++,Disisis++++, Eis++++, Geses++++,Aseses++++, Disisisis++++, Eisis++++, Ges++++,Ases++++, Eisisis++++, Fisis++++,As++++, Beseses++++, Fisisis++++,Beses++++, Ceseses+++++, Fisisisis++++, Gisis++++,Bes++++, Ceses+++++, Gisisis++++,Aisis++++, Ces+++++, Deseses+++++, Gisisisis++++,Aisisis++++, Bis++++, Deses+++++,Aisisisis++++, Bisis++++, Des+++++, Eseses+++++,Bisisis++++, Cisis+++++, Eses+++++, Feseses+++++,Cisisis+++++, Es+++++, Feses+++++,Cisisisis+++++, Disis+++++, Fes+++++, Geseses+++++,Disisis+++++, Eis+++++, Geses+++++,Aseses+++++, Disisisis+++++, Eisis+++++, Ges+++++,Ases+++++, Eisisis+++++, Fisis+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Aisisis-2, Bis-2, Deses-1,Aisisisis-2, Bisis-2, Des-1, Eseses-1,Bisisis-2, Cisis-1, Eses-1, Feseses-1,Cisisis-1, Es-1, Feses-1,Cisisisis-1, Disis-1, Fes-1, Geseses-1,Disisis-1, Eis-1, Geses-1,Aseses-1, Disisisis-1, Eisis-1, Ges-1,Ases-1, Eisisis-1, Fisis-1,As-1, Beseses-1, Fisisis-1,Beses-1, Ceseses0, Fisisisis-1, Gisis-1,Bes-1, Ceses0, Gisisis-1,Aisis-1, Ces0, Deseses0, Gisisisis-1,Aisisis-1, Bis-1, Deses0,Aisisisis-1, Bisis-1, Des0, Eseses0,Bisisis-1, Cisis0, Eses0, Feseses0,Cisisis0, Es0, Feses0,Cisisisis0, Disis0, Fes0, Geseses0,Disisis0, Eis0, Geses0,Aseses0, Disisisis0, Eisis0, Ges0,Ases0, Eisisis0, Fisis0,As0, Beseses0, Fisisis0,Beses0, Ceseses1, Fisisisis0, Gisis0,Bes0, Ceses1, Gisisis0,Aisis0, Ces1, Deseses1, Gisisisis0,Aisisis0, Bis0, Deses1,Aisisisis0, Bisis0, Des1, Eseses1,Bisisis0, Cisis1, Eses1, Feseses1,Cisisis1, Es1, Feses1,Cisisisis1, Disis1, Fes1, Geseses1,Disisis1, Eis1, Geses1,Aseses1, Disisisis1, Eisis1, Ges1,Ases1, Eisisis1, Fisis1,As1, Beseses1, Fisisis1,Beses1, Ceseses2, Fisisisis1, Gisis1,Bes1, Ceses2, Gisisis1,Aisis1, Ces2, Deseses2, Gisisisis1,Aisisis1, Bis1, Deses2,Aisisisis1, Bisis1, Des2, Eseses2,Bisisis1, Cisis2, Eses2, Feseses2,Cisisis2, Es2, Feses2,Cisisisis2, Disis2, Fes2, Geseses2,Disisis2, Eis2, Geses2,Aseses2, Disisisis2, Eisis2, Ges2,Ases2, Eisisis2, Fisis2,As2, Beseses2, Fisisis2,Beses2, Ceseses3, Fisisisis2, Gisis2,Bes2, Ceses3, Gisisis2,Aisis2, Ces3, Deseses3, Gisisisis2,Aisisis2, Bis2, Deses3,Aisisisis2, Bisis2, Des3, Eseses3,Bisisis2, Cisis3, Eses3, Feseses3,Cisisis3, Es3, Feses3,Cisisisis3, Disis3, Fes3, Geseses3,Disisis3, Eis3, Geses3,Aseses3, Disisisis3, Eisis3, Ges3,Ases3, Eisisis3, Fisis3,As3, Beseses3, Fisisis3,Beses3, Ceseses4, Fisisisis3, Gisis3,Bes3, Ceses4, Gisisis3,Aisis3, Ces4, Deseses4, Gisisisis3,Aisisis3, Bis3, Deses4,Aisisisis3, Bisis3, Des4, Eseses4,Bisisis3, Cisis4, Eses4, Feseses4,Cisisis4, Es4, Feses4,Cisisisis4, Disis4, Fes4, Geseses4,Disisis4, Eis4, Geses4,Aseses4, Disisisis4, Eisis4, Ges4,Ases4, Eisisis4, Fisis4,As4, Beseses4, Fisisis4,Beses4, Ceseses5, Fisisisis4, Gisis4,Bes4, Ceses5, Gisisis4,Aisis4, Ces5, Deseses5, Gisisisis4,Aisisis4, Bis4, Deses5,Aisisisis4, Bisis4, Des5, Eseses5,Bisisis4, Cisis5, Eses5, Feseses5,Cisisis5, Es5, Feses5,Cisisisis5, Disis5, Fes5, Geseses5,Disisis5, Eis5, Geses5,Aseses5, Disisisis5, Eisis5, Ges5,Ases5, Eisisis5, Fisis5,As5, Beseses5, Fisisis5,Beses5, Ceseses6, Fisisisis5, Gisis5,Bes5, Ceses6, Gisisis5,Aisis5, Ces6, Deseses6, Gisisisis5,Aisisis5, Bis5, Deses6,Aisisisis5, Bisis5, Des6, Eseses6,Bisisis5, Cisis6, Eses6, Feseses6,Cisisis6, Es6, Feses6,Cisisisis6, Disis6, Fes6, Geseses6,Disisis6, Eis6, Geses6,Aseses6, Disisisis6, Eisis6, Ges6,Ases6, Eisisis6, Fisis6,As6, Beseses6, Fisisis6,Beses6, Ceseses7, Fisisisis6, Gisis6,Bes6, Ceses7, Gisisis6,Aisis6, Ces7, Deseses7, Gisisisis6,Aisisis6, Bis6, Deses7,Aisisisis6, Bisis6, Des7, Eseses7,Bisisis6, Cisis7, Eses7, Feseses7,Cisisis7, Es7, Feses7,Cisisisis7, Disis7, Fes7, Geseses7,Disisis7, Eis7, Geses7,Aseses7, Disisisis7, Eisis7, Ges7,Ases7, Eisisis7, Fisis7,As7, Beseses7, Fisisis7,Beses7, Ceseses8, Fisisisis7, Gisis7,Bes7, Ceses8, Gisisis7,Aisis7, Ces8, Deseses8, Gisisisis7,Aisisis7, Bis7, Deses8,Aisisisis7, Bisis7, Des8, Eseses8,Bisisis7, Cisis8, Eses8, Feseses8,Cisisis8, Es8, Feses8,Cisisisis8, Disis8, Fes8, Geseses8,Disisis8, Eis8, Geses8,Aseses8, Disisisis8, Eisis8, Ges8,Ases8, Eisisis8, Fisis8,As8, Beseses8, Fisisis8,Beses8, Ceseses9, Fisisisis8, Gisis8,Bes8, Ceses9, Gisisis8,Aisis8, Ces9, Deseses9, Gisisisis8,Aisisis8, Bis8, Deses9,Aisisisis8, Bisis8, Des9, Eseses9,Bisisis8, Cisis9, Eses9, Feseses9,Cisisis9, Es9, Feses9,Cisisisis9, Disis9, Fes9, Geseses9,Disisis9, Eis9, Geses9,Aseses9, Disisisis9, Eisis9, Ges9,Ases9, Eisisis9, Fisis9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Aisisis'''', Bis'''', Deses''',Aisisisis'''', Bisis'''', Des''', Eseses''',Bisisis'''', Cisis''', Eses''', Feseses''',Cisisis''', Es''', Feses''',Cisisisis''', Disis''', Fes''', Geseses''',Disisis''', Eis''', Geses''',Aseses''', Disisisis''', Eisis''', Ges''',Ases''', Eisisis''', Fisis''',As''', Beseses''', Fisisis''',Beses''', Ceseses'', Fisisisis''', Gisis''',Bes''', Ceses'', Gisisis''',Aisis''', Ces'', Deseses'', Gisisisis''',Aisisis''', Bis''', Deses'',Aisisisis''', Bisis''', Des'', Eseses'',Bisisis''', Cisis'', Eses'', Feseses'',Cisisis'', Es'', Feses'',Cisisisis'', Disis'', Fes'', Geseses'',Disisis'', Eis'', Geses'',Aseses'', Disisisis'', Eisis'', Ges'',Ases'', Eisisis'', Fisis'',As'', Beseses'', Fisisis'',Beses'', Ceseses', Fisisisis'', Gisis'',Bes'', Ceses', Gisisis'',Aisis'', Ces', Deseses', Gisisisis'',Aisisis'', Bis'', Deses',Aisisisis'', Bisis'', Des', Eseses',Bisisis'', Cisis', Eses', Feseses',Cisisis', Es', Feses',Cisisisis', Disis', Fes', Geseses',Disisis', Eis', Geses',Aseses', Disisisis', Eisis', Ges',Ases', Eisisis', Fisis',As', Beseses', Fisisis',Beses', Ceseses, Fisisisis', Gisis',Bes', Ceses, Gisisis',Aisis', Ces, Deseses, Gisisisis',Aisisis', Bis', Deses,Aisisisis', Bisis', Des, Eseses,Bisisis', Cisis, Eses, Feseses,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Eisisis, Fisis,As, Beseses, Fisisis,Beses, Fisisisis, Gisis, ceseses,Bes, Gisisis, ceses,Aisis, Gisisisis, ces, deseses,Aisisis, Bis, deses,Aisisisis, Bisis, des, eseses,Bisisis, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, eisisis, fisis,as, beseses, fisisis,beses, ceseses', fisisisis, gisis,bes, ceses', gisisis,aisis, ces', deseses', gisisisis,aisisis, bis, deses',aisisisis, bisis, des', eseses',bisisis, cisis', eses', feseses',cisisis', es', feses',cisisisis', disis', fes', geseses',disisis', eis', geses',aseses', disisisis', eisis', ges',ases', eisisis', fisis',as', beseses', fisisis',beses', ceseses'', fisisisis', gisis',bes', ceses'', gisisis',aisis', ces'', deseses'', gisisisis',aisisis', bis', deses'',aisisisis', bisis', des'', eseses'',bisisis', cisis'', eses'', feseses'',cisisis'', es'', feses'',cisisisis'', disis'', fes'', geseses'',disisis'', eis'', geses'',aseses'', disisisis'', eisis'', ges'',ases'', eisisis'', fisis'',as'', beseses'', fisisis'',beses'', ceseses''', fisisisis'', gisis'',bes'', ceses''', gisisis'',aisis'', ces''', deseses''', gisisisis'',aisisis'', bis'', deses''',aisisisis'', bisis'', des''', eseses''',bisisis'', cisis''', eses''', feseses''',cisisis''', es''', feses''',cisisisis''', disis''', fes''', geseses''',disisis''', eis''', geses''',aseses''', disisisis''', eisis''', ges''',ases''', eisisis''', fisis''',as''', beseses''', fisisis''',beses''', ceseses'''', fisisisis''', gisis''',bes''', ceses'''', gisisis''',aisis''', ces'''', deseses'''', gisisisis''',aisisis''', bis''', deses'''',aisisisis''', bisis''', des'''', eseses'''',bisisis''', cisis'''', eses'''', feseses'''',cisisis'''', es'''', feses'''',cisisisis'''', disis'''', fes'''', geseses'''',disisis'''', eis'''', geses'''',aseses'''', disisisis'''', eisis'''', ges'''',ases'''', eisisis'''', fisis'''',as'''', beseses'''', fisisis'''',beses'''', ceseses''''', fisisisis'''', gisis'''',bes'''', ceses''''', gisisis'''',aisis'''', ces''''', deseses''''', gisisisis'''',aisisis'''', bis'''', deses''''',aisisisis'''', bisis'''', des''''', eseses''''',bisisis'''', cisis''''', eses''''', feseses''''',cisisis''''', es''''', feses''''',cisisisis''''', disis''''', fes''''', geseses''''',disisis''''', eis''''', geses''''',aseses''''', disisisis''''', eisis''''', ges''''',ases''''', eisisis''''', fisis''''',as''''', beseses''''', fisisis''''',beses''''', ceseses'''''', fisisisis''''', gisis''''',bes''''', ceses'''''', gisisis''''',aisis''''', ces'''''', deseses'''''', gisisisis''''',aisisis''''', bis''''', deses'''''',aisisisis''''', bisis''''', des'''''', eseses'''''',bisisis''''', cisis'''''', eses'''''', feseses'''''',cisisis'''''', es'''''', feses'''''',cisisisis'''''', disis'''''', fes'''''', geseses'''''',disisis'''''', eis'''''', geses'''''',aseses'''''', disisisis'''''', eisis'''''', ges'''''',ases'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Aisisis-6, Bis-6, Deses-5, Eseseses-5,Bisis-6, Cis-5, Eseses-5,Bisisis-6, Cisis-5, Eses-5, Feseses-5,Cisisis-5, Dis-5, Feses-5, Geseseses-5,Disis-5, Fes-5, Geseses-5,Aseseses-5, Disisis-5, Eis-5, Geses-5,Aseses-5, Eisis-5, Fis-5,Ases-5, Beseseses-5, Eisisis-5, Fisis-5,Beseses-5, Fisisis-5, Gis-5,Beses-5, Ceseses-4, Gisis-5,Ais-5, Ceses-4, Deseseses-4, Gisisis-5,Aisis-5, Ces-4, Deseses-4,Aisisis-5, Bis-5, Deses-4, Eseseses-4,Bisis-5, Cis-4, Eseses-4,Bisisis-5, Cisis-4, Eses-4, Feseses-4,Cisisis-4, Dis-4, Feses-4, Geseseses-4,Disis-4, Fes-4, Geseses-4,Aseseses-4, Disisis-4, Eis-4, Geses-4,Aseses-4, Eisis-4, Fis-4,Ases-4, Beseseses-4, Eisisis-4, Fisis-4,Beseses-4, Fisisis-4, Gis-4,Beses-4, Ceseses-3, Gisis-4,Ais-4, Ceses-3, Deseseses-3, Gisisis-4,Aisis-4, Ces-3, Deseses-3,Aisisis-4, Bis-4, Deses-3, Eseseses-3,Bisis-4, Cis-3, Eseses-3,Bisisis-4, Cisis-3, Eses-3, Feseses-3,Cisisis-3, Dis-3, Feses-3, Geseseses-3,Disis-3, Fes-3, Geseses-3,Aseseses-3, Disisis-3, Eis-3, Geses-3,Aseses-3, Eisis-3, Fis-3,Ases-3, Beseseses-3, Eisisis-3, Fisis-3,Beseses-3, Fisisis-3, Gis-3,Beses-3, Ceseses-2, Gisis-3,Ais-3, Ceses-2, Deseseses-2, Gisisis-3,Aisis-3, Ces-2, Deseses-2,Aisisis-3, Bis-3, Deses-2, Eseseses-2,Bisis-3, Cis-2, Eseses-2,Bisisis-3, Cisis-2, Eses-2, Feseses-2,Cisisis-2, Dis-2, Feses-2, Geseseses-2,Disis-2, Fes-2, Geseses-2,Aseseses-2, Disisis-2, Eis-2, Geses-2,Aseses-2, Eisis-2, Fis-2,Ases-2, Beseseses-2, Eisisis-2, Fisis-2,Beseses-2, Fisisis-2, Gis-2,Beses-2, Ceseses-, Gisis-2,Ais-2, Ceses-, Deseseses-, Gisisis-2,Aisis-2, Ces-, Deseses-,Aisisis-2, Bis-2, Deses-, Eseseses-,Bisis-2, Cis-, Eseses-,Bisisis-2, Cisis-, Eses-, Feseses-,Cisisis-, Dis-, Feses-, Geseseses-,Disis-, Fes-, Geseses-,Aseseses-, Disisis-, Eis-, Geses-,Aseses-, Eisis-, Fis-,Ases-, Beseseses-, Eisisis-, Fisis-,Beseses-, Fisisis-, Gis-,Beses-, Ceseses, Gisis-,Ais-, Ceses, Deseseses, Gisisis-,Aisis-, Ces, Deseses,Aisisis-, Bis-, Deses, Eseseses,Bisis-, Cis, Eseses,Bisisis-, Cisis, Eses, Feseses,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseseses, Eisisis, Fisis,Beseses, Fisisis, Gis,Beses, Ceseses+, Gisis,Ais, Ceses+, Deseseses+, Gisisis,Aisis, Ces+, Deseses+,Aisisis, Bis, Deses+, Eseseses+,Bisis, Cis+, Eseses+,Bisisis, Cisis+, Eses+, Feseses+,Cisisis+, Dis+, Feses+, Geseseses+,Disis+, Fes+, Geseses+,Aseseses+, Disisis+, Eis+, Geses+,Aseses+, Eisis+, Fis+,Ases+, Beseseses+, Eisisis+, Fisis+,Beseses+, Fisisis+, Gis+,Beses+, Ceseses+2, Gisis+,Ais+, Ceses+2, Deseseses+2, Gisisis+,Aisis+, Ces+2, Deseses+2,Aisisis+, Bis+, Deses+2, Eseseses+2,Bisis+, Cis+2, Eseses+2,Bisisis+, Cisis+2, Eses+2, Feseses+2,Cisisis+2, Dis+2, Feses+2, Geseseses+2,Disis+2, Fes+2, Geseses+2,Aseseses+2, Disisis+2, Eis+2, Geses+2,Aseses+2, Eisis+2, Fis+2,Ases+2, Beseseses+2, Eisisis+2, Fisis+2,Beseses+2, Fisisis+2, Gis+2,Beses+2, Ceseses+3, Gisis+2,Ais+2, Ceses+3, Deseseses+3, Gisisis+2,Aisis+2, Ces+3, Deseses+3,Aisisis+2, Bis+2, Deses+3, Eseseses+3,Bisis+2, Cis+3, Eseses+3,Bisisis+2, Cisis+3, Eses+3, Feseses+3,Cisisis+3, Dis+3, Feses+3, Geseseses+3,Disis+3, Fes+3, Geseses+3,Aseseses+3, Disisis+3, Eis+3, Geses+3,Aseses+3, Eisis+3, Fis+3,Ases+3, Beseseses+3, Eisisis+3, Fisis+3,Beseses+3, Fisisis+3, Gis+3,Beses+3, Ceseses+4, Gisis+3,Ais+3, Ceses+4, Deseseses+4, Gisisis+3,Aisis+3, Ces+4, Deseses+4,Aisisis+3, Bis+3, Deses+4, Eseseses+4,Bisis+3, Cis+4, Eseses+4,Bisisis+3, Cisis+4, Eses+4, Feseses+4,Cisisis+4, Dis+4, Feses+4, Geseseses+4,Disis+4, Fes+4, Geseses+4,Aseseses+4, Disisis+4, Eis+4, Geses+4,Aseses+4, Eisis+4, Fis+4,Ases+4, Beseseses+4, Eisisis+4, Fisis+4,Beseses+4, Fisisis+4, Gis+4,Beses+4, Ceseses+5, Gisis+4,Ais+4, Ceses+5, Deseseses+5, Gisisis+4,Aisis+4, Ces+5, Deseses+5,Aisisis+4, Bis+4, Deses+5, Eseseses+5,Bisis+4, Cis+5, Eseses+5,Bisisis+4, Cisis+5, Eses+5, Feseses+5,Cisisis+5, Dis+5, Feses+5, Geseseses+5,Disis+5, Fes+5, Geseses+5,Aseseses+5, Disisis+5, Eis+5, Geses+5,Aseses+5, Eisis+5, Fis+5,Ases+5, Beseseses+5, Eisisis+5, Fisis+5\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Aisisis------, Bis------, Deses-----, Eseseses-----,Bisis------, Cis-----, Eseses-----,Bisisis------, Cisis-----, Eses-----, Feseses-----,Cisisis-----, Dis-----, Feses-----, Geseseses-----,Disis-----, Fes-----, Geseses-----,Aseseses-----, Disisis-----, Eis-----, Geses-----,Aseses-----, Eisis-----, Fis-----,Ases-----, Beseseses-----, Eisisis-----, Fisis-----,Beseses-----, Fisisis-----, Gis-----,Beses-----, Ceseses----, Gisis-----,Ais-----, Ceses----, Deseseses----, Gisisis-----,Aisis-----, Ces----, Deseses----,Aisisis-----, Bis-----, Deses----, Eseseses----,Bisis-----, Cis----, Eseses----,Bisisis-----, Cisis----, Eses----, Feseses----,Cisisis----, Dis----, Feses----, Geseseses----,Disis----, Fes----, Geseses----,Aseseses----, Disisis----, Eis----, Geses----,Aseses----, Eisis----, Fis----,Ases----, Beseseses----, Eisisis----, Fisis----,Beseses----, Fisisis----, Gis----,Beses----, Ceseses---, Gisis----,Ais----, Ceses---, Deseseses---, Gisisis----,Aisis----, Ces---, Deseses---,Aisisis----, Bis----, Deses---, Eseseses---,Bisis----, Cis---, Eseses---,Bisisis----, Cisis---, Eses---, Feseses---,Cisisis---, Dis---, Feses---, Geseseses---,Disis---, Fes---, Geseses---,Aseseses---, Disisis---, Eis---, Geses---,Aseses---, Eisis---, Fis---,Ases---, Beseseses---, Eisisis---, Fisis---,Beseses---, Fisisis---, Gis---,Beses---, Ceseses--, Gisis---,Ais---, Ceses--, Deseseses--, Gisisis---,Aisis---, Ces--, Deseses--,Aisisis---, Bis---, Deses--, Eseseses--,Bisis---, Cis--, Eseses--,Bisisis---, Cisis--, Eses--, Feseses--,Cisisis--, Dis--, Feses--, Geseseses--,Disis--, Fes--, Geseses--,Aseseses--, Disisis--, Eis--, Geses--,Aseses--, Eisis--, Fis--,Ases--, Beseseses--, Eisisis--, Fisis--,Beseses--, Fisisis--, Gis--,Beses--, Ceseses-, Gisis--,Ais--, Ceses-, Deseseses-, Gisisis--,Aisis--, Ces-, Deseses-,Aisisis--, Bis--, Deses-, Eseseses-,Bisis--, Cis-, Eseses-,Bisisis--, Cisis-, Eses-, Feseses-,Cisisis-, Dis-, Feses-, Geseseses-,Disis-, Fes-, Geseses-,Aseseses-, Disisis-, Eis-, Geses-,Aseses-, Eisis-, Fis-,Ases-, Beseseses-, Eisisis-, Fisis-,Beseses-, Fisisis-, Gis-,Beses-, Ceseses, Gisis-,Ais-, Ceses, Deseseses, Gisisis-,Aisis-, Ces, Deseses,Aisisis-, Bis-, Deses, Eseseses,Bisis-, Cis, Eseses,Bisisis-, Cisis, Eses, Feseses,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseseses, Eisisis, Fisis,Beseses, Fisisis, Gis,Beses, Ceseses+, Gisis,Ais, Ceses+, Deseseses+, Gisisis,Aisis, Ces+, Deseses+,Aisisis, Bis, Deses+, Eseseses+,Bisis, Cis+, Eseses+,Bisisis, Cisis+, Eses+, Feseses+,Cisisis+, Dis+, Feses+, Geseseses+,Disis+, Fes+, Geseses+,Aseseses+, Disisis+, Eis+, Geses+,Aseses+, Eisis+, Fis+,Ases+, Beseseses+, Eisisis+, Fisis+,Beseses+, Fisisis+, Gis+,Beses+, Ceseses++, Gisis+,Ais+, Ceses++, Deseseses++, Gisisis+,Aisis+, Ces++, Deseses++,Aisisis+, Bis+, Deses++, Eseseses++,Bisis+, Cis++, Eseses++,Bisisis+, Cisis++, Eses++, Feseses++,Cisisis++, Dis++, Feses++, Geseseses++,Disis++, Fes++, Geseses++,Aseseses++, Disisis++, Eis++, Geses++,Aseses++, Eisis++, Fis++,Ases++, Beseseses++, Eisisis++, Fisis++,Beseses++, Fisisis++, Gis++,Beses++, Ceseses+++, Gisis++,Ais++, Ceses+++, Deseseses+++, Gisisis++,Aisis++, Ces+++, Deseses+++,Aisisis++, Bis++, Deses+++, Eseseses+++,Bisis++, Cis+++, Eseses+++,Bisisis++, Cisis+++, Eses+++, Feseses+++,Cisisis+++, Dis+++, Feses+++, Geseseses+++,Disis+++, Fes+++, Geseses+++,Aseseses+++, Disisis+++, Eis+++, Geses+++,Aseses+++, Eisis+++, Fis+++,Ases+++, Beseseses+++, Eisisis+++, Fisis+++,Beseses+++, Fisisis+++, Gis+++,Beses+++, Ceseses++++, Gisis+++,Ais+++, Ceses++++, Deseseses++++, Gisisis+++,Aisis+++, Ces++++, Deseses++++,Aisisis+++, Bis+++, Deses++++, Eseseses++++,Bisis+++, Cis++++, Eseses++++,Bisisis+++, Cisis++++, Eses++++, Feseses++++,Cisisis++++, Dis++++, Feses++++, Geseseses++++,Disis++++, Fes++++, Geseses++++,Aseseses++++, Disisis++++, Eis++++, Geses++++,Aseses++++, Eisis++++, Fis++++,Ases++++, Beseseses++++, Eisisis++++, Fisis++++,Beseses++++, Fisisis++++, Gis++++,Beses++++, Ceseses+++++, Gisis++++,Ais++++, Ceses+++++, Deseseses+++++, Gisisis++++,Aisis++++, Ces+++++, Deseses+++++,Aisisis++++, Bis++++, Deses+++++, Eseseses+++++,Bisis++++, Cis+++++, Eseses+++++,Bisisis++++, Cisis+++++, Eses+++++, Feseses+++++,Cisisis+++++, Dis+++++, Feses+++++, Geseseses+++++,Disis+++++, Fes+++++, Geseses+++++,Aseseses+++++, Disisis+++++, Eis+++++, Geses+++++,Aseses+++++, Eisis+++++, Fis+++++,Ases+++++, Beseseses+++++, Eisisis+++++, Fisis+++++\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Aisisis-2, Bis-2, Deses-1, Eseseses-1,Bisis-2, Cis-1, Eseses-1,Bisisis-2, Cisis-1, Eses-1, Feseses-1,Cisisis-1, Dis-1, Feses-1, Geseseses-1,Disis-1, Fes-1, Geseses-1,Aseseses-1, Disisis-1, Eis-1, Geses-1,Aseses-1, Eisis-1, Fis-1,Ases-1, Beseseses-1, Eisisis-1, Fisis-1,Beseses-1, Fisisis-1, Gis-1,Beses-1, Ceseses0, Gisis-1,Ais-1, Ceses0, Deseseses0, Gisisis-1,Aisis-1, Ces0, Deseses0,Aisisis-1, Bis-1, Deses0, Eseseses0,Bisis-1, Cis0, Eseses0,Bisisis-1, Cisis0, Eses0, Feseses0,Cisisis0, Dis0, Feses0, Geseseses0,Disis0, Fes0, Geseses0,Aseseses0, Disisis0, Eis0, Geses0,Aseses0, Eisis0, Fis0,Ases0, Beseseses0, Eisisis0, Fisis0,Beseses0, Fisisis0, Gis0,Beses0, Ceseses1, Gisis0,Ais0, Ceses1, Deseseses1, Gisisis0,Aisis0, Ces1, Deseses1,Aisisis0, Bis0, Deses1, Eseseses1,Bisis0, Cis1, Eseses1,Bisisis0, Cisis1, Eses1, Feseses1,Cisisis1, Dis1, Feses1, Geseseses1,Disis1, Fes1, Geseses1,Aseseses1, Disisis1, Eis1, Geses1,Aseses1, Eisis1, Fis1,Ases1, Beseseses1, Eisisis1, Fisis1,Beseses1, Fisisis1, Gis1,Beses1, Ceseses2, Gisis1,Ais1, Ceses2, Deseseses2, Gisisis1,Aisis1, Ces2, Deseses2,Aisisis1, Bis1, Deses2, Eseseses2,Bisis1, Cis2, Eseses2,Bisisis1, Cisis2, Eses2, Feseses2,Cisisis2, Dis2, Feses2, Geseseses2,Disis2, Fes2, Geseses2,Aseseses2, Disisis2, Eis2, Geses2,Aseses2, Eisis2, Fis2,Ases2, Beseseses2, Eisisis2, Fisis2,Beseses2, Fisisis2, Gis2,Beses2, Ceseses3, Gisis2,Ais2, Ceses3, Deseseses3, Gisisis2,Aisis2, Ces3, Deseses3,Aisisis2, Bis2, Deses3, Eseseses3,Bisis2, Cis3, Eseses3,Bisisis2, Cisis3, Eses3, Feseses3,Cisisis3, Dis3, Feses3, Geseseses3,Disis3, Fes3, Geseses3,Aseseses3, Disisis3, Eis3, Geses3,Aseses3, Eisis3, Fis3,Ases3, Beseseses3, Eisisis3, Fisis3,Beseses3, Fisisis3, Gis3,Beses3, Ceseses4, Gisis3,Ais3, Ceses4, Deseseses4, Gisisis3,Aisis3, Ces4, Deseses4,Aisisis3, Bis3, Deses4, Eseseses4,Bisis3, Cis4, Eseses4,Bisisis3, Cisis4, Eses4, Feseses4,Cisisis4, Dis4, Feses4, Geseseses4,Disis4, Fes4, Geseses4,Aseseses4, Disisis4, Eis4, Geses4,Aseses4, Eisis4, Fis4,Ases4, Beseseses4, Eisisis4, Fisis4,Beseses4, Fisisis4, Gis4,Beses4, Ceseses5, Gisis4,Ais4, Ceses5, Deseseses5, Gisisis4,Aisis4, Ces5, Deseses5,Aisisis4, Bis4, Deses5, Eseseses5,Bisis4, Cis5, Eseses5,Bisisis4, Cisis5, Eses5, Feseses5,Cisisis5, Dis5, Feses5, Geseseses5,Disis5, Fes5, Geseses5,Aseseses5, Disisis5, Eis5, Geses5,Aseses5, Eisis5, Fis5,Ases5, Beseseses5, Eisisis5, Fisis5,Beseses5, Fisisis5, Gis5,Beses5, Ceseses6, Gisis5,Ais5, Ceses6, Deseseses6, Gisisis5,Aisis5, Ces6, Deseses6,Aisisis5, Bis5, Deses6, Eseseses6,Bisis5, Cis6, Eseses6,Bisisis5, Cisis6, Eses6, Feseses6,Cisisis6, Dis6, Feses6, Geseseses6,Disis6, Fes6, Geseses6,Aseseses6, Disisis6, Eis6, Geses6,Aseses6, Eisis6, Fis6,Ases6, Beseseses6, Eisisis6, Fisis6,Beseses6, Fisisis6, Gis6,Beses6, Ceseses7, Gisis6,Ais6, Ceses7, Deseseses7, Gisisis6,Aisis6, Ces7, Deseses7,Aisisis6, Bis6, Deses7, Eseseses7,Bisis6, Cis7, Eseses7,Bisisis6, Cisis7, Eses7, Feseses7,Cisisis7, Dis7, Feses7, Geseseses7,Disis7, Fes7, Geseses7,Aseseses7, Disisis7, Eis7, Geses7,Aseses7, Eisis7, Fis7,Ases7, Beseseses7, Eisisis7, Fisis7,Beseses7, Fisisis7, Gis7,Beses7, Ceseses8, Gisis7,Ais7, Ceses8, Deseseses8, Gisisis7,Aisis7, Ces8, Deseses8,Aisisis7, Bis7, Deses8, Eseseses8,Bisis7, Cis8, Eseses8,Bisisis7, Cisis8, Eses8, Feseses8,Cisisis8, Dis8, Feses8, Geseseses8,Disis8, Fes8, Geseses8,Aseseses8, Disisis8, Eis8, Geses8,Aseses8, Eisis8, Fis8,Ases8, Beseseses8, Eisisis8, Fisis8,Beseses8, Fisisis8, Gis8,Beses8, Ceseses9, Gisis8,Ais8, Ceses9, Deseseses9, Gisisis8,Aisis8, Ces9, Deseses9,Aisisis8, Bis8, Deses9, Eseseses9,Bisis8, Cis9, Eseses9,Bisisis8, Cisis9, Eses9, Feseses9,Cisisis9, Dis9, Feses9, Geseseses9,Disis9, Fes9, Geseses9,Aseseses9, Disisis9, Eis9, Geses9,Aseses9, Eisis9, Fis9,Ases9, Beseseses9, Eisisis9, Fisis9\n"
			+ "cbx_note_id_international_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Aisisis'''', Bis'''', Deses''', Eseseses''',Bisis'''', Cis''', Eseses''',Bisisis'''', Cisis''', Eses''', Feseses''',Cisisis''', Dis''', Feses''', Geseseses''',Disis''', Fes''', Geseses''',Aseseses''', Disisis''', Eis''', Geses''',Aseses''', Eisis''', Fis''',Ases''', Beseseses''', Eisisis''', Fisis''',Beseses''', Fisisis''', Gis''',Beses''', Ceseses'', Gisis''',Ais''', Ceses'', Deseseses'', Gisisis''',Aisis''', Ces'', Deseses'',Aisisis''', Bis''', Deses'', Eseseses'',Bisis''', Cis'', Eseses'',Bisisis''', Cisis'', Eses'', Feseses'',Cisisis'', Dis'', Feses'', Geseseses'',Disis'', Fes'', Geseses'',Aseseses'', Disisis'', Eis'', Geses'',Aseses'', Eisis'', Fis'',Ases'', Beseseses'', Eisisis'', Fisis'',Beseses'', Fisisis'', Gis'',Beses'', Ceseses', Gisis'',Ais'', Ceses', Deseseses', Gisisis'',Aisis'', Ces', Deseses',Aisisis'', Bis'', Deses', Eseseses',Bisis'', Cis', Eseses',Bisisis'', Cisis', Eses', Feseses',Cisisis', Dis', Feses', Geseseses',Disis', Fes', Geseses',Aseseses', Disisis', Eis', Geses',Aseses', Eisis', Fis',Ases', Beseseses', Eisisis', Fisis',Beseses', Fisisis', Gis',Beses', Ceseses, Gisis',Ais', Ceses, Deseseses, Gisisis',Aisis', Ces, Deseses,Aisisis', Bis', Deses, Eseseses,Bisis', Cis, Eseses,Bisisis', Cisis, Eses, Feseses,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseseses, Eisisis, Fisis,Beseses, Fisisis, Gis,Beses, Gisis, ceseses,Ais, Gisisis, ceses, deseseses,Aisis, ces, deseses,Aisisis, Bis, deses, eseseses,Bisis, cis, eseses,Bisisis, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseseses, eisisis, fisis,beseses, fisisis, gis,beses, ceseses', gisis,ais, ceses', deseseses', gisisis,aisis, ces', deseses',aisisis, bis, deses', eseseses',bisis, cis', eseses',bisisis, cisis', eses', feseses',cisisis', dis', feses', geseseses',disis', fes', geseses',aseseses', disisis', eis', geses',aseses', eisis', fis',ases', beseseses', eisisis', fisis',beseses', fisisis', gis',beses', ceseses'', gisis',ais', ceses'', deseseses'', gisisis',aisis', ces'', deseses'',aisisis', bis', deses'', eseseses'',bisis', cis'', eseses'',bisisis', cisis'', eses'', feseses'',cisisis'', dis'', feses'', geseseses'',disis'', fes'', geseses'',aseseses'', disisis'', eis'', geses'',aseses'', eisis'', fis'',ases'', beseseses'', eisisis'', fisis'',beseses'', fisisis'', gis'',beses'', ceseses''', gisis'',ais'', ceses''', deseseses''', gisisis'',aisis'', ces''', deseses''',aisisis'', bis'', deses''', eseseses''',bisis'', cis''', eseses''',bisisis'', cisis''', eses''', feseses''',cisisis''', dis''', feses''', geseseses''',disis''', fes''', geseses''',aseseses''', disisis''', eis''', geses''',aseses''', eisis''', fis''',ases''', beseseses''', eisisis''', fisis''',beseses''', fisisis''', gis''',beses''', ceseses'''', gisis''',ais''', ceses'''', deseseses'''', gisisis''',aisis''', ces'''', deseses'''',aisisis''', bis''', deses'''', eseseses'''',bisis''', cis'''', eseses'''',bisisis''', cisis'''', eses'''', feseses'''',cisisis'''', dis'''', feses'''', geseseses'''',disis'''', fes'''', geseses'''',aseseses'''', disisis'''', eis'''', geses'''',aseses'''', eisis'''', fis'''',ases'''', beseseses'''', eisisis'''', fisis'''',beseses'''', fisisis'''', gis'''',beses'''', ceseses''''', gisis'''',ais'''', ceses''''', deseseses''''', gisisis'''',aisis'''', ces''''', deseses''''',aisisis'''', bis'''', deses''''', eseseses''''',bisis'''', cis''''', eseses''''',bisisis'''', cisis''''', eses''''', feseses''''',cisisis''''', dis''''', feses''''', geseseses''''',disis''''', fes''''', geseses''''',aseseses''''', disisis''''', eis''''', geses''''',aseses''''', eisis''''', fis''''',ases''''', beseseses''''', eisisis''''', fisis''''',beseses''''', fisisis''''', gis''''',beses''''', ceseses'''''', gisis''''',ais''''', ceses'''''', deseseses'''''', gisisis''''',aisis''''', ces'''''', deseses'''''',aisisis''''', bis''''', deses'''''', eseseses'''''',bisis''''', cis'''''', eseses'''''',bisisis''''', cisis'''''', eses'''''', feseses'''''',cisisis'''''', dis'''''', feses'''''', geseseses'''''',disis'''''', fes'''''', geseses'''''',aseseses'''''', disisis'''''', eis'''''', geses'''''',aseses'''''', eisis'''''', fis'''''',ases'''''', beseseses'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "la###-6, rebb-5, si#-6,la####-6, mibbb-5, reb-5, si##-6,do##-5, fabbb-5, mibb-5, si###-6,do###-5, fabb-5, mib-5,do####-5, fab-5, re##-5, solbbb-5,mi#-5, re###-5, solbb-5,labbb-5, mi##-5, re####-5, solb-5,fa##-5, labb-5, mi###-5,fa###-5, lab-5, sibbb-5,dobbb-4, fa####-5, sibb-5, sol##-5,dobb-4, sib-5, sol###-5,dob-4, la##-5, rebbb-4, sol####-5,la###-5, rebb-4, si#-5,la####-5, mibbb-4, reb-4, si##-5,do##-4, fabbb-4, mibb-4, si###-5,do###-4, fabb-4, mib-4,do####-4, fab-4, re##-4, solbbb-4,mi#-4, re###-4, solbb-4,labbb-4, mi##-4, re####-4, solb-4,fa##-4, labb-4, mi###-4,fa###-4, lab-4, sibbb-4,dobbb-3, fa####-4, sibb-4, sol##-4,dobb-3, sib-4, sol###-4,dob-3, la##-4, rebbb-3, sol####-4,la###-4, rebb-3, si#-4,la####-4, mibbb-3, reb-3, si##-4,do##-3, fabbb-3, mibb-3, si###-4,do###-3, fabb-3, mib-3,do####-3, fab-3, re##-3, solbbb-3,mi#-3, re###-3, solbb-3,labbb-3, mi##-3, re####-3, solb-3,fa##-3, labb-3, mi###-3,fa###-3, lab-3, sibbb-3,dobbb-2, fa####-3, sibb-3, sol##-3,dobb-2, sib-3, sol###-3,dob-2, la##-3, rebbb-2, sol####-3,la###-3, rebb-2, si#-3,la####-3, mibbb-2, reb-2, si##-3,do##-2, fabbb-2, mibb-2, si###-3,do###-2, fabb-2, mib-2,do####-2, fab-2, re##-2, solbbb-2,mi#-2, re###-2, solbb-2,labbb-2, mi##-2, re####-2, solb-2,fa##-2, labb-2, mi###-2,fa###-2, lab-2, sibbb-2,dobbb-, fa####-2, sibb-2, sol##-2,dobb-, sib-2, sol###-2,dob-, la##-2, rebbb-, sol####-2,la###-2, rebb-, si#-2,la####-2, mibbb-, reb-, si##-2,do##-, fabbb-, mibb-, si###-2,do###-, fabb-, mib-,do####-, fab-, re##-, solbbb-,mi#-, re###-, solbb-,labbb-, mi##-, re####-, solb-,fa##-, labb-, mi###-,fa###-, lab-, sibbb-,dobbb, fa####-, sibb-, sol##-,dobb, sib-, sol###-,dob, la##-, rebbb, sol####-,la###-, rebb, si#-,la####-, mibbb, reb, si##-,do##, fabbb, mibb, si###-,do###, fabb, mib,do####, fab, re##, solbbb,mi#, re###, solbb,labbb, mi##, re####, solb,fa##, labb, mi###,fa###, lab, sibbb,dobbb+, fa####, sibb, sol##,dobb+, sib, sol###,dob+, la##, rebbb+, sol####,la###, rebb+, si#,la####, mibbb+, reb+, si##,do##+, fabbb+, mibb+, si###,do###+, fabb+, mib+,do####+, fab+, re##+, solbbb+,mi#+, re###+, solbb+,labbb+, mi##+, re####+, solb+,fa##+, labb+, mi###+,fa###+, lab+, sibbb+,dobbb+2, fa####+, sibb+, sol##+,dobb+2, sib+, sol###+,dob+2, la##+, rebbb+2, sol####+,la###+, rebb+2, si#+,la####+, mibbb+2, reb+2, si##+,do##+2, fabbb+2, mibb+2, si###+,do###+2, fabb+2, mib+2,do####+2, fab+2, re##+2, solbbb+2,mi#+2, re###+2, solbb+2,labbb+2, mi##+2, re####+2, solb+2,fa##+2, labb+2, mi###+2,fa###+2, lab+2, sibbb+2,dobbb+3, fa####+2, sibb+2, sol##+2,dobb+3, sib+2, sol###+2,dob+3, la##+2, rebbb+3, sol####+2,la###+2, rebb+3, si#+2,la####+2, mibbb+3, reb+3, si##+2,do##+3, fabbb+3, mibb+3, si###+2,do###+3, fabb+3, mib+3,do####+3, fab+3, re##+3, solbbb+3,mi#+3, re###+3, solbb+3,labbb+3, mi##+3, re####+3, solb+3,fa##+3, labb+3, mi###+3,fa###+3, lab+3, sibbb+3,dobbb+4, fa####+3, sibb+3, sol##+3,dobb+4, sib+3, sol###+3,dob+4, la##+3, rebbb+4, sol####+3,la###+3, rebb+4, si#+3,la####+3, mibbb+4, reb+4, si##+3,do##+4, fabbb+4, mibb+4, si###+3,do###+4, fabb+4, mib+4,do####+4, fab+4, re##+4, solbbb+4,mi#+4, re###+4, solbb+4,labbb+4, mi##+4, re####+4, solb+4,fa##+4, labb+4, mi###+4,fa###+4, lab+4, sibbb+4,dobbb+5, fa####+4, sibb+4, sol##+4,dobb+5, sib+4, sol###+4,dob+5, la##+4, rebbb+5, sol####+4,la###+4, rebb+5, si#+4,la####+4, mibbb+5, reb+5, si##+4,do##+5, fabbb+5, mibb+5, si###+4,do###+5, fabb+5, mib+5,do####+5, fab+5, re##+5, solbbb+5,mi#+5, re###+5, solbb+5,labbb+5, mi##+5, re####+5, solb+5,fa##+5, labb+5, mi###+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "la###------, rebb-----, si#------,la####------, mibbb-----, reb-----, si##------,do##-----, fabbb-----, mibb-----, si###------,do###-----, fabb-----, mib-----,do####-----, fab-----, re##-----, solbbb-----,mi#-----, re###-----, solbb-----,labbb-----, mi##-----, re####-----, solb-----,fa##-----, labb-----, mi###-----,fa###-----, lab-----, sibbb-----,dobbb----, fa####-----, sibb-----, sol##-----,dobb----, sib-----, sol###-----,dob----, la##-----, rebbb----, sol####-----,la###-----, rebb----, si#-----,la####-----, mibbb----, reb----, si##-----,do##----, fabbb----, mibb----, si###-----,do###----, fabb----, mib----,do####----, fab----, re##----, solbbb----,mi#----, re###----, solbb----,labbb----, mi##----, re####----, solb----,fa##----, labb----, mi###----,fa###----, lab----, sibbb----,dobbb---, fa####----, sibb----, sol##----,dobb---, sib----, sol###----,dob---, la##----, rebbb---, sol####----,la###----, rebb---, si#----,la####----, mibbb---, reb---, si##----,do##---, fabbb---, mibb---, si###----,do###---, fabb---, mib---,do####---, fab---, re##---, solbbb---,mi#---, re###---, solbb---,labbb---, mi##---, re####---, solb---,fa##---, labb---, mi###---,fa###---, lab---, sibbb---,dobbb--, fa####---, sibb---, sol##---,dobb--, sib---, sol###---,dob--, la##---, rebbb--, sol####---,la###---, rebb--, si#---,la####---, mibbb--, reb--, si##---,do##--, fabbb--, mibb--, si###---,do###--, fabb--, mib--,do####--, fab--, re##--, solbbb--,mi#--, re###--, solbb--,labbb--, mi##--, re####--, solb--,fa##--, labb--, mi###--,fa###--, lab--, sibbb--,dobbb-, fa####--, sibb--, sol##--,dobb-, sib--, sol###--,dob-, la##--, rebbb-, sol####--,la###--, rebb-, si#--,la####--, mibbb-, reb-, si##--,do##-, fabbb-, mibb-, si###--,do###-, fabb-, mib-,do####-, fab-, re##-, solbbb-,mi#-, re###-, solbb-,labbb-, mi##-, re####-, solb-,fa##-, labb-, mi###-,fa###-, lab-, sibbb-,dobbb, fa####-, sibb-, sol##-,dobb, sib-, sol###-,dob, la##-, rebbb, sol####-,la###-, rebb, si#-,la####-, mibbb, reb, si##-,do##, fabbb, mibb, si###-,do###, fabb, mib,do####, fab, re##, solbbb,mi#, re###, solbb,labbb, mi##, re####, solb,fa##, labb, mi###,fa###, lab, sibbb,dobbb+, fa####, sibb, sol##,dobb+, sib, sol###,dob+, la##, rebbb+, sol####,la###, rebb+, si#,la####, mibbb+, reb+, si##,do##+, fabbb+, mibb+, si###,do###+, fabb+, mib+,do####+, fab+, re##+, solbbb+,mi#+, re###+, solbb+,labbb+, mi##+, re####+, solb+,fa##+, labb+, mi###+,fa###+, lab+, sibbb+,dobbb++, fa####+, sibb+, sol##+,dobb++, sib+, sol###+,dob++, la##+, rebbb++, sol####+,la###+, rebb++, si#+,la####+, mibbb++, reb++, si##+,do##++, fabbb++, mibb++, si###+,do###++, fabb++, mib++,do####++, fab++, re##++, solbbb++,mi#++, re###++, solbb++,labbb++, mi##++, re####++, solb++,fa##++, labb++, mi###++,fa###++, lab++, sibbb++,dobbb+++, fa####++, sibb++, sol##++,dobb+++, sib++, sol###++,dob+++, la##++, rebbb+++, sol####++,la###++, rebb+++, si#++,la####++, mibbb+++, reb+++, si##++,do##+++, fabbb+++, mibb+++, si###++,do###+++, fabb+++, mib+++,do####+++, fab+++, re##+++, solbbb+++,mi#+++, re###+++, solbb+++,labbb+++, mi##+++, re####+++, solb+++,fa##+++, labb+++, mi###+++,fa###+++, lab+++, sibbb+++,dobbb++++, fa####+++, sibb+++, sol##+++,dobb++++, sib+++, sol###+++,dob++++, la##+++, rebbb++++, sol####+++,la###+++, rebb++++, si#+++,la####+++, mibbb++++, reb++++, si##+++,do##++++, fabbb++++, mibb++++, si###+++,do###++++, fabb++++, mib++++,do####++++, fab++++, re##++++, solbbb++++,mi#++++, re###++++, solbb++++,labbb++++, mi##++++, re####++++, solb++++,fa##++++, labb++++, mi###++++,fa###++++, lab++++, sibbb++++,dobbb+++++, fa####++++, sibb++++, sol##++++,dobb+++++, sib++++, sol###++++,dob+++++, la##++++, rebbb+++++, sol####++++,la###++++, rebb+++++, si#++++,la####++++, mibbb+++++, reb+++++, si##++++,do##+++++, fabbb+++++, mibb+++++, si###++++,do###+++++, fabb+++++, mib+++++,do####+++++, fab+++++, re##+++++, solbbb+++++,mi#+++++, re###+++++, solbb+++++,labbb+++++, mi##+++++, re####+++++, solb+++++,fa##+++++, labb+++++, mi###+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "la###-2, rebb-1, si#-2,la####-2, mibbb-1, reb-1, si##-2,do##-1, fabbb-1, mibb-1, si###-2,do###-1, fabb-1, mib-1,do####-1, fab-1, re##-1, solbbb-1,mi#-1, re###-1, solbb-1,labbb-1, mi##-1, re####-1, solb-1,fa##-1, labb-1, mi###-1,fa###-1, lab-1, sibbb-1,dobbb0, fa####-1, sibb-1, sol##-1,dobb0, sib-1, sol###-1,dob0, la##-1, rebbb0, sol####-1,la###-1, rebb0, si#-1,la####-1, mibbb0, reb0, si##-1,do##0, fabbb0, mibb0, si###-1,do###0, fabb0, mib0,do####0, fab0, re##0, solbbb0,mi#0, re###0, solbb0,labbb0, mi##0, re####0, solb0,fa##0, labb0, mi###0,fa###0, lab0, sibbb0,dobbb1, fa####0, sibb0, sol##0,dobb1, sib0, sol###0,dob1, la##0, rebbb1, sol####0,la###0, rebb1, si#0,la####0, mibbb1, reb1, si##0,do##1, fabbb1, mibb1, si###0,do###1, fabb1, mib1,do####1, fab1, re##1, solbbb1,mi#1, re###1, solbb1,labbb1, mi##1, re####1, solb1,fa##1, labb1, mi###1,fa###1, lab1, sibbb1,dobbb2, fa####1, sibb1, sol##1,dobb2, sib1, sol###1,dob2, la##1, rebbb2, sol####1,la###1, rebb2, si#1,la####1, mibbb2, reb2, si##1,do##2, fabbb2, mibb2, si###1,do###2, fabb2, mib2,do####2, fab2, re##2, solbbb2,mi#2, re###2, solbb2,labbb2, mi##2, re####2, solb2,fa##2, labb2, mi###2,fa###2, lab2, sibbb2,dobbb3, fa####2, sibb2, sol##2,dobb3, sib2, sol###2,dob3, la##2, rebbb3, sol####2,la###2, rebb3, si#2,la####2, mibbb3, reb3, si##2,do##3, fabbb3, mibb3, si###2,do###3, fabb3, mib3,do####3, fab3, re##3, solbbb3,mi#3, re###3, solbb3,labbb3, mi##3, re####3, solb3,fa##3, labb3, mi###3,fa###3, lab3, sibbb3,dobbb4, fa####3, sibb3, sol##3,dobb4, sib3, sol###3,dob4, la##3, rebbb4, sol####3,la###3, rebb4, si#3,la####3, mibbb4, reb4, si##3,do##4, fabbb4, mibb4, si###3,do###4, fabb4, mib4,do####4, fab4, re##4, solbbb4,mi#4, re###4, solbb4,labbb4, mi##4, re####4, solb4,fa##4, labb4, mi###4,fa###4, lab4, sibbb4,dobbb5, fa####4, sibb4, sol##4,dobb5, sib4, sol###4,dob5, la##4, rebbb5, sol####4,la###4, rebb5, si#4,la####4, mibbb5, reb5, si##4,do##5, fabbb5, mibb5, si###4,do###5, fabb5, mib5,do####5, fab5, re##5, solbbb5,mi#5, re###5, solbb5,labbb5, mi##5, re####5, solb5,fa##5, labb5, mi###5,fa###5, lab5, sibbb5,dobbb6, fa####5, sibb5, sol##5,dobb6, sib5, sol###5,dob6, la##5, rebbb6, sol####5,la###5, rebb6, si#5,la####5, mibbb6, reb6, si##5,do##6, fabbb6, mibb6, si###5,do###6, fabb6, mib6,do####6, fab6, re##6, solbbb6,mi#6, re###6, solbb6,labbb6, mi##6, re####6, solb6,fa##6, labb6, mi###6,fa###6, lab6, sibbb6,dobbb7, fa####6, sibb6, sol##6,dobb7, sib6, sol###6,dob7, la##6, rebbb7, sol####6,la###6, rebb7, si#6,la####6, mibbb7, reb7, si##6,do##7, fabbb7, mibb7, si###6,do###7, fabb7, mib7,do####7, fab7, re##7, solbbb7,mi#7, re###7, solbb7,labbb7, mi##7, re####7, solb7,fa##7, labb7, mi###7,fa###7, lab7, sibbb7,dobbb8, fa####7, sibb7, sol##7,dobb8, sib7, sol###7,dob8, la##7, rebbb8, sol####7,la###7, rebb8, si#7,la####7, mibbb8, reb8, si##7,do##8, fabbb8, mibb8, si###7,do###8, fabb8, mib8,do####8, fab8, re##8, solbbb8,mi#8, re###8, solbb8,labbb8, mi##8, re####8, solb8,fa##8, labb8, mi###8,fa###8, lab8, sibbb8,dobbb9, fa####8, sibb8, sol##8,dobb9, sib8, sol###8,dob9, la##8, rebbb9, sol####8,la###8, rebb9, si#8,la####8, mibbb9, reb9, si##8,do##9, fabbb9, mibb9, si###8,do###9, fabb9, mib9,do####9, fab9, re##9, solbbb9,mi#9, re###9, solbb9,labbb9, mi##9, re####9, solb9,fa##9, labb9, mi###9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "La###'''', Rebb''', Si#'''',La####'''', Mibbb''', Reb''', Si##'''',Do##''', Fabbb''', Mibb''', Si###'''',Do###''', Fabb''', Mib''',Do####''', Fab''', Re##''', Solbbb''',Mi#''', Re###''', Solbb''',Labbb''', Mi##''', Re####''', Solb''',Fa##''', Labb''', Mi###''',Fa###''', Lab''', Sibbb''',Dobbb'', Fa####''', Sibb''', Sol##''',Dobb'', Sib''', Sol###''',Dob'', La##''', Rebbb'', Sol####''',La###''', Rebb'', Si#''',La####''', Mibbb'', Reb'', Si##''',Do##'', Fabbb'', Mibb'', Si###''',Do###'', Fabb'', Mib'',Do####'', Fab'', Re##'', Solbbb'',Mi#'', Re###'', Solbb'',Labbb'', Mi##'', Re####'', Solb'',Fa##'', Labb'', Mi###'',Fa###'', Lab'', Sibbb'',Dobbb', Fa####'', Sibb'', Sol##'',Dobb', Sib'', Sol###'',Dob', La##'', Rebbb', Sol####'',La###'', Rebb', Si#'',La####'', Mibbb', Reb', Si##'',Do##', Fabbb', Mibb', Si###'',Do###', Fabb', Mib',Do####', Fab', Re##', Solbbb',Mi#', Re###', Solbb',Labbb', Mi##', Re####', Solb',Fa##', Labb', Mi###',Fa###', Lab', Sibbb',Dobbb, Fa####', Sibb', Sol##',Dobb, Sib', Sol###',Dob, La##', Rebbb, Sol####',La###', Rebb, Si#',La####', Mibbb, Reb, Si##',Do##, Fabbb, Mibb, Si###',Do###, Fabb, Mib,Do####, Fab, Re##, Solbbb,Mi#, Re###, Solbb,Labbb, Mi##, Re####, Solb,Fa##, Labb, Mi###,Fa###, Lab, Sibbb,Fa####, Sibb, Sol##, dobbb,Sib, Sol###, dobb,La##, Sol####, dob, rebbb,La###, Si#, rebb,La####, Si##, mibbb, reb,Si###, do##, fabbb, mibb,do###, fabb, mib,do####, fab, re##, solbbb,mi#, re###, solbb,labbb, mi##, re####, solb,fa##, labb, mi###,fa###, lab, sibbb,dobbb', fa####, sibb, sol##,dobb', sib, sol###,dob', la##, rebbb', sol####,la###, rebb', si#,la####, mibbb', reb', si##,do##', fabbb', mibb', si###,do###', fabb', mib',do####', fab', re##', solbbb',mi#', re###', solbb',labbb', mi##', re####', solb',fa##', labb', mi###',fa###', lab', sibbb',dobbb'', fa####', sibb', sol##',dobb'', sib', sol###',dob'', la##', rebbb'', sol####',la###', rebb'', si#',la####', mibbb'', reb'', si##',do##'', fabbb'', mibb'', si###',do###'', fabb'', mib'',do####'', fab'', re##'', solbbb'',mi#'', re###'', solbb'',labbb'', mi##'', re####'', solb'',fa##'', labb'', mi###'',fa###'', lab'', sibbb'',dobbb''', fa####'', sibb'', sol##'',dobb''', sib'', sol###'',dob''', la##'', rebbb''', sol####'',la###'', rebb''', si#'',la####'', mibbb''', reb''', si##'',do##''', fabbb''', mibb''', si###'',do###''', fabb''', mib''',do####''', fab''', re##''', solbbb''',mi#''', re###''', solbb''',labbb''', mi##''', re####''', solb''',fa##''', labb''', mi###''',fa###''', lab''', sibbb''',dobbb'''', fa####''', sibb''', sol##''',dobb'''', sib''', sol###''',dob'''', la##''', rebbb'''', sol####''',la###''', rebb'''', si#''',la####''', mibbb'''', reb'''', si##''',do##'''', fabbb'''', mibb'''', si###''',do###'''', fabb'''', mib'''',do####'''', fab'''', re##'''', solbbb'''',mi#'''', re###'''', solbb'''',labbb'''', mi##'''', re####'''', solb'''',fa##'''', labb'''', mi###'''',fa###'''', lab'''', sibbb'''',dobbb''''', fa####'''', sibb'''', sol##'''',dobb''''', sib'''', sol###'''',dob''''', la##'''', rebbb''''', sol####'''',la###'''', rebb''''', si#'''',la####'''', mibbb''''', reb''''', si##'''',do##''''', fabbb''''', mibb''''', si###'''',do###''''', fabb''''', mib''''',do####''''', fab''''', re##''''', solbbb''''',mi#''''', re###''''', solbb''''',labbb''''', mi##''''', re####''''', solb''''',fa##''''', labb''''', mi###''''',fa###''''', lab''''', sibbb''''',dobbb'''''', fa####''''', sibb''''', sol##''''',dobb'''''', sib''''', sol###''''',dob'''''', la##''''', rebbb'''''', sol####''''',la###''''', rebb'''''', si#''''',la####''''', mibbb'''''', reb'''''', si##''''',do##'''''', fabbb'''''', mibb'''''', si###''''',do###'''''', fabb'''''', mib'''''',do####'''''', fab'''''', re##'''''', solbbb'''''',mi#'''''', re###'''''', solbb'''''',labbb'''''', mi##'''''', re####'''''', solb'''''',fa##'''''', labb'''''', mi###''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "la###-6, mibbbb-5, rebb-5, si#-6,do#-5, mibbb-5, si##-6,do##-5, fabbb-5, mibb-5, si###-6,do###-5, fabb-5, re#-5, solbbbb-5,fab-5, re##-5, solbbb-5,labbbb-5, mi#-5, re###-5, solbb-5,fa#-5, labbb-5, mi##-5,fa##-5, labb-5, mi###-5, sibbbb-5,fa###-5, sibbb-5, sol#-5,dobbb-4, sibb-5, sol##-5,dobb-4, la#-5, rebbbb-4, sol###-5,dob-4, la##-5, rebbb-4,la###-5, mibbbb-4, rebb-4, si#-5,do#-4, mibbb-4, si##-5,do##-4, fabbb-4, mibb-4, si###-5,do###-4, fabb-4, re#-4, solbbbb-4,fab-4, re##-4, solbbb-4,labbbb-4, mi#-4, re###-4, solbb-4,fa#-4, labbb-4, mi##-4,fa##-4, labb-4, mi###-4, sibbbb-4,fa###-4, sibbb-4, sol#-4,dobbb-3, sibb-4, sol##-4,dobb-3, la#-4, rebbbb-3, sol###-4,dob-3, la##-4, rebbb-3,la###-4, mibbbb-3, rebb-3, si#-4,do#-3, mibbb-3, si##-4,do##-3, fabbb-3, mibb-3, si###-4,do###-3, fabb-3, re#-3, solbbbb-3,fab-3, re##-3, solbbb-3,labbbb-3, mi#-3, re###-3, solbb-3,fa#-3, labbb-3, mi##-3,fa##-3, labb-3, mi###-3, sibbbb-3,fa###-3, sibbb-3, sol#-3,dobbb-2, sibb-3, sol##-3,dobb-2, la#-3, rebbbb-2, sol###-3,dob-2, la##-3, rebbb-2,la###-3, mibbbb-2, rebb-2, si#-3,do#-2, mibbb-2, si##-3,do##-2, fabbb-2, mibb-2, si###-3,do###-2, fabb-2, re#-2, solbbbb-2,fab-2, re##-2, solbbb-2,labbbb-2, mi#-2, re###-2, solbb-2,fa#-2, labbb-2, mi##-2,fa##-2, labb-2, mi###-2, sibbbb-2,fa###-2, sibbb-2, sol#-2,dobbb-, sibb-2, sol##-2,dobb-, la#-2, rebbbb-, sol###-2,dob-, la##-2, rebbb-,la###-2, mibbbb-, rebb-, si#-2,do#-, mibbb-, si##-2,do##-, fabbb-, mibb-, si###-2,do###-, fabb-, re#-, solbbbb-,fab-, re##-, solbbb-,labbbb-, mi#-, re###-, solbb-,fa#-, labbb-, mi##-,fa##-, labb-, mi###-, sibbbb-,fa###-, sibbb-, sol#-,dobbb, sibb-, sol##-,dobb, la#-, rebbbb, sol###-,dob, la##-, rebbb,la###-, mibbbb, rebb, si#-,do#, mibbb, si##-,do##, fabbb, mibb, si###-,do###, fabb, re#, solbbbb,fab, re##, solbbb,labbbb, mi#, re###, solbb,fa#, labbb, mi##,fa##, labb, mi###, sibbbb,fa###, sibbb, sol#,dobbb+, sibb, sol##,dobb+, la#, rebbbb+, sol###,dob+, la##, rebbb+,la###, mibbbb+, rebb+, si#,do#+, mibbb+, si##,do##+, fabbb+, mibb+, si###,do###+, fabb+, re#+, solbbbb+,fab+, re##+, solbbb+,labbbb+, mi#+, re###+, solbb+,fa#+, labbb+, mi##+,fa##+, labb+, mi###+, sibbbb+,fa###+, sibbb+, sol#+,dobbb+2, sibb+, sol##+,dobb+2, la#+, rebbbb+2, sol###+,dob+2, la##+, rebbb+2,la###+, mibbbb+2, rebb+2, si#+,do#+2, mibbb+2, si##+,do##+2, fabbb+2, mibb+2, si###+,do###+2, fabb+2, re#+2, solbbbb+2,fab+2, re##+2, solbbb+2,labbbb+2, mi#+2, re###+2, solbb+2,fa#+2, labbb+2, mi##+2,fa##+2, labb+2, mi###+2, sibbbb+2,fa###+2, sibbb+2, sol#+2,dobbb+3, sibb+2, sol##+2,dobb+3, la#+2, rebbbb+3, sol###+2,dob+3, la##+2, rebbb+3,la###+2, mibbbb+3, rebb+3, si#+2,do#+3, mibbb+3, si##+2,do##+3, fabbb+3, mibb+3, si###+2,do###+3, fabb+3, re#+3, solbbbb+3,fab+3, re##+3, solbbb+3,labbbb+3, mi#+3, re###+3, solbb+3,fa#+3, labbb+3, mi##+3,fa##+3, labb+3, mi###+3, sibbbb+3,fa###+3, sibbb+3, sol#+3,dobbb+4, sibb+3, sol##+3,dobb+4, la#+3, rebbbb+4, sol###+3,dob+4, la##+3, rebbb+4,la###+3, mibbbb+4, rebb+4, si#+3,do#+4, mibbb+4, si##+3,do##+4, fabbb+4, mibb+4, si###+3,do###+4, fabb+4, re#+4, solbbbb+4,fab+4, re##+4, solbbb+4,labbbb+4, mi#+4, re###+4, solbb+4,fa#+4, labbb+4, mi##+4,fa##+4, labb+4, mi###+4, sibbbb+4,fa###+4, sibbb+4, sol#+4,dobbb+5, sibb+4, sol##+4,dobb+5, la#+4, rebbbb+5, sol###+4,dob+5, la##+4, rebbb+5,la###+4, mibbbb+5, rebb+5, si#+4,do#+5, mibbb+5, si##+4,do##+5, fabbb+5, mibb+5, si###+4,do###+5, fabb+5, re#+5, solbbbb+5,fab+5, re##+5, solbbb+5,labbbb+5, mi#+5, re###+5, solbb+5,fa#+5, labbb+5, mi##+5,fa##+5, labb+5, mi###+5, sibbbb+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "la###------, mibbbb-----, rebb-----, si#------,do#-----, mibbb-----, si##------,do##-----, fabbb-----, mibb-----, si###------,do###-----, fabb-----, re#-----, solbbbb-----,fab-----, re##-----, solbbb-----,labbbb-----, mi#-----, re###-----, solbb-----,fa#-----, labbb-----, mi##-----,fa##-----, labb-----, mi###-----, sibbbb-----,fa###-----, sibbb-----, sol#-----,dobbb----, sibb-----, sol##-----,dobb----, la#-----, rebbbb----, sol###-----,dob----, la##-----, rebbb----,la###-----, mibbbb----, rebb----, si#-----,do#----, mibbb----, si##-----,do##----, fabbb----, mibb----, si###-----,do###----, fabb----, re#----, solbbbb----,fab----, re##----, solbbb----,labbbb----, mi#----, re###----, solbb----,fa#----, labbb----, mi##----,fa##----, labb----, mi###----, sibbbb----,fa###----, sibbb----, sol#----,dobbb---, sibb----, sol##----,dobb---, la#----, rebbbb---, sol###----,dob---, la##----, rebbb---,la###----, mibbbb---, rebb---, si#----,do#---, mibbb---, si##----,do##---, fabbb---, mibb---, si###----,do###---, fabb---, re#---, solbbbb---,fab---, re##---, solbbb---,labbbb---, mi#---, re###---, solbb---,fa#---, labbb---, mi##---,fa##---, labb---, mi###---, sibbbb---,fa###---, sibbb---, sol#---,dobbb--, sibb---, sol##---,dobb--, la#---, rebbbb--, sol###---,dob--, la##---, rebbb--,la###---, mibbbb--, rebb--, si#---,do#--, mibbb--, si##---,do##--, fabbb--, mibb--, si###---,do###--, fabb--, re#--, solbbbb--,fab--, re##--, solbbb--,labbbb--, mi#--, re###--, solbb--,fa#--, labbb--, mi##--,fa##--, labb--, mi###--, sibbbb--,fa###--, sibbb--, sol#--,dobbb-, sibb--, sol##--,dobb-, la#--, rebbbb-, sol###--,dob-, la##--, rebbb-,la###--, mibbbb-, rebb-, si#--,do#-, mibbb-, si##--,do##-, fabbb-, mibb-, si###--,do###-, fabb-, re#-, solbbbb-,fab-, re##-, solbbb-,labbbb-, mi#-, re###-, solbb-,fa#-, labbb-, mi##-,fa##-, labb-, mi###-, sibbbb-,fa###-, sibbb-, sol#-,dobbb, sibb-, sol##-,dobb, la#-, rebbbb, sol###-,dob, la##-, rebbb,la###-, mibbbb, rebb, si#-,do#, mibbb, si##-,do##, fabbb, mibb, si###-,do###, fabb, re#, solbbbb,fab, re##, solbbb,labbbb, mi#, re###, solbb,fa#, labbb, mi##,fa##, labb, mi###, sibbbb,fa###, sibbb, sol#,dobbb+, sibb, sol##,dobb+, la#, rebbbb+, sol###,dob+, la##, rebbb+,la###, mibbbb+, rebb+, si#,do#+, mibbb+, si##,do##+, fabbb+, mibb+, si###,do###+, fabb+, re#+, solbbbb+,fab+, re##+, solbbb+,labbbb+, mi#+, re###+, solbb+,fa#+, labbb+, mi##+,fa##+, labb+, mi###+, sibbbb+,fa###+, sibbb+, sol#+,dobbb++, sibb+, sol##+,dobb++, la#+, rebbbb++, sol###+,dob++, la##+, rebbb++,la###+, mibbbb++, rebb++, si#+,do#++, mibbb++, si##+,do##++, fabbb++, mibb++, si###+,do###++, fabb++, re#++, solbbbb++,fab++, re##++, solbbb++,labbbb++, mi#++, re###++, solbb++,fa#++, labbb++, mi##++,fa##++, labb++, mi###++, sibbbb++,fa###++, sibbb++, sol#++,dobbb+++, sibb++, sol##++,dobb+++, la#++, rebbbb+++, sol###++,dob+++, la##++, rebbb+++,la###++, mibbbb+++, rebb+++, si#++,do#+++, mibbb+++, si##++,do##+++, fabbb+++, mibb+++, si###++,do###+++, fabb+++, re#+++, solbbbb+++,fab+++, re##+++, solbbb+++,labbbb+++, mi#+++, re###+++, solbb+++,fa#+++, labbb+++, mi##+++,fa##+++, labb+++, mi###+++, sibbbb+++,fa###+++, sibbb+++, sol#+++,dobbb++++, sibb+++, sol##+++,dobb++++, la#+++, rebbbb++++, sol###+++,dob++++, la##+++, rebbb++++,la###+++, mibbbb++++, rebb++++, si#+++,do#++++, mibbb++++, si##+++,do##++++, fabbb++++, mibb++++, si###+++,do###++++, fabb++++, re#++++, solbbbb++++,fab++++, re##++++, solbbb++++,labbbb++++, mi#++++, re###++++, solbb++++,fa#++++, labbb++++, mi##++++,fa##++++, labb++++, mi###++++, sibbbb++++,fa###++++, sibbb++++, sol#++++,dobbb+++++, sibb++++, sol##++++,dobb+++++, la#++++, rebbbb+++++, sol###++++,dob+++++, la##++++, rebbb+++++,la###++++, mibbbb+++++, rebb+++++, si#++++,do#+++++, mibbb+++++, si##++++,do##+++++, fabbb+++++, mibb+++++, si###++++,do###+++++, fabb+++++, re#+++++, solbbbb+++++,fab+++++, re##+++++, solbbb+++++,labbbb+++++, mi#+++++, re###+++++, solbb+++++,fa#+++++, labbb+++++, mi##+++++,fa##+++++, labb+++++, mi###+++++, sibbbb+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "la###-2, mibbbb-1, rebb-1, si#-2,do#-1, mibbb-1, si##-2,do##-1, fabbb-1, mibb-1, si###-2,do###-1, fabb-1, re#-1, solbbbb-1,fab-1, re##-1, solbbb-1,labbbb-1, mi#-1, re###-1, solbb-1,fa#-1, labbb-1, mi##-1,fa##-1, labb-1, mi###-1, sibbbb-1,fa###-1, sibbb-1, sol#-1,dobbb0, sibb-1, sol##-1,dobb0, la#-1, rebbbb0, sol###-1,dob0, la##-1, rebbb0,la###-1, mibbbb0, rebb0, si#-1,do#0, mibbb0, si##-1,do##0, fabbb0, mibb0, si###-1,do###0, fabb0, re#0, solbbbb0,fab0, re##0, solbbb0,labbbb0, mi#0, re###0, solbb0,fa#0, labbb0, mi##0,fa##0, labb0, mi###0, sibbbb0,fa###0, sibbb0, sol#0,dobbb1, sibb0, sol##0,dobb1, la#0, rebbbb1, sol###0,dob1, la##0, rebbb1,la###0, mibbbb1, rebb1, si#0,do#1, mibbb1, si##0,do##1, fabbb1, mibb1, si###0,do###1, fabb1, re#1, solbbbb1,fab1, re##1, solbbb1,labbbb1, mi#1, re###1, solbb1,fa#1, labbb1, mi##1,fa##1, labb1, mi###1, sibbbb1,fa###1, sibbb1, sol#1,dobbb2, sibb1, sol##1,dobb2, la#1, rebbbb2, sol###1,dob2, la##1, rebbb2,la###1, mibbbb2, rebb2, si#1,do#2, mibbb2, si##1,do##2, fabbb2, mibb2, si###1,do###2, fabb2, re#2, solbbbb2,fab2, re##2, solbbb2,labbbb2, mi#2, re###2, solbb2,fa#2, labbb2, mi##2,fa##2, labb2, mi###2, sibbbb2,fa###2, sibbb2, sol#2,dobbb3, sibb2, sol##2,dobb3, la#2, rebbbb3, sol###2,dob3, la##2, rebbb3,la###2, mibbbb3, rebb3, si#2,do#3, mibbb3, si##2,do##3, fabbb3, mibb3, si###2,do###3, fabb3, re#3, solbbbb3,fab3, re##3, solbbb3,labbbb3, mi#3, re###3, solbb3,fa#3, labbb3, mi##3,fa##3, labb3, mi###3, sibbbb3,fa###3, sibbb3, sol#3,dobbb4, sibb3, sol##3,dobb4, la#3, rebbbb4, sol###3,dob4, la##3, rebbb4,la###3, mibbbb4, rebb4, si#3,do#4, mibbb4, si##3,do##4, fabbb4, mibb4, si###3,do###4, fabb4, re#4, solbbbb4,fab4, re##4, solbbb4,labbbb4, mi#4, re###4, solbb4,fa#4, labbb4, mi##4,fa##4, labb4, mi###4, sibbbb4,fa###4, sibbb4, sol#4,dobbb5, sibb4, sol##4,dobb5, la#4, rebbbb5, sol###4,dob5, la##4, rebbb5,la###4, mibbbb5, rebb5, si#4,do#5, mibbb5, si##4,do##5, fabbb5, mibb5, si###4,do###5, fabb5, re#5, solbbbb5,fab5, re##5, solbbb5,labbbb5, mi#5, re###5, solbb5,fa#5, labbb5, mi##5,fa##5, labb5, mi###5, sibbbb5,fa###5, sibbb5, sol#5,dobbb6, sibb5, sol##5,dobb6, la#5, rebbbb6, sol###5,dob6, la##5, rebbb6,la###5, mibbbb6, rebb6, si#5,do#6, mibbb6, si##5,do##6, fabbb6, mibb6, si###5,do###6, fabb6, re#6, solbbbb6,fab6, re##6, solbbb6,labbbb6, mi#6, re###6, solbb6,fa#6, labbb6, mi##6,fa##6, labb6, mi###6, sibbbb6,fa###6, sibbb6, sol#6,dobbb7, sibb6, sol##6,dobb7, la#6, rebbbb7, sol###6,dob7, la##6, rebbb7,la###6, mibbbb7, rebb7, si#6,do#7, mibbb7, si##6,do##7, fabbb7, mibb7, si###6,do###7, fabb7, re#7, solbbbb7,fab7, re##7, solbbb7,labbbb7, mi#7, re###7, solbb7,fa#7, labbb7, mi##7,fa##7, labb7, mi###7, sibbbb7,fa###7, sibbb7, sol#7,dobbb8, sibb7, sol##7,dobb8, la#7, rebbbb8, sol###7,dob8, la##7, rebbb8,la###7, mibbbb8, rebb8, si#7,do#8, mibbb8, si##7,do##8, fabbb8, mibb8, si###7,do###8, fabb8, re#8, solbbbb8,fab8, re##8, solbbb8,labbbb8, mi#8, re###8, solbb8,fa#8, labbb8, mi##8,fa##8, labb8, mi###8, sibbbb8,fa###8, sibbb8, sol#8,dobbb9, sibb8, sol##8,dobb9, la#8, rebbbb9, sol###8,dob9, la##8, rebbb9,la###8, mibbbb9, rebb9, si#8,do#9, mibbb9, si##8,do##9, fabbb9, mibb9, si###8,do###9, fabb9, re#9, solbbbb9,fab9, re##9, solbbb9,labbbb9, mi#9, re###9, solbb9,fa#9, labbb9, mi##9,fa##9, labb9, mi###9, sibbbb9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "La###'''', Mibbbb''', Rebb''', Si#'''',Do#''', Mibbb''', Si##'''',Do##''', Fabbb''', Mibb''', Si###'''',Do###''', Fabb''', Re#''', Solbbbb''',Fab''', Re##''', Solbbb''',Labbbb''', Mi#''', Re###''', Solbb''',Fa#''', Labbb''', Mi##''',Fa##''', Labb''', Mi###''', Sibbbb''',Fa###''', Sibbb''', Sol#''',Dobbb'', Sibb''', Sol##''',Dobb'', La#''', Rebbbb'', Sol###''',Dob'', La##''', Rebbb'',La###''', Mibbbb'', Rebb'', Si#''',Do#'', Mibbb'', Si##''',Do##'', Fabbb'', Mibb'', Si###''',Do###'', Fabb'', Re#'', Solbbbb'',Fab'', Re##'', Solbbb'',Labbbb'', Mi#'', Re###'', Solbb'',Fa#'', Labbb'', Mi##'',Fa##'', Labb'', Mi###'', Sibbbb'',Fa###'', Sibbb'', Sol#'',Dobbb', Sibb'', Sol##'',Dobb', La#'', Rebbbb', Sol###'',Dob', La##'', Rebbb',La###'', Mibbbb', Rebb', Si#'',Do#', Mibbb', Si##'',Do##', Fabbb', Mibb', Si###'',Do###', Fabb', Re#', Solbbbb',Fab', Re##', Solbbb',Labbbb', Mi#', Re###', Solbb',Fa#', Labbb', Mi##',Fa##', Labb', Mi###', Sibbbb',Fa###', Sibbb', Sol#',Dobbb, Sibb', Sol##',Dobb, La#', Rebbbb, Sol###',Dob, La##', Rebbb,La###', Mibbbb, Rebb, Si#',Do#, Mibbb, Si##',Do##, Fabbb, Mibb, Si###',Do###, Fabb, Re#, Solbbbb,Fab, Re##, Solbbb,Labbbb, Mi#, Re###, Solbb,Fa#, Labbb, Mi##,Fa##, Labb, Mi###, Sibbbb,Fa###, Sibbb, Sol#,Sibb, Sol##, dobbb,La#, Sol###, dobb, rebbbb,La##, dob, rebbb,La###, Si#, mibbbb, rebb,Si##, do#, mibbb,Si###, do##, fabbb, mibb,do###, fabb, re#, solbbbb,fab, re##, solbbb,labbbb, mi#, re###, solbb,fa#, labbb, mi##,fa##, labb, mi###, sibbbb,fa###, sibbb, sol#,dobbb', sibb, sol##,dobb', la#, rebbbb', sol###,dob', la##, rebbb',la###, mibbbb', rebb', si#,do#', mibbb', si##,do##', fabbb', mibb', si###,do###', fabb', re#', solbbbb',fab', re##', solbbb',labbbb', mi#', re###', solbb',fa#', labbb', mi##',fa##', labb', mi###', sibbbb',fa###', sibbb', sol#',dobbb'', sibb', sol##',dobb'', la#', rebbbb'', sol###',dob'', la##', rebbb'',la###', mibbbb'', rebb'', si#',do#'', mibbb'', si##',do##'', fabbb'', mibb'', si###',do###'', fabb'', re#'', solbbbb'',fab'', re##'', solbbb'',labbbb'', mi#'', re###'', solbb'',fa#'', labbb'', mi##'',fa##'', labb'', mi###'', sibbbb'',fa###'', sibbb'', sol#'',dobbb''', sibb'', sol##'',dobb''', la#'', rebbbb''', sol###'',dob''', la##'', rebbb''',la###'', mibbbb''', rebb''', si#'',do#''', mibbb''', si##'',do##''', fabbb''', mibb''', si###'',do###''', fabb''', re#''', solbbbb''',fab''', re##''', solbbb''',labbbb''', mi#''', re###''', solbb''',fa#''', labbb''', mi##''',fa##''', labb''', mi###''', sibbbb''',fa###''', sibbb''', sol#''',dobbb'''', sibb''', sol##''',dobb'''', la#''', rebbbb'''', sol###''',dob'''', la##''', rebbb'''',la###''', mibbbb'''', rebb'''', si#''',do#'''', mibbb'''', si##''',do##'''', fabbb'''', mibb'''', si###''',do###'''', fabb'''', re#'''', solbbbb'''',fab'''', re##'''', solbbb'''',labbbb'''', mi#'''', re###'''', solbb'''',fa#'''', labbb'''', mi##'''',fa##'''', labb'''', mi###'''', sibbbb'''',fa###'''', sibbb'''', sol#'''',dobbb''''', sibb'''', sol##'''',dobb''''', la#'''', rebbbb''''', sol###'''',dob''''', la##'''', rebbb''''',la###'''', mibbbb''''', rebb''''', si#'''',do#''''', mibbb''''', si##'''',do##''''', fabbb''''', mibb''''', si###'''',do###''''', fabb''''', re#''''', solbbbb''''',fab''''', re##''''', solbbb''''',labbbb''''', mi#''''', re###''''', solbb''''',fa#''''', labbb''''', mi##''''',fa##''''', labb''''', mi###''''', sibbbb''''',fa###''''', sibbb''''', sol#''''',dobbb'''''', sibb''''', sol##''''',dobb'''''', la#''''', rebbbb'''''', sol###''''',dob'''''', la##''''', rebbb'''''',la###''''', mibbbb'''''', rebb'''''', si#''''',do#'''''', mibbb'''''', si##''''',do##'''''', fabbb'''''', mibb'''''', si###''''',do###'''''', fabb'''''', re#'''''', solbbbb'''''',fab'''''', re##'''''', solbbb'''''',labbbb'''''', mi#'''''', re###'''''', solbb'''''',fa#'''''', labbb'''''', mi##'''''',fa##'''''', labb'''''', mi###'''''', sibbbb''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "la-diesis-diesis-diesis-6, re-bemolle-bemolle-5, si-diesis-6,la-diesis-diesis-diesis-diesis-6, mi-bemolle-bemolle-bemolle-5, re-bemolle-5, si-diesis-diesis-6,do-diesis-diesis-5, fa-bemolle-bemolle-bemolle-5, mi-bemolle-bemolle-5, si-diesis-diesis-diesis-6,do-diesis-diesis-diesis-5, fa-bemolle-bemolle-5, mi-bemolle-5,do-diesis-diesis-diesis-diesis-5, fa-bemolle-5, re-diesis-diesis-5, sol-bemolle-bemolle-bemolle-5,mi-diesis-5, re-diesis-diesis-diesis-5, sol-bemolle-bemolle-5,la-bemolle-bemolle-bemolle-5, mi-diesis-diesis-5, re-diesis-diesis-diesis-diesis-5, sol-bemolle-5,fa-diesis-diesis-5, la-bemolle-bemolle-5, mi-diesis-diesis-diesis-5,fa-diesis-diesis-diesis-5, la-bemolle-5, si-bemolle-bemolle-bemolle-5,do-bemolle-bemolle-bemolle-4, fa-diesis-diesis-diesis-diesis-5, si-bemolle-bemolle-5, sol-diesis-diesis-5,do-bemolle-bemolle-4, si-bemolle-5, sol-diesis-diesis-diesis-5,do-bemolle-4, la-diesis-diesis-5, re-bemolle-bemolle-bemolle-4, sol-diesis-diesis-diesis-diesis-5,la-diesis-diesis-diesis-5, re-bemolle-bemolle-4, si-diesis-5,la-diesis-diesis-diesis-diesis-5, mi-bemolle-bemolle-bemolle-4, re-bemolle-4, si-diesis-diesis-5,do-diesis-diesis-4, fa-bemolle-bemolle-bemolle-4, mi-bemolle-bemolle-4, si-diesis-diesis-diesis-5,do-diesis-diesis-diesis-4, fa-bemolle-bemolle-4, mi-bemolle-4,do-diesis-diesis-diesis-diesis-4, fa-bemolle-4, re-diesis-diesis-4, sol-bemolle-bemolle-bemolle-4,mi-diesis-4, re-diesis-diesis-diesis-4, sol-bemolle-bemolle-4,la-bemolle-bemolle-bemolle-4, mi-diesis-diesis-4, re-diesis-diesis-diesis-diesis-4, sol-bemolle-4,fa-diesis-diesis-4, la-bemolle-bemolle-4, mi-diesis-diesis-diesis-4,fa-diesis-diesis-diesis-4, la-bemolle-4, si-bemolle-bemolle-bemolle-4,do-bemolle-bemolle-bemolle-3, fa-diesis-diesis-diesis-diesis-4, si-bemolle-bemolle-4, sol-diesis-diesis-4,do-bemolle-bemolle-3, si-bemolle-4, sol-diesis-diesis-diesis-4,do-bemolle-3, la-diesis-diesis-4, re-bemolle-bemolle-bemolle-3, sol-diesis-diesis-diesis-diesis-4,la-diesis-diesis-diesis-4, re-bemolle-bemolle-3, si-diesis-4,la-diesis-diesis-diesis-diesis-4, mi-bemolle-bemolle-bemolle-3, re-bemolle-3, si-diesis-diesis-4,do-diesis-diesis-3, fa-bemolle-bemolle-bemolle-3, mi-bemolle-bemolle-3, si-diesis-diesis-diesis-4,do-diesis-diesis-diesis-3, fa-bemolle-bemolle-3, mi-bemolle-3,do-diesis-diesis-diesis-diesis-3, fa-bemolle-3, re-diesis-diesis-3, sol-bemolle-bemolle-bemolle-3,mi-diesis-3, re-diesis-diesis-diesis-3, sol-bemolle-bemolle-3,la-bemolle-bemolle-bemolle-3, mi-diesis-diesis-3, re-diesis-diesis-diesis-diesis-3, sol-bemolle-3,fa-diesis-diesis-3, la-bemolle-bemolle-3, mi-diesis-diesis-diesis-3,fa-diesis-diesis-diesis-3, la-bemolle-3, si-bemolle-bemolle-bemolle-3,do-bemolle-bemolle-bemolle-2, fa-diesis-diesis-diesis-diesis-3, si-bemolle-bemolle-3, sol-diesis-diesis-3,do-bemolle-bemolle-2, si-bemolle-3, sol-diesis-diesis-diesis-3,do-bemolle-2, la-diesis-diesis-3, re-bemolle-bemolle-bemolle-2, sol-diesis-diesis-diesis-diesis-3,la-diesis-diesis-diesis-3, re-bemolle-bemolle-2, si-diesis-3,la-diesis-diesis-diesis-diesis-3, mi-bemolle-bemolle-bemolle-2, re-bemolle-2, si-diesis-diesis-3,do-diesis-diesis-2, fa-bemolle-bemolle-bemolle-2, mi-bemolle-bemolle-2, si-diesis-diesis-diesis-3,do-diesis-diesis-diesis-2, fa-bemolle-bemolle-2, mi-bemolle-2,do-diesis-diesis-diesis-diesis-2, fa-bemolle-2, re-diesis-diesis-2, sol-bemolle-bemolle-bemolle-2,mi-diesis-2, re-diesis-diesis-diesis-2, sol-bemolle-bemolle-2,la-bemolle-bemolle-bemolle-2, mi-diesis-diesis-2, re-diesis-diesis-diesis-diesis-2, sol-bemolle-2,fa-diesis-diesis-2, la-bemolle-bemolle-2, mi-diesis-diesis-diesis-2,fa-diesis-diesis-diesis-2, la-bemolle-2, si-bemolle-bemolle-bemolle-2,do-bemolle-bemolle-bemolle-, fa-diesis-diesis-diesis-diesis-2, si-bemolle-bemolle-2, sol-diesis-diesis-2,do-bemolle-bemolle-, si-bemolle-2, sol-diesis-diesis-diesis-2,do-bemolle-, la-diesis-diesis-2, re-bemolle-bemolle-bemolle-, sol-diesis-diesis-diesis-diesis-2,la-diesis-diesis-diesis-2, re-bemolle-bemolle-, si-diesis-2,la-diesis-diesis-diesis-diesis-2, mi-bemolle-bemolle-bemolle-, re-bemolle-, si-diesis-diesis-2,do-diesis-diesis-, fa-bemolle-bemolle-bemolle-, mi-bemolle-bemolle-, si-diesis-diesis-diesis-2,do-diesis-diesis-diesis-, fa-bemolle-bemolle-, mi-bemolle-,do-diesis-diesis-diesis-diesis-, fa-bemolle-, re-diesis-diesis-, sol-bemolle-bemolle-bemolle-,mi-diesis-, re-diesis-diesis-diesis-, sol-bemolle-bemolle-,la-bemolle-bemolle-bemolle-, mi-diesis-diesis-, re-diesis-diesis-diesis-diesis-, sol-bemolle-,fa-diesis-diesis-, la-bemolle-bemolle-, mi-diesis-diesis-diesis-,fa-diesis-diesis-diesis-, la-bemolle-, si-bemolle-bemolle-bemolle-,do-bemolle-bemolle-bemolle, fa-diesis-diesis-diesis-diesis-, si-bemolle-bemolle-, sol-diesis-diesis-,do-bemolle-bemolle, si-bemolle-, sol-diesis-diesis-diesis-,do-bemolle, la-diesis-diesis-, re-bemolle-bemolle-bemolle, sol-diesis-diesis-diesis-diesis-,la-diesis-diesis-diesis-, re-bemolle-bemolle, si-diesis-,la-diesis-diesis-diesis-diesis-, mi-bemolle-bemolle-bemolle, re-bemolle, si-diesis-diesis-,do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle, si-diesis-diesis-diesis-,do-diesis-diesis-diesis, fa-bemolle-bemolle, mi-bemolle,do-diesis-diesis-diesis-diesis, fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,la-bemolle-bemolle-bemolle, mi-diesis-diesis, re-diesis-diesis-diesis-diesis, sol-bemolle,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis,fa-diesis-diesis-diesis, la-bemolle, si-bemolle-bemolle-bemolle,do-bemolle-bemolle-bemolle+, fa-diesis-diesis-diesis-diesis, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle+, si-bemolle, sol-diesis-diesis-diesis,do-bemolle+, la-diesis-diesis, re-bemolle-bemolle-bemolle+, sol-diesis-diesis-diesis-diesis,la-diesis-diesis-diesis, re-bemolle-bemolle+, si-diesis,la-diesis-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle+, re-bemolle+, si-diesis-diesis,do-diesis-diesis+, fa-bemolle-bemolle-bemolle+, mi-bemolle-bemolle+, si-diesis-diesis-diesis,do-diesis-diesis-diesis+, fa-bemolle-bemolle+, mi-bemolle+,do-diesis-diesis-diesis-diesis+, fa-bemolle+, re-diesis-diesis+, sol-bemolle-bemolle-bemolle+,mi-diesis+, re-diesis-diesis-diesis+, sol-bemolle-bemolle+,la-bemolle-bemolle-bemolle+, mi-diesis-diesis+, re-diesis-diesis-diesis-diesis+, sol-bemolle+,fa-diesis-diesis+, la-bemolle-bemolle+, mi-diesis-diesis-diesis+,fa-diesis-diesis-diesis+, la-bemolle+, si-bemolle-bemolle-bemolle+,do-bemolle-bemolle-bemolle+2, fa-diesis-diesis-diesis-diesis+, si-bemolle-bemolle+, sol-diesis-diesis+,do-bemolle-bemolle+2, si-bemolle+, sol-diesis-diesis-diesis+,do-bemolle+2, la-diesis-diesis+, re-bemolle-bemolle-bemolle+2, sol-diesis-diesis-diesis-diesis+,la-diesis-diesis-diesis+, re-bemolle-bemolle+2, si-diesis+,la-diesis-diesis-diesis-diesis+, mi-bemolle-bemolle-bemolle+2, re-bemolle+2, si-diesis-diesis+,do-diesis-diesis+2, fa-bemolle-bemolle-bemolle+2, mi-bemolle-bemolle+2, si-diesis-diesis-diesis+,do-diesis-diesis-diesis+2, fa-bemolle-bemolle+2, mi-bemolle+2,do-diesis-diesis-diesis-diesis+2, fa-bemolle+2, re-diesis-diesis+2, sol-bemolle-bemolle-bemolle+2,mi-diesis+2, re-diesis-diesis-diesis+2, sol-bemolle-bemolle+2,la-bemolle-bemolle-bemolle+2, mi-diesis-diesis+2, re-diesis-diesis-diesis-diesis+2, sol-bemolle+2,fa-diesis-diesis+2, la-bemolle-bemolle+2, mi-diesis-diesis-diesis+2,fa-diesis-diesis-diesis+2, la-bemolle+2, si-bemolle-bemolle-bemolle+2,do-bemolle-bemolle-bemolle+3, fa-diesis-diesis-diesis-diesis+2, si-bemolle-bemolle+2, sol-diesis-diesis+2,do-bemolle-bemolle+3, si-bemolle+2, sol-diesis-diesis-diesis+2,do-bemolle+3, la-diesis-diesis+2, re-bemolle-bemolle-bemolle+3, sol-diesis-diesis-diesis-diesis+2,la-diesis-diesis-diesis+2, re-bemolle-bemolle+3, si-diesis+2,la-diesis-diesis-diesis-diesis+2, mi-bemolle-bemolle-bemolle+3, re-bemolle+3, si-diesis-diesis+2,do-diesis-diesis+3, fa-bemolle-bemolle-bemolle+3, mi-bemolle-bemolle+3, si-diesis-diesis-diesis+2,do-diesis-diesis-diesis+3, fa-bemolle-bemolle+3, mi-bemolle+3,do-diesis-diesis-diesis-diesis+3, fa-bemolle+3, re-diesis-diesis+3, sol-bemolle-bemolle-bemolle+3,mi-diesis+3, re-diesis-diesis-diesis+3, sol-bemolle-bemolle+3,la-bemolle-bemolle-bemolle+3, mi-diesis-diesis+3, re-diesis-diesis-diesis-diesis+3, sol-bemolle+3,fa-diesis-diesis+3, la-bemolle-bemolle+3, mi-diesis-diesis-diesis+3,fa-diesis-diesis-diesis+3, la-bemolle+3, si-bemolle-bemolle-bemolle+3,do-bemolle-bemolle-bemolle+4, fa-diesis-diesis-diesis-diesis+3, si-bemolle-bemolle+3, sol-diesis-diesis+3,do-bemolle-bemolle+4, si-bemolle+3, sol-diesis-diesis-diesis+3,do-bemolle+4, la-diesis-diesis+3, re-bemolle-bemolle-bemolle+4, sol-diesis-diesis-diesis-diesis+3,la-diesis-diesis-diesis+3, re-bemolle-bemolle+4, si-diesis+3,la-diesis-diesis-diesis-diesis+3, mi-bemolle-bemolle-bemolle+4, re-bemolle+4, si-diesis-diesis+3,do-diesis-diesis+4, fa-bemolle-bemolle-bemolle+4, mi-bemolle-bemolle+4, si-diesis-diesis-diesis+3,do-diesis-diesis-diesis+4, fa-bemolle-bemolle+4, mi-bemolle+4,do-diesis-diesis-diesis-diesis+4, fa-bemolle+4, re-diesis-diesis+4, sol-bemolle-bemolle-bemolle+4,mi-diesis+4, re-diesis-diesis-diesis+4, sol-bemolle-bemolle+4,la-bemolle-bemolle-bemolle+4, mi-diesis-diesis+4, re-diesis-diesis-diesis-diesis+4, sol-bemolle+4,fa-diesis-diesis+4, la-bemolle-bemolle+4, mi-diesis-diesis-diesis+4,fa-diesis-diesis-diesis+4, la-bemolle+4, si-bemolle-bemolle-bemolle+4,do-bemolle-bemolle-bemolle+5, fa-diesis-diesis-diesis-diesis+4, si-bemolle-bemolle+4, sol-diesis-diesis+4,do-bemolle-bemolle+5, si-bemolle+4, sol-diesis-diesis-diesis+4,do-bemolle+5, la-diesis-diesis+4, re-bemolle-bemolle-bemolle+5, sol-diesis-diesis-diesis-diesis+4,la-diesis-diesis-diesis+4, re-bemolle-bemolle+5, si-diesis+4,la-diesis-diesis-diesis-diesis+4, mi-bemolle-bemolle-bemolle+5, re-bemolle+5, si-diesis-diesis+4,do-diesis-diesis+5, fa-bemolle-bemolle-bemolle+5, mi-bemolle-bemolle+5, si-diesis-diesis-diesis+4,do-diesis-diesis-diesis+5, fa-bemolle-bemolle+5, mi-bemolle+5,do-diesis-diesis-diesis-diesis+5, fa-bemolle+5, re-diesis-diesis+5, sol-bemolle-bemolle-bemolle+5,mi-diesis+5, re-diesis-diesis-diesis+5, sol-bemolle-bemolle+5,la-bemolle-bemolle-bemolle+5, mi-diesis-diesis+5, re-diesis-diesis-diesis-diesis+5, sol-bemolle+5,fa-diesis-diesis+5, la-bemolle-bemolle+5, mi-diesis-diesis-diesis+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "la-diesis-diesis-diesis------, re-bemolle-bemolle-----, si-diesis------,la-diesis-diesis-diesis-diesis------, mi-bemolle-bemolle-bemolle-----, re-bemolle-----, si-diesis-diesis------,do-diesis-diesis-----, fa-bemolle-bemolle-bemolle-----, mi-bemolle-bemolle-----, si-diesis-diesis-diesis------,do-diesis-diesis-diesis-----, fa-bemolle-bemolle-----, mi-bemolle-----,do-diesis-diesis-diesis-diesis-----, fa-bemolle-----, re-diesis-diesis-----, sol-bemolle-bemolle-bemolle-----,mi-diesis-----, re-diesis-diesis-diesis-----, sol-bemolle-bemolle-----,la-bemolle-bemolle-bemolle-----, mi-diesis-diesis-----, re-diesis-diesis-diesis-diesis-----, sol-bemolle-----,fa-diesis-diesis-----, la-bemolle-bemolle-----, mi-diesis-diesis-diesis-----,fa-diesis-diesis-diesis-----, la-bemolle-----, si-bemolle-bemolle-bemolle-----,do-bemolle-bemolle-bemolle----, fa-diesis-diesis-diesis-diesis-----, si-bemolle-bemolle-----, sol-diesis-diesis-----,do-bemolle-bemolle----, si-bemolle-----, sol-diesis-diesis-diesis-----,do-bemolle----, la-diesis-diesis-----, re-bemolle-bemolle-bemolle----, sol-diesis-diesis-diesis-diesis-----,la-diesis-diesis-diesis-----, re-bemolle-bemolle----, si-diesis-----,la-diesis-diesis-diesis-diesis-----, mi-bemolle-bemolle-bemolle----, re-bemolle----, si-diesis-diesis-----,do-diesis-diesis----, fa-bemolle-bemolle-bemolle----, mi-bemolle-bemolle----, si-diesis-diesis-diesis-----,do-diesis-diesis-diesis----, fa-bemolle-bemolle----, mi-bemolle----,do-diesis-diesis-diesis-diesis----, fa-bemolle----, re-diesis-diesis----, sol-bemolle-bemolle-bemolle----,mi-diesis----, re-diesis-diesis-diesis----, sol-bemolle-bemolle----,la-bemolle-bemolle-bemolle----, mi-diesis-diesis----, re-diesis-diesis-diesis-diesis----, sol-bemolle----,fa-diesis-diesis----, la-bemolle-bemolle----, mi-diesis-diesis-diesis----,fa-diesis-diesis-diesis----, la-bemolle----, si-bemolle-bemolle-bemolle----,do-bemolle-bemolle-bemolle---, fa-diesis-diesis-diesis-diesis----, si-bemolle-bemolle----, sol-diesis-diesis----,do-bemolle-bemolle---, si-bemolle----, sol-diesis-diesis-diesis----,do-bemolle---, la-diesis-diesis----, re-bemolle-bemolle-bemolle---, sol-diesis-diesis-diesis-diesis----,la-diesis-diesis-diesis----, re-bemolle-bemolle---, si-diesis----,la-diesis-diesis-diesis-diesis----, mi-bemolle-bemolle-bemolle---, re-bemolle---, si-diesis-diesis----,do-diesis-diesis---, fa-bemolle-bemolle-bemolle---, mi-bemolle-bemolle---, si-diesis-diesis-diesis----,do-diesis-diesis-diesis---, fa-bemolle-bemolle---, mi-bemolle---,do-diesis-diesis-diesis-diesis---, fa-bemolle---, re-diesis-diesis---, sol-bemolle-bemolle-bemolle---,mi-diesis---, re-diesis-diesis-diesis---, sol-bemolle-bemolle---,la-bemolle-bemolle-bemolle---, mi-diesis-diesis---, re-diesis-diesis-diesis-diesis---, sol-bemolle---,fa-diesis-diesis---, la-bemolle-bemolle---, mi-diesis-diesis-diesis---,fa-diesis-diesis-diesis---, la-bemolle---, si-bemolle-bemolle-bemolle---,do-bemolle-bemolle-bemolle--, fa-diesis-diesis-diesis-diesis---, si-bemolle-bemolle---, sol-diesis-diesis---,do-bemolle-bemolle--, si-bemolle---, sol-diesis-diesis-diesis---,do-bemolle--, la-diesis-diesis---, re-bemolle-bemolle-bemolle--, sol-diesis-diesis-diesis-diesis---,la-diesis-diesis-diesis---, re-bemolle-bemolle--, si-diesis---,la-diesis-diesis-diesis-diesis---, mi-bemolle-bemolle-bemolle--, re-bemolle--, si-diesis-diesis---,do-diesis-diesis--, fa-bemolle-bemolle-bemolle--, mi-bemolle-bemolle--, si-diesis-diesis-diesis---,do-diesis-diesis-diesis--, fa-bemolle-bemolle--, mi-bemolle--,do-diesis-diesis-diesis-diesis--, fa-bemolle--, re-diesis-diesis--, sol-bemolle-bemolle-bemolle--,mi-diesis--, re-diesis-diesis-diesis--, sol-bemolle-bemolle--,la-bemolle-bemolle-bemolle--, mi-diesis-diesis--, re-diesis-diesis-diesis-diesis--, sol-bemolle--,fa-diesis-diesis--, la-bemolle-bemolle--, mi-diesis-diesis-diesis--,fa-diesis-diesis-diesis--, la-bemolle--, si-bemolle-bemolle-bemolle--,do-bemolle-bemolle-bemolle-, fa-diesis-diesis-diesis-diesis--, si-bemolle-bemolle--, sol-diesis-diesis--,do-bemolle-bemolle-, si-bemolle--, sol-diesis-diesis-diesis--,do-bemolle-, la-diesis-diesis--, re-bemolle-bemolle-bemolle-, sol-diesis-diesis-diesis-diesis--,la-diesis-diesis-diesis--, re-bemolle-bemolle-, si-diesis--,la-diesis-diesis-diesis-diesis--, mi-bemolle-bemolle-bemolle-, re-bemolle-, si-diesis-diesis--,do-diesis-diesis-, fa-bemolle-bemolle-bemolle-, mi-bemolle-bemolle-, si-diesis-diesis-diesis--,do-diesis-diesis-diesis-, fa-bemolle-bemolle-, mi-bemolle-,do-diesis-diesis-diesis-diesis-, fa-bemolle-, re-diesis-diesis-, sol-bemolle-bemolle-bemolle-,mi-diesis-, re-diesis-diesis-diesis-, sol-bemolle-bemolle-,la-bemolle-bemolle-bemolle-, mi-diesis-diesis-, re-diesis-diesis-diesis-diesis-, sol-bemolle-,fa-diesis-diesis-, la-bemolle-bemolle-, mi-diesis-diesis-diesis-,fa-diesis-diesis-diesis-, la-bemolle-, si-bemolle-bemolle-bemolle-,do-bemolle-bemolle-bemolle, fa-diesis-diesis-diesis-diesis-, si-bemolle-bemolle-, sol-diesis-diesis-,do-bemolle-bemolle, si-bemolle-, sol-diesis-diesis-diesis-,do-bemolle, la-diesis-diesis-, re-bemolle-bemolle-bemolle, sol-diesis-diesis-diesis-diesis-,la-diesis-diesis-diesis-, re-bemolle-bemolle, si-diesis-,la-diesis-diesis-diesis-diesis-, mi-bemolle-bemolle-bemolle, re-bemolle, si-diesis-diesis-,do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle, si-diesis-diesis-diesis-,do-diesis-diesis-diesis, fa-bemolle-bemolle, mi-bemolle,do-diesis-diesis-diesis-diesis, fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,la-bemolle-bemolle-bemolle, mi-diesis-diesis, re-diesis-diesis-diesis-diesis, sol-bemolle,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis,fa-diesis-diesis-diesis, la-bemolle, si-bemolle-bemolle-bemolle,do-bemolle-bemolle-bemolle+, fa-diesis-diesis-diesis-diesis, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle+, si-bemolle, sol-diesis-diesis-diesis,do-bemolle+, la-diesis-diesis, re-bemolle-bemolle-bemolle+, sol-diesis-diesis-diesis-diesis,la-diesis-diesis-diesis, re-bemolle-bemolle+, si-diesis,la-diesis-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle+, re-bemolle+, si-diesis-diesis,do-diesis-diesis+, fa-bemolle-bemolle-bemolle+, mi-bemolle-bemolle+, si-diesis-diesis-diesis,do-diesis-diesis-diesis+, fa-bemolle-bemolle+, mi-bemolle+,do-diesis-diesis-diesis-diesis+, fa-bemolle+, re-diesis-diesis+, sol-bemolle-bemolle-bemolle+,mi-diesis+, re-diesis-diesis-diesis+, sol-bemolle-bemolle+,la-bemolle-bemolle-bemolle+, mi-diesis-diesis+, re-diesis-diesis-diesis-diesis+, sol-bemolle+,fa-diesis-diesis+, la-bemolle-bemolle+, mi-diesis-diesis-diesis+,fa-diesis-diesis-diesis+, la-bemolle+, si-bemolle-bemolle-bemolle+,do-bemolle-bemolle-bemolle++, fa-diesis-diesis-diesis-diesis+, si-bemolle-bemolle+, sol-diesis-diesis+,do-bemolle-bemolle++, si-bemolle+, sol-diesis-diesis-diesis+,do-bemolle++, la-diesis-diesis+, re-bemolle-bemolle-bemolle++, sol-diesis-diesis-diesis-diesis+,la-diesis-diesis-diesis+, re-bemolle-bemolle++, si-diesis+,la-diesis-diesis-diesis-diesis+, mi-bemolle-bemolle-bemolle++, re-bemolle++, si-diesis-diesis+,do-diesis-diesis++, fa-bemolle-bemolle-bemolle++, mi-bemolle-bemolle++, si-diesis-diesis-diesis+,do-diesis-diesis-diesis++, fa-bemolle-bemolle++, mi-bemolle++,do-diesis-diesis-diesis-diesis++, fa-bemolle++, re-diesis-diesis++, sol-bemolle-bemolle-bemolle++,mi-diesis++, re-diesis-diesis-diesis++, sol-bemolle-bemolle++,la-bemolle-bemolle-bemolle++, mi-diesis-diesis++, re-diesis-diesis-diesis-diesis++, sol-bemolle++,fa-diesis-diesis++, la-bemolle-bemolle++, mi-diesis-diesis-diesis++,fa-diesis-diesis-diesis++, la-bemolle++, si-bemolle-bemolle-bemolle++,do-bemolle-bemolle-bemolle+++, fa-diesis-diesis-diesis-diesis++, si-bemolle-bemolle++, sol-diesis-diesis++,do-bemolle-bemolle+++, si-bemolle++, sol-diesis-diesis-diesis++,do-bemolle+++, la-diesis-diesis++, re-bemolle-bemolle-bemolle+++, sol-diesis-diesis-diesis-diesis++,la-diesis-diesis-diesis++, re-bemolle-bemolle+++, si-diesis++,la-diesis-diesis-diesis-diesis++, mi-bemolle-bemolle-bemolle+++, re-bemolle+++, si-diesis-diesis++,do-diesis-diesis+++, fa-bemolle-bemolle-bemolle+++, mi-bemolle-bemolle+++, si-diesis-diesis-diesis++,do-diesis-diesis-diesis+++, fa-bemolle-bemolle+++, mi-bemolle+++,do-diesis-diesis-diesis-diesis+++, fa-bemolle+++, re-diesis-diesis+++, sol-bemolle-bemolle-bemolle+++,mi-diesis+++, re-diesis-diesis-diesis+++, sol-bemolle-bemolle+++,la-bemolle-bemolle-bemolle+++, mi-diesis-diesis+++, re-diesis-diesis-diesis-diesis+++, sol-bemolle+++,fa-diesis-diesis+++, la-bemolle-bemolle+++, mi-diesis-diesis-diesis+++,fa-diesis-diesis-diesis+++, la-bemolle+++, si-bemolle-bemolle-bemolle+++,do-bemolle-bemolle-bemolle++++, fa-diesis-diesis-diesis-diesis+++, si-bemolle-bemolle+++, sol-diesis-diesis+++,do-bemolle-bemolle++++, si-bemolle+++, sol-diesis-diesis-diesis+++,do-bemolle++++, la-diesis-diesis+++, re-bemolle-bemolle-bemolle++++, sol-diesis-diesis-diesis-diesis+++,la-diesis-diesis-diesis+++, re-bemolle-bemolle++++, si-diesis+++,la-diesis-diesis-diesis-diesis+++, mi-bemolle-bemolle-bemolle++++, re-bemolle++++, si-diesis-diesis+++,do-diesis-diesis++++, fa-bemolle-bemolle-bemolle++++, mi-bemolle-bemolle++++, si-diesis-diesis-diesis+++,do-diesis-diesis-diesis++++, fa-bemolle-bemolle++++, mi-bemolle++++,do-diesis-diesis-diesis-diesis++++, fa-bemolle++++, re-diesis-diesis++++, sol-bemolle-bemolle-bemolle++++,mi-diesis++++, re-diesis-diesis-diesis++++, sol-bemolle-bemolle++++,la-bemolle-bemolle-bemolle++++, mi-diesis-diesis++++, re-diesis-diesis-diesis-diesis++++, sol-bemolle++++,fa-diesis-diesis++++, la-bemolle-bemolle++++, mi-diesis-diesis-diesis++++,fa-diesis-diesis-diesis++++, la-bemolle++++, si-bemolle-bemolle-bemolle++++,do-bemolle-bemolle-bemolle+++++, fa-diesis-diesis-diesis-diesis++++, si-bemolle-bemolle++++, sol-diesis-diesis++++,do-bemolle-bemolle+++++, si-bemolle++++, sol-diesis-diesis-diesis++++,do-bemolle+++++, la-diesis-diesis++++, re-bemolle-bemolle-bemolle+++++, sol-diesis-diesis-diesis-diesis++++,la-diesis-diesis-diesis++++, re-bemolle-bemolle+++++, si-diesis++++,la-diesis-diesis-diesis-diesis++++, mi-bemolle-bemolle-bemolle+++++, re-bemolle+++++, si-diesis-diesis++++,do-diesis-diesis+++++, fa-bemolle-bemolle-bemolle+++++, mi-bemolle-bemolle+++++, si-diesis-diesis-diesis++++,do-diesis-diesis-diesis+++++, fa-bemolle-bemolle+++++, mi-bemolle+++++,do-diesis-diesis-diesis-diesis+++++, fa-bemolle+++++, re-diesis-diesis+++++, sol-bemolle-bemolle-bemolle+++++,mi-diesis+++++, re-diesis-diesis-diesis+++++, sol-bemolle-bemolle+++++,la-bemolle-bemolle-bemolle+++++, mi-diesis-diesis+++++, re-diesis-diesis-diesis-diesis+++++, sol-bemolle+++++,fa-diesis-diesis+++++, la-bemolle-bemolle+++++, mi-diesis-diesis-diesis+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "la-diesis-diesis-diesis-2, re-bemolle-bemolle-1, si-diesis-2,la-diesis-diesis-diesis-diesis-2, mi-bemolle-bemolle-bemolle-1, re-bemolle-1, si-diesis-diesis-2,do-diesis-diesis-1, fa-bemolle-bemolle-bemolle-1, mi-bemolle-bemolle-1, si-diesis-diesis-diesis-2,do-diesis-diesis-diesis-1, fa-bemolle-bemolle-1, mi-bemolle-1,do-diesis-diesis-diesis-diesis-1, fa-bemolle-1, re-diesis-diesis-1, sol-bemolle-bemolle-bemolle-1,mi-diesis-1, re-diesis-diesis-diesis-1, sol-bemolle-bemolle-1,la-bemolle-bemolle-bemolle-1, mi-diesis-diesis-1, re-diesis-diesis-diesis-diesis-1, sol-bemolle-1,fa-diesis-diesis-1, la-bemolle-bemolle-1, mi-diesis-diesis-diesis-1,fa-diesis-diesis-diesis-1, la-bemolle-1, si-bemolle-bemolle-bemolle-1,do-bemolle-bemolle-bemolle0, fa-diesis-diesis-diesis-diesis-1, si-bemolle-bemolle-1, sol-diesis-diesis-1,do-bemolle-bemolle0, si-bemolle-1, sol-diesis-diesis-diesis-1,do-bemolle0, la-diesis-diesis-1, re-bemolle-bemolle-bemolle0, sol-diesis-diesis-diesis-diesis-1,la-diesis-diesis-diesis-1, re-bemolle-bemolle0, si-diesis-1,la-diesis-diesis-diesis-diesis-1, mi-bemolle-bemolle-bemolle0, re-bemolle0, si-diesis-diesis-1,do-diesis-diesis0, fa-bemolle-bemolle-bemolle0, mi-bemolle-bemolle0, si-diesis-diesis-diesis-1,do-diesis-diesis-diesis0, fa-bemolle-bemolle0, mi-bemolle0,do-diesis-diesis-diesis-diesis0, fa-bemolle0, re-diesis-diesis0, sol-bemolle-bemolle-bemolle0,mi-diesis0, re-diesis-diesis-diesis0, sol-bemolle-bemolle0,la-bemolle-bemolle-bemolle0, mi-diesis-diesis0, re-diesis-diesis-diesis-diesis0, sol-bemolle0,fa-diesis-diesis0, la-bemolle-bemolle0, mi-diesis-diesis-diesis0,fa-diesis-diesis-diesis0, la-bemolle0, si-bemolle-bemolle-bemolle0,do-bemolle-bemolle-bemolle1, fa-diesis-diesis-diesis-diesis0, si-bemolle-bemolle0, sol-diesis-diesis0,do-bemolle-bemolle1, si-bemolle0, sol-diesis-diesis-diesis0,do-bemolle1, la-diesis-diesis0, re-bemolle-bemolle-bemolle1, sol-diesis-diesis-diesis-diesis0,la-diesis-diesis-diesis0, re-bemolle-bemolle1, si-diesis0,la-diesis-diesis-diesis-diesis0, mi-bemolle-bemolle-bemolle1, re-bemolle1, si-diesis-diesis0,do-diesis-diesis1, fa-bemolle-bemolle-bemolle1, mi-bemolle-bemolle1, si-diesis-diesis-diesis0,do-diesis-diesis-diesis1, fa-bemolle-bemolle1, mi-bemolle1,do-diesis-diesis-diesis-diesis1, fa-bemolle1, re-diesis-diesis1, sol-bemolle-bemolle-bemolle1,mi-diesis1, re-diesis-diesis-diesis1, sol-bemolle-bemolle1,la-bemolle-bemolle-bemolle1, mi-diesis-diesis1, re-diesis-diesis-diesis-diesis1, sol-bemolle1,fa-diesis-diesis1, la-bemolle-bemolle1, mi-diesis-diesis-diesis1,fa-diesis-diesis-diesis1, la-bemolle1, si-bemolle-bemolle-bemolle1,do-bemolle-bemolle-bemolle2, fa-diesis-diesis-diesis-diesis1, si-bemolle-bemolle1, sol-diesis-diesis1,do-bemolle-bemolle2, si-bemolle1, sol-diesis-diesis-diesis1,do-bemolle2, la-diesis-diesis1, re-bemolle-bemolle-bemolle2, sol-diesis-diesis-diesis-diesis1,la-diesis-diesis-diesis1, re-bemolle-bemolle2, si-diesis1,la-diesis-diesis-diesis-diesis1, mi-bemolle-bemolle-bemolle2, re-bemolle2, si-diesis-diesis1,do-diesis-diesis2, fa-bemolle-bemolle-bemolle2, mi-bemolle-bemolle2, si-diesis-diesis-diesis1,do-diesis-diesis-diesis2, fa-bemolle-bemolle2, mi-bemolle2,do-diesis-diesis-diesis-diesis2, fa-bemolle2, re-diesis-diesis2, sol-bemolle-bemolle-bemolle2,mi-diesis2, re-diesis-diesis-diesis2, sol-bemolle-bemolle2,la-bemolle-bemolle-bemolle2, mi-diesis-diesis2, re-diesis-diesis-diesis-diesis2, sol-bemolle2,fa-diesis-diesis2, la-bemolle-bemolle2, mi-diesis-diesis-diesis2,fa-diesis-diesis-diesis2, la-bemolle2, si-bemolle-bemolle-bemolle2,do-bemolle-bemolle-bemolle3, fa-diesis-diesis-diesis-diesis2, si-bemolle-bemolle2, sol-diesis-diesis2,do-bemolle-bemolle3, si-bemolle2, sol-diesis-diesis-diesis2,do-bemolle3, la-diesis-diesis2, re-bemolle-bemolle-bemolle3, sol-diesis-diesis-diesis-diesis2,la-diesis-diesis-diesis2, re-bemolle-bemolle3, si-diesis2,la-diesis-diesis-diesis-diesis2, mi-bemolle-bemolle-bemolle3, re-bemolle3, si-diesis-diesis2,do-diesis-diesis3, fa-bemolle-bemolle-bemolle3, mi-bemolle-bemolle3, si-diesis-diesis-diesis2,do-diesis-diesis-diesis3, fa-bemolle-bemolle3, mi-bemolle3,do-diesis-diesis-diesis-diesis3, fa-bemolle3, re-diesis-diesis3, sol-bemolle-bemolle-bemolle3,mi-diesis3, re-diesis-diesis-diesis3, sol-bemolle-bemolle3,la-bemolle-bemolle-bemolle3, mi-diesis-diesis3, re-diesis-diesis-diesis-diesis3, sol-bemolle3,fa-diesis-diesis3, la-bemolle-bemolle3, mi-diesis-diesis-diesis3,fa-diesis-diesis-diesis3, la-bemolle3, si-bemolle-bemolle-bemolle3,do-bemolle-bemolle-bemolle4, fa-diesis-diesis-diesis-diesis3, si-bemolle-bemolle3, sol-diesis-diesis3,do-bemolle-bemolle4, si-bemolle3, sol-diesis-diesis-diesis3,do-bemolle4, la-diesis-diesis3, re-bemolle-bemolle-bemolle4, sol-diesis-diesis-diesis-diesis3,la-diesis-diesis-diesis3, re-bemolle-bemolle4, si-diesis3,la-diesis-diesis-diesis-diesis3, mi-bemolle-bemolle-bemolle4, re-bemolle4, si-diesis-diesis3,do-diesis-diesis4, fa-bemolle-bemolle-bemolle4, mi-bemolle-bemolle4, si-diesis-diesis-diesis3,do-diesis-diesis-diesis4, fa-bemolle-bemolle4, mi-bemolle4,do-diesis-diesis-diesis-diesis4, fa-bemolle4, re-diesis-diesis4, sol-bemolle-bemolle-bemolle4,mi-diesis4, re-diesis-diesis-diesis4, sol-bemolle-bemolle4,la-bemolle-bemolle-bemolle4, mi-diesis-diesis4, re-diesis-diesis-diesis-diesis4, sol-bemolle4,fa-diesis-diesis4, la-bemolle-bemolle4, mi-diesis-diesis-diesis4,fa-diesis-diesis-diesis4, la-bemolle4, si-bemolle-bemolle-bemolle4,do-bemolle-bemolle-bemolle5, fa-diesis-diesis-diesis-diesis4, si-bemolle-bemolle4, sol-diesis-diesis4,do-bemolle-bemolle5, si-bemolle4, sol-diesis-diesis-diesis4,do-bemolle5, la-diesis-diesis4, re-bemolle-bemolle-bemolle5, sol-diesis-diesis-diesis-diesis4,la-diesis-diesis-diesis4, re-bemolle-bemolle5, si-diesis4,la-diesis-diesis-diesis-diesis4, mi-bemolle-bemolle-bemolle5, re-bemolle5, si-diesis-diesis4,do-diesis-diesis5, fa-bemolle-bemolle-bemolle5, mi-bemolle-bemolle5, si-diesis-diesis-diesis4,do-diesis-diesis-diesis5, fa-bemolle-bemolle5, mi-bemolle5,do-diesis-diesis-diesis-diesis5, fa-bemolle5, re-diesis-diesis5, sol-bemolle-bemolle-bemolle5,mi-diesis5, re-diesis-diesis-diesis5, sol-bemolle-bemolle5,la-bemolle-bemolle-bemolle5, mi-diesis-diesis5, re-diesis-diesis-diesis-diesis5, sol-bemolle5,fa-diesis-diesis5, la-bemolle-bemolle5, mi-diesis-diesis-diesis5,fa-diesis-diesis-diesis5, la-bemolle5, si-bemolle-bemolle-bemolle5,do-bemolle-bemolle-bemolle6, fa-diesis-diesis-diesis-diesis5, si-bemolle-bemolle5, sol-diesis-diesis5,do-bemolle-bemolle6, si-bemolle5, sol-diesis-diesis-diesis5,do-bemolle6, la-diesis-diesis5, re-bemolle-bemolle-bemolle6, sol-diesis-diesis-diesis-diesis5,la-diesis-diesis-diesis5, re-bemolle-bemolle6, si-diesis5,la-diesis-diesis-diesis-diesis5, mi-bemolle-bemolle-bemolle6, re-bemolle6, si-diesis-diesis5,do-diesis-diesis6, fa-bemolle-bemolle-bemolle6, mi-bemolle-bemolle6, si-diesis-diesis-diesis5,do-diesis-diesis-diesis6, fa-bemolle-bemolle6, mi-bemolle6,do-diesis-diesis-diesis-diesis6, fa-bemolle6, re-diesis-diesis6, sol-bemolle-bemolle-bemolle6,mi-diesis6, re-diesis-diesis-diesis6, sol-bemolle-bemolle6,la-bemolle-bemolle-bemolle6, mi-diesis-diesis6, re-diesis-diesis-diesis-diesis6, sol-bemolle6,fa-diesis-diesis6, la-bemolle-bemolle6, mi-diesis-diesis-diesis6,fa-diesis-diesis-diesis6, la-bemolle6, si-bemolle-bemolle-bemolle6,do-bemolle-bemolle-bemolle7, fa-diesis-diesis-diesis-diesis6, si-bemolle-bemolle6, sol-diesis-diesis6,do-bemolle-bemolle7, si-bemolle6, sol-diesis-diesis-diesis6,do-bemolle7, la-diesis-diesis6, re-bemolle-bemolle-bemolle7, sol-diesis-diesis-diesis-diesis6,la-diesis-diesis-diesis6, re-bemolle-bemolle7, si-diesis6,la-diesis-diesis-diesis-diesis6, mi-bemolle-bemolle-bemolle7, re-bemolle7, si-diesis-diesis6,do-diesis-diesis7, fa-bemolle-bemolle-bemolle7, mi-bemolle-bemolle7, si-diesis-diesis-diesis6,do-diesis-diesis-diesis7, fa-bemolle-bemolle7, mi-bemolle7,do-diesis-diesis-diesis-diesis7, fa-bemolle7, re-diesis-diesis7, sol-bemolle-bemolle-bemolle7,mi-diesis7, re-diesis-diesis-diesis7, sol-bemolle-bemolle7,la-bemolle-bemolle-bemolle7, mi-diesis-diesis7, re-diesis-diesis-diesis-diesis7, sol-bemolle7,fa-diesis-diesis7, la-bemolle-bemolle7, mi-diesis-diesis-diesis7,fa-diesis-diesis-diesis7, la-bemolle7, si-bemolle-bemolle-bemolle7,do-bemolle-bemolle-bemolle8, fa-diesis-diesis-diesis-diesis7, si-bemolle-bemolle7, sol-diesis-diesis7,do-bemolle-bemolle8, si-bemolle7, sol-diesis-diesis-diesis7,do-bemolle8, la-diesis-diesis7, re-bemolle-bemolle-bemolle8, sol-diesis-diesis-diesis-diesis7,la-diesis-diesis-diesis7, re-bemolle-bemolle8, si-diesis7,la-diesis-diesis-diesis-diesis7, mi-bemolle-bemolle-bemolle8, re-bemolle8, si-diesis-diesis7,do-diesis-diesis8, fa-bemolle-bemolle-bemolle8, mi-bemolle-bemolle8, si-diesis-diesis-diesis7,do-diesis-diesis-diesis8, fa-bemolle-bemolle8, mi-bemolle8,do-diesis-diesis-diesis-diesis8, fa-bemolle8, re-diesis-diesis8, sol-bemolle-bemolle-bemolle8,mi-diesis8, re-diesis-diesis-diesis8, sol-bemolle-bemolle8,la-bemolle-bemolle-bemolle8, mi-diesis-diesis8, re-diesis-diesis-diesis-diesis8, sol-bemolle8,fa-diesis-diesis8, la-bemolle-bemolle8, mi-diesis-diesis-diesis8,fa-diesis-diesis-diesis8, la-bemolle8, si-bemolle-bemolle-bemolle8,do-bemolle-bemolle-bemolle9, fa-diesis-diesis-diesis-diesis8, si-bemolle-bemolle8, sol-diesis-diesis8,do-bemolle-bemolle9, si-bemolle8, sol-diesis-diesis-diesis8,do-bemolle9, la-diesis-diesis8, re-bemolle-bemolle-bemolle9, sol-diesis-diesis-diesis-diesis8,la-diesis-diesis-diesis8, re-bemolle-bemolle9, si-diesis8,la-diesis-diesis-diesis-diesis8, mi-bemolle-bemolle-bemolle9, re-bemolle9, si-diesis-diesis8,do-diesis-diesis9, fa-bemolle-bemolle-bemolle9, mi-bemolle-bemolle9, si-diesis-diesis-diesis8,do-diesis-diesis-diesis9, fa-bemolle-bemolle9, mi-bemolle9,do-diesis-diesis-diesis-diesis9, fa-bemolle9, re-diesis-diesis9, sol-bemolle-bemolle-bemolle9,mi-diesis9, re-diesis-diesis-diesis9, sol-bemolle-bemolle9,la-bemolle-bemolle-bemolle9, mi-diesis-diesis9, re-diesis-diesis-diesis-diesis9, sol-bemolle9,fa-diesis-diesis9, la-bemolle-bemolle9, mi-diesis-diesis-diesis9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "La-diesis-diesis-diesis'''', Re-bemolle-bemolle''', Si-diesis'''',La-diesis-diesis-diesis-diesis'''', Mi-bemolle-bemolle-bemolle''', Re-bemolle''', Si-diesis-diesis'''',Do-diesis-diesis''', Fa-bemolle-bemolle-bemolle''', Mi-bemolle-bemolle''', Si-diesis-diesis-diesis'''',Do-diesis-diesis-diesis''', Fa-bemolle-bemolle''', Mi-bemolle''',Do-diesis-diesis-diesis-diesis''', Fa-bemolle''', Re-diesis-diesis''', Sol-bemolle-bemolle-bemolle''',Mi-diesis''', Re-diesis-diesis-diesis''', Sol-bemolle-bemolle''',La-bemolle-bemolle-bemolle''', Mi-diesis-diesis''', Re-diesis-diesis-diesis-diesis''', Sol-bemolle''',Fa-diesis-diesis''', La-bemolle-bemolle''', Mi-diesis-diesis-diesis''',Fa-diesis-diesis-diesis''', La-bemolle''', Si-bemolle-bemolle-bemolle''',Do-bemolle-bemolle-bemolle'', Fa-diesis-diesis-diesis-diesis''', Si-bemolle-bemolle''', Sol-diesis-diesis''',Do-bemolle-bemolle'', Si-bemolle''', Sol-diesis-diesis-diesis''',Do-bemolle'', La-diesis-diesis''', Re-bemolle-bemolle-bemolle'', Sol-diesis-diesis-diesis-diesis''',La-diesis-diesis-diesis''', Re-bemolle-bemolle'', Si-diesis''',La-diesis-diesis-diesis-diesis''', Mi-bemolle-bemolle-bemolle'', Re-bemolle'', Si-diesis-diesis''',Do-diesis-diesis'', Fa-bemolle-bemolle-bemolle'', Mi-bemolle-bemolle'', Si-diesis-diesis-diesis''',Do-diesis-diesis-diesis'', Fa-bemolle-bemolle'', Mi-bemolle'',Do-diesis-diesis-diesis-diesis'', Fa-bemolle'', Re-diesis-diesis'', Sol-bemolle-bemolle-bemolle'',Mi-diesis'', Re-diesis-diesis-diesis'', Sol-bemolle-bemolle'',La-bemolle-bemolle-bemolle'', Mi-diesis-diesis'', Re-diesis-diesis-diesis-diesis'', Sol-bemolle'',Fa-diesis-diesis'', La-bemolle-bemolle'', Mi-diesis-diesis-diesis'',Fa-diesis-diesis-diesis'', La-bemolle'', Si-bemolle-bemolle-bemolle'',Do-bemolle-bemolle-bemolle', Fa-diesis-diesis-diesis-diesis'', Si-bemolle-bemolle'', Sol-diesis-diesis'',Do-bemolle-bemolle', Si-bemolle'', Sol-diesis-diesis-diesis'',Do-bemolle', La-diesis-diesis'', Re-bemolle-bemolle-bemolle', Sol-diesis-diesis-diesis-diesis'',La-diesis-diesis-diesis'', Re-bemolle-bemolle', Si-diesis'',La-diesis-diesis-diesis-diesis'', Mi-bemolle-bemolle-bemolle', Re-bemolle', Si-diesis-diesis'',Do-diesis-diesis', Fa-bemolle-bemolle-bemolle', Mi-bemolle-bemolle', Si-diesis-diesis-diesis'',Do-diesis-diesis-diesis', Fa-bemolle-bemolle', Mi-bemolle',Do-diesis-diesis-diesis-diesis', Fa-bemolle', Re-diesis-diesis', Sol-bemolle-bemolle-bemolle',Mi-diesis', Re-diesis-diesis-diesis', Sol-bemolle-bemolle',La-bemolle-bemolle-bemolle', Mi-diesis-diesis', Re-diesis-diesis-diesis-diesis', Sol-bemolle',Fa-diesis-diesis', La-bemolle-bemolle', Mi-diesis-diesis-diesis',Fa-diesis-diesis-diesis', La-bemolle', Si-bemolle-bemolle-bemolle',Do-bemolle-bemolle-bemolle, Fa-diesis-diesis-diesis-diesis', Si-bemolle-bemolle', Sol-diesis-diesis',Do-bemolle-bemolle, Si-bemolle', Sol-diesis-diesis-diesis',Do-bemolle, La-diesis-diesis', Re-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-diesis',La-diesis-diesis-diesis', Re-bemolle-bemolle, Si-diesis',La-diesis-diesis-diesis-diesis', Mi-bemolle-bemolle-bemolle, Re-bemolle, Si-diesis-diesis',Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis',Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Mi-bemolle,Do-diesis-diesis-diesis-diesis, Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,La-bemolle-bemolle-bemolle, Mi-diesis-diesis, Re-diesis-diesis-diesis-diesis, Sol-bemolle,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis,Fa-diesis-diesis-diesis, La-bemolle, Si-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis-diesis, Si-bemolle-bemolle, Sol-diesis-diesis, do-bemolle-bemolle-bemolle,Si-bemolle, Sol-diesis-diesis-diesis, do-bemolle-bemolle,La-diesis-diesis, Sol-diesis-diesis-diesis-diesis, do-bemolle, re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis, Si-diesis, re-bemolle-bemolle,La-diesis-diesis-diesis-diesis, Si-diesis-diesis, mi-bemolle-bemolle-bemolle, re-bemolle,Si-diesis-diesis-diesis, do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle,do-diesis-diesis-diesis, fa-bemolle-bemolle, mi-bemolle,do-diesis-diesis-diesis-diesis, fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,la-bemolle-bemolle-bemolle, mi-diesis-diesis, re-diesis-diesis-diesis-diesis, sol-bemolle,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis,fa-diesis-diesis-diesis, la-bemolle, si-bemolle-bemolle-bemolle,do-bemolle-bemolle-bemolle', fa-diesis-diesis-diesis-diesis, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle', si-bemolle, sol-diesis-diesis-diesis,do-bemolle', la-diesis-diesis, re-bemolle-bemolle-bemolle', sol-diesis-diesis-diesis-diesis,la-diesis-diesis-diesis, re-bemolle-bemolle', si-diesis,la-diesis-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle', re-bemolle', si-diesis-diesis,do-diesis-diesis', fa-bemolle-bemolle-bemolle', mi-bemolle-bemolle', si-diesis-diesis-diesis,do-diesis-diesis-diesis', fa-bemolle-bemolle', mi-bemolle',do-diesis-diesis-diesis-diesis', fa-bemolle', re-diesis-diesis', sol-bemolle-bemolle-bemolle',mi-diesis', re-diesis-diesis-diesis', sol-bemolle-bemolle',la-bemolle-bemolle-bemolle', mi-diesis-diesis', re-diesis-diesis-diesis-diesis', sol-bemolle',fa-diesis-diesis', la-bemolle-bemolle', mi-diesis-diesis-diesis',fa-diesis-diesis-diesis', la-bemolle', si-bemolle-bemolle-bemolle',do-bemolle-bemolle-bemolle'', fa-diesis-diesis-diesis-diesis', si-bemolle-bemolle', sol-diesis-diesis',do-bemolle-bemolle'', si-bemolle', sol-diesis-diesis-diesis',do-bemolle'', la-diesis-diesis', re-bemolle-bemolle-bemolle'', sol-diesis-diesis-diesis-diesis',la-diesis-diesis-diesis', re-bemolle-bemolle'', si-diesis',la-diesis-diesis-diesis-diesis', mi-bemolle-bemolle-bemolle'', re-bemolle'', si-diesis-diesis',do-diesis-diesis'', fa-bemolle-bemolle-bemolle'', mi-bemolle-bemolle'', si-diesis-diesis-diesis',do-diesis-diesis-diesis'', fa-bemolle-bemolle'', mi-bemolle'',do-diesis-diesis-diesis-diesis'', fa-bemolle'', re-diesis-diesis'', sol-bemolle-bemolle-bemolle'',mi-diesis'', re-diesis-diesis-diesis'', sol-bemolle-bemolle'',la-bemolle-bemolle-bemolle'', mi-diesis-diesis'', re-diesis-diesis-diesis-diesis'', sol-bemolle'',fa-diesis-diesis'', la-bemolle-bemolle'', mi-diesis-diesis-diesis'',fa-diesis-diesis-diesis'', la-bemolle'', si-bemolle-bemolle-bemolle'',do-bemolle-bemolle-bemolle''', fa-diesis-diesis-diesis-diesis'', si-bemolle-bemolle'', sol-diesis-diesis'',do-bemolle-bemolle''', si-bemolle'', sol-diesis-diesis-diesis'',do-bemolle''', la-diesis-diesis'', re-bemolle-bemolle-bemolle''', sol-diesis-diesis-diesis-diesis'',la-diesis-diesis-diesis'', re-bemolle-bemolle''', si-diesis'',la-diesis-diesis-diesis-diesis'', mi-bemolle-bemolle-bemolle''', re-bemolle''', si-diesis-diesis'',do-diesis-diesis''', fa-bemolle-bemolle-bemolle''', mi-bemolle-bemolle''', si-diesis-diesis-diesis'',do-diesis-diesis-diesis''', fa-bemolle-bemolle''', mi-bemolle''',do-diesis-diesis-diesis-diesis''', fa-bemolle''', re-diesis-diesis''', sol-bemolle-bemolle-bemolle''',mi-diesis''', re-diesis-diesis-diesis''', sol-bemolle-bemolle''',la-bemolle-bemolle-bemolle''', mi-diesis-diesis''', re-diesis-diesis-diesis-diesis''', sol-bemolle''',fa-diesis-diesis''', la-bemolle-bemolle''', mi-diesis-diesis-diesis''',fa-diesis-diesis-diesis''', la-bemolle''', si-bemolle-bemolle-bemolle''',do-bemolle-bemolle-bemolle'''', fa-diesis-diesis-diesis-diesis''', si-bemolle-bemolle''', sol-diesis-diesis''',do-bemolle-bemolle'''', si-bemolle''', sol-diesis-diesis-diesis''',do-bemolle'''', la-diesis-diesis''', re-bemolle-bemolle-bemolle'''', sol-diesis-diesis-diesis-diesis''',la-diesis-diesis-diesis''', re-bemolle-bemolle'''', si-diesis''',la-diesis-diesis-diesis-diesis''', mi-bemolle-bemolle-bemolle'''', re-bemolle'''', si-diesis-diesis''',do-diesis-diesis'''', fa-bemolle-bemolle-bemolle'''', mi-bemolle-bemolle'''', si-diesis-diesis-diesis''',do-diesis-diesis-diesis'''', fa-bemolle-bemolle'''', mi-bemolle'''',do-diesis-diesis-diesis-diesis'''', fa-bemolle'''', re-diesis-diesis'''', sol-bemolle-bemolle-bemolle'''',mi-diesis'''', re-diesis-diesis-diesis'''', sol-bemolle-bemolle'''',la-bemolle-bemolle-bemolle'''', mi-diesis-diesis'''', re-diesis-diesis-diesis-diesis'''', sol-bemolle'''',fa-diesis-diesis'''', la-bemolle-bemolle'''', mi-diesis-diesis-diesis'''',fa-diesis-diesis-diesis'''', la-bemolle'''', si-bemolle-bemolle-bemolle'''',do-bemolle-bemolle-bemolle''''', fa-diesis-diesis-diesis-diesis'''', si-bemolle-bemolle'''', sol-diesis-diesis'''',do-bemolle-bemolle''''', si-bemolle'''', sol-diesis-diesis-diesis'''',do-bemolle''''', la-diesis-diesis'''', re-bemolle-bemolle-bemolle''''', sol-diesis-diesis-diesis-diesis'''',la-diesis-diesis-diesis'''', re-bemolle-bemolle''''', si-diesis'''',la-diesis-diesis-diesis-diesis'''', mi-bemolle-bemolle-bemolle''''', re-bemolle''''', si-diesis-diesis'''',do-diesis-diesis''''', fa-bemolle-bemolle-bemolle''''', mi-bemolle-bemolle''''', si-diesis-diesis-diesis'''',do-diesis-diesis-diesis''''', fa-bemolle-bemolle''''', mi-bemolle''''',do-diesis-diesis-diesis-diesis''''', fa-bemolle''''', re-diesis-diesis''''', sol-bemolle-bemolle-bemolle''''',mi-diesis''''', re-diesis-diesis-diesis''''', sol-bemolle-bemolle''''',la-bemolle-bemolle-bemolle''''', mi-diesis-diesis''''', re-diesis-diesis-diesis-diesis''''', sol-bemolle''''',fa-diesis-diesis''''', la-bemolle-bemolle''''', mi-diesis-diesis-diesis''''',fa-diesis-diesis-diesis''''', la-bemolle''''', si-bemolle-bemolle-bemolle''''',do-bemolle-bemolle-bemolle'''''', fa-diesis-diesis-diesis-diesis''''', si-bemolle-bemolle''''', sol-diesis-diesis''''',do-bemolle-bemolle'''''', si-bemolle''''', sol-diesis-diesis-diesis''''',do-bemolle'''''', la-diesis-diesis''''', re-bemolle-bemolle-bemolle'''''', sol-diesis-diesis-diesis-diesis''''',la-diesis-diesis-diesis''''', re-bemolle-bemolle'''''', si-diesis''''',la-diesis-diesis-diesis-diesis''''', mi-bemolle-bemolle-bemolle'''''', re-bemolle'''''', si-diesis-diesis''''',do-diesis-diesis'''''', fa-bemolle-bemolle-bemolle'''''', mi-bemolle-bemolle'''''', si-diesis-diesis-diesis''''',do-diesis-diesis-diesis'''''', fa-bemolle-bemolle'''''', mi-bemolle'''''',do-diesis-diesis-diesis-diesis'''''', fa-bemolle'''''', re-diesis-diesis'''''', sol-bemolle-bemolle-bemolle'''''',mi-diesis'''''', re-diesis-diesis-diesis'''''', sol-bemolle-bemolle'''''',la-bemolle-bemolle-bemolle'''''', mi-diesis-diesis'''''', re-diesis-diesis-diesis-diesis'''''', sol-bemolle'''''',fa-diesis-diesis'''''', la-bemolle-bemolle'''''', mi-diesis-diesis-diesis''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "la-diesis-diesis-diesis-6, mi-bemolle-bemolle-bemolle-bemolle-5, re-bemolle-bemolle-5, si-diesis-6,do-diesis-5, mi-bemolle-bemolle-bemolle-5, si-diesis-diesis-6,do-diesis-diesis-5, fa-bemolle-bemolle-bemolle-5, mi-bemolle-bemolle-5, si-diesis-diesis-diesis-6,do-diesis-diesis-diesis-5, fa-bemolle-bemolle-5, re-diesis-5, sol-bemolle-bemolle-bemolle-bemolle-5,fa-bemolle-5, re-diesis-diesis-5, sol-bemolle-bemolle-bemolle-5,la-bemolle-bemolle-bemolle-bemolle-5, mi-diesis-5, re-diesis-diesis-diesis-5, sol-bemolle-bemolle-5,fa-diesis-5, la-bemolle-bemolle-bemolle-5, mi-diesis-diesis-5,fa-diesis-diesis-5, la-bemolle-bemolle-5, mi-diesis-diesis-diesis-5, si-bemolle-bemolle-bemolle-bemolle-5,fa-diesis-diesis-diesis-5, si-bemolle-bemolle-bemolle-5, sol-diesis-5,do-bemolle-bemolle-bemolle-4, si-bemolle-bemolle-5, sol-diesis-diesis-5,do-bemolle-bemolle-4, la-diesis-5, re-bemolle-bemolle-bemolle-bemolle-4, sol-diesis-diesis-diesis-5,do-bemolle-4, la-diesis-diesis-5, re-bemolle-bemolle-bemolle-4,la-diesis-diesis-diesis-5, mi-bemolle-bemolle-bemolle-bemolle-4, re-bemolle-bemolle-4, si-diesis-5,do-diesis-4, mi-bemolle-bemolle-bemolle-4, si-diesis-diesis-5,do-diesis-diesis-4, fa-bemolle-bemolle-bemolle-4, mi-bemolle-bemolle-4, si-diesis-diesis-diesis-5,do-diesis-diesis-diesis-4, fa-bemolle-bemolle-4, re-diesis-4, sol-bemolle-bemolle-bemolle-bemolle-4,fa-bemolle-4, re-diesis-diesis-4, sol-bemolle-bemolle-bemolle-4,la-bemolle-bemolle-bemolle-bemolle-4, mi-diesis-4, re-diesis-diesis-diesis-4, sol-bemolle-bemolle-4,fa-diesis-4, la-bemolle-bemolle-bemolle-4, mi-diesis-diesis-4,fa-diesis-diesis-4, la-bemolle-bemolle-4, mi-diesis-diesis-diesis-4, si-bemolle-bemolle-bemolle-bemolle-4,fa-diesis-diesis-diesis-4, si-bemolle-bemolle-bemolle-4, sol-diesis-4,do-bemolle-bemolle-bemolle-3, si-bemolle-bemolle-4, sol-diesis-diesis-4,do-bemolle-bemolle-3, la-diesis-4, re-bemolle-bemolle-bemolle-bemolle-3, sol-diesis-diesis-diesis-4,do-bemolle-3, la-diesis-diesis-4, re-bemolle-bemolle-bemolle-3,la-diesis-diesis-diesis-4, mi-bemolle-bemolle-bemolle-bemolle-3, re-bemolle-bemolle-3, si-diesis-4,do-diesis-3, mi-bemolle-bemolle-bemolle-3, si-diesis-diesis-4,do-diesis-diesis-3, fa-bemolle-bemolle-bemolle-3, mi-bemolle-bemolle-3, si-diesis-diesis-diesis-4,do-diesis-diesis-diesis-3, fa-bemolle-bemolle-3, re-diesis-3, sol-bemolle-bemolle-bemolle-bemolle-3,fa-bemolle-3, re-diesis-diesis-3, sol-bemolle-bemolle-bemolle-3,la-bemolle-bemolle-bemolle-bemolle-3, mi-diesis-3, re-diesis-diesis-diesis-3, sol-bemolle-bemolle-3,fa-diesis-3, la-bemolle-bemolle-bemolle-3, mi-diesis-diesis-3,fa-diesis-diesis-3, la-bemolle-bemolle-3, mi-diesis-diesis-diesis-3, si-bemolle-bemolle-bemolle-bemolle-3,fa-diesis-diesis-diesis-3, si-bemolle-bemolle-bemolle-3, sol-diesis-3,do-bemolle-bemolle-bemolle-2, si-bemolle-bemolle-3, sol-diesis-diesis-3,do-bemolle-bemolle-2, la-diesis-3, re-bemolle-bemolle-bemolle-bemolle-2, sol-diesis-diesis-diesis-3,do-bemolle-2, la-diesis-diesis-3, re-bemolle-bemolle-bemolle-2,la-diesis-diesis-diesis-3, mi-bemolle-bemolle-bemolle-bemolle-2, re-bemolle-bemolle-2, si-diesis-3,do-diesis-2, mi-bemolle-bemolle-bemolle-2, si-diesis-diesis-3,do-diesis-diesis-2, fa-bemolle-bemolle-bemolle-2, mi-bemolle-bemolle-2, si-diesis-diesis-diesis-3,do-diesis-diesis-diesis-2, fa-bemolle-bemolle-2, re-diesis-2, sol-bemolle-bemolle-bemolle-bemolle-2,fa-bemolle-2, re-diesis-diesis-2, sol-bemolle-bemolle-bemolle-2,la-bemolle-bemolle-bemolle-bemolle-2, mi-diesis-2, re-diesis-diesis-diesis-2, sol-bemolle-bemolle-2,fa-diesis-2, la-bemolle-bemolle-bemolle-2, mi-diesis-diesis-2,fa-diesis-diesis-2, la-bemolle-bemolle-2, mi-diesis-diesis-diesis-2, si-bemolle-bemolle-bemolle-bemolle-2,fa-diesis-diesis-diesis-2, si-bemolle-bemolle-bemolle-2, sol-diesis-2,do-bemolle-bemolle-bemolle-, si-bemolle-bemolle-2, sol-diesis-diesis-2,do-bemolle-bemolle-, la-diesis-2, re-bemolle-bemolle-bemolle-bemolle-, sol-diesis-diesis-diesis-2,do-bemolle-, la-diesis-diesis-2, re-bemolle-bemolle-bemolle-,la-diesis-diesis-diesis-2, mi-bemolle-bemolle-bemolle-bemolle-, re-bemolle-bemolle-, si-diesis-2,do-diesis-, mi-bemolle-bemolle-bemolle-, si-diesis-diesis-2,do-diesis-diesis-, fa-bemolle-bemolle-bemolle-, mi-bemolle-bemolle-, si-diesis-diesis-diesis-2,do-diesis-diesis-diesis-, fa-bemolle-bemolle-, re-diesis-, sol-bemolle-bemolle-bemolle-bemolle-,fa-bemolle-, re-diesis-diesis-, sol-bemolle-bemolle-bemolle-,la-bemolle-bemolle-bemolle-bemolle-, mi-diesis-, re-diesis-diesis-diesis-, sol-bemolle-bemolle-,fa-diesis-, la-bemolle-bemolle-bemolle-, mi-diesis-diesis-,fa-diesis-diesis-, la-bemolle-bemolle-, mi-diesis-diesis-diesis-, si-bemolle-bemolle-bemolle-bemolle-,fa-diesis-diesis-diesis-, si-bemolle-bemolle-bemolle-, sol-diesis-,do-bemolle-bemolle-bemolle, si-bemolle-bemolle-, sol-diesis-diesis-,do-bemolle-bemolle, la-diesis-, re-bemolle-bemolle-bemolle-bemolle, sol-diesis-diesis-diesis-,do-bemolle, la-diesis-diesis-, re-bemolle-bemolle-bemolle,la-diesis-diesis-diesis-, mi-bemolle-bemolle-bemolle-bemolle, re-bemolle-bemolle, si-diesis-,do-diesis, mi-bemolle-bemolle-bemolle, si-diesis-diesis-,do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle, si-diesis-diesis-diesis-,do-diesis-diesis-diesis, fa-bemolle-bemolle, re-diesis, sol-bemolle-bemolle-bemolle-bemolle,fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,la-bemolle-bemolle-bemolle-bemolle, mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,fa-diesis, la-bemolle-bemolle-bemolle, mi-diesis-diesis,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis, si-bemolle-bemolle-bemolle-bemolle,fa-diesis-diesis-diesis, si-bemolle-bemolle-bemolle, sol-diesis,do-bemolle-bemolle-bemolle+, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle+, la-diesis, re-bemolle-bemolle-bemolle-bemolle+, sol-diesis-diesis-diesis,do-bemolle+, la-diesis-diesis, re-bemolle-bemolle-bemolle+,la-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle-bemolle+, re-bemolle-bemolle+, si-diesis,do-diesis+, mi-bemolle-bemolle-bemolle+, si-diesis-diesis,do-diesis-diesis+, fa-bemolle-bemolle-bemolle+, mi-bemolle-bemolle+, si-diesis-diesis-diesis,do-diesis-diesis-diesis+, fa-bemolle-bemolle+, re-diesis+, sol-bemolle-bemolle-bemolle-bemolle+,fa-bemolle+, re-diesis-diesis+, sol-bemolle-bemolle-bemolle+,la-bemolle-bemolle-bemolle-bemolle+, mi-diesis+, re-diesis-diesis-diesis+, sol-bemolle-bemolle+,fa-diesis+, la-bemolle-bemolle-bemolle+, mi-diesis-diesis+,fa-diesis-diesis+, la-bemolle-bemolle+, mi-diesis-diesis-diesis+, si-bemolle-bemolle-bemolle-bemolle+,fa-diesis-diesis-diesis+, si-bemolle-bemolle-bemolle+, sol-diesis+,do-bemolle-bemolle-bemolle+2, si-bemolle-bemolle+, sol-diesis-diesis+,do-bemolle-bemolle+2, la-diesis+, re-bemolle-bemolle-bemolle-bemolle+2, sol-diesis-diesis-diesis+,do-bemolle+2, la-diesis-diesis+, re-bemolle-bemolle-bemolle+2,la-diesis-diesis-diesis+, mi-bemolle-bemolle-bemolle-bemolle+2, re-bemolle-bemolle+2, si-diesis+,do-diesis+2, mi-bemolle-bemolle-bemolle+2, si-diesis-diesis+,do-diesis-diesis+2, fa-bemolle-bemolle-bemolle+2, mi-bemolle-bemolle+2, si-diesis-diesis-diesis+,do-diesis-diesis-diesis+2, fa-bemolle-bemolle+2, re-diesis+2, sol-bemolle-bemolle-bemolle-bemolle+2,fa-bemolle+2, re-diesis-diesis+2, sol-bemolle-bemolle-bemolle+2,la-bemolle-bemolle-bemolle-bemolle+2, mi-diesis+2, re-diesis-diesis-diesis+2, sol-bemolle-bemolle+2,fa-diesis+2, la-bemolle-bemolle-bemolle+2, mi-diesis-diesis+2,fa-diesis-diesis+2, la-bemolle-bemolle+2, mi-diesis-diesis-diesis+2, si-bemolle-bemolle-bemolle-bemolle+2,fa-diesis-diesis-diesis+2, si-bemolle-bemolle-bemolle+2, sol-diesis+2,do-bemolle-bemolle-bemolle+3, si-bemolle-bemolle+2, sol-diesis-diesis+2,do-bemolle-bemolle+3, la-diesis+2, re-bemolle-bemolle-bemolle-bemolle+3, sol-diesis-diesis-diesis+2,do-bemolle+3, la-diesis-diesis+2, re-bemolle-bemolle-bemolle+3,la-diesis-diesis-diesis+2, mi-bemolle-bemolle-bemolle-bemolle+3, re-bemolle-bemolle+3, si-diesis+2,do-diesis+3, mi-bemolle-bemolle-bemolle+3, si-diesis-diesis+2,do-diesis-diesis+3, fa-bemolle-bemolle-bemolle+3, mi-bemolle-bemolle+3, si-diesis-diesis-diesis+2,do-diesis-diesis-diesis+3, fa-bemolle-bemolle+3, re-diesis+3, sol-bemolle-bemolle-bemolle-bemolle+3,fa-bemolle+3, re-diesis-diesis+3, sol-bemolle-bemolle-bemolle+3,la-bemolle-bemolle-bemolle-bemolle+3, mi-diesis+3, re-diesis-diesis-diesis+3, sol-bemolle-bemolle+3,fa-diesis+3, la-bemolle-bemolle-bemolle+3, mi-diesis-diesis+3,fa-diesis-diesis+3, la-bemolle-bemolle+3, mi-diesis-diesis-diesis+3, si-bemolle-bemolle-bemolle-bemolle+3,fa-diesis-diesis-diesis+3, si-bemolle-bemolle-bemolle+3, sol-diesis+3,do-bemolle-bemolle-bemolle+4, si-bemolle-bemolle+3, sol-diesis-diesis+3,do-bemolle-bemolle+4, la-diesis+3, re-bemolle-bemolle-bemolle-bemolle+4, sol-diesis-diesis-diesis+3,do-bemolle+4, la-diesis-diesis+3, re-bemolle-bemolle-bemolle+4,la-diesis-diesis-diesis+3, mi-bemolle-bemolle-bemolle-bemolle+4, re-bemolle-bemolle+4, si-diesis+3,do-diesis+4, mi-bemolle-bemolle-bemolle+4, si-diesis-diesis+3,do-diesis-diesis+4, fa-bemolle-bemolle-bemolle+4, mi-bemolle-bemolle+4, si-diesis-diesis-diesis+3,do-diesis-diesis-diesis+4, fa-bemolle-bemolle+4, re-diesis+4, sol-bemolle-bemolle-bemolle-bemolle+4,fa-bemolle+4, re-diesis-diesis+4, sol-bemolle-bemolle-bemolle+4,la-bemolle-bemolle-bemolle-bemolle+4, mi-diesis+4, re-diesis-diesis-diesis+4, sol-bemolle-bemolle+4,fa-diesis+4, la-bemolle-bemolle-bemolle+4, mi-diesis-diesis+4,fa-diesis-diesis+4, la-bemolle-bemolle+4, mi-diesis-diesis-diesis+4, si-bemolle-bemolle-bemolle-bemolle+4,fa-diesis-diesis-diesis+4, si-bemolle-bemolle-bemolle+4, sol-diesis+4,do-bemolle-bemolle-bemolle+5, si-bemolle-bemolle+4, sol-diesis-diesis+4,do-bemolle-bemolle+5, la-diesis+4, re-bemolle-bemolle-bemolle-bemolle+5, sol-diesis-diesis-diesis+4,do-bemolle+5, la-diesis-diesis+4, re-bemolle-bemolle-bemolle+5,la-diesis-diesis-diesis+4, mi-bemolle-bemolle-bemolle-bemolle+5, re-bemolle-bemolle+5, si-diesis+4,do-diesis+5, mi-bemolle-bemolle-bemolle+5, si-diesis-diesis+4,do-diesis-diesis+5, fa-bemolle-bemolle-bemolle+5, mi-bemolle-bemolle+5, si-diesis-diesis-diesis+4,do-diesis-diesis-diesis+5, fa-bemolle-bemolle+5, re-diesis+5, sol-bemolle-bemolle-bemolle-bemolle+5,fa-bemolle+5, re-diesis-diesis+5, sol-bemolle-bemolle-bemolle+5,la-bemolle-bemolle-bemolle-bemolle+5, mi-diesis+5, re-diesis-diesis-diesis+5, sol-bemolle-bemolle+5,fa-diesis+5, la-bemolle-bemolle-bemolle+5, mi-diesis-diesis+5,fa-diesis-diesis+5, la-bemolle-bemolle+5, mi-diesis-diesis-diesis+5, si-bemolle-bemolle-bemolle-bemolle+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "la-diesis-diesis-diesis------, mi-bemolle-bemolle-bemolle-bemolle-----, re-bemolle-bemolle-----, si-diesis------,do-diesis-----, mi-bemolle-bemolle-bemolle-----, si-diesis-diesis------,do-diesis-diesis-----, fa-bemolle-bemolle-bemolle-----, mi-bemolle-bemolle-----, si-diesis-diesis-diesis------,do-diesis-diesis-diesis-----, fa-bemolle-bemolle-----, re-diesis-----, sol-bemolle-bemolle-bemolle-bemolle-----,fa-bemolle-----, re-diesis-diesis-----, sol-bemolle-bemolle-bemolle-----,la-bemolle-bemolle-bemolle-bemolle-----, mi-diesis-----, re-diesis-diesis-diesis-----, sol-bemolle-bemolle-----,fa-diesis-----, la-bemolle-bemolle-bemolle-----, mi-diesis-diesis-----,fa-diesis-diesis-----, la-bemolle-bemolle-----, mi-diesis-diesis-diesis-----, si-bemolle-bemolle-bemolle-bemolle-----,fa-diesis-diesis-diesis-----, si-bemolle-bemolle-bemolle-----, sol-diesis-----,do-bemolle-bemolle-bemolle----, si-bemolle-bemolle-----, sol-diesis-diesis-----,do-bemolle-bemolle----, la-diesis-----, re-bemolle-bemolle-bemolle-bemolle----, sol-diesis-diesis-diesis-----,do-bemolle----, la-diesis-diesis-----, re-bemolle-bemolle-bemolle----,la-diesis-diesis-diesis-----, mi-bemolle-bemolle-bemolle-bemolle----, re-bemolle-bemolle----, si-diesis-----,do-diesis----, mi-bemolle-bemolle-bemolle----, si-diesis-diesis-----,do-diesis-diesis----, fa-bemolle-bemolle-bemolle----, mi-bemolle-bemolle----, si-diesis-diesis-diesis-----,do-diesis-diesis-diesis----, fa-bemolle-bemolle----, re-diesis----, sol-bemolle-bemolle-bemolle-bemolle----,fa-bemolle----, re-diesis-diesis----, sol-bemolle-bemolle-bemolle----,la-bemolle-bemolle-bemolle-bemolle----, mi-diesis----, re-diesis-diesis-diesis----, sol-bemolle-bemolle----,fa-diesis----, la-bemolle-bemolle-bemolle----, mi-diesis-diesis----,fa-diesis-diesis----, la-bemolle-bemolle----, mi-diesis-diesis-diesis----, si-bemolle-bemolle-bemolle-bemolle----,fa-diesis-diesis-diesis----, si-bemolle-bemolle-bemolle----, sol-diesis----,do-bemolle-bemolle-bemolle---, si-bemolle-bemolle----, sol-diesis-diesis----,do-bemolle-bemolle---, la-diesis----, re-bemolle-bemolle-bemolle-bemolle---, sol-diesis-diesis-diesis----,do-bemolle---, la-diesis-diesis----, re-bemolle-bemolle-bemolle---,la-diesis-diesis-diesis----, mi-bemolle-bemolle-bemolle-bemolle---, re-bemolle-bemolle---, si-diesis----,do-diesis---, mi-bemolle-bemolle-bemolle---, si-diesis-diesis----,do-diesis-diesis---, fa-bemolle-bemolle-bemolle---, mi-bemolle-bemolle---, si-diesis-diesis-diesis----,do-diesis-diesis-diesis---, fa-bemolle-bemolle---, re-diesis---, sol-bemolle-bemolle-bemolle-bemolle---,fa-bemolle---, re-diesis-diesis---, sol-bemolle-bemolle-bemolle---,la-bemolle-bemolle-bemolle-bemolle---, mi-diesis---, re-diesis-diesis-diesis---, sol-bemolle-bemolle---,fa-diesis---, la-bemolle-bemolle-bemolle---, mi-diesis-diesis---,fa-diesis-diesis---, la-bemolle-bemolle---, mi-diesis-diesis-diesis---, si-bemolle-bemolle-bemolle-bemolle---,fa-diesis-diesis-diesis---, si-bemolle-bemolle-bemolle---, sol-diesis---,do-bemolle-bemolle-bemolle--, si-bemolle-bemolle---, sol-diesis-diesis---,do-bemolle-bemolle--, la-diesis---, re-bemolle-bemolle-bemolle-bemolle--, sol-diesis-diesis-diesis---,do-bemolle--, la-diesis-diesis---, re-bemolle-bemolle-bemolle--,la-diesis-diesis-diesis---, mi-bemolle-bemolle-bemolle-bemolle--, re-bemolle-bemolle--, si-diesis---,do-diesis--, mi-bemolle-bemolle-bemolle--, si-diesis-diesis---,do-diesis-diesis--, fa-bemolle-bemolle-bemolle--, mi-bemolle-bemolle--, si-diesis-diesis-diesis---,do-diesis-diesis-diesis--, fa-bemolle-bemolle--, re-diesis--, sol-bemolle-bemolle-bemolle-bemolle--,fa-bemolle--, re-diesis-diesis--, sol-bemolle-bemolle-bemolle--,la-bemolle-bemolle-bemolle-bemolle--, mi-diesis--, re-diesis-diesis-diesis--, sol-bemolle-bemolle--,fa-diesis--, la-bemolle-bemolle-bemolle--, mi-diesis-diesis--,fa-diesis-diesis--, la-bemolle-bemolle--, mi-diesis-diesis-diesis--, si-bemolle-bemolle-bemolle-bemolle--,fa-diesis-diesis-diesis--, si-bemolle-bemolle-bemolle--, sol-diesis--,do-bemolle-bemolle-bemolle-, si-bemolle-bemolle--, sol-diesis-diesis--,do-bemolle-bemolle-, la-diesis--, re-bemolle-bemolle-bemolle-bemolle-, sol-diesis-diesis-diesis--,do-bemolle-, la-diesis-diesis--, re-bemolle-bemolle-bemolle-,la-diesis-diesis-diesis--, mi-bemolle-bemolle-bemolle-bemolle-, re-bemolle-bemolle-, si-diesis--,do-diesis-, mi-bemolle-bemolle-bemolle-, si-diesis-diesis--,do-diesis-diesis-, fa-bemolle-bemolle-bemolle-, mi-bemolle-bemolle-, si-diesis-diesis-diesis--,do-diesis-diesis-diesis-, fa-bemolle-bemolle-, re-diesis-, sol-bemolle-bemolle-bemolle-bemolle-,fa-bemolle-, re-diesis-diesis-, sol-bemolle-bemolle-bemolle-,la-bemolle-bemolle-bemolle-bemolle-, mi-diesis-, re-diesis-diesis-diesis-, sol-bemolle-bemolle-,fa-diesis-, la-bemolle-bemolle-bemolle-, mi-diesis-diesis-,fa-diesis-diesis-, la-bemolle-bemolle-, mi-diesis-diesis-diesis-, si-bemolle-bemolle-bemolle-bemolle-,fa-diesis-diesis-diesis-, si-bemolle-bemolle-bemolle-, sol-diesis-,do-bemolle-bemolle-bemolle, si-bemolle-bemolle-, sol-diesis-diesis-,do-bemolle-bemolle, la-diesis-, re-bemolle-bemolle-bemolle-bemolle, sol-diesis-diesis-diesis-,do-bemolle, la-diesis-diesis-, re-bemolle-bemolle-bemolle,la-diesis-diesis-diesis-, mi-bemolle-bemolle-bemolle-bemolle, re-bemolle-bemolle, si-diesis-,do-diesis, mi-bemolle-bemolle-bemolle, si-diesis-diesis-,do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle, si-diesis-diesis-diesis-,do-diesis-diesis-diesis, fa-bemolle-bemolle, re-diesis, sol-bemolle-bemolle-bemolle-bemolle,fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,la-bemolle-bemolle-bemolle-bemolle, mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,fa-diesis, la-bemolle-bemolle-bemolle, mi-diesis-diesis,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis, si-bemolle-bemolle-bemolle-bemolle,fa-diesis-diesis-diesis, si-bemolle-bemolle-bemolle, sol-diesis,do-bemolle-bemolle-bemolle+, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle+, la-diesis, re-bemolle-bemolle-bemolle-bemolle+, sol-diesis-diesis-diesis,do-bemolle+, la-diesis-diesis, re-bemolle-bemolle-bemolle+,la-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle-bemolle+, re-bemolle-bemolle+, si-diesis,do-diesis+, mi-bemolle-bemolle-bemolle+, si-diesis-diesis,do-diesis-diesis+, fa-bemolle-bemolle-bemolle+, mi-bemolle-bemolle+, si-diesis-diesis-diesis,do-diesis-diesis-diesis+, fa-bemolle-bemolle+, re-diesis+, sol-bemolle-bemolle-bemolle-bemolle+,fa-bemolle+, re-diesis-diesis+, sol-bemolle-bemolle-bemolle+,la-bemolle-bemolle-bemolle-bemolle+, mi-diesis+, re-diesis-diesis-diesis+, sol-bemolle-bemolle+,fa-diesis+, la-bemolle-bemolle-bemolle+, mi-diesis-diesis+,fa-diesis-diesis+, la-bemolle-bemolle+, mi-diesis-diesis-diesis+, si-bemolle-bemolle-bemolle-bemolle+,fa-diesis-diesis-diesis+, si-bemolle-bemolle-bemolle+, sol-diesis+,do-bemolle-bemolle-bemolle++, si-bemolle-bemolle+, sol-diesis-diesis+,do-bemolle-bemolle++, la-diesis+, re-bemolle-bemolle-bemolle-bemolle++, sol-diesis-diesis-diesis+,do-bemolle++, la-diesis-diesis+, re-bemolle-bemolle-bemolle++,la-diesis-diesis-diesis+, mi-bemolle-bemolle-bemolle-bemolle++, re-bemolle-bemolle++, si-diesis+,do-diesis++, mi-bemolle-bemolle-bemolle++, si-diesis-diesis+,do-diesis-diesis++, fa-bemolle-bemolle-bemolle++, mi-bemolle-bemolle++, si-diesis-diesis-diesis+,do-diesis-diesis-diesis++, fa-bemolle-bemolle++, re-diesis++, sol-bemolle-bemolle-bemolle-bemolle++,fa-bemolle++, re-diesis-diesis++, sol-bemolle-bemolle-bemolle++,la-bemolle-bemolle-bemolle-bemolle++, mi-diesis++, re-diesis-diesis-diesis++, sol-bemolle-bemolle++,fa-diesis++, la-bemolle-bemolle-bemolle++, mi-diesis-diesis++,fa-diesis-diesis++, la-bemolle-bemolle++, mi-diesis-diesis-diesis++, si-bemolle-bemolle-bemolle-bemolle++,fa-diesis-diesis-diesis++, si-bemolle-bemolle-bemolle++, sol-diesis++,do-bemolle-bemolle-bemolle+++, si-bemolle-bemolle++, sol-diesis-diesis++,do-bemolle-bemolle+++, la-diesis++, re-bemolle-bemolle-bemolle-bemolle+++, sol-diesis-diesis-diesis++,do-bemolle+++, la-diesis-diesis++, re-bemolle-bemolle-bemolle+++,la-diesis-diesis-diesis++, mi-bemolle-bemolle-bemolle-bemolle+++, re-bemolle-bemolle+++, si-diesis++,do-diesis+++, mi-bemolle-bemolle-bemolle+++, si-diesis-diesis++,do-diesis-diesis+++, fa-bemolle-bemolle-bemolle+++, mi-bemolle-bemolle+++, si-diesis-diesis-diesis++,do-diesis-diesis-diesis+++, fa-bemolle-bemolle+++, re-diesis+++, sol-bemolle-bemolle-bemolle-bemolle+++,fa-bemolle+++, re-diesis-diesis+++, sol-bemolle-bemolle-bemolle+++,la-bemolle-bemolle-bemolle-bemolle+++, mi-diesis+++, re-diesis-diesis-diesis+++, sol-bemolle-bemolle+++,fa-diesis+++, la-bemolle-bemolle-bemolle+++, mi-diesis-diesis+++,fa-diesis-diesis+++, la-bemolle-bemolle+++, mi-diesis-diesis-diesis+++, si-bemolle-bemolle-bemolle-bemolle+++,fa-diesis-diesis-diesis+++, si-bemolle-bemolle-bemolle+++, sol-diesis+++,do-bemolle-bemolle-bemolle++++, si-bemolle-bemolle+++, sol-diesis-diesis+++,do-bemolle-bemolle++++, la-diesis+++, re-bemolle-bemolle-bemolle-bemolle++++, sol-diesis-diesis-diesis+++,do-bemolle++++, la-diesis-diesis+++, re-bemolle-bemolle-bemolle++++,la-diesis-diesis-diesis+++, mi-bemolle-bemolle-bemolle-bemolle++++, re-bemolle-bemolle++++, si-diesis+++,do-diesis++++, mi-bemolle-bemolle-bemolle++++, si-diesis-diesis+++,do-diesis-diesis++++, fa-bemolle-bemolle-bemolle++++, mi-bemolle-bemolle++++, si-diesis-diesis-diesis+++,do-diesis-diesis-diesis++++, fa-bemolle-bemolle++++, re-diesis++++, sol-bemolle-bemolle-bemolle-bemolle++++,fa-bemolle++++, re-diesis-diesis++++, sol-bemolle-bemolle-bemolle++++,la-bemolle-bemolle-bemolle-bemolle++++, mi-diesis++++, re-diesis-diesis-diesis++++, sol-bemolle-bemolle++++,fa-diesis++++, la-bemolle-bemolle-bemolle++++, mi-diesis-diesis++++,fa-diesis-diesis++++, la-bemolle-bemolle++++, mi-diesis-diesis-diesis++++, si-bemolle-bemolle-bemolle-bemolle++++,fa-diesis-diesis-diesis++++, si-bemolle-bemolle-bemolle++++, sol-diesis++++,do-bemolle-bemolle-bemolle+++++, si-bemolle-bemolle++++, sol-diesis-diesis++++,do-bemolle-bemolle+++++, la-diesis++++, re-bemolle-bemolle-bemolle-bemolle+++++, sol-diesis-diesis-diesis++++,do-bemolle+++++, la-diesis-diesis++++, re-bemolle-bemolle-bemolle+++++,la-diesis-diesis-diesis++++, mi-bemolle-bemolle-bemolle-bemolle+++++, re-bemolle-bemolle+++++, si-diesis++++,do-diesis+++++, mi-bemolle-bemolle-bemolle+++++, si-diesis-diesis++++,do-diesis-diesis+++++, fa-bemolle-bemolle-bemolle+++++, mi-bemolle-bemolle+++++, si-diesis-diesis-diesis++++,do-diesis-diesis-diesis+++++, fa-bemolle-bemolle+++++, re-diesis+++++, sol-bemolle-bemolle-bemolle-bemolle+++++,fa-bemolle+++++, re-diesis-diesis+++++, sol-bemolle-bemolle-bemolle+++++,la-bemolle-bemolle-bemolle-bemolle+++++, mi-diesis+++++, re-diesis-diesis-diesis+++++, sol-bemolle-bemolle+++++,fa-diesis+++++, la-bemolle-bemolle-bemolle+++++, mi-diesis-diesis+++++,fa-diesis-diesis+++++, la-bemolle-bemolle+++++, mi-diesis-diesis-diesis+++++, si-bemolle-bemolle-bemolle-bemolle+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "la-diesis-diesis-diesis-2, mi-bemolle-bemolle-bemolle-bemolle-1, re-bemolle-bemolle-1, si-diesis-2,do-diesis-1, mi-bemolle-bemolle-bemolle-1, si-diesis-diesis-2,do-diesis-diesis-1, fa-bemolle-bemolle-bemolle-1, mi-bemolle-bemolle-1, si-diesis-diesis-diesis-2,do-diesis-diesis-diesis-1, fa-bemolle-bemolle-1, re-diesis-1, sol-bemolle-bemolle-bemolle-bemolle-1,fa-bemolle-1, re-diesis-diesis-1, sol-bemolle-bemolle-bemolle-1,la-bemolle-bemolle-bemolle-bemolle-1, mi-diesis-1, re-diesis-diesis-diesis-1, sol-bemolle-bemolle-1,fa-diesis-1, la-bemolle-bemolle-bemolle-1, mi-diesis-diesis-1,fa-diesis-diesis-1, la-bemolle-bemolle-1, mi-diesis-diesis-diesis-1, si-bemolle-bemolle-bemolle-bemolle-1,fa-diesis-diesis-diesis-1, si-bemolle-bemolle-bemolle-1, sol-diesis-1,do-bemolle-bemolle-bemolle0, si-bemolle-bemolle-1, sol-diesis-diesis-1,do-bemolle-bemolle0, la-diesis-1, re-bemolle-bemolle-bemolle-bemolle0, sol-diesis-diesis-diesis-1,do-bemolle0, la-diesis-diesis-1, re-bemolle-bemolle-bemolle0,la-diesis-diesis-diesis-1, mi-bemolle-bemolle-bemolle-bemolle0, re-bemolle-bemolle0, si-diesis-1,do-diesis0, mi-bemolle-bemolle-bemolle0, si-diesis-diesis-1,do-diesis-diesis0, fa-bemolle-bemolle-bemolle0, mi-bemolle-bemolle0, si-diesis-diesis-diesis-1,do-diesis-diesis-diesis0, fa-bemolle-bemolle0, re-diesis0, sol-bemolle-bemolle-bemolle-bemolle0,fa-bemolle0, re-diesis-diesis0, sol-bemolle-bemolle-bemolle0,la-bemolle-bemolle-bemolle-bemolle0, mi-diesis0, re-diesis-diesis-diesis0, sol-bemolle-bemolle0,fa-diesis0, la-bemolle-bemolle-bemolle0, mi-diesis-diesis0,fa-diesis-diesis0, la-bemolle-bemolle0, mi-diesis-diesis-diesis0, si-bemolle-bemolle-bemolle-bemolle0,fa-diesis-diesis-diesis0, si-bemolle-bemolle-bemolle0, sol-diesis0,do-bemolle-bemolle-bemolle1, si-bemolle-bemolle0, sol-diesis-diesis0,do-bemolle-bemolle1, la-diesis0, re-bemolle-bemolle-bemolle-bemolle1, sol-diesis-diesis-diesis0,do-bemolle1, la-diesis-diesis0, re-bemolle-bemolle-bemolle1,la-diesis-diesis-diesis0, mi-bemolle-bemolle-bemolle-bemolle1, re-bemolle-bemolle1, si-diesis0,do-diesis1, mi-bemolle-bemolle-bemolle1, si-diesis-diesis0,do-diesis-diesis1, fa-bemolle-bemolle-bemolle1, mi-bemolle-bemolle1, si-diesis-diesis-diesis0,do-diesis-diesis-diesis1, fa-bemolle-bemolle1, re-diesis1, sol-bemolle-bemolle-bemolle-bemolle1,fa-bemolle1, re-diesis-diesis1, sol-bemolle-bemolle-bemolle1,la-bemolle-bemolle-bemolle-bemolle1, mi-diesis1, re-diesis-diesis-diesis1, sol-bemolle-bemolle1,fa-diesis1, la-bemolle-bemolle-bemolle1, mi-diesis-diesis1,fa-diesis-diesis1, la-bemolle-bemolle1, mi-diesis-diesis-diesis1, si-bemolle-bemolle-bemolle-bemolle1,fa-diesis-diesis-diesis1, si-bemolle-bemolle-bemolle1, sol-diesis1,do-bemolle-bemolle-bemolle2, si-bemolle-bemolle1, sol-diesis-diesis1,do-bemolle-bemolle2, la-diesis1, re-bemolle-bemolle-bemolle-bemolle2, sol-diesis-diesis-diesis1,do-bemolle2, la-diesis-diesis1, re-bemolle-bemolle-bemolle2,la-diesis-diesis-diesis1, mi-bemolle-bemolle-bemolle-bemolle2, re-bemolle-bemolle2, si-diesis1,do-diesis2, mi-bemolle-bemolle-bemolle2, si-diesis-diesis1,do-diesis-diesis2, fa-bemolle-bemolle-bemolle2, mi-bemolle-bemolle2, si-diesis-diesis-diesis1,do-diesis-diesis-diesis2, fa-bemolle-bemolle2, re-diesis2, sol-bemolle-bemolle-bemolle-bemolle2,fa-bemolle2, re-diesis-diesis2, sol-bemolle-bemolle-bemolle2,la-bemolle-bemolle-bemolle-bemolle2, mi-diesis2, re-diesis-diesis-diesis2, sol-bemolle-bemolle2,fa-diesis2, la-bemolle-bemolle-bemolle2, mi-diesis-diesis2,fa-diesis-diesis2, la-bemolle-bemolle2, mi-diesis-diesis-diesis2, si-bemolle-bemolle-bemolle-bemolle2,fa-diesis-diesis-diesis2, si-bemolle-bemolle-bemolle2, sol-diesis2,do-bemolle-bemolle-bemolle3, si-bemolle-bemolle2, sol-diesis-diesis2,do-bemolle-bemolle3, la-diesis2, re-bemolle-bemolle-bemolle-bemolle3, sol-diesis-diesis-diesis2,do-bemolle3, la-diesis-diesis2, re-bemolle-bemolle-bemolle3,la-diesis-diesis-diesis2, mi-bemolle-bemolle-bemolle-bemolle3, re-bemolle-bemolle3, si-diesis2,do-diesis3, mi-bemolle-bemolle-bemolle3, si-diesis-diesis2,do-diesis-diesis3, fa-bemolle-bemolle-bemolle3, mi-bemolle-bemolle3, si-diesis-diesis-diesis2,do-diesis-diesis-diesis3, fa-bemolle-bemolle3, re-diesis3, sol-bemolle-bemolle-bemolle-bemolle3,fa-bemolle3, re-diesis-diesis3, sol-bemolle-bemolle-bemolle3,la-bemolle-bemolle-bemolle-bemolle3, mi-diesis3, re-diesis-diesis-diesis3, sol-bemolle-bemolle3,fa-diesis3, la-bemolle-bemolle-bemolle3, mi-diesis-diesis3,fa-diesis-diesis3, la-bemolle-bemolle3, mi-diesis-diesis-diesis3, si-bemolle-bemolle-bemolle-bemolle3,fa-diesis-diesis-diesis3, si-bemolle-bemolle-bemolle3, sol-diesis3,do-bemolle-bemolle-bemolle4, si-bemolle-bemolle3, sol-diesis-diesis3,do-bemolle-bemolle4, la-diesis3, re-bemolle-bemolle-bemolle-bemolle4, sol-diesis-diesis-diesis3,do-bemolle4, la-diesis-diesis3, re-bemolle-bemolle-bemolle4,la-diesis-diesis-diesis3, mi-bemolle-bemolle-bemolle-bemolle4, re-bemolle-bemolle4, si-diesis3,do-diesis4, mi-bemolle-bemolle-bemolle4, si-diesis-diesis3,do-diesis-diesis4, fa-bemolle-bemolle-bemolle4, mi-bemolle-bemolle4, si-diesis-diesis-diesis3,do-diesis-diesis-diesis4, fa-bemolle-bemolle4, re-diesis4, sol-bemolle-bemolle-bemolle-bemolle4,fa-bemolle4, re-diesis-diesis4, sol-bemolle-bemolle-bemolle4,la-bemolle-bemolle-bemolle-bemolle4, mi-diesis4, re-diesis-diesis-diesis4, sol-bemolle-bemolle4,fa-diesis4, la-bemolle-bemolle-bemolle4, mi-diesis-diesis4,fa-diesis-diesis4, la-bemolle-bemolle4, mi-diesis-diesis-diesis4, si-bemolle-bemolle-bemolle-bemolle4,fa-diesis-diesis-diesis4, si-bemolle-bemolle-bemolle4, sol-diesis4,do-bemolle-bemolle-bemolle5, si-bemolle-bemolle4, sol-diesis-diesis4,do-bemolle-bemolle5, la-diesis4, re-bemolle-bemolle-bemolle-bemolle5, sol-diesis-diesis-diesis4,do-bemolle5, la-diesis-diesis4, re-bemolle-bemolle-bemolle5,la-diesis-diesis-diesis4, mi-bemolle-bemolle-bemolle-bemolle5, re-bemolle-bemolle5, si-diesis4,do-diesis5, mi-bemolle-bemolle-bemolle5, si-diesis-diesis4,do-diesis-diesis5, fa-bemolle-bemolle-bemolle5, mi-bemolle-bemolle5, si-diesis-diesis-diesis4,do-diesis-diesis-diesis5, fa-bemolle-bemolle5, re-diesis5, sol-bemolle-bemolle-bemolle-bemolle5,fa-bemolle5, re-diesis-diesis5, sol-bemolle-bemolle-bemolle5,la-bemolle-bemolle-bemolle-bemolle5, mi-diesis5, re-diesis-diesis-diesis5, sol-bemolle-bemolle5,fa-diesis5, la-bemolle-bemolle-bemolle5, mi-diesis-diesis5,fa-diesis-diesis5, la-bemolle-bemolle5, mi-diesis-diesis-diesis5, si-bemolle-bemolle-bemolle-bemolle5,fa-diesis-diesis-diesis5, si-bemolle-bemolle-bemolle5, sol-diesis5,do-bemolle-bemolle-bemolle6, si-bemolle-bemolle5, sol-diesis-diesis5,do-bemolle-bemolle6, la-diesis5, re-bemolle-bemolle-bemolle-bemolle6, sol-diesis-diesis-diesis5,do-bemolle6, la-diesis-diesis5, re-bemolle-bemolle-bemolle6,la-diesis-diesis-diesis5, mi-bemolle-bemolle-bemolle-bemolle6, re-bemolle-bemolle6, si-diesis5,do-diesis6, mi-bemolle-bemolle-bemolle6, si-diesis-diesis5,do-diesis-diesis6, fa-bemolle-bemolle-bemolle6, mi-bemolle-bemolle6, si-diesis-diesis-diesis5,do-diesis-diesis-diesis6, fa-bemolle-bemolle6, re-diesis6, sol-bemolle-bemolle-bemolle-bemolle6,fa-bemolle6, re-diesis-diesis6, sol-bemolle-bemolle-bemolle6,la-bemolle-bemolle-bemolle-bemolle6, mi-diesis6, re-diesis-diesis-diesis6, sol-bemolle-bemolle6,fa-diesis6, la-bemolle-bemolle-bemolle6, mi-diesis-diesis6,fa-diesis-diesis6, la-bemolle-bemolle6, mi-diesis-diesis-diesis6, si-bemolle-bemolle-bemolle-bemolle6,fa-diesis-diesis-diesis6, si-bemolle-bemolle-bemolle6, sol-diesis6,do-bemolle-bemolle-bemolle7, si-bemolle-bemolle6, sol-diesis-diesis6,do-bemolle-bemolle7, la-diesis6, re-bemolle-bemolle-bemolle-bemolle7, sol-diesis-diesis-diesis6,do-bemolle7, la-diesis-diesis6, re-bemolle-bemolle-bemolle7,la-diesis-diesis-diesis6, mi-bemolle-bemolle-bemolle-bemolle7, re-bemolle-bemolle7, si-diesis6,do-diesis7, mi-bemolle-bemolle-bemolle7, si-diesis-diesis6,do-diesis-diesis7, fa-bemolle-bemolle-bemolle7, mi-bemolle-bemolle7, si-diesis-diesis-diesis6,do-diesis-diesis-diesis7, fa-bemolle-bemolle7, re-diesis7, sol-bemolle-bemolle-bemolle-bemolle7,fa-bemolle7, re-diesis-diesis7, sol-bemolle-bemolle-bemolle7,la-bemolle-bemolle-bemolle-bemolle7, mi-diesis7, re-diesis-diesis-diesis7, sol-bemolle-bemolle7,fa-diesis7, la-bemolle-bemolle-bemolle7, mi-diesis-diesis7,fa-diesis-diesis7, la-bemolle-bemolle7, mi-diesis-diesis-diesis7, si-bemolle-bemolle-bemolle-bemolle7,fa-diesis-diesis-diesis7, si-bemolle-bemolle-bemolle7, sol-diesis7,do-bemolle-bemolle-bemolle8, si-bemolle-bemolle7, sol-diesis-diesis7,do-bemolle-bemolle8, la-diesis7, re-bemolle-bemolle-bemolle-bemolle8, sol-diesis-diesis-diesis7,do-bemolle8, la-diesis-diesis7, re-bemolle-bemolle-bemolle8,la-diesis-diesis-diesis7, mi-bemolle-bemolle-bemolle-bemolle8, re-bemolle-bemolle8, si-diesis7,do-diesis8, mi-bemolle-bemolle-bemolle8, si-diesis-diesis7,do-diesis-diesis8, fa-bemolle-bemolle-bemolle8, mi-bemolle-bemolle8, si-diesis-diesis-diesis7,do-diesis-diesis-diesis8, fa-bemolle-bemolle8, re-diesis8, sol-bemolle-bemolle-bemolle-bemolle8,fa-bemolle8, re-diesis-diesis8, sol-bemolle-bemolle-bemolle8,la-bemolle-bemolle-bemolle-bemolle8, mi-diesis8, re-diesis-diesis-diesis8, sol-bemolle-bemolle8,fa-diesis8, la-bemolle-bemolle-bemolle8, mi-diesis-diesis8,fa-diesis-diesis8, la-bemolle-bemolle8, mi-diesis-diesis-diesis8, si-bemolle-bemolle-bemolle-bemolle8,fa-diesis-diesis-diesis8, si-bemolle-bemolle-bemolle8, sol-diesis8,do-bemolle-bemolle-bemolle9, si-bemolle-bemolle8, sol-diesis-diesis8,do-bemolle-bemolle9, la-diesis8, re-bemolle-bemolle-bemolle-bemolle9, sol-diesis-diesis-diesis8,do-bemolle9, la-diesis-diesis8, re-bemolle-bemolle-bemolle9,la-diesis-diesis-diesis8, mi-bemolle-bemolle-bemolle-bemolle9, re-bemolle-bemolle9, si-diesis8,do-diesis9, mi-bemolle-bemolle-bemolle9, si-diesis-diesis8,do-diesis-diesis9, fa-bemolle-bemolle-bemolle9, mi-bemolle-bemolle9, si-diesis-diesis-diesis8,do-diesis-diesis-diesis9, fa-bemolle-bemolle9, re-diesis9, sol-bemolle-bemolle-bemolle-bemolle9,fa-bemolle9, re-diesis-diesis9, sol-bemolle-bemolle-bemolle9,la-bemolle-bemolle-bemolle-bemolle9, mi-diesis9, re-diesis-diesis-diesis9, sol-bemolle-bemolle9,fa-diesis9, la-bemolle-bemolle-bemolle9, mi-diesis-diesis9,fa-diesis-diesis9, la-bemolle-bemolle9, mi-diesis-diesis-diesis9, si-bemolle-bemolle-bemolle-bemolle9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "La-diesis-diesis-diesis'''', Mi-bemolle-bemolle-bemolle-bemolle''', Re-bemolle-bemolle''', Si-diesis'''',Do-diesis''', Mi-bemolle-bemolle-bemolle''', Si-diesis-diesis'''',Do-diesis-diesis''', Fa-bemolle-bemolle-bemolle''', Mi-bemolle-bemolle''', Si-diesis-diesis-diesis'''',Do-diesis-diesis-diesis''', Fa-bemolle-bemolle''', Re-diesis''', Sol-bemolle-bemolle-bemolle-bemolle''',Fa-bemolle''', Re-diesis-diesis''', Sol-bemolle-bemolle-bemolle''',La-bemolle-bemolle-bemolle-bemolle''', Mi-diesis''', Re-diesis-diesis-diesis''', Sol-bemolle-bemolle''',Fa-diesis''', La-bemolle-bemolle-bemolle''', Mi-diesis-diesis''',Fa-diesis-diesis''', La-bemolle-bemolle''', Mi-diesis-diesis-diesis''', Si-bemolle-bemolle-bemolle-bemolle''',Fa-diesis-diesis-diesis''', Si-bemolle-bemolle-bemolle''', Sol-diesis''',Do-bemolle-bemolle-bemolle'', Si-bemolle-bemolle''', Sol-diesis-diesis''',Do-bemolle-bemolle'', La-diesis''', Re-bemolle-bemolle-bemolle-bemolle'', Sol-diesis-diesis-diesis''',Do-bemolle'', La-diesis-diesis''', Re-bemolle-bemolle-bemolle'',La-diesis-diesis-diesis''', Mi-bemolle-bemolle-bemolle-bemolle'', Re-bemolle-bemolle'', Si-diesis''',Do-diesis'', Mi-bemolle-bemolle-bemolle'', Si-diesis-diesis''',Do-diesis-diesis'', Fa-bemolle-bemolle-bemolle'', Mi-bemolle-bemolle'', Si-diesis-diesis-diesis''',Do-diesis-diesis-diesis'', Fa-bemolle-bemolle'', Re-diesis'', Sol-bemolle-bemolle-bemolle-bemolle'',Fa-bemolle'', Re-diesis-diesis'', Sol-bemolle-bemolle-bemolle'',La-bemolle-bemolle-bemolle-bemolle'', Mi-diesis'', Re-diesis-diesis-diesis'', Sol-bemolle-bemolle'',Fa-diesis'', La-bemolle-bemolle-bemolle'', Mi-diesis-diesis'',Fa-diesis-diesis'', La-bemolle-bemolle'', Mi-diesis-diesis-diesis'', Si-bemolle-bemolle-bemolle-bemolle'',Fa-diesis-diesis-diesis'', Si-bemolle-bemolle-bemolle'', Sol-diesis'',Do-bemolle-bemolle-bemolle', Si-bemolle-bemolle'', Sol-diesis-diesis'',Do-bemolle-bemolle', La-diesis'', Re-bemolle-bemolle-bemolle-bemolle', Sol-diesis-diesis-diesis'',Do-bemolle', La-diesis-diesis'', Re-bemolle-bemolle-bemolle',La-diesis-diesis-diesis'', Mi-bemolle-bemolle-bemolle-bemolle', Re-bemolle-bemolle', Si-diesis'',Do-diesis', Mi-bemolle-bemolle-bemolle', Si-diesis-diesis'',Do-diesis-diesis', Fa-bemolle-bemolle-bemolle', Mi-bemolle-bemolle', Si-diesis-diesis-diesis'',Do-diesis-diesis-diesis', Fa-bemolle-bemolle', Re-diesis', Sol-bemolle-bemolle-bemolle-bemolle',Fa-bemolle', Re-diesis-diesis', Sol-bemolle-bemolle-bemolle',La-bemolle-bemolle-bemolle-bemolle', Mi-diesis', Re-diesis-diesis-diesis', Sol-bemolle-bemolle',Fa-diesis', La-bemolle-bemolle-bemolle', Mi-diesis-diesis',Fa-diesis-diesis', La-bemolle-bemolle', Mi-diesis-diesis-diesis', Si-bemolle-bemolle-bemolle-bemolle',Fa-diesis-diesis-diesis', Si-bemolle-bemolle-bemolle', Sol-diesis',Do-bemolle-bemolle-bemolle, Si-bemolle-bemolle', Sol-diesis-diesis',Do-bemolle-bemolle, La-diesis', Re-bemolle-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis',Do-bemolle, La-diesis-diesis', Re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis', Mi-bemolle-bemolle-bemolle-bemolle, Re-bemolle-bemolle, Si-diesis',Do-diesis, Mi-bemolle-bemolle-bemolle, Si-diesis-diesis',Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis',Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Re-diesis, Sol-bemolle-bemolle-bemolle-bemolle,Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,La-bemolle-bemolle-bemolle-bemolle, Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,Fa-diesis, La-bemolle-bemolle-bemolle, Mi-diesis-diesis,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle, Sol-diesis,Si-bemolle-bemolle, Sol-diesis-diesis, do-bemolle-bemolle-bemolle,La-diesis, Sol-diesis-diesis-diesis, do-bemolle-bemolle, re-bemolle-bemolle-bemolle-bemolle,La-diesis-diesis, do-bemolle, re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis, Si-diesis, mi-bemolle-bemolle-bemolle-bemolle, re-bemolle-bemolle,Si-diesis-diesis, do-diesis, mi-bemolle-bemolle-bemolle,Si-diesis-diesis-diesis, do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle,do-diesis-diesis-diesis, fa-bemolle-bemolle, re-diesis, sol-bemolle-bemolle-bemolle-bemolle,fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,la-bemolle-bemolle-bemolle-bemolle, mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,fa-diesis, la-bemolle-bemolle-bemolle, mi-diesis-diesis,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis, si-bemolle-bemolle-bemolle-bemolle,fa-diesis-diesis-diesis, si-bemolle-bemolle-bemolle, sol-diesis,do-bemolle-bemolle-bemolle', si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle', la-diesis, re-bemolle-bemolle-bemolle-bemolle', sol-diesis-diesis-diesis,do-bemolle', la-diesis-diesis, re-bemolle-bemolle-bemolle',la-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle-bemolle', re-bemolle-bemolle', si-diesis,do-diesis', mi-bemolle-bemolle-bemolle', si-diesis-diesis,do-diesis-diesis', fa-bemolle-bemolle-bemolle', mi-bemolle-bemolle', si-diesis-diesis-diesis,do-diesis-diesis-diesis', fa-bemolle-bemolle', re-diesis', sol-bemolle-bemolle-bemolle-bemolle',fa-bemolle', re-diesis-diesis', sol-bemolle-bemolle-bemolle',la-bemolle-bemolle-bemolle-bemolle', mi-diesis', re-diesis-diesis-diesis', sol-bemolle-bemolle',fa-diesis', la-bemolle-bemolle-bemolle', mi-diesis-diesis',fa-diesis-diesis', la-bemolle-bemolle', mi-diesis-diesis-diesis', si-bemolle-bemolle-bemolle-bemolle',fa-diesis-diesis-diesis', si-bemolle-bemolle-bemolle', sol-diesis',do-bemolle-bemolle-bemolle'', si-bemolle-bemolle', sol-diesis-diesis',do-bemolle-bemolle'', la-diesis', re-bemolle-bemolle-bemolle-bemolle'', sol-diesis-diesis-diesis',do-bemolle'', la-diesis-diesis', re-bemolle-bemolle-bemolle'',la-diesis-diesis-diesis', mi-bemolle-bemolle-bemolle-bemolle'', re-bemolle-bemolle'', si-diesis',do-diesis'', mi-bemolle-bemolle-bemolle'', si-diesis-diesis',do-diesis-diesis'', fa-bemolle-bemolle-bemolle'', mi-bemolle-bemolle'', si-diesis-diesis-diesis',do-diesis-diesis-diesis'', fa-bemolle-bemolle'', re-diesis'', sol-bemolle-bemolle-bemolle-bemolle'',fa-bemolle'', re-diesis-diesis'', sol-bemolle-bemolle-bemolle'',la-bemolle-bemolle-bemolle-bemolle'', mi-diesis'', re-diesis-diesis-diesis'', sol-bemolle-bemolle'',fa-diesis'', la-bemolle-bemolle-bemolle'', mi-diesis-diesis'',fa-diesis-diesis'', la-bemolle-bemolle'', mi-diesis-diesis-diesis'', si-bemolle-bemolle-bemolle-bemolle'',fa-diesis-diesis-diesis'', si-bemolle-bemolle-bemolle'', sol-diesis'',do-bemolle-bemolle-bemolle''', si-bemolle-bemolle'', sol-diesis-diesis'',do-bemolle-bemolle''', la-diesis'', re-bemolle-bemolle-bemolle-bemolle''', sol-diesis-diesis-diesis'',do-bemolle''', la-diesis-diesis'', re-bemolle-bemolle-bemolle''',la-diesis-diesis-diesis'', mi-bemolle-bemolle-bemolle-bemolle''', re-bemolle-bemolle''', si-diesis'',do-diesis''', mi-bemolle-bemolle-bemolle''', si-diesis-diesis'',do-diesis-diesis''', fa-bemolle-bemolle-bemolle''', mi-bemolle-bemolle''', si-diesis-diesis-diesis'',do-diesis-diesis-diesis''', fa-bemolle-bemolle''', re-diesis''', sol-bemolle-bemolle-bemolle-bemolle''',fa-bemolle''', re-diesis-diesis''', sol-bemolle-bemolle-bemolle''',la-bemolle-bemolle-bemolle-bemolle''', mi-diesis''', re-diesis-diesis-diesis''', sol-bemolle-bemolle''',fa-diesis''', la-bemolle-bemolle-bemolle''', mi-diesis-diesis''',fa-diesis-diesis''', la-bemolle-bemolle''', mi-diesis-diesis-diesis''', si-bemolle-bemolle-bemolle-bemolle''',fa-diesis-diesis-diesis''', si-bemolle-bemolle-bemolle''', sol-diesis''',do-bemolle-bemolle-bemolle'''', si-bemolle-bemolle''', sol-diesis-diesis''',do-bemolle-bemolle'''', la-diesis''', re-bemolle-bemolle-bemolle-bemolle'''', sol-diesis-diesis-diesis''',do-bemolle'''', la-diesis-diesis''', re-bemolle-bemolle-bemolle'''',la-diesis-diesis-diesis''', mi-bemolle-bemolle-bemolle-bemolle'''', re-bemolle-bemolle'''', si-diesis''',do-diesis'''', mi-bemolle-bemolle-bemolle'''', si-diesis-diesis''',do-diesis-diesis'''', fa-bemolle-bemolle-bemolle'''', mi-bemolle-bemolle'''', si-diesis-diesis-diesis''',do-diesis-diesis-diesis'''', fa-bemolle-bemolle'''', re-diesis'''', sol-bemolle-bemolle-bemolle-bemolle'''',fa-bemolle'''', re-diesis-diesis'''', sol-bemolle-bemolle-bemolle'''',la-bemolle-bemolle-bemolle-bemolle'''', mi-diesis'''', re-diesis-diesis-diesis'''', sol-bemolle-bemolle'''',fa-diesis'''', la-bemolle-bemolle-bemolle'''', mi-diesis-diesis'''',fa-diesis-diesis'''', la-bemolle-bemolle'''', mi-diesis-diesis-diesis'''', si-bemolle-bemolle-bemolle-bemolle'''',fa-diesis-diesis-diesis'''', si-bemolle-bemolle-bemolle'''', sol-diesis'''',do-bemolle-bemolle-bemolle''''', si-bemolle-bemolle'''', sol-diesis-diesis'''',do-bemolle-bemolle''''', la-diesis'''', re-bemolle-bemolle-bemolle-bemolle''''', sol-diesis-diesis-diesis'''',do-bemolle''''', la-diesis-diesis'''', re-bemolle-bemolle-bemolle''''',la-diesis-diesis-diesis'''', mi-bemolle-bemolle-bemolle-bemolle''''', re-bemolle-bemolle''''', si-diesis'''',do-diesis''''', mi-bemolle-bemolle-bemolle''''', si-diesis-diesis'''',do-diesis-diesis''''', fa-bemolle-bemolle-bemolle''''', mi-bemolle-bemolle''''', si-diesis-diesis-diesis'''',do-diesis-diesis-diesis''''', fa-bemolle-bemolle''''', re-diesis''''', sol-bemolle-bemolle-bemolle-bemolle''''',fa-bemolle''''', re-diesis-diesis''''', sol-bemolle-bemolle-bemolle''''',la-bemolle-bemolle-bemolle-bemolle''''', mi-diesis''''', re-diesis-diesis-diesis''''', sol-bemolle-bemolle''''',fa-diesis''''', la-bemolle-bemolle-bemolle''''', mi-diesis-diesis''''',fa-diesis-diesis''''', la-bemolle-bemolle''''', mi-diesis-diesis-diesis''''', si-bemolle-bemolle-bemolle-bemolle''''',fa-diesis-diesis-diesis''''', si-bemolle-bemolle-bemolle''''', sol-diesis''''',do-bemolle-bemolle-bemolle'''''', si-bemolle-bemolle''''', sol-diesis-diesis''''',do-bemolle-bemolle'''''', la-diesis''''', re-bemolle-bemolle-bemolle-bemolle'''''', sol-diesis-diesis-diesis''''',do-bemolle'''''', la-diesis-diesis''''', re-bemolle-bemolle-bemolle'''''',la-diesis-diesis-diesis''''', mi-bemolle-bemolle-bemolle-bemolle'''''', re-bemolle-bemolle'''''', si-diesis''''',do-diesis'''''', mi-bemolle-bemolle-bemolle'''''', si-diesis-diesis''''',do-diesis-diesis'''''', fa-bemolle-bemolle-bemolle'''''', mi-bemolle-bemolle'''''', si-diesis-diesis-diesis''''',do-diesis-diesis-diesis'''''', fa-bemolle-bemolle'''''', re-diesis'''''', sol-bemolle-bemolle-bemolle-bemolle'''''',fa-bemolle'''''', re-diesis-diesis'''''', sol-bemolle-bemolle-bemolle'''''',la-bemolle-bemolle-bemolle-bemolle'''''', mi-diesis'''''', re-diesis-diesis-diesis'''''', sol-bemolle-bemolle'''''',fa-diesis'''''', la-bemolle-bemolle-bemolle'''''', mi-diesis-diesis'''''',fa-diesis-diesis'''''', la-bemolle-bemolle'''''', mi-diesis-diesis-diesis'''''', si-bemolle-bemolle-bemolle-bemolle''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "laisisis-6, reeses-5, siis-6,laisisisis-6, mieseses-5, rees-5, siisis-6,doisis-5, faeseses-5, mieses-5, siisisis-6,doisisis-5, faeses-5, mies-5,doisisisis-5, faes-5, reisis-5, soleseses-5,miis-5, reisisis-5, soleses-5,laeseses-5, miisis-5, reisisisis-5, soles-5,faisis-5, laeses-5, miisisis-5,faisisis-5, laes-5, sieseses-5,doeseses-4, faisisisis-5, sieses-5, solisis-5,doeses-4, sies-5, solisisis-5,does-4, laisis-5, reeseses-4, solisisisis-5,laisisis-5, reeses-4, siis-5,laisisisis-5, mieseses-4, rees-4, siisis-5,doisis-4, faeseses-4, mieses-4, siisisis-5,doisisis-4, faeses-4, mies-4,doisisisis-4, faes-4, reisis-4, soleseses-4,miis-4, reisisis-4, soleses-4,laeseses-4, miisis-4, reisisisis-4, soles-4,faisis-4, laeses-4, miisisis-4,faisisis-4, laes-4, sieseses-4,doeseses-3, faisisisis-4, sieses-4, solisis-4,doeses-3, sies-4, solisisis-4,does-3, laisis-4, reeseses-3, solisisisis-4,laisisis-4, reeses-3, siis-4,laisisisis-4, mieseses-3, rees-3, siisis-4,doisis-3, faeseses-3, mieses-3, siisisis-4,doisisis-3, faeses-3, mies-3,doisisisis-3, faes-3, reisis-3, soleseses-3,miis-3, reisisis-3, soleses-3,laeseses-3, miisis-3, reisisisis-3, soles-3,faisis-3, laeses-3, miisisis-3,faisisis-3, laes-3, sieseses-3,doeseses-2, faisisisis-3, sieses-3, solisis-3,doeses-2, sies-3, solisisis-3,does-2, laisis-3, reeseses-2, solisisisis-3,laisisis-3, reeses-2, siis-3,laisisisis-3, mieseses-2, rees-2, siisis-3,doisis-2, faeseses-2, mieses-2, siisisis-3,doisisis-2, faeses-2, mies-2,doisisisis-2, faes-2, reisis-2, soleseses-2,miis-2, reisisis-2, soleses-2,laeseses-2, miisis-2, reisisisis-2, soles-2,faisis-2, laeses-2, miisisis-2,faisisis-2, laes-2, sieseses-2,doeseses-, faisisisis-2, sieses-2, solisis-2,doeses-, sies-2, solisisis-2,does-, laisis-2, reeseses-, solisisisis-2,laisisis-2, reeses-, siis-2,laisisisis-2, mieseses-, rees-, siisis-2,doisis-, faeseses-, mieses-, siisisis-2,doisisis-, faeses-, mies-,doisisisis-, faes-, reisis-, soleseses-,miis-, reisisis-, soleses-,laeseses-, miisis-, reisisisis-, soles-,faisis-, laeses-, miisisis-,faisisis-, laes-, sieseses-,doeseses, faisisisis-, sieses-, solisis-,doeses, sies-, solisisis-,does, laisis-, reeseses, solisisisis-,laisisis-, reeses, siis-,laisisisis-, mieseses, rees, siisis-,doisis, faeseses, mieses, siisisis-,doisisis, faeses, mies,doisisisis, faes, reisis, soleseses,miis, reisisis, soleses,laeseses, miisis, reisisisis, soles,faisis, laeses, miisisis,faisisis, laes, sieseses,doeseses+, faisisisis, sieses, solisis,doeses+, sies, solisisis,does+, laisis, reeseses+, solisisisis,laisisis, reeses+, siis,laisisisis, mieseses+, rees+, siisis,doisis+, faeseses+, mieses+, siisisis,doisisis+, faeses+, mies+,doisisisis+, faes+, reisis+, soleseses+,miis+, reisisis+, soleses+,laeseses+, miisis+, reisisisis+, soles+,faisis+, laeses+, miisisis+,faisisis+, laes+, sieseses+,doeseses+2, faisisisis+, sieses+, solisis+,doeses+2, sies+, solisisis+,does+2, laisis+, reeseses+2, solisisisis+,laisisis+, reeses+2, siis+,laisisisis+, mieseses+2, rees+2, siisis+,doisis+2, faeseses+2, mieses+2, siisisis+,doisisis+2, faeses+2, mies+2,doisisisis+2, faes+2, reisis+2, soleseses+2,miis+2, reisisis+2, soleses+2,laeseses+2, miisis+2, reisisisis+2, soles+2,faisis+2, laeses+2, miisisis+2,faisisis+2, laes+2, sieseses+2,doeseses+3, faisisisis+2, sieses+2, solisis+2,doeses+3, sies+2, solisisis+2,does+3, laisis+2, reeseses+3, solisisisis+2,laisisis+2, reeses+3, siis+2,laisisisis+2, mieseses+3, rees+3, siisis+2,doisis+3, faeseses+3, mieses+3, siisisis+2,doisisis+3, faeses+3, mies+3,doisisisis+3, faes+3, reisis+3, soleseses+3,miis+3, reisisis+3, soleses+3,laeseses+3, miisis+3, reisisisis+3, soles+3,faisis+3, laeses+3, miisisis+3,faisisis+3, laes+3, sieseses+3,doeseses+4, faisisisis+3, sieses+3, solisis+3,doeses+4, sies+3, solisisis+3,does+4, laisis+3, reeseses+4, solisisisis+3,laisisis+3, reeses+4, siis+3,laisisisis+3, mieseses+4, rees+4, siisis+3,doisis+4, faeseses+4, mieses+4, siisisis+3,doisisis+4, faeses+4, mies+4,doisisisis+4, faes+4, reisis+4, soleseses+4,miis+4, reisisis+4, soleses+4,laeseses+4, miisis+4, reisisisis+4, soles+4,faisis+4, laeses+4, miisisis+4,faisisis+4, laes+4, sieseses+4,doeseses+5, faisisisis+4, sieses+4, solisis+4,doeses+5, sies+4, solisisis+4,does+5, laisis+4, reeseses+5, solisisisis+4,laisisis+4, reeses+5, siis+4,laisisisis+4, mieseses+5, rees+5, siisis+4,doisis+5, faeseses+5, mieses+5, siisisis+4,doisisis+5, faeses+5, mies+5,doisisisis+5, faes+5, reisis+5, soleseses+5,miis+5, reisisis+5, soleses+5,laeseses+5, miisis+5, reisisisis+5, soles+5,faisis+5, laeses+5, miisisis+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "laisisis------, reeses-----, siis------,laisisisis------, mieseses-----, rees-----, siisis------,doisis-----, faeseses-----, mieses-----, siisisis------,doisisis-----, faeses-----, mies-----,doisisisis-----, faes-----, reisis-----, soleseses-----,miis-----, reisisis-----, soleses-----,laeseses-----, miisis-----, reisisisis-----, soles-----,faisis-----, laeses-----, miisisis-----,faisisis-----, laes-----, sieseses-----,doeseses----, faisisisis-----, sieses-----, solisis-----,doeses----, sies-----, solisisis-----,does----, laisis-----, reeseses----, solisisisis-----,laisisis-----, reeses----, siis-----,laisisisis-----, mieseses----, rees----, siisis-----,doisis----, faeseses----, mieses----, siisisis-----,doisisis----, faeses----, mies----,doisisisis----, faes----, reisis----, soleseses----,miis----, reisisis----, soleses----,laeseses----, miisis----, reisisisis----, soles----,faisis----, laeses----, miisisis----,faisisis----, laes----, sieseses----,doeseses---, faisisisis----, sieses----, solisis----,doeses---, sies----, solisisis----,does---, laisis----, reeseses---, solisisisis----,laisisis----, reeses---, siis----,laisisisis----, mieseses---, rees---, siisis----,doisis---, faeseses---, mieses---, siisisis----,doisisis---, faeses---, mies---,doisisisis---, faes---, reisis---, soleseses---,miis---, reisisis---, soleses---,laeseses---, miisis---, reisisisis---, soles---,faisis---, laeses---, miisisis---,faisisis---, laes---, sieseses---,doeseses--, faisisisis---, sieses---, solisis---,doeses--, sies---, solisisis---,does--, laisis---, reeseses--, solisisisis---,laisisis---, reeses--, siis---,laisisisis---, mieseses--, rees--, siisis---,doisis--, faeseses--, mieses--, siisisis---,doisisis--, faeses--, mies--,doisisisis--, faes--, reisis--, soleseses--,miis--, reisisis--, soleses--,laeseses--, miisis--, reisisisis--, soles--,faisis--, laeses--, miisisis--,faisisis--, laes--, sieseses--,doeseses-, faisisisis--, sieses--, solisis--,doeses-, sies--, solisisis--,does-, laisis--, reeseses-, solisisisis--,laisisis--, reeses-, siis--,laisisisis--, mieseses-, rees-, siisis--,doisis-, faeseses-, mieses-, siisisis--,doisisis-, faeses-, mies-,doisisisis-, faes-, reisis-, soleseses-,miis-, reisisis-, soleses-,laeseses-, miisis-, reisisisis-, soles-,faisis-, laeses-, miisisis-,faisisis-, laes-, sieseses-,doeseses, faisisisis-, sieses-, solisis-,doeses, sies-, solisisis-,does, laisis-, reeseses, solisisisis-,laisisis-, reeses, siis-,laisisisis-, mieseses, rees, siisis-,doisis, faeseses, mieses, siisisis-,doisisis, faeses, mies,doisisisis, faes, reisis, soleseses,miis, reisisis, soleses,laeseses, miisis, reisisisis, soles,faisis, laeses, miisisis,faisisis, laes, sieseses,doeseses+, faisisisis, sieses, solisis,doeses+, sies, solisisis,does+, laisis, reeseses+, solisisisis,laisisis, reeses+, siis,laisisisis, mieseses+, rees+, siisis,doisis+, faeseses+, mieses+, siisisis,doisisis+, faeses+, mies+,doisisisis+, faes+, reisis+, soleseses+,miis+, reisisis+, soleses+,laeseses+, miisis+, reisisisis+, soles+,faisis+, laeses+, miisisis+,faisisis+, laes+, sieseses+,doeseses++, faisisisis+, sieses+, solisis+,doeses++, sies+, solisisis+,does++, laisis+, reeseses++, solisisisis+,laisisis+, reeses++, siis+,laisisisis+, mieseses++, rees++, siisis+,doisis++, faeseses++, mieses++, siisisis+,doisisis++, faeses++, mies++,doisisisis++, faes++, reisis++, soleseses++,miis++, reisisis++, soleses++,laeseses++, miisis++, reisisisis++, soles++,faisis++, laeses++, miisisis++,faisisis++, laes++, sieseses++,doeseses+++, faisisisis++, sieses++, solisis++,doeses+++, sies++, solisisis++,does+++, laisis++, reeseses+++, solisisisis++,laisisis++, reeses+++, siis++,laisisisis++, mieseses+++, rees+++, siisis++,doisis+++, faeseses+++, mieses+++, siisisis++,doisisis+++, faeses+++, mies+++,doisisisis+++, faes+++, reisis+++, soleseses+++,miis+++, reisisis+++, soleses+++,laeseses+++, miisis+++, reisisisis+++, soles+++,faisis+++, laeses+++, miisisis+++,faisisis+++, laes+++, sieseses+++,doeseses++++, faisisisis+++, sieses+++, solisis+++,doeses++++, sies+++, solisisis+++,does++++, laisis+++, reeseses++++, solisisisis+++,laisisis+++, reeses++++, siis+++,laisisisis+++, mieseses++++, rees++++, siisis+++,doisis++++, faeseses++++, mieses++++, siisisis+++,doisisis++++, faeses++++, mies++++,doisisisis++++, faes++++, reisis++++, soleseses++++,miis++++, reisisis++++, soleses++++,laeseses++++, miisis++++, reisisisis++++, soles++++,faisis++++, laeses++++, miisisis++++,faisisis++++, laes++++, sieseses++++,doeseses+++++, faisisisis++++, sieses++++, solisis++++,doeses+++++, sies++++, solisisis++++,does+++++, laisis++++, reeseses+++++, solisisisis++++,laisisis++++, reeses+++++, siis++++,laisisisis++++, mieseses+++++, rees+++++, siisis++++,doisis+++++, faeseses+++++, mieses+++++, siisisis++++,doisisis+++++, faeses+++++, mies+++++,doisisisis+++++, faes+++++, reisis+++++, soleseses+++++,miis+++++, reisisis+++++, soleses+++++,laeseses+++++, miisis+++++, reisisisis+++++, soles+++++,faisis+++++, laeses+++++, miisisis+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "laisisis-2, reeses-1, siis-2,laisisisis-2, mieseses-1, rees-1, siisis-2,doisis-1, faeseses-1, mieses-1, siisisis-2,doisisis-1, faeses-1, mies-1,doisisisis-1, faes-1, reisis-1, soleseses-1,miis-1, reisisis-1, soleses-1,laeseses-1, miisis-1, reisisisis-1, soles-1,faisis-1, laeses-1, miisisis-1,faisisis-1, laes-1, sieseses-1,doeseses0, faisisisis-1, sieses-1, solisis-1,doeses0, sies-1, solisisis-1,does0, laisis-1, reeseses0, solisisisis-1,laisisis-1, reeses0, siis-1,laisisisis-1, mieseses0, rees0, siisis-1,doisis0, faeseses0, mieses0, siisisis-1,doisisis0, faeses0, mies0,doisisisis0, faes0, reisis0, soleseses0,miis0, reisisis0, soleses0,laeseses0, miisis0, reisisisis0, soles0,faisis0, laeses0, miisisis0,faisisis0, laes0, sieseses0,doeseses1, faisisisis0, sieses0, solisis0,doeses1, sies0, solisisis0,does1, laisis0, reeseses1, solisisisis0,laisisis0, reeses1, siis0,laisisisis0, mieseses1, rees1, siisis0,doisis1, faeseses1, mieses1, siisisis0,doisisis1, faeses1, mies1,doisisisis1, faes1, reisis1, soleseses1,miis1, reisisis1, soleses1,laeseses1, miisis1, reisisisis1, soles1,faisis1, laeses1, miisisis1,faisisis1, laes1, sieseses1,doeseses2, faisisisis1, sieses1, solisis1,doeses2, sies1, solisisis1,does2, laisis1, reeseses2, solisisisis1,laisisis1, reeses2, siis1,laisisisis1, mieseses2, rees2, siisis1,doisis2, faeseses2, mieses2, siisisis1,doisisis2, faeses2, mies2,doisisisis2, faes2, reisis2, soleseses2,miis2, reisisis2, soleses2,laeseses2, miisis2, reisisisis2, soles2,faisis2, laeses2, miisisis2,faisisis2, laes2, sieseses2,doeseses3, faisisisis2, sieses2, solisis2,doeses3, sies2, solisisis2,does3, laisis2, reeseses3, solisisisis2,laisisis2, reeses3, siis2,laisisisis2, mieseses3, rees3, siisis2,doisis3, faeseses3, mieses3, siisisis2,doisisis3, faeses3, mies3,doisisisis3, faes3, reisis3, soleseses3,miis3, reisisis3, soleses3,laeseses3, miisis3, reisisisis3, soles3,faisis3, laeses3, miisisis3,faisisis3, laes3, sieseses3,doeseses4, faisisisis3, sieses3, solisis3,doeses4, sies3, solisisis3,does4, laisis3, reeseses4, solisisisis3,laisisis3, reeses4, siis3,laisisisis3, mieseses4, rees4, siisis3,doisis4, faeseses4, mieses4, siisisis3,doisisis4, faeses4, mies4,doisisisis4, faes4, reisis4, soleseses4,miis4, reisisis4, soleses4,laeseses4, miisis4, reisisisis4, soles4,faisis4, laeses4, miisisis4,faisisis4, laes4, sieseses4,doeseses5, faisisisis4, sieses4, solisis4,doeses5, sies4, solisisis4,does5, laisis4, reeseses5, solisisisis4,laisisis4, reeses5, siis4,laisisisis4, mieseses5, rees5, siisis4,doisis5, faeseses5, mieses5, siisisis4,doisisis5, faeses5, mies5,doisisisis5, faes5, reisis5, soleseses5,miis5, reisisis5, soleses5,laeseses5, miisis5, reisisisis5, soles5,faisis5, laeses5, miisisis5,faisisis5, laes5, sieseses5,doeseses6, faisisisis5, sieses5, solisis5,doeses6, sies5, solisisis5,does6, laisis5, reeseses6, solisisisis5,laisisis5, reeses6, siis5,laisisisis5, mieseses6, rees6, siisis5,doisis6, faeseses6, mieses6, siisisis5,doisisis6, faeses6, mies6,doisisisis6, faes6, reisis6, soleseses6,miis6, reisisis6, soleses6,laeseses6, miisis6, reisisisis6, soles6,faisis6, laeses6, miisisis6,faisisis6, laes6, sieseses6,doeseses7, faisisisis6, sieses6, solisis6,doeses7, sies6, solisisis6,does7, laisis6, reeseses7, solisisisis6,laisisis6, reeses7, siis6,laisisisis6, mieseses7, rees7, siisis6,doisis7, faeseses7, mieses7, siisisis6,doisisis7, faeses7, mies7,doisisisis7, faes7, reisis7, soleseses7,miis7, reisisis7, soleses7,laeseses7, miisis7, reisisisis7, soles7,faisis7, laeses7, miisisis7,faisisis7, laes7, sieseses7,doeseses8, faisisisis7, sieses7, solisis7,doeses8, sies7, solisisis7,does8, laisis7, reeseses8, solisisisis7,laisisis7, reeses8, siis7,laisisisis7, mieseses8, rees8, siisis7,doisis8, faeseses8, mieses8, siisisis7,doisisis8, faeses8, mies8,doisisisis8, faes8, reisis8, soleseses8,miis8, reisisis8, soleses8,laeseses8, miisis8, reisisisis8, soles8,faisis8, laeses8, miisisis8,faisisis8, laes8, sieseses8,doeseses9, faisisisis8, sieses8, solisis8,doeses9, sies8, solisisis8,does9, laisis8, reeseses9, solisisisis8,laisisis8, reeses9, siis8,laisisisis8, mieseses9, rees9, siisis8,doisis9, faeseses9, mieses9, siisisis8,doisisis9, faeses9, mies9,doisisisis9, faes9, reisis9, soleseses9,miis9, reisisis9, soleses9,laeseses9, miisis9, reisisisis9, soles9,faisis9, laeses9, miisisis9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Laisisis'''', Reeses''', Siis'''',Laisisisis'''', Mieseses''', Rees''', Siisis'''',Doisis''', Faeseses''', Mieses''', Siisisis'''',Doisisis''', Faeses''', Mies''',Doisisisis''', Faes''', Reisis''', Soleseses''',Miis''', Reisisis''', Soleses''',Laeseses''', Miisis''', Reisisisis''', Soles''',Faisis''', Laeses''', Miisisis''',Faisisis''', Laes''', Sieseses''',Doeseses'', Faisisisis''', Sieses''', Solisis''',Doeses'', Sies''', Solisisis''',Does'', Laisis''', Reeseses'', Solisisisis''',Laisisis''', Reeses'', Siis''',Laisisisis''', Mieseses'', Rees'', Siisis''',Doisis'', Faeseses'', Mieses'', Siisisis''',Doisisis'', Faeses'', Mies'',Doisisisis'', Faes'', Reisis'', Soleseses'',Miis'', Reisisis'', Soleses'',Laeseses'', Miisis'', Reisisisis'', Soles'',Faisis'', Laeses'', Miisisis'',Faisisis'', Laes'', Sieseses'',Doeseses', Faisisisis'', Sieses'', Solisis'',Doeses', Sies'', Solisisis'',Does', Laisis'', Reeseses', Solisisisis'',Laisisis'', Reeses', Siis'',Laisisisis'', Mieseses', Rees', Siisis'',Doisis', Faeseses', Mieses', Siisisis'',Doisisis', Faeses', Mies',Doisisisis', Faes', Reisis', Soleseses',Miis', Reisisis', Soleses',Laeseses', Miisis', Reisisisis', Soles',Faisis', Laeses', Miisisis',Faisisis', Laes', Sieseses',Doeseses, Faisisisis', Sieses', Solisis',Doeses, Sies', Solisisis',Does, Laisis', Reeseses, Solisisisis',Laisisis', Reeses, Siis',Laisisisis', Mieseses, Rees, Siisis',Doisis, Faeseses, Mieses, Siisisis',Doisisis, Faeses, Mies,Doisisisis, Faes, Reisis, Soleseses,Miis, Reisisis, Soleses,Laeseses, Miisis, Reisisisis, Soles,Faisis, Laeses, Miisisis,Faisisis, Laes, Sieseses,Faisisisis, Sieses, Solisis, doeseses,Sies, Solisisis, doeses,Laisis, Solisisisis, does, reeseses,Laisisis, Siis, reeses,Laisisisis, Siisis, mieseses, rees,Siisisis, doisis, faeseses, mieses,doisisis, faeses, mies,doisisisis, faes, reisis, soleseses,miis, reisisis, soleses,laeseses, miisis, reisisisis, soles,faisis, laeses, miisisis,faisisis, laes, sieseses,doeseses', faisisisis, sieses, solisis,doeses', sies, solisisis,does', laisis, reeseses', solisisisis,laisisis, reeses', siis,laisisisis, mieseses', rees', siisis,doisis', faeseses', mieses', siisisis,doisisis', faeses', mies',doisisisis', faes', reisis', soleseses',miis', reisisis', soleses',laeseses', miisis', reisisisis', soles',faisis', laeses', miisisis',faisisis', laes', sieseses',doeseses'', faisisisis', sieses', solisis',doeses'', sies', solisisis',does'', laisis', reeseses'', solisisisis',laisisis', reeses'', siis',laisisisis', mieseses'', rees'', siisis',doisis'', faeseses'', mieses'', siisisis',doisisis'', faeses'', mies'',doisisisis'', faes'', reisis'', soleseses'',miis'', reisisis'', soleses'',laeseses'', miisis'', reisisisis'', soles'',faisis'', laeses'', miisisis'',faisisis'', laes'', sieseses'',doeseses''', faisisisis'', sieses'', solisis'',doeses''', sies'', solisisis'',does''', laisis'', reeseses''', solisisisis'',laisisis'', reeses''', siis'',laisisisis'', mieseses''', rees''', siisis'',doisis''', faeseses''', mieses''', siisisis'',doisisis''', faeses''', mies''',doisisisis''', faes''', reisis''', soleseses''',miis''', reisisis''', soleses''',laeseses''', miisis''', reisisisis''', soles''',faisis''', laeses''', miisisis''',faisisis''', laes''', sieseses''',doeseses'''', faisisisis''', sieses''', solisis''',doeses'''', sies''', solisisis''',does'''', laisis''', reeseses'''', solisisisis''',laisisis''', reeses'''', siis''',laisisisis''', mieseses'''', rees'''', siisis''',doisis'''', faeseses'''', mieses'''', siisisis''',doisisis'''', faeses'''', mies'''',doisisisis'''', faes'''', reisis'''', soleseses'''',miis'''', reisisis'''', soleses'''',laeseses'''', miisis'''', reisisisis'''', soles'''',faisis'''', laeses'''', miisisis'''',faisisis'''', laes'''', sieseses'''',doeseses''''', faisisisis'''', sieses'''', solisis'''',doeses''''', sies'''', solisisis'''',does''''', laisis'''', reeseses''''', solisisisis'''',laisisis'''', reeses''''', siis'''',laisisisis'''', mieseses''''', rees''''', siisis'''',doisis''''', faeseses''''', mieses''''', siisisis'''',doisisis''''', faeses''''', mies''''',doisisisis''''', faes''''', reisis''''', soleseses''''',miis''''', reisisis''''', soleses''''',laeseses''''', miisis''''', reisisisis''''', soles''''',faisis''''', laeses''''', miisisis''''',faisisis''''', laes''''', sieseses''''',doeseses'''''', faisisisis''''', sieses''''', solisis''''',doeses'''''', sies''''', solisisis''''',does'''''', laisis''''', reeseses'''''', solisisisis''''',laisisis''''', reeses'''''', siis''''',laisisisis''''', mieseses'''''', rees'''''', siisis''''',doisis'''''', faeseses'''''', mieses'''''', siisisis''''',doisisis'''''', faeses'''''', mies'''''',doisisisis'''''', faes'''''', reisis'''''', soleseses'''''',miis'''''', reisisis'''''', soleses'''''',laeseses'''''', miisis'''''', reisisisis'''''', soles'''''',faisis'''''', laeses'''''', miisisis''''''\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "laisisis-6, mieseseses-5, reeses-5, siis-6,dois-5, mieseses-5, siisis-6,doisis-5, faeseses-5, mieses-5, siisisis-6,doisisis-5, faeses-5, reis-5, soleseseses-5,faes-5, reisis-5, soleseses-5,laeseseses-5, miis-5, reisisis-5, soleses-5,fais-5, laeseses-5, miisis-5,faisis-5, laeses-5, miisisis-5, sieseseses-5,faisisis-5, sieseses-5, solis-5,doeseses-4, sieses-5, solisis-5,doeses-4, lais-5, reeseseses-4, solisisis-5,does-4, laisis-5, reeseses-4,laisisis-5, mieseseses-4, reeses-4, siis-5,dois-4, mieseses-4, siisis-5,doisis-4, faeseses-4, mieses-4, siisisis-5,doisisis-4, faeses-4, reis-4, soleseseses-4,faes-4, reisis-4, soleseses-4,laeseseses-4, miis-4, reisisis-4, soleses-4,fais-4, laeseses-4, miisis-4,faisis-4, laeses-4, miisisis-4, sieseseses-4,faisisis-4, sieseses-4, solis-4,doeseses-3, sieses-4, solisis-4,doeses-3, lais-4, reeseseses-3, solisisis-4,does-3, laisis-4, reeseses-3,laisisis-4, mieseseses-3, reeses-3, siis-4,dois-3, mieseses-3, siisis-4,doisis-3, faeseses-3, mieses-3, siisisis-4,doisisis-3, faeses-3, reis-3, soleseseses-3,faes-3, reisis-3, soleseses-3,laeseseses-3, miis-3, reisisis-3, soleses-3,fais-3, laeseses-3, miisis-3,faisis-3, laeses-3, miisisis-3, sieseseses-3,faisisis-3, sieseses-3, solis-3,doeseses-2, sieses-3, solisis-3,doeses-2, lais-3, reeseseses-2, solisisis-3,does-2, laisis-3, reeseses-2,laisisis-3, mieseseses-2, reeses-2, siis-3,dois-2, mieseses-2, siisis-3,doisis-2, faeseses-2, mieses-2, siisisis-3,doisisis-2, faeses-2, reis-2, soleseseses-2,faes-2, reisis-2, soleseses-2,laeseseses-2, miis-2, reisisis-2, soleses-2,fais-2, laeseses-2, miisis-2,faisis-2, laeses-2, miisisis-2, sieseseses-2,faisisis-2, sieseses-2, solis-2,doeseses-, sieses-2, solisis-2,doeses-, lais-2, reeseseses-, solisisis-2,does-, laisis-2, reeseses-,laisisis-2, mieseseses-, reeses-, siis-2,dois-, mieseses-, siisis-2,doisis-, faeseses-, mieses-, siisisis-2,doisisis-, faeses-, reis-, soleseseses-,faes-, reisis-, soleseses-,laeseseses-, miis-, reisisis-, soleses-,fais-, laeseses-, miisis-,faisis-, laeses-, miisisis-, sieseseses-,faisisis-, sieseses-, solis-,doeseses, sieses-, solisis-,doeses, lais-, reeseseses, solisisis-,does, laisis-, reeseses,laisisis-, mieseseses, reeses, siis-,dois, mieseses, siisis-,doisis, faeseses, mieses, siisisis-,doisisis, faeses, reis, soleseseses,faes, reisis, soleseses,laeseseses, miis, reisisis, soleses,fais, laeseses, miisis,faisis, laeses, miisisis, sieseseses,faisisis, sieseses, solis,doeseses+, sieses, solisis,doeses+, lais, reeseseses+, solisisis,does+, laisis, reeseses+,laisisis, mieseseses+, reeses+, siis,dois+, mieseses+, siisis,doisis+, faeseses+, mieses+, siisisis,doisisis+, faeses+, reis+, soleseseses+,faes+, reisis+, soleseses+,laeseseses+, miis+, reisisis+, soleses+,fais+, laeseses+, miisis+,faisis+, laeses+, miisisis+, sieseseses+,faisisis+, sieseses+, solis+,doeseses+2, sieses+, solisis+,doeses+2, lais+, reeseseses+2, solisisis+,does+2, laisis+, reeseses+2,laisisis+, mieseseses+2, reeses+2, siis+,dois+2, mieseses+2, siisis+,doisis+2, faeseses+2, mieses+2, siisisis+,doisisis+2, faeses+2, reis+2, soleseseses+2,faes+2, reisis+2, soleseses+2,laeseseses+2, miis+2, reisisis+2, soleses+2,fais+2, laeseses+2, miisis+2,faisis+2, laeses+2, miisisis+2, sieseseses+2,faisisis+2, sieseses+2, solis+2,doeseses+3, sieses+2, solisis+2,doeses+3, lais+2, reeseseses+3, solisisis+2,does+3, laisis+2, reeseses+3,laisisis+2, mieseseses+3, reeses+3, siis+2,dois+3, mieseses+3, siisis+2,doisis+3, faeseses+3, mieses+3, siisisis+2,doisisis+3, faeses+3, reis+3, soleseseses+3,faes+3, reisis+3, soleseses+3,laeseseses+3, miis+3, reisisis+3, soleses+3,fais+3, laeseses+3, miisis+3,faisis+3, laeses+3, miisisis+3, sieseseses+3,faisisis+3, sieseses+3, solis+3,doeseses+4, sieses+3, solisis+3,doeses+4, lais+3, reeseseses+4, solisisis+3,does+4, laisis+3, reeseses+4,laisisis+3, mieseseses+4, reeses+4, siis+3,dois+4, mieseses+4, siisis+3,doisis+4, faeseses+4, mieses+4, siisisis+3,doisisis+4, faeses+4, reis+4, soleseseses+4,faes+4, reisis+4, soleseses+4,laeseseses+4, miis+4, reisisis+4, soleses+4,fais+4, laeseses+4, miisis+4,faisis+4, laeses+4, miisisis+4, sieseseses+4,faisisis+4, sieseses+4, solis+4,doeseses+5, sieses+4, solisis+4,doeses+5, lais+4, reeseseses+5, solisisis+4,does+5, laisis+4, reeseses+5,laisisis+4, mieseseses+5, reeses+5, siis+4,dois+5, mieseses+5, siisis+4,doisis+5, faeseses+5, mieses+5, siisisis+4,doisisis+5, faeses+5, reis+5, soleseseses+5,faes+5, reisis+5, soleseses+5,laeseseses+5, miis+5, reisisis+5, soleses+5,fais+5, laeseses+5, miisis+5,faisis+5, laeses+5, miisisis+5, sieseseses+5\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "laisisis------, mieseseses-----, reeses-----, siis------,dois-----, mieseses-----, siisis------,doisis-----, faeseses-----, mieses-----, siisisis------,doisisis-----, faeses-----, reis-----, soleseseses-----,faes-----, reisis-----, soleseses-----,laeseseses-----, miis-----, reisisis-----, soleses-----,fais-----, laeseses-----, miisis-----,faisis-----, laeses-----, miisisis-----, sieseseses-----,faisisis-----, sieseses-----, solis-----,doeseses----, sieses-----, solisis-----,doeses----, lais-----, reeseseses----, solisisis-----,does----, laisis-----, reeseses----,laisisis-----, mieseseses----, reeses----, siis-----,dois----, mieseses----, siisis-----,doisis----, faeseses----, mieses----, siisisis-----,doisisis----, faeses----, reis----, soleseseses----,faes----, reisis----, soleseses----,laeseseses----, miis----, reisisis----, soleses----,fais----, laeseses----, miisis----,faisis----, laeses----, miisisis----, sieseseses----,faisisis----, sieseses----, solis----,doeseses---, sieses----, solisis----,doeses---, lais----, reeseseses---, solisisis----,does---, laisis----, reeseses---,laisisis----, mieseseses---, reeses---, siis----,dois---, mieseses---, siisis----,doisis---, faeseses---, mieses---, siisisis----,doisisis---, faeses---, reis---, soleseseses---,faes---, reisis---, soleseses---,laeseseses---, miis---, reisisis---, soleses---,fais---, laeseses---, miisis---,faisis---, laeses---, miisisis---, sieseseses---,faisisis---, sieseses---, solis---,doeseses--, sieses---, solisis---,doeses--, lais---, reeseseses--, solisisis---,does--, laisis---, reeseses--,laisisis---, mieseseses--, reeses--, siis---,dois--, mieseses--, siisis---,doisis--, faeseses--, mieses--, siisisis---,doisisis--, faeses--, reis--, soleseseses--,faes--, reisis--, soleseses--,laeseseses--, miis--, reisisis--, soleses--,fais--, laeseses--, miisis--,faisis--, laeses--, miisisis--, sieseseses--,faisisis--, sieseses--, solis--,doeseses-, sieses--, solisis--,doeses-, lais--, reeseseses-, solisisis--,does-, laisis--, reeseses-,laisisis--, mieseseses-, reeses-, siis--,dois-, mieseses-, siisis--,doisis-, faeseses-, mieses-, siisisis--,doisisis-, faeses-, reis-, soleseseses-,faes-, reisis-, soleseses-,laeseseses-, miis-, reisisis-, soleses-,fais-, laeseses-, miisis-,faisis-, laeses-, miisisis-, sieseseses-,faisisis-, sieseses-, solis-,doeseses, sieses-, solisis-,doeses, lais-, reeseseses, solisisis-,does, laisis-, reeseses,laisisis-, mieseseses, reeses, siis-,dois, mieseses, siisis-,doisis, faeseses, mieses, siisisis-,doisisis, faeses, reis, soleseseses,faes, reisis, soleseses,laeseseses, miis, reisisis, soleses,fais, laeseses, miisis,faisis, laeses, miisisis, sieseseses,faisisis, sieseses, solis,doeseses+, sieses, solisis,doeses+, lais, reeseseses+, solisisis,does+, laisis, reeseses+,laisisis, mieseseses+, reeses+, siis,dois+, mieseses+, siisis,doisis+, faeseses+, mieses+, siisisis,doisisis+, faeses+, reis+, soleseseses+,faes+, reisis+, soleseses+,laeseseses+, miis+, reisisis+, soleses+,fais+, laeseses+, miisis+,faisis+, laeses+, miisisis+, sieseseses+,faisisis+, sieseses+, solis+,doeseses++, sieses+, solisis+,doeses++, lais+, reeseseses++, solisisis+,does++, laisis+, reeseses++,laisisis+, mieseseses++, reeses++, siis+,dois++, mieseses++, siisis+,doisis++, faeseses++, mieses++, siisisis+,doisisis++, faeses++, reis++, soleseseses++,faes++, reisis++, soleseses++,laeseseses++, miis++, reisisis++, soleses++,fais++, laeseses++, miisis++,faisis++, laeses++, miisisis++, sieseseses++,faisisis++, sieseses++, solis++,doeseses+++, sieses++, solisis++,doeses+++, lais++, reeseseses+++, solisisis++,does+++, laisis++, reeseses+++,laisisis++, mieseseses+++, reeses+++, siis++,dois+++, mieseses+++, siisis++,doisis+++, faeseses+++, mieses+++, siisisis++,doisisis+++, faeses+++, reis+++, soleseseses+++,faes+++, reisis+++, soleseses+++,laeseseses+++, miis+++, reisisis+++, soleses+++,fais+++, laeseses+++, miisis+++,faisis+++, laeses+++, miisisis+++, sieseseses+++,faisisis+++, sieseses+++, solis+++,doeseses++++, sieses+++, solisis+++,doeses++++, lais+++, reeseseses++++, solisisis+++,does++++, laisis+++, reeseses++++,laisisis+++, mieseseses++++, reeses++++, siis+++,dois++++, mieseses++++, siisis+++,doisis++++, faeseses++++, mieses++++, siisisis+++,doisisis++++, faeses++++, reis++++, soleseseses++++,faes++++, reisis++++, soleseses++++,laeseseses++++, miis++++, reisisis++++, soleses++++,fais++++, laeseses++++, miisis++++,faisis++++, laeses++++, miisisis++++, sieseseses++++,faisisis++++, sieseses++++, solis++++,doeseses+++++, sieses++++, solisis++++,doeses+++++, lais++++, reeseseses+++++, solisisis++++,does+++++, laisis++++, reeseses+++++,laisisis++++, mieseseses+++++, reeses+++++, siis++++,dois+++++, mieseses+++++, siisis++++,doisis+++++, faeseses+++++, mieses+++++, siisisis++++,doisisis+++++, faeses+++++, reis+++++, soleseseses+++++,faes+++++, reisis+++++, soleseses+++++,laeseseses+++++, miis+++++, reisisis+++++, soleses+++++,fais+++++, laeseses+++++, miisis+++++,faisis+++++, laeses+++++, miisisis+++++, sieseseses+++++\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "laisisis-2, mieseseses-1, reeses-1, siis-2,dois-1, mieseses-1, siisis-2,doisis-1, faeseses-1, mieses-1, siisisis-2,doisisis-1, faeses-1, reis-1, soleseseses-1,faes-1, reisis-1, soleseses-1,laeseseses-1, miis-1, reisisis-1, soleses-1,fais-1, laeseses-1, miisis-1,faisis-1, laeses-1, miisisis-1, sieseseses-1,faisisis-1, sieseses-1, solis-1,doeseses0, sieses-1, solisis-1,doeses0, lais-1, reeseseses0, solisisis-1,does0, laisis-1, reeseses0,laisisis-1, mieseseses0, reeses0, siis-1,dois0, mieseses0, siisis-1,doisis0, faeseses0, mieses0, siisisis-1,doisisis0, faeses0, reis0, soleseseses0,faes0, reisis0, soleseses0,laeseseses0, miis0, reisisis0, soleses0,fais0, laeseses0, miisis0,faisis0, laeses0, miisisis0, sieseseses0,faisisis0, sieseses0, solis0,doeseses1, sieses0, solisis0,doeses1, lais0, reeseseses1, solisisis0,does1, laisis0, reeseses1,laisisis0, mieseseses1, reeses1, siis0,dois1, mieseses1, siisis0,doisis1, faeseses1, mieses1, siisisis0,doisisis1, faeses1, reis1, soleseseses1,faes1, reisis1, soleseses1,laeseseses1, miis1, reisisis1, soleses1,fais1, laeseses1, miisis1,faisis1, laeses1, miisisis1, sieseseses1,faisisis1, sieseses1, solis1,doeseses2, sieses1, solisis1,doeses2, lais1, reeseseses2, solisisis1,does2, laisis1, reeseses2,laisisis1, mieseseses2, reeses2, siis1,dois2, mieseses2, siisis1,doisis2, faeseses2, mieses2, siisisis1,doisisis2, faeses2, reis2, soleseseses2,faes2, reisis2, soleseses2,laeseseses2, miis2, reisisis2, soleses2,fais2, laeseses2, miisis2,faisis2, laeses2, miisisis2, sieseseses2,faisisis2, sieseses2, solis2,doeseses3, sieses2, solisis2,doeses3, lais2, reeseseses3, solisisis2,does3, laisis2, reeseses3,laisisis2, mieseseses3, reeses3, siis2,dois3, mieseses3, siisis2,doisis3, faeseses3, mieses3, siisisis2,doisisis3, faeses3, reis3, soleseseses3,faes3, reisis3, soleseses3,laeseseses3, miis3, reisisis3, soleses3,fais3, laeseses3, miisis3,faisis3, laeses3, miisisis3, sieseseses3,faisisis3, sieseses3, solis3,doeseses4, sieses3, solisis3,doeses4, lais3, reeseseses4, solisisis3,does4, laisis3, reeseses4,laisisis3, mieseseses4, reeses4, siis3,dois4, mieseses4, siisis3,doisis4, faeseses4, mieses4, siisisis3,doisisis4, faeses4, reis4, soleseseses4,faes4, reisis4, soleseses4,laeseseses4, miis4, reisisis4, soleses4,fais4, laeseses4, miisis4,faisis4, laeses4, miisisis4, sieseseses4,faisisis4, sieseses4, solis4,doeseses5, sieses4, solisis4,doeses5, lais4, reeseseses5, solisisis4,does5, laisis4, reeseses5,laisisis4, mieseseses5, reeses5, siis4,dois5, mieseses5, siisis4,doisis5, faeseses5, mieses5, siisisis4,doisisis5, faeses5, reis5, soleseseses5,faes5, reisis5, soleseses5,laeseseses5, miis5, reisisis5, soleses5,fais5, laeseses5, miisis5,faisis5, laeses5, miisisis5, sieseseses5,faisisis5, sieseses5, solis5,doeseses6, sieses5, solisis5,doeses6, lais5, reeseseses6, solisisis5,does6, laisis5, reeseses6,laisisis5, mieseseses6, reeses6, siis5,dois6, mieseses6, siisis5,doisis6, faeseses6, mieses6, siisisis5,doisisis6, faeses6, reis6, soleseseses6,faes6, reisis6, soleseses6,laeseseses6, miis6, reisisis6, soleses6,fais6, laeseses6, miisis6,faisis6, laeses6, miisisis6, sieseseses6,faisisis6, sieseses6, solis6,doeseses7, sieses6, solisis6,doeses7, lais6, reeseseses7, solisisis6,does7, laisis6, reeseses7,laisisis6, mieseseses7, reeses7, siis6,dois7, mieseses7, siisis6,doisis7, faeseses7, mieses7, siisisis6,doisisis7, faeses7, reis7, soleseseses7,faes7, reisis7, soleseses7,laeseseses7, miis7, reisisis7, soleses7,fais7, laeseses7, miisis7,faisis7, laeses7, miisisis7, sieseseses7,faisisis7, sieseses7, solis7,doeseses8, sieses7, solisis7,doeses8, lais7, reeseseses8, solisisis7,does8, laisis7, reeseses8,laisisis7, mieseseses8, reeses8, siis7,dois8, mieseses8, siisis7,doisis8, faeseses8, mieses8, siisisis7,doisisis8, faeses8, reis8, soleseseses8,faes8, reisis8, soleseses8,laeseseses8, miis8, reisisis8, soleses8,fais8, laeseses8, miisis8,faisis8, laeses8, miisisis8, sieseseses8,faisisis8, sieseses8, solis8,doeseses9, sieses8, solisis8,doeses9, lais8, reeseseses9, solisisis8,does9, laisis8, reeseses9,laisisis8, mieseseses9, reeses9, siis8,dois9, mieseses9, siisis8,doisis9, faeseses9, mieses9, siisisis8,doisisis9, faeses9, reis9, soleseseses9,faes9, reisis9, soleseses9,laeseseses9, miis9, reisisis9, soleses9,fais9, laeseses9, miisis9,faisis9, laeses9, miisisis9, sieseseses9\n"
			+ "cbx_note_id_italian_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Laisisis'''', Mieseseses''', Reeses''', Siis'''',Dois''', Mieseses''', Siisis'''',Doisis''', Faeseses''', Mieses''', Siisisis'''',Doisisis''', Faeses''', Reis''', Soleseseses''',Faes''', Reisis''', Soleseses''',Laeseseses''', Miis''', Reisisis''', Soleses''',Fais''', Laeseses''', Miisis''',Faisis''', Laeses''', Miisisis''', Sieseseses''',Faisisis''', Sieseses''', Solis''',Doeseses'', Sieses''', Solisis''',Doeses'', Lais''', Reeseseses'', Solisisis''',Does'', Laisis''', Reeseses'',Laisisis''', Mieseseses'', Reeses'', Siis''',Dois'', Mieseses'', Siisis''',Doisis'', Faeseses'', Mieses'', Siisisis''',Doisisis'', Faeses'', Reis'', Soleseseses'',Faes'', Reisis'', Soleseses'',Laeseseses'', Miis'', Reisisis'', Soleses'',Fais'', Laeseses'', Miisis'',Faisis'', Laeses'', Miisisis'', Sieseseses'',Faisisis'', Sieseses'', Solis'',Doeseses', Sieses'', Solisis'',Doeses', Lais'', Reeseseses', Solisisis'',Does', Laisis'', Reeseses',Laisisis'', Mieseseses', Reeses', Siis'',Dois', Mieseses', Siisis'',Doisis', Faeseses', Mieses', Siisisis'',Doisisis', Faeses', Reis', Soleseseses',Faes', Reisis', Soleseses',Laeseseses', Miis', Reisisis', Soleses',Fais', Laeseses', Miisis',Faisis', Laeses', Miisisis', Sieseseses',Faisisis', Sieseses', Solis',Doeseses, Sieses', Solisis',Doeses, Lais', Reeseseses, Solisisis',Does, Laisis', Reeseses,Laisisis', Mieseseses, Reeses, Siis',Dois, Mieseses, Siisis',Doisis, Faeseses, Mieses, Siisisis',Doisisis, Faeses, Reis, Soleseseses,Faes, Reisis, Soleseses,Laeseseses, Miis, Reisisis, Soleses,Fais, Laeseses, Miisis,Faisis, Laeses, Miisisis, Sieseseses,Faisisis, Sieseses, Solis,Sieses, Solisis, doeseses,Lais, Solisisis, doeses, reeseseses,Laisis, does, reeseses,Laisisis, Siis, mieseseses, reeses,Siisis, dois, mieseses,Siisisis, doisis, faeseses, mieses,doisisis, faeses, reis, soleseseses,faes, reisis, soleseses,laeseseses, miis, reisisis, soleses,fais, laeseses, miisis,faisis, laeses, miisisis, sieseseses,faisisis, sieseses, solis,doeseses', sieses, solisis,doeses', lais, reeseseses', solisisis,does', laisis, reeseses',laisisis, mieseseses', reeses', siis,dois', mieseses', siisis,doisis', faeseses', mieses', siisisis,doisisis', faeses', reis', soleseseses',faes', reisis', soleseses',laeseseses', miis', reisisis', soleses',fais', laeseses', miisis',faisis', laeses', miisisis', sieseseses',faisisis', sieseses', solis',doeseses'', sieses', solisis',doeses'', lais', reeseseses'', solisisis',does'', laisis', reeseses'',laisisis', mieseseses'', reeses'', siis',dois'', mieseses'', siisis',doisis'', faeseses'', mieses'', siisisis',doisisis'', faeses'', reis'', soleseseses'',faes'', reisis'', soleseses'',laeseseses'', miis'', reisisis'', soleses'',fais'', laeseses'', miisis'',faisis'', laeses'', miisisis'', sieseseses'',faisisis'', sieseses'', solis'',doeseses''', sieses'', solisis'',doeses''', lais'', reeseseses''', solisisis'',does''', laisis'', reeseses''',laisisis'', mieseseses''', reeses''', siis'',dois''', mieseses''', siisis'',doisis''', faeseses''', mieses''', siisisis'',doisisis''', faeses''', reis''', soleseseses''',faes''', reisis''', soleseses''',laeseseses''', miis''', reisisis''', soleses''',fais''', laeseses''', miisis''',faisis''', laeses''', miisisis''', sieseseses''',faisisis''', sieseses''', solis''',doeseses'''', sieses''', solisis''',doeses'''', lais''', reeseseses'''', solisisis''',does'''', laisis''', reeseses'''',laisisis''', mieseseses'''', reeses'''', siis''',dois'''', mieseses'''', siisis''',doisis'''', faeseses'''', mieses'''', siisisis''',doisisis'''', faeses'''', reis'''', soleseseses'''',faes'''', reisis'''', soleseses'''',laeseseses'''', miis'''', reisisis'''', soleses'''',fais'''', laeseses'''', miisis'''',faisis'''', laeses'''', miisisis'''', sieseseses'''',faisisis'''', sieseses'''', solis'''',doeseses''''', sieses'''', solisis'''',doeses''''', lais'''', reeseseses''''', solisisis'''',does''''', laisis'''', reeseses''''',laisisis'''', mieseseses''''', reeses''''', siis'''',dois''''', mieseses''''', siisis'''',doisis''''', faeseses''''', mieses''''', siisisis'''',doisisis''''', faeses''''', reis''''', soleseseses''''',faes''''', reisis''''', soleseses''''',laeseseses''''', miis''''', reisisis''''', soleses''''',fais''''', laeseses''''', miisis''''',faisis''''', laeses''''', miisisis''''', sieseseses''''',faisisis''''', sieseses''''', solis''''',doeseses'''''', sieses''''', solisis''''',doeses'''''', lais''''', reeseseses'''''', solisisis''''',does'''''', laisis''''', reeseses'''''',laisisis''''', mieseseses'''''', reeses'''''', siis''''',dois'''''', mieseses'''''', siisis''''',doisis'''''', faeseses'''''', mieses'''''', siisisis''''',doisisis'''''', faeses'''''', reis'''''', soleseseses'''''',faes'''''', reisis'''''', soleseses'''''',laeseseses'''''', miis'''''', reisisis'''''', soleses'''''',fais'''''', laeseses'''''', miisis'''''',faisis'''''', laeses'''''', miisisis'''''', sieseseses''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "La###-6, Rebb-5, Si#-6,La####-6, Mibbb-5, Reb-5, Si##-6,Do##-5, Fabbb-5, Mibb-5, Si###-6,Do###-5, Fabb-5, Mib-5,Do####-5, Fab-5, Re##-5, Solbbb-5,Mi#-5, Re###-5, Solbb-5,Labbb-5, Mi##-5, Re####-5, Solb-5,Fa##-5, Labb-5, Mi###-5,Fa###-5, Lab-5, Sibbb-5,Dobbb-4, Fa####-5, Sibb-5, Sol##-5,Dobb-4, Sib-5, Sol###-5,Dob-4, La##-5, Rebbb-4, Sol####-5,La###-5, Rebb-4, Si#-5,La####-5, Mibbb-4, Reb-4, Si##-5,Do##-4, Fabbb-4, Mibb-4, Si###-5,Do###-4, Fabb-4, Mib-4,Do####-4, Fab-4, Re##-4, Solbbb-4,Mi#-4, Re###-4, Solbb-4,Labbb-4, Mi##-4, Re####-4, Solb-4,Fa##-4, Labb-4, Mi###-4,Fa###-4, Lab-4, Sibbb-4,Dobbb-3, Fa####-4, Sibb-4, Sol##-4,Dobb-3, Sib-4, Sol###-4,Dob-3, La##-4, Rebbb-3, Sol####-4,La###-4, Rebb-3, Si#-4,La####-4, Mibbb-3, Reb-3, Si##-4,Do##-3, Fabbb-3, Mibb-3, Si###-4,Do###-3, Fabb-3, Mib-3,Do####-3, Fab-3, Re##-3, Solbbb-3,Mi#-3, Re###-3, Solbb-3,Labbb-3, Mi##-3, Re####-3, Solb-3,Fa##-3, Labb-3, Mi###-3,Fa###-3, Lab-3, Sibbb-3,Dobbb-2, Fa####-3, Sibb-3, Sol##-3,Dobb-2, Sib-3, Sol###-3,Dob-2, La##-3, Rebbb-2, Sol####-3,La###-3, Rebb-2, Si#-3,La####-3, Mibbb-2, Reb-2, Si##-3,Do##-2, Fabbb-2, Mibb-2, Si###-3,Do###-2, Fabb-2, Mib-2,Do####-2, Fab-2, Re##-2, Solbbb-2,Mi#-2, Re###-2, Solbb-2,Labbb-2, Mi##-2, Re####-2, Solb-2,Fa##-2, Labb-2, Mi###-2,Fa###-2, Lab-2, Sibbb-2,Dobbb-, Fa####-2, Sibb-2, Sol##-2,Dobb-, Sib-2, Sol###-2,Dob-, La##-2, Rebbb-, Sol####-2,La###-2, Rebb-, Si#-2,La####-2, Mibbb-, Reb-, Si##-2,Do##-, Fabbb-, Mibb-, Si###-2,Do###-, Fabb-, Mib-,Do####-, Fab-, Re##-, Solbbb-,Mi#-, Re###-, Solbb-,Labbb-, Mi##-, Re####-, Solb-,Fa##-, Labb-, Mi###-,Fa###-, Lab-, Sibbb-,Dobbb, Fa####-, Sibb-, Sol##-,Dobb, Sib-, Sol###-,Dob, La##-, Rebbb, Sol####-,La###-, Rebb, Si#-,La####-, Mibbb, Reb, Si##-,Do##, Fabbb, Mibb, Si###-,Do###, Fabb, Mib,Do####, Fab, Re##, Solbbb,Mi#, Re###, Solbb,Labbb, Mi##, Re####, Solb,Fa##, Labb, Mi###,Fa###, Lab, Sibbb,Dobbb+, Fa####, Sibb, Sol##,Dobb+, Sib, Sol###,Dob+, La##, Rebbb+, Sol####,La###, Rebb+, Si#,La####, Mibbb+, Reb+, Si##,Do##+, Fabbb+, Mibb+, Si###,Do###+, Fabb+, Mib+,Do####+, Fab+, Re##+, Solbbb+,Mi#+, Re###+, Solbb+,Labbb+, Mi##+, Re####+, Solb+,Fa##+, Labb+, Mi###+,Fa###+, Lab+, Sibbb+,Dobbb+2, Fa####+, Sibb+, Sol##+,Dobb+2, Sib+, Sol###+,Dob+2, La##+, Rebbb+2, Sol####+,La###+, Rebb+2, Si#+,La####+, Mibbb+2, Reb+2, Si##+,Do##+2, Fabbb+2, Mibb+2, Si###+,Do###+2, Fabb+2, Mib+2,Do####+2, Fab+2, Re##+2, Solbbb+2,Mi#+2, Re###+2, Solbb+2,Labbb+2, Mi##+2, Re####+2, Solb+2,Fa##+2, Labb+2, Mi###+2,Fa###+2, Lab+2, Sibbb+2,Dobbb+3, Fa####+2, Sibb+2, Sol##+2,Dobb+3, Sib+2, Sol###+2,Dob+3, La##+2, Rebbb+3, Sol####+2,La###+2, Rebb+3, Si#+2,La####+2, Mibbb+3, Reb+3, Si##+2,Do##+3, Fabbb+3, Mibb+3, Si###+2,Do###+3, Fabb+3, Mib+3,Do####+3, Fab+3, Re##+3, Solbbb+3,Mi#+3, Re###+3, Solbb+3,Labbb+3, Mi##+3, Re####+3, Solb+3,Fa##+3, Labb+3, Mi###+3,Fa###+3, Lab+3, Sibbb+3,Dobbb+4, Fa####+3, Sibb+3, Sol##+3,Dobb+4, Sib+3, Sol###+3,Dob+4, La##+3, Rebbb+4, Sol####+3,La###+3, Rebb+4, Si#+3,La####+3, Mibbb+4, Reb+4, Si##+3,Do##+4, Fabbb+4, Mibb+4, Si###+3,Do###+4, Fabb+4, Mib+4,Do####+4, Fab+4, Re##+4, Solbbb+4,Mi#+4, Re###+4, Solbb+4,Labbb+4, Mi##+4, Re####+4, Solb+4,Fa##+4, Labb+4, Mi###+4,Fa###+4, Lab+4, Sibbb+4,Dobbb+5, Fa####+4, Sibb+4, Sol##+4,Dobb+5, Sib+4, Sol###+4,Dob+5, La##+4, Rebbb+5, Sol####+4,La###+4, Rebb+5, Si#+4,La####+4, Mibbb+5, Reb+5, Si##+4,Do##+5, Fabbb+5, Mibb+5, Si###+4,Do###+5, Fabb+5, Mib+5,Do####+5, Fab+5, Re##+5, Solbbb+5,Mi#+5, Re###+5, Solbb+5,Labbb+5, Mi##+5, Re####+5, Solb+5,Fa##+5, Labb+5, Mi###+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "La###------, Rebb-----, Si#------,La####------, Mibbb-----, Reb-----, Si##------,Do##-----, Fabbb-----, Mibb-----, Si###------,Do###-----, Fabb-----, Mib-----,Do####-----, Fab-----, Re##-----, Solbbb-----,Mi#-----, Re###-----, Solbb-----,Labbb-----, Mi##-----, Re####-----, Solb-----,Fa##-----, Labb-----, Mi###-----,Fa###-----, Lab-----, Sibbb-----,Dobbb----, Fa####-----, Sibb-----, Sol##-----,Dobb----, Sib-----, Sol###-----,Dob----, La##-----, Rebbb----, Sol####-----,La###-----, Rebb----, Si#-----,La####-----, Mibbb----, Reb----, Si##-----,Do##----, Fabbb----, Mibb----, Si###-----,Do###----, Fabb----, Mib----,Do####----, Fab----, Re##----, Solbbb----,Mi#----, Re###----, Solbb----,Labbb----, Mi##----, Re####----, Solb----,Fa##----, Labb----, Mi###----,Fa###----, Lab----, Sibbb----,Dobbb---, Fa####----, Sibb----, Sol##----,Dobb---, Sib----, Sol###----,Dob---, La##----, Rebbb---, Sol####----,La###----, Rebb---, Si#----,La####----, Mibbb---, Reb---, Si##----,Do##---, Fabbb---, Mibb---, Si###----,Do###---, Fabb---, Mib---,Do####---, Fab---, Re##---, Solbbb---,Mi#---, Re###---, Solbb---,Labbb---, Mi##---, Re####---, Solb---,Fa##---, Labb---, Mi###---,Fa###---, Lab---, Sibbb---,Dobbb--, Fa####---, Sibb---, Sol##---,Dobb--, Sib---, Sol###---,Dob--, La##---, Rebbb--, Sol####---,La###---, Rebb--, Si#---,La####---, Mibbb--, Reb--, Si##---,Do##--, Fabbb--, Mibb--, Si###---,Do###--, Fabb--, Mib--,Do####--, Fab--, Re##--, Solbbb--,Mi#--, Re###--, Solbb--,Labbb--, Mi##--, Re####--, Solb--,Fa##--, Labb--, Mi###--,Fa###--, Lab--, Sibbb--,Dobbb-, Fa####--, Sibb--, Sol##--,Dobb-, Sib--, Sol###--,Dob-, La##--, Rebbb-, Sol####--,La###--, Rebb-, Si#--,La####--, Mibbb-, Reb-, Si##--,Do##-, Fabbb-, Mibb-, Si###--,Do###-, Fabb-, Mib-,Do####-, Fab-, Re##-, Solbbb-,Mi#-, Re###-, Solbb-,Labbb-, Mi##-, Re####-, Solb-,Fa##-, Labb-, Mi###-,Fa###-, Lab-, Sibbb-,Dobbb, Fa####-, Sibb-, Sol##-,Dobb, Sib-, Sol###-,Dob, La##-, Rebbb, Sol####-,La###-, Rebb, Si#-,La####-, Mibbb, Reb, Si##-,Do##, Fabbb, Mibb, Si###-,Do###, Fabb, Mib,Do####, Fab, Re##, Solbbb,Mi#, Re###, Solbb,Labbb, Mi##, Re####, Solb,Fa##, Labb, Mi###,Fa###, Lab, Sibbb,Dobbb+, Fa####, Sibb, Sol##,Dobb+, Sib, Sol###,Dob+, La##, Rebbb+, Sol####,La###, Rebb+, Si#,La####, Mibbb+, Reb+, Si##,Do##+, Fabbb+, Mibb+, Si###,Do###+, Fabb+, Mib+,Do####+, Fab+, Re##+, Solbbb+,Mi#+, Re###+, Solbb+,Labbb+, Mi##+, Re####+, Solb+,Fa##+, Labb+, Mi###+,Fa###+, Lab+, Sibbb+,Dobbb++, Fa####+, Sibb+, Sol##+,Dobb++, Sib+, Sol###+,Dob++, La##+, Rebbb++, Sol####+,La###+, Rebb++, Si#+,La####+, Mibbb++, Reb++, Si##+,Do##++, Fabbb++, Mibb++, Si###+,Do###++, Fabb++, Mib++,Do####++, Fab++, Re##++, Solbbb++,Mi#++, Re###++, Solbb++,Labbb++, Mi##++, Re####++, Solb++,Fa##++, Labb++, Mi###++,Fa###++, Lab++, Sibbb++,Dobbb+++, Fa####++, Sibb++, Sol##++,Dobb+++, Sib++, Sol###++,Dob+++, La##++, Rebbb+++, Sol####++,La###++, Rebb+++, Si#++,La####++, Mibbb+++, Reb+++, Si##++,Do##+++, Fabbb+++, Mibb+++, Si###++,Do###+++, Fabb+++, Mib+++,Do####+++, Fab+++, Re##+++, Solbbb+++,Mi#+++, Re###+++, Solbb+++,Labbb+++, Mi##+++, Re####+++, Solb+++,Fa##+++, Labb+++, Mi###+++,Fa###+++, Lab+++, Sibbb+++,Dobbb++++, Fa####+++, Sibb+++, Sol##+++,Dobb++++, Sib+++, Sol###+++,Dob++++, La##+++, Rebbb++++, Sol####+++,La###+++, Rebb++++, Si#+++,La####+++, Mibbb++++, Reb++++, Si##+++,Do##++++, Fabbb++++, Mibb++++, Si###+++,Do###++++, Fabb++++, Mib++++,Do####++++, Fab++++, Re##++++, Solbbb++++,Mi#++++, Re###++++, Solbb++++,Labbb++++, Mi##++++, Re####++++, Solb++++,Fa##++++, Labb++++, Mi###++++,Fa###++++, Lab++++, Sibbb++++,Dobbb+++++, Fa####++++, Sibb++++, Sol##++++,Dobb+++++, Sib++++, Sol###++++,Dob+++++, La##++++, Rebbb+++++, Sol####++++,La###++++, Rebb+++++, Si#++++,La####++++, Mibbb+++++, Reb+++++, Si##++++,Do##+++++, Fabbb+++++, Mibb+++++, Si###++++,Do###+++++, Fabb+++++, Mib+++++,Do####+++++, Fab+++++, Re##+++++, Solbbb+++++,Mi#+++++, Re###+++++, Solbb+++++,Labbb+++++, Mi##+++++, Re####+++++, Solb+++++,Fa##+++++, Labb+++++, Mi###+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "La###-2, Rebb-1, Si#-2,La####-2, Mibbb-1, Reb-1, Si##-2,Do##-1, Fabbb-1, Mibb-1, Si###-2,Do###-1, Fabb-1, Mib-1,Do####-1, Fab-1, Re##-1, Solbbb-1,Mi#-1, Re###-1, Solbb-1,Labbb-1, Mi##-1, Re####-1, Solb-1,Fa##-1, Labb-1, Mi###-1,Fa###-1, Lab-1, Sibbb-1,Dobbb0, Fa####-1, Sibb-1, Sol##-1,Dobb0, Sib-1, Sol###-1,Dob0, La##-1, Rebbb0, Sol####-1,La###-1, Rebb0, Si#-1,La####-1, Mibbb0, Reb0, Si##-1,Do##0, Fabbb0, Mibb0, Si###-1,Do###0, Fabb0, Mib0,Do####0, Fab0, Re##0, Solbbb0,Mi#0, Re###0, Solbb0,Labbb0, Mi##0, Re####0, Solb0,Fa##0, Labb0, Mi###0,Fa###0, Lab0, Sibbb0,Dobbb1, Fa####0, Sibb0, Sol##0,Dobb1, Sib0, Sol###0,Dob1, La##0, Rebbb1, Sol####0,La###0, Rebb1, Si#0,La####0, Mibbb1, Reb1, Si##0,Do##1, Fabbb1, Mibb1, Si###0,Do###1, Fabb1, Mib1,Do####1, Fab1, Re##1, Solbbb1,Mi#1, Re###1, Solbb1,Labbb1, Mi##1, Re####1, Solb1,Fa##1, Labb1, Mi###1,Fa###1, Lab1, Sibbb1,Dobbb2, Fa####1, Sibb1, Sol##1,Dobb2, Sib1, Sol###1,Dob2, La##1, Rebbb2, Sol####1,La###1, Rebb2, Si#1,La####1, Mibbb2, Reb2, Si##1,Do##2, Fabbb2, Mibb2, Si###1,Do###2, Fabb2, Mib2,Do####2, Fab2, Re##2, Solbbb2,Mi#2, Re###2, Solbb2,Labbb2, Mi##2, Re####2, Solb2,Fa##2, Labb2, Mi###2,Fa###2, Lab2, Sibbb2,Dobbb3, Fa####2, Sibb2, Sol##2,Dobb3, Sib2, Sol###2,Dob3, La##2, Rebbb3, Sol####2,La###2, Rebb3, Si#2,La####2, Mibbb3, Reb3, Si##2,Do##3, Fabbb3, Mibb3, Si###2,Do###3, Fabb3, Mib3,Do####3, Fab3, Re##3, Solbbb3,Mi#3, Re###3, Solbb3,Labbb3, Mi##3, Re####3, Solb3,Fa##3, Labb3, Mi###3,Fa###3, Lab3, Sibbb3,Dobbb4, Fa####3, Sibb3, Sol##3,Dobb4, Sib3, Sol###3,Dob4, La##3, Rebbb4, Sol####3,La###3, Rebb4, Si#3,La####3, Mibbb4, Reb4, Si##3,Do##4, Fabbb4, Mibb4, Si###3,Do###4, Fabb4, Mib4,Do####4, Fab4, Re##4, Solbbb4,Mi#4, Re###4, Solbb4,Labbb4, Mi##4, Re####4, Solb4,Fa##4, Labb4, Mi###4,Fa###4, Lab4, Sibbb4,Dobbb5, Fa####4, Sibb4, Sol##4,Dobb5, Sib4, Sol###4,Dob5, La##4, Rebbb5, Sol####4,La###4, Rebb5, Si#4,La####4, Mibbb5, Reb5, Si##4,Do##5, Fabbb5, Mibb5, Si###4,Do###5, Fabb5, Mib5,Do####5, Fab5, Re##5, Solbbb5,Mi#5, Re###5, Solbb5,Labbb5, Mi##5, Re####5, Solb5,Fa##5, Labb5, Mi###5,Fa###5, Lab5, Sibbb5,Dobbb6, Fa####5, Sibb5, Sol##5,Dobb6, Sib5, Sol###5,Dob6, La##5, Rebbb6, Sol####5,La###5, Rebb6, Si#5,La####5, Mibbb6, Reb6, Si##5,Do##6, Fabbb6, Mibb6, Si###5,Do###6, Fabb6, Mib6,Do####6, Fab6, Re##6, Solbbb6,Mi#6, Re###6, Solbb6,Labbb6, Mi##6, Re####6, Solb6,Fa##6, Labb6, Mi###6,Fa###6, Lab6, Sibbb6,Dobbb7, Fa####6, Sibb6, Sol##6,Dobb7, Sib6, Sol###6,Dob7, La##6, Rebbb7, Sol####6,La###6, Rebb7, Si#6,La####6, Mibbb7, Reb7, Si##6,Do##7, Fabbb7, Mibb7, Si###6,Do###7, Fabb7, Mib7,Do####7, Fab7, Re##7, Solbbb7,Mi#7, Re###7, Solbb7,Labbb7, Mi##7, Re####7, Solb7,Fa##7, Labb7, Mi###7,Fa###7, Lab7, Sibbb7,Dobbb8, Fa####7, Sibb7, Sol##7,Dobb8, Sib7, Sol###7,Dob8, La##7, Rebbb8, Sol####7,La###7, Rebb8, Si#7,La####7, Mibbb8, Reb8, Si##7,Do##8, Fabbb8, Mibb8, Si###7,Do###8, Fabb8, Mib8,Do####8, Fab8, Re##8, Solbbb8,Mi#8, Re###8, Solbb8,Labbb8, Mi##8, Re####8, Solb8,Fa##8, Labb8, Mi###8,Fa###8, Lab8, Sibbb8,Dobbb9, Fa####8, Sibb8, Sol##8,Dobb9, Sib8, Sol###8,Dob9, La##8, Rebbb9, Sol####8,La###8, Rebb9, Si#8,La####8, Mibbb9, Reb9, Si##8,Do##9, Fabbb9, Mibb9, Si###8,Do###9, Fabb9, Mib9,Do####9, Fab9, Re##9, Solbbb9,Mi#9, Re###9, Solbb9,Labbb9, Mi##9, Re####9, Solb9,Fa##9, Labb9, Mi###9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "La###'''', Rebb''', Si#'''',La####'''', Mibbb''', Reb''', Si##'''',Do##''', Fabbb''', Mibb''', Si###'''',Do###''', Fabb''', Mib''',Do####''', Fab''', Re##''', Solbbb''',Mi#''', Re###''', Solbb''',Labbb''', Mi##''', Re####''', Solb''',Fa##''', Labb''', Mi###''',Fa###''', Lab''', Sibbb''',Dobbb'', Fa####''', Sibb''', Sol##''',Dobb'', Sib''', Sol###''',Dob'', La##''', Rebbb'', Sol####''',La###''', Rebb'', Si#''',La####''', Mibbb'', Reb'', Si##''',Do##'', Fabbb'', Mibb'', Si###''',Do###'', Fabb'', Mib'',Do####'', Fab'', Re##'', Solbbb'',Mi#'', Re###'', Solbb'',Labbb'', Mi##'', Re####'', Solb'',Fa##'', Labb'', Mi###'',Fa###'', Lab'', Sibbb'',Dobbb', Fa####'', Sibb'', Sol##'',Dobb', Sib'', Sol###'',Dob', La##'', Rebbb', Sol####'',La###'', Rebb', Si#'',La####'', Mibbb', Reb', Si##'',Do##', Fabbb', Mibb', Si###'',Do###', Fabb', Mib',Do####', Fab', Re##', Solbbb',Mi#', Re###', Solbb',Labbb', Mi##', Re####', Solb',Fa##', Labb', Mi###',Fa###', Lab', Sibbb',Dobbb, Fa####', Sibb', Sol##',Dobb, Sib', Sol###',Dob, La##', Rebbb, Sol####',La###', Rebb, Si#',La####', Mibbb, Reb, Si##',Do##, Fabbb, Mibb, Si###',Do###, Fabb, Mib,Do####, Fab, Re##, Solbbb,Mi#, Re###, Solbb,Labbb, Mi##, Re####, Solb,Fa##, Labb, Mi###,Fa###, Lab, Sibbb,Fa####, Sibb, Sol##, dobbb,Sib, Sol###, dobb,La##, Sol####, dob, rebbb,La###, Si#, rebb,La####, Si##, mibbb, reb,Si###, do##, fabbb, mibb,do###, fabb, mib,do####, fab, re##, solbbb,mi#, re###, solbb,labbb, mi##, re####, solb,fa##, labb, mi###,fa###, lab, sibbb,dobbb', fa####, sibb, sol##,dobb', sib, sol###,dob', la##, rebbb', sol####,la###, rebb', si#,la####, mibbb', reb', si##,do##', fabbb', mibb', si###,do###', fabb', mib',do####', fab', re##', solbbb',mi#', re###', solbb',labbb', mi##', re####', solb',fa##', labb', mi###',fa###', lab', sibbb',dobbb'', fa####', sibb', sol##',dobb'', sib', sol###',dob'', la##', rebbb'', sol####',la###', rebb'', si#',la####', mibbb'', reb'', si##',do##'', fabbb'', mibb'', si###',do###'', fabb'', mib'',do####'', fab'', re##'', solbbb'',mi#'', re###'', solbb'',labbb'', mi##'', re####'', solb'',fa##'', labb'', mi###'',fa###'', lab'', sibbb'',dobbb''', fa####'', sibb'', sol##'',dobb''', sib'', sol###'',dob''', la##'', rebbb''', sol####'',la###'', rebb''', si#'',la####'', mibbb''', reb''', si##'',do##''', fabbb''', mibb''', si###'',do###''', fabb''', mib''',do####''', fab''', re##''', solbbb''',mi#''', re###''', solbb''',labbb''', mi##''', re####''', solb''',fa##''', labb''', mi###''',fa###''', lab''', sibbb''',dobbb'''', fa####''', sibb''', sol##''',dobb'''', sib''', sol###''',dob'''', la##''', rebbb'''', sol####''',la###''', rebb'''', si#''',la####''', mibbb'''', reb'''', si##''',do##'''', fabbb'''', mibb'''', si###''',do###'''', fabb'''', mib'''',do####'''', fab'''', re##'''', solbbb'''',mi#'''', re###'''', solbb'''',labbb'''', mi##'''', re####'''', solb'''',fa##'''', labb'''', mi###'''',fa###'''', lab'''', sibbb'''',dobbb''''', fa####'''', sibb'''', sol##'''',dobb''''', sib'''', sol###'''',dob''''', la##'''', rebbb''''', sol####'''',la###'''', rebb''''', si#'''',la####'''', mibbb''''', reb''''', si##'''',do##''''', fabbb''''', mibb''''', si###'''',do###''''', fabb''''', mib''''',do####''''', fab''''', re##''''', solbbb''''',mi#''''', re###''''', solbb''''',labbb''''', mi##''''', re####''''', solb''''',fa##''''', labb''''', mi###''''',fa###''''', lab''''', sibbb''''',dobbb'''''', fa####''''', sibb''''', sol##''''',dobb'''''', sib''''', sol###''''',dob'''''', la##''''', rebbb'''''', sol####''''',la###''''', rebb'''''', si#''''',la####''''', mibbb'''''', reb'''''', si##''''',do##'''''', fabbb'''''', mibb'''''', si###''''',do###'''''', fabb'''''', mib'''''',do####'''''', fab'''''', re##'''''', solbbb'''''',mi#'''''', re###'''''', solbb'''''',labbb'''''', mi##'''''', re####'''''', solb'''''',fa##'''''', labb'''''', mi###''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "La###-6, Mibbbb-5, Rebb-5, Si#-6,Do#-5, Mibbb-5, Si##-6,Do##-5, Fabbb-5, Mibb-5, Si###-6,Do###-5, Fabb-5, Re#-5, Solbbbb-5,Fab-5, Re##-5, Solbbb-5,Labbbb-5, Mi#-5, Re###-5, Solbb-5,Fa#-5, Labbb-5, Mi##-5,Fa##-5, Labb-5, Mi###-5, Sibbbb-5,Fa###-5, Sibbb-5, Sol#-5,Dobbb-4, Sibb-5, Sol##-5,Dobb-4, La#-5, Rebbbb-4, Sol###-5,Dob-4, La##-5, Rebbb-4,La###-5, Mibbbb-4, Rebb-4, Si#-5,Do#-4, Mibbb-4, Si##-5,Do##-4, Fabbb-4, Mibb-4, Si###-5,Do###-4, Fabb-4, Re#-4, Solbbbb-4,Fab-4, Re##-4, Solbbb-4,Labbbb-4, Mi#-4, Re###-4, Solbb-4,Fa#-4, Labbb-4, Mi##-4,Fa##-4, Labb-4, Mi###-4, Sibbbb-4,Fa###-4, Sibbb-4, Sol#-4,Dobbb-3, Sibb-4, Sol##-4,Dobb-3, La#-4, Rebbbb-3, Sol###-4,Dob-3, La##-4, Rebbb-3,La###-4, Mibbbb-3, Rebb-3, Si#-4,Do#-3, Mibbb-3, Si##-4,Do##-3, Fabbb-3, Mibb-3, Si###-4,Do###-3, Fabb-3, Re#-3, Solbbbb-3,Fab-3, Re##-3, Solbbb-3,Labbbb-3, Mi#-3, Re###-3, Solbb-3,Fa#-3, Labbb-3, Mi##-3,Fa##-3, Labb-3, Mi###-3, Sibbbb-3,Fa###-3, Sibbb-3, Sol#-3,Dobbb-2, Sibb-3, Sol##-3,Dobb-2, La#-3, Rebbbb-2, Sol###-3,Dob-2, La##-3, Rebbb-2,La###-3, Mibbbb-2, Rebb-2, Si#-3,Do#-2, Mibbb-2, Si##-3,Do##-2, Fabbb-2, Mibb-2, Si###-3,Do###-2, Fabb-2, Re#-2, Solbbbb-2,Fab-2, Re##-2, Solbbb-2,Labbbb-2, Mi#-2, Re###-2, Solbb-2,Fa#-2, Labbb-2, Mi##-2,Fa##-2, Labb-2, Mi###-2, Sibbbb-2,Fa###-2, Sibbb-2, Sol#-2,Dobbb-, Sibb-2, Sol##-2,Dobb-, La#-2, Rebbbb-, Sol###-2,Dob-, La##-2, Rebbb-,La###-2, Mibbbb-, Rebb-, Si#-2,Do#-, Mibbb-, Si##-2,Do##-, Fabbb-, Mibb-, Si###-2,Do###-, Fabb-, Re#-, Solbbbb-,Fab-, Re##-, Solbbb-,Labbbb-, Mi#-, Re###-, Solbb-,Fa#-, Labbb-, Mi##-,Fa##-, Labb-, Mi###-, Sibbbb-,Fa###-, Sibbb-, Sol#-,Dobbb, Sibb-, Sol##-,Dobb, La#-, Rebbbb, Sol###-,Dob, La##-, Rebbb,La###-, Mibbbb, Rebb, Si#-,Do#, Mibbb, Si##-,Do##, Fabbb, Mibb, Si###-,Do###, Fabb, Re#, Solbbbb,Fab, Re##, Solbbb,Labbbb, Mi#, Re###, Solbb,Fa#, Labbb, Mi##,Fa##, Labb, Mi###, Sibbbb,Fa###, Sibbb, Sol#,Dobbb+, Sibb, Sol##,Dobb+, La#, Rebbbb+, Sol###,Dob+, La##, Rebbb+,La###, Mibbbb+, Rebb+, Si#,Do#+, Mibbb+, Si##,Do##+, Fabbb+, Mibb+, Si###,Do###+, Fabb+, Re#+, Solbbbb+,Fab+, Re##+, Solbbb+,Labbbb+, Mi#+, Re###+, Solbb+,Fa#+, Labbb+, Mi##+,Fa##+, Labb+, Mi###+, Sibbbb+,Fa###+, Sibbb+, Sol#+,Dobbb+2, Sibb+, Sol##+,Dobb+2, La#+, Rebbbb+2, Sol###+,Dob+2, La##+, Rebbb+2,La###+, Mibbbb+2, Rebb+2, Si#+,Do#+2, Mibbb+2, Si##+,Do##+2, Fabbb+2, Mibb+2, Si###+,Do###+2, Fabb+2, Re#+2, Solbbbb+2,Fab+2, Re##+2, Solbbb+2,Labbbb+2, Mi#+2, Re###+2, Solbb+2,Fa#+2, Labbb+2, Mi##+2,Fa##+2, Labb+2, Mi###+2, Sibbbb+2,Fa###+2, Sibbb+2, Sol#+2,Dobbb+3, Sibb+2, Sol##+2,Dobb+3, La#+2, Rebbbb+3, Sol###+2,Dob+3, La##+2, Rebbb+3,La###+2, Mibbbb+3, Rebb+3, Si#+2,Do#+3, Mibbb+3, Si##+2,Do##+3, Fabbb+3, Mibb+3, Si###+2,Do###+3, Fabb+3, Re#+3, Solbbbb+3,Fab+3, Re##+3, Solbbb+3,Labbbb+3, Mi#+3, Re###+3, Solbb+3,Fa#+3, Labbb+3, Mi##+3,Fa##+3, Labb+3, Mi###+3, Sibbbb+3,Fa###+3, Sibbb+3, Sol#+3,Dobbb+4, Sibb+3, Sol##+3,Dobb+4, La#+3, Rebbbb+4, Sol###+3,Dob+4, La##+3, Rebbb+4,La###+3, Mibbbb+4, Rebb+4, Si#+3,Do#+4, Mibbb+4, Si##+3,Do##+4, Fabbb+4, Mibb+4, Si###+3,Do###+4, Fabb+4, Re#+4, Solbbbb+4,Fab+4, Re##+4, Solbbb+4,Labbbb+4, Mi#+4, Re###+4, Solbb+4,Fa#+4, Labbb+4, Mi##+4,Fa##+4, Labb+4, Mi###+4, Sibbbb+4,Fa###+4, Sibbb+4, Sol#+4,Dobbb+5, Sibb+4, Sol##+4,Dobb+5, La#+4, Rebbbb+5, Sol###+4,Dob+5, La##+4, Rebbb+5,La###+4, Mibbbb+5, Rebb+5, Si#+4,Do#+5, Mibbb+5, Si##+4,Do##+5, Fabbb+5, Mibb+5, Si###+4,Do###+5, Fabb+5, Re#+5, Solbbbb+5,Fab+5, Re##+5, Solbbb+5,Labbbb+5, Mi#+5, Re###+5, Solbb+5,Fa#+5, Labbb+5, Mi##+5,Fa##+5, Labb+5, Mi###+5, Sibbbb+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "La###------, Mibbbb-----, Rebb-----, Si#------,Do#-----, Mibbb-----, Si##------,Do##-----, Fabbb-----, Mibb-----, Si###------,Do###-----, Fabb-----, Re#-----, Solbbbb-----,Fab-----, Re##-----, Solbbb-----,Labbbb-----, Mi#-----, Re###-----, Solbb-----,Fa#-----, Labbb-----, Mi##-----,Fa##-----, Labb-----, Mi###-----, Sibbbb-----,Fa###-----, Sibbb-----, Sol#-----,Dobbb----, Sibb-----, Sol##-----,Dobb----, La#-----, Rebbbb----, Sol###-----,Dob----, La##-----, Rebbb----,La###-----, Mibbbb----, Rebb----, Si#-----,Do#----, Mibbb----, Si##-----,Do##----, Fabbb----, Mibb----, Si###-----,Do###----, Fabb----, Re#----, Solbbbb----,Fab----, Re##----, Solbbb----,Labbbb----, Mi#----, Re###----, Solbb----,Fa#----, Labbb----, Mi##----,Fa##----, Labb----, Mi###----, Sibbbb----,Fa###----, Sibbb----, Sol#----,Dobbb---, Sibb----, Sol##----,Dobb---, La#----, Rebbbb---, Sol###----,Dob---, La##----, Rebbb---,La###----, Mibbbb---, Rebb---, Si#----,Do#---, Mibbb---, Si##----,Do##---, Fabbb---, Mibb---, Si###----,Do###---, Fabb---, Re#---, Solbbbb---,Fab---, Re##---, Solbbb---,Labbbb---, Mi#---, Re###---, Solbb---,Fa#---, Labbb---, Mi##---,Fa##---, Labb---, Mi###---, Sibbbb---,Fa###---, Sibbb---, Sol#---,Dobbb--, Sibb---, Sol##---,Dobb--, La#---, Rebbbb--, Sol###---,Dob--, La##---, Rebbb--,La###---, Mibbbb--, Rebb--, Si#---,Do#--, Mibbb--, Si##---,Do##--, Fabbb--, Mibb--, Si###---,Do###--, Fabb--, Re#--, Solbbbb--,Fab--, Re##--, Solbbb--,Labbbb--, Mi#--, Re###--, Solbb--,Fa#--, Labbb--, Mi##--,Fa##--, Labb--, Mi###--, Sibbbb--,Fa###--, Sibbb--, Sol#--,Dobbb-, Sibb--, Sol##--,Dobb-, La#--, Rebbbb-, Sol###--,Dob-, La##--, Rebbb-,La###--, Mibbbb-, Rebb-, Si#--,Do#-, Mibbb-, Si##--,Do##-, Fabbb-, Mibb-, Si###--,Do###-, Fabb-, Re#-, Solbbbb-,Fab-, Re##-, Solbbb-,Labbbb-, Mi#-, Re###-, Solbb-,Fa#-, Labbb-, Mi##-,Fa##-, Labb-, Mi###-, Sibbbb-,Fa###-, Sibbb-, Sol#-,Dobbb, Sibb-, Sol##-,Dobb, La#-, Rebbbb, Sol###-,Dob, La##-, Rebbb,La###-, Mibbbb, Rebb, Si#-,Do#, Mibbb, Si##-,Do##, Fabbb, Mibb, Si###-,Do###, Fabb, Re#, Solbbbb,Fab, Re##, Solbbb,Labbbb, Mi#, Re###, Solbb,Fa#, Labbb, Mi##,Fa##, Labb, Mi###, Sibbbb,Fa###, Sibbb, Sol#,Dobbb+, Sibb, Sol##,Dobb+, La#, Rebbbb+, Sol###,Dob+, La##, Rebbb+,La###, Mibbbb+, Rebb+, Si#,Do#+, Mibbb+, Si##,Do##+, Fabbb+, Mibb+, Si###,Do###+, Fabb+, Re#+, Solbbbb+,Fab+, Re##+, Solbbb+,Labbbb+, Mi#+, Re###+, Solbb+,Fa#+, Labbb+, Mi##+,Fa##+, Labb+, Mi###+, Sibbbb+,Fa###+, Sibbb+, Sol#+,Dobbb++, Sibb+, Sol##+,Dobb++, La#+, Rebbbb++, Sol###+,Dob++, La##+, Rebbb++,La###+, Mibbbb++, Rebb++, Si#+,Do#++, Mibbb++, Si##+,Do##++, Fabbb++, Mibb++, Si###+,Do###++, Fabb++, Re#++, Solbbbb++,Fab++, Re##++, Solbbb++,Labbbb++, Mi#++, Re###++, Solbb++,Fa#++, Labbb++, Mi##++,Fa##++, Labb++, Mi###++, Sibbbb++,Fa###++, Sibbb++, Sol#++,Dobbb+++, Sibb++, Sol##++,Dobb+++, La#++, Rebbbb+++, Sol###++,Dob+++, La##++, Rebbb+++,La###++, Mibbbb+++, Rebb+++, Si#++,Do#+++, Mibbb+++, Si##++,Do##+++, Fabbb+++, Mibb+++, Si###++,Do###+++, Fabb+++, Re#+++, Solbbbb+++,Fab+++, Re##+++, Solbbb+++,Labbbb+++, Mi#+++, Re###+++, Solbb+++,Fa#+++, Labbb+++, Mi##+++,Fa##+++, Labb+++, Mi###+++, Sibbbb+++,Fa###+++, Sibbb+++, Sol#+++,Dobbb++++, Sibb+++, Sol##+++,Dobb++++, La#+++, Rebbbb++++, Sol###+++,Dob++++, La##+++, Rebbb++++,La###+++, Mibbbb++++, Rebb++++, Si#+++,Do#++++, Mibbb++++, Si##+++,Do##++++, Fabbb++++, Mibb++++, Si###+++,Do###++++, Fabb++++, Re#++++, Solbbbb++++,Fab++++, Re##++++, Solbbb++++,Labbbb++++, Mi#++++, Re###++++, Solbb++++,Fa#++++, Labbb++++, Mi##++++,Fa##++++, Labb++++, Mi###++++, Sibbbb++++,Fa###++++, Sibbb++++, Sol#++++,Dobbb+++++, Sibb++++, Sol##++++,Dobb+++++, La#++++, Rebbbb+++++, Sol###++++,Dob+++++, La##++++, Rebbb+++++,La###++++, Mibbbb+++++, Rebb+++++, Si#++++,Do#+++++, Mibbb+++++, Si##++++,Do##+++++, Fabbb+++++, Mibb+++++, Si###++++,Do###+++++, Fabb+++++, Re#+++++, Solbbbb+++++,Fab+++++, Re##+++++, Solbbb+++++,Labbbb+++++, Mi#+++++, Re###+++++, Solbb+++++,Fa#+++++, Labbb+++++, Mi##+++++,Fa##+++++, Labb+++++, Mi###+++++, Sibbbb+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "La###-2, Mibbbb-1, Rebb-1, Si#-2,Do#-1, Mibbb-1, Si##-2,Do##-1, Fabbb-1, Mibb-1, Si###-2,Do###-1, Fabb-1, Re#-1, Solbbbb-1,Fab-1, Re##-1, Solbbb-1,Labbbb-1, Mi#-1, Re###-1, Solbb-1,Fa#-1, Labbb-1, Mi##-1,Fa##-1, Labb-1, Mi###-1, Sibbbb-1,Fa###-1, Sibbb-1, Sol#-1,Dobbb0, Sibb-1, Sol##-1,Dobb0, La#-1, Rebbbb0, Sol###-1,Dob0, La##-1, Rebbb0,La###-1, Mibbbb0, Rebb0, Si#-1,Do#0, Mibbb0, Si##-1,Do##0, Fabbb0, Mibb0, Si###-1,Do###0, Fabb0, Re#0, Solbbbb0,Fab0, Re##0, Solbbb0,Labbbb0, Mi#0, Re###0, Solbb0,Fa#0, Labbb0, Mi##0,Fa##0, Labb0, Mi###0, Sibbbb0,Fa###0, Sibbb0, Sol#0,Dobbb1, Sibb0, Sol##0,Dobb1, La#0, Rebbbb1, Sol###0,Dob1, La##0, Rebbb1,La###0, Mibbbb1, Rebb1, Si#0,Do#1, Mibbb1, Si##0,Do##1, Fabbb1, Mibb1, Si###0,Do###1, Fabb1, Re#1, Solbbbb1,Fab1, Re##1, Solbbb1,Labbbb1, Mi#1, Re###1, Solbb1,Fa#1, Labbb1, Mi##1,Fa##1, Labb1, Mi###1, Sibbbb1,Fa###1, Sibbb1, Sol#1,Dobbb2, Sibb1, Sol##1,Dobb2, La#1, Rebbbb2, Sol###1,Dob2, La##1, Rebbb2,La###1, Mibbbb2, Rebb2, Si#1,Do#2, Mibbb2, Si##1,Do##2, Fabbb2, Mibb2, Si###1,Do###2, Fabb2, Re#2, Solbbbb2,Fab2, Re##2, Solbbb2,Labbbb2, Mi#2, Re###2, Solbb2,Fa#2, Labbb2, Mi##2,Fa##2, Labb2, Mi###2, Sibbbb2,Fa###2, Sibbb2, Sol#2,Dobbb3, Sibb2, Sol##2,Dobb3, La#2, Rebbbb3, Sol###2,Dob3, La##2, Rebbb3,La###2, Mibbbb3, Rebb3, Si#2,Do#3, Mibbb3, Si##2,Do##3, Fabbb3, Mibb3, Si###2,Do###3, Fabb3, Re#3, Solbbbb3,Fab3, Re##3, Solbbb3,Labbbb3, Mi#3, Re###3, Solbb3,Fa#3, Labbb3, Mi##3,Fa##3, Labb3, Mi###3, Sibbbb3,Fa###3, Sibbb3, Sol#3,Dobbb4, Sibb3, Sol##3,Dobb4, La#3, Rebbbb4, Sol###3,Dob4, La##3, Rebbb4,La###3, Mibbbb4, Rebb4, Si#3,Do#4, Mibbb4, Si##3,Do##4, Fabbb4, Mibb4, Si###3,Do###4, Fabb4, Re#4, Solbbbb4,Fab4, Re##4, Solbbb4,Labbbb4, Mi#4, Re###4, Solbb4,Fa#4, Labbb4, Mi##4,Fa##4, Labb4, Mi###4, Sibbbb4,Fa###4, Sibbb4, Sol#4,Dobbb5, Sibb4, Sol##4,Dobb5, La#4, Rebbbb5, Sol###4,Dob5, La##4, Rebbb5,La###4, Mibbbb5, Rebb5, Si#4,Do#5, Mibbb5, Si##4,Do##5, Fabbb5, Mibb5, Si###4,Do###5, Fabb5, Re#5, Solbbbb5,Fab5, Re##5, Solbbb5,Labbbb5, Mi#5, Re###5, Solbb5,Fa#5, Labbb5, Mi##5,Fa##5, Labb5, Mi###5, Sibbbb5,Fa###5, Sibbb5, Sol#5,Dobbb6, Sibb5, Sol##5,Dobb6, La#5, Rebbbb6, Sol###5,Dob6, La##5, Rebbb6,La###5, Mibbbb6, Rebb6, Si#5,Do#6, Mibbb6, Si##5,Do##6, Fabbb6, Mibb6, Si###5,Do###6, Fabb6, Re#6, Solbbbb6,Fab6, Re##6, Solbbb6,Labbbb6, Mi#6, Re###6, Solbb6,Fa#6, Labbb6, Mi##6,Fa##6, Labb6, Mi###6, Sibbbb6,Fa###6, Sibbb6, Sol#6,Dobbb7, Sibb6, Sol##6,Dobb7, La#6, Rebbbb7, Sol###6,Dob7, La##6, Rebbb7,La###6, Mibbbb7, Rebb7, Si#6,Do#7, Mibbb7, Si##6,Do##7, Fabbb7, Mibb7, Si###6,Do###7, Fabb7, Re#7, Solbbbb7,Fab7, Re##7, Solbbb7,Labbbb7, Mi#7, Re###7, Solbb7,Fa#7, Labbb7, Mi##7,Fa##7, Labb7, Mi###7, Sibbbb7,Fa###7, Sibbb7, Sol#7,Dobbb8, Sibb7, Sol##7,Dobb8, La#7, Rebbbb8, Sol###7,Dob8, La##7, Rebbb8,La###7, Mibbbb8, Rebb8, Si#7,Do#8, Mibbb8, Si##7,Do##8, Fabbb8, Mibb8, Si###7,Do###8, Fabb8, Re#8, Solbbbb8,Fab8, Re##8, Solbbb8,Labbbb8, Mi#8, Re###8, Solbb8,Fa#8, Labbb8, Mi##8,Fa##8, Labb8, Mi###8, Sibbbb8,Fa###8, Sibbb8, Sol#8,Dobbb9, Sibb8, Sol##8,Dobb9, La#8, Rebbbb9, Sol###8,Dob9, La##8, Rebbb9,La###8, Mibbbb9, Rebb9, Si#8,Do#9, Mibbb9, Si##8,Do##9, Fabbb9, Mibb9, Si###8,Do###9, Fabb9, Re#9, Solbbbb9,Fab9, Re##9, Solbbb9,Labbbb9, Mi#9, Re###9, Solbb9,Fa#9, Labbb9, Mi##9,Fa##9, Labb9, Mi###9, Sibbbb9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "La###'''', Mibbbb''', Rebb''', Si#'''',Do#''', Mibbb''', Si##'''',Do##''', Fabbb''', Mibb''', Si###'''',Do###''', Fabb''', Re#''', Solbbbb''',Fab''', Re##''', Solbbb''',Labbbb''', Mi#''', Re###''', Solbb''',Fa#''', Labbb''', Mi##''',Fa##''', Labb''', Mi###''', Sibbbb''',Fa###''', Sibbb''', Sol#''',Dobbb'', Sibb''', Sol##''',Dobb'', La#''', Rebbbb'', Sol###''',Dob'', La##''', Rebbb'',La###''', Mibbbb'', Rebb'', Si#''',Do#'', Mibbb'', Si##''',Do##'', Fabbb'', Mibb'', Si###''',Do###'', Fabb'', Re#'', Solbbbb'',Fab'', Re##'', Solbbb'',Labbbb'', Mi#'', Re###'', Solbb'',Fa#'', Labbb'', Mi##'',Fa##'', Labb'', Mi###'', Sibbbb'',Fa###'', Sibbb'', Sol#'',Dobbb', Sibb'', Sol##'',Dobb', La#'', Rebbbb', Sol###'',Dob', La##'', Rebbb',La###'', Mibbbb', Rebb', Si#'',Do#', Mibbb', Si##'',Do##', Fabbb', Mibb', Si###'',Do###', Fabb', Re#', Solbbbb',Fab', Re##', Solbbb',Labbbb', Mi#', Re###', Solbb',Fa#', Labbb', Mi##',Fa##', Labb', Mi###', Sibbbb',Fa###', Sibbb', Sol#',Dobbb, Sibb', Sol##',Dobb, La#', Rebbbb, Sol###',Dob, La##', Rebbb,La###', Mibbbb, Rebb, Si#',Do#, Mibbb, Si##',Do##, Fabbb, Mibb, Si###',Do###, Fabb, Re#, Solbbbb,Fab, Re##, Solbbb,Labbbb, Mi#, Re###, Solbb,Fa#, Labbb, Mi##,Fa##, Labb, Mi###, Sibbbb,Fa###, Sibbb, Sol#,Sibb, Sol##, dobbb,La#, Sol###, dobb, rebbbb,La##, dob, rebbb,La###, Si#, mibbbb, rebb,Si##, do#, mibbb,Si###, do##, fabbb, mibb,do###, fabb, re#, solbbbb,fab, re##, solbbb,labbbb, mi#, re###, solbb,fa#, labbb, mi##,fa##, labb, mi###, sibbbb,fa###, sibbb, sol#,dobbb', sibb, sol##,dobb', la#, rebbbb', sol###,dob', la##, rebbb',la###, mibbbb', rebb', si#,do#', mibbb', si##,do##', fabbb', mibb', si###,do###', fabb', re#', solbbbb',fab', re##', solbbb',labbbb', mi#', re###', solbb',fa#', labbb', mi##',fa##', labb', mi###', sibbbb',fa###', sibbb', sol#',dobbb'', sibb', sol##',dobb'', la#', rebbbb'', sol###',dob'', la##', rebbb'',la###', mibbbb'', rebb'', si#',do#'', mibbb'', si##',do##'', fabbb'', mibb'', si###',do###'', fabb'', re#'', solbbbb'',fab'', re##'', solbbb'',labbbb'', mi#'', re###'', solbb'',fa#'', labbb'', mi##'',fa##'', labb'', mi###'', sibbbb'',fa###'', sibbb'', sol#'',dobbb''', sibb'', sol##'',dobb''', la#'', rebbbb''', sol###'',dob''', la##'', rebbb''',la###'', mibbbb''', rebb''', si#'',do#''', mibbb''', si##'',do##''', fabbb''', mibb''', si###'',do###''', fabb''', re#''', solbbbb''',fab''', re##''', solbbb''',labbbb''', mi#''', re###''', solbb''',fa#''', labbb''', mi##''',fa##''', labb''', mi###''', sibbbb''',fa###''', sibbb''', sol#''',dobbb'''', sibb''', sol##''',dobb'''', la#''', rebbbb'''', sol###''',dob'''', la##''', rebbb'''',la###''', mibbbb'''', rebb'''', si#''',do#'''', mibbb'''', si##''',do##'''', fabbb'''', mibb'''', si###''',do###'''', fabb'''', re#'''', solbbbb'''',fab'''', re##'''', solbbb'''',labbbb'''', mi#'''', re###'''', solbb'''',fa#'''', labbb'''', mi##'''',fa##'''', labb'''', mi###'''', sibbbb'''',fa###'''', sibbb'''', sol#'''',dobbb''''', sibb'''', sol##'''',dobb''''', la#'''', rebbbb''''', sol###'''',dob''''', la##'''', rebbb''''',la###'''', mibbbb''''', rebb''''', si#'''',do#''''', mibbb''''', si##'''',do##''''', fabbb''''', mibb''''', si###'''',do###''''', fabb''''', re#''''', solbbbb''''',fab''''', re##''''', solbbb''''',labbbb''''', mi#''''', re###''''', solbb''''',fa#''''', labbb''''', mi##''''',fa##''''', labb''''', mi###''''', sibbbb''''',fa###''''', sibbb''''', sol#''''',dobbb'''''', sibb''''', sol##''''',dobb'''''', la#''''', rebbbb'''''', sol###''''',dob'''''', la##''''', rebbb'''''',la###''''', mibbbb'''''', rebb'''''', si#''''',do#'''''', mibbb'''''', si##''''',do##'''''', fabbb'''''', mibb'''''', si###''''',do###'''''', fabb'''''', re#'''''', solbbbb'''''',fab'''''', re##'''''', solbbb'''''',labbbb'''''', mi#'''''', re###'''''', solbb'''''',fa#'''''', labbb'''''', mi##'''''',fa##'''''', labb'''''', mi###'''''', sibbbb''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "La-diesis-diesis-diesis-6, Re-bemolle-bemolle-5, Si-diesis-6,La-diesis-diesis-diesis-diesis-6, Mi-bemolle-bemolle-bemolle-5, Re-bemolle-5, Si-diesis-diesis-6,Do-diesis-diesis-5, Fa-bemolle-bemolle-bemolle-5, Mi-bemolle-bemolle-5, Si-diesis-diesis-diesis-6,Do-diesis-diesis-diesis-5, Fa-bemolle-bemolle-5, Mi-bemolle-5,Do-diesis-diesis-diesis-diesis-5, Fa-bemolle-5, Re-diesis-diesis-5, Sol-bemolle-bemolle-bemolle-5,Mi-diesis-5, Re-diesis-diesis-diesis-5, Sol-bemolle-bemolle-5,La-bemolle-bemolle-bemolle-5, Mi-diesis-diesis-5, Re-diesis-diesis-diesis-diesis-5, Sol-bemolle-5,Fa-diesis-diesis-5, La-bemolle-bemolle-5, Mi-diesis-diesis-diesis-5,Fa-diesis-diesis-diesis-5, La-bemolle-5, Si-bemolle-bemolle-bemolle-5,Do-bemolle-bemolle-bemolle-4, Fa-diesis-diesis-diesis-diesis-5, Si-bemolle-bemolle-5, Sol-diesis-diesis-5,Do-bemolle-bemolle-4, Si-bemolle-5, Sol-diesis-diesis-diesis-5,Do-bemolle-4, La-diesis-diesis-5, Re-bemolle-bemolle-bemolle-4, Sol-diesis-diesis-diesis-diesis-5,La-diesis-diesis-diesis-5, Re-bemolle-bemolle-4, Si-diesis-5,La-diesis-diesis-diesis-diesis-5, Mi-bemolle-bemolle-bemolle-4, Re-bemolle-4, Si-diesis-diesis-5,Do-diesis-diesis-4, Fa-bemolle-bemolle-bemolle-4, Mi-bemolle-bemolle-4, Si-diesis-diesis-diesis-5,Do-diesis-diesis-diesis-4, Fa-bemolle-bemolle-4, Mi-bemolle-4,Do-diesis-diesis-diesis-diesis-4, Fa-bemolle-4, Re-diesis-diesis-4, Sol-bemolle-bemolle-bemolle-4,Mi-diesis-4, Re-diesis-diesis-diesis-4, Sol-bemolle-bemolle-4,La-bemolle-bemolle-bemolle-4, Mi-diesis-diesis-4, Re-diesis-diesis-diesis-diesis-4, Sol-bemolle-4,Fa-diesis-diesis-4, La-bemolle-bemolle-4, Mi-diesis-diesis-diesis-4,Fa-diesis-diesis-diesis-4, La-bemolle-4, Si-bemolle-bemolle-bemolle-4,Do-bemolle-bemolle-bemolle-3, Fa-diesis-diesis-diesis-diesis-4, Si-bemolle-bemolle-4, Sol-diesis-diesis-4,Do-bemolle-bemolle-3, Si-bemolle-4, Sol-diesis-diesis-diesis-4,Do-bemolle-3, La-diesis-diesis-4, Re-bemolle-bemolle-bemolle-3, Sol-diesis-diesis-diesis-diesis-4,La-diesis-diesis-diesis-4, Re-bemolle-bemolle-3, Si-diesis-4,La-diesis-diesis-diesis-diesis-4, Mi-bemolle-bemolle-bemolle-3, Re-bemolle-3, Si-diesis-diesis-4,Do-diesis-diesis-3, Fa-bemolle-bemolle-bemolle-3, Mi-bemolle-bemolle-3, Si-diesis-diesis-diesis-4,Do-diesis-diesis-diesis-3, Fa-bemolle-bemolle-3, Mi-bemolle-3,Do-diesis-diesis-diesis-diesis-3, Fa-bemolle-3, Re-diesis-diesis-3, Sol-bemolle-bemolle-bemolle-3,Mi-diesis-3, Re-diesis-diesis-diesis-3, Sol-bemolle-bemolle-3,La-bemolle-bemolle-bemolle-3, Mi-diesis-diesis-3, Re-diesis-diesis-diesis-diesis-3, Sol-bemolle-3,Fa-diesis-diesis-3, La-bemolle-bemolle-3, Mi-diesis-diesis-diesis-3,Fa-diesis-diesis-diesis-3, La-bemolle-3, Si-bemolle-bemolle-bemolle-3,Do-bemolle-bemolle-bemolle-2, Fa-diesis-diesis-diesis-diesis-3, Si-bemolle-bemolle-3, Sol-diesis-diesis-3,Do-bemolle-bemolle-2, Si-bemolle-3, Sol-diesis-diesis-diesis-3,Do-bemolle-2, La-diesis-diesis-3, Re-bemolle-bemolle-bemolle-2, Sol-diesis-diesis-diesis-diesis-3,La-diesis-diesis-diesis-3, Re-bemolle-bemolle-2, Si-diesis-3,La-diesis-diesis-diesis-diesis-3, Mi-bemolle-bemolle-bemolle-2, Re-bemolle-2, Si-diesis-diesis-3,Do-diesis-diesis-2, Fa-bemolle-bemolle-bemolle-2, Mi-bemolle-bemolle-2, Si-diesis-diesis-diesis-3,Do-diesis-diesis-diesis-2, Fa-bemolle-bemolle-2, Mi-bemolle-2,Do-diesis-diesis-diesis-diesis-2, Fa-bemolle-2, Re-diesis-diesis-2, Sol-bemolle-bemolle-bemolle-2,Mi-diesis-2, Re-diesis-diesis-diesis-2, Sol-bemolle-bemolle-2,La-bemolle-bemolle-bemolle-2, Mi-diesis-diesis-2, Re-diesis-diesis-diesis-diesis-2, Sol-bemolle-2,Fa-diesis-diesis-2, La-bemolle-bemolle-2, Mi-diesis-diesis-diesis-2,Fa-diesis-diesis-diesis-2, La-bemolle-2, Si-bemolle-bemolle-bemolle-2,Do-bemolle-bemolle-bemolle-, Fa-diesis-diesis-diesis-diesis-2, Si-bemolle-bemolle-2, Sol-diesis-diesis-2,Do-bemolle-bemolle-, Si-bemolle-2, Sol-diesis-diesis-diesis-2,Do-bemolle-, La-diesis-diesis-2, Re-bemolle-bemolle-bemolle-, Sol-diesis-diesis-diesis-diesis-2,La-diesis-diesis-diesis-2, Re-bemolle-bemolle-, Si-diesis-2,La-diesis-diesis-diesis-diesis-2, Mi-bemolle-bemolle-bemolle-, Re-bemolle-, Si-diesis-diesis-2,Do-diesis-diesis-, Fa-bemolle-bemolle-bemolle-, Mi-bemolle-bemolle-, Si-diesis-diesis-diesis-2,Do-diesis-diesis-diesis-, Fa-bemolle-bemolle-, Mi-bemolle-,Do-diesis-diesis-diesis-diesis-, Fa-bemolle-, Re-diesis-diesis-, Sol-bemolle-bemolle-bemolle-,Mi-diesis-, Re-diesis-diesis-diesis-, Sol-bemolle-bemolle-,La-bemolle-bemolle-bemolle-, Mi-diesis-diesis-, Re-diesis-diesis-diesis-diesis-, Sol-bemolle-,Fa-diesis-diesis-, La-bemolle-bemolle-, Mi-diesis-diesis-diesis-,Fa-diesis-diesis-diesis-, La-bemolle-, Si-bemolle-bemolle-bemolle-,Do-bemolle-bemolle-bemolle, Fa-diesis-diesis-diesis-diesis-, Si-bemolle-bemolle-, Sol-diesis-diesis-,Do-bemolle-bemolle, Si-bemolle-, Sol-diesis-diesis-diesis-,Do-bemolle, La-diesis-diesis-, Re-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-diesis-,La-diesis-diesis-diesis-, Re-bemolle-bemolle, Si-diesis-,La-diesis-diesis-diesis-diesis-, Mi-bemolle-bemolle-bemolle, Re-bemolle, Si-diesis-diesis-,Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis-,Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Mi-bemolle,Do-diesis-diesis-diesis-diesis, Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,La-bemolle-bemolle-bemolle, Mi-diesis-diesis, Re-diesis-diesis-diesis-diesis, Sol-bemolle,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis,Fa-diesis-diesis-diesis, La-bemolle, Si-bemolle-bemolle-bemolle,Do-bemolle-bemolle-bemolle+, Fa-diesis-diesis-diesis-diesis, Si-bemolle-bemolle, Sol-diesis-diesis,Do-bemolle-bemolle+, Si-bemolle, Sol-diesis-diesis-diesis,Do-bemolle+, La-diesis-diesis, Re-bemolle-bemolle-bemolle+, Sol-diesis-diesis-diesis-diesis,La-diesis-diesis-diesis, Re-bemolle-bemolle+, Si-diesis,La-diesis-diesis-diesis-diesis, Mi-bemolle-bemolle-bemolle+, Re-bemolle+, Si-diesis-diesis,Do-diesis-diesis+, Fa-bemolle-bemolle-bemolle+, Mi-bemolle-bemolle+, Si-diesis-diesis-diesis,Do-diesis-diesis-diesis+, Fa-bemolle-bemolle+, Mi-bemolle+,Do-diesis-diesis-diesis-diesis+, Fa-bemolle+, Re-diesis-diesis+, Sol-bemolle-bemolle-bemolle+,Mi-diesis+, Re-diesis-diesis-diesis+, Sol-bemolle-bemolle+,La-bemolle-bemolle-bemolle+, Mi-diesis-diesis+, Re-diesis-diesis-diesis-diesis+, Sol-bemolle+,Fa-diesis-diesis+, La-bemolle-bemolle+, Mi-diesis-diesis-diesis+,Fa-diesis-diesis-diesis+, La-bemolle+, Si-bemolle-bemolle-bemolle+,Do-bemolle-bemolle-bemolle+2, Fa-diesis-diesis-diesis-diesis+, Si-bemolle-bemolle+, Sol-diesis-diesis+,Do-bemolle-bemolle+2, Si-bemolle+, Sol-diesis-diesis-diesis+,Do-bemolle+2, La-diesis-diesis+, Re-bemolle-bemolle-bemolle+2, Sol-diesis-diesis-diesis-diesis+,La-diesis-diesis-diesis+, Re-bemolle-bemolle+2, Si-diesis+,La-diesis-diesis-diesis-diesis+, Mi-bemolle-bemolle-bemolle+2, Re-bemolle+2, Si-diesis-diesis+,Do-diesis-diesis+2, Fa-bemolle-bemolle-bemolle+2, Mi-bemolle-bemolle+2, Si-diesis-diesis-diesis+,Do-diesis-diesis-diesis+2, Fa-bemolle-bemolle+2, Mi-bemolle+2,Do-diesis-diesis-diesis-diesis+2, Fa-bemolle+2, Re-diesis-diesis+2, Sol-bemolle-bemolle-bemolle+2,Mi-diesis+2, Re-diesis-diesis-diesis+2, Sol-bemolle-bemolle+2,La-bemolle-bemolle-bemolle+2, Mi-diesis-diesis+2, Re-diesis-diesis-diesis-diesis+2, Sol-bemolle+2,Fa-diesis-diesis+2, La-bemolle-bemolle+2, Mi-diesis-diesis-diesis+2,Fa-diesis-diesis-diesis+2, La-bemolle+2, Si-bemolle-bemolle-bemolle+2,Do-bemolle-bemolle-bemolle+3, Fa-diesis-diesis-diesis-diesis+2, Si-bemolle-bemolle+2, Sol-diesis-diesis+2,Do-bemolle-bemolle+3, Si-bemolle+2, Sol-diesis-diesis-diesis+2,Do-bemolle+3, La-diesis-diesis+2, Re-bemolle-bemolle-bemolle+3, Sol-diesis-diesis-diesis-diesis+2,La-diesis-diesis-diesis+2, Re-bemolle-bemolle+3, Si-diesis+2,La-diesis-diesis-diesis-diesis+2, Mi-bemolle-bemolle-bemolle+3, Re-bemolle+3, Si-diesis-diesis+2,Do-diesis-diesis+3, Fa-bemolle-bemolle-bemolle+3, Mi-bemolle-bemolle+3, Si-diesis-diesis-diesis+2,Do-diesis-diesis-diesis+3, Fa-bemolle-bemolle+3, Mi-bemolle+3,Do-diesis-diesis-diesis-diesis+3, Fa-bemolle+3, Re-diesis-diesis+3, Sol-bemolle-bemolle-bemolle+3,Mi-diesis+3, Re-diesis-diesis-diesis+3, Sol-bemolle-bemolle+3,La-bemolle-bemolle-bemolle+3, Mi-diesis-diesis+3, Re-diesis-diesis-diesis-diesis+3, Sol-bemolle+3,Fa-diesis-diesis+3, La-bemolle-bemolle+3, Mi-diesis-diesis-diesis+3,Fa-diesis-diesis-diesis+3, La-bemolle+3, Si-bemolle-bemolle-bemolle+3,Do-bemolle-bemolle-bemolle+4, Fa-diesis-diesis-diesis-diesis+3, Si-bemolle-bemolle+3, Sol-diesis-diesis+3,Do-bemolle-bemolle+4, Si-bemolle+3, Sol-diesis-diesis-diesis+3,Do-bemolle+4, La-diesis-diesis+3, Re-bemolle-bemolle-bemolle+4, Sol-diesis-diesis-diesis-diesis+3,La-diesis-diesis-diesis+3, Re-bemolle-bemolle+4, Si-diesis+3,La-diesis-diesis-diesis-diesis+3, Mi-bemolle-bemolle-bemolle+4, Re-bemolle+4, Si-diesis-diesis+3,Do-diesis-diesis+4, Fa-bemolle-bemolle-bemolle+4, Mi-bemolle-bemolle+4, Si-diesis-diesis-diesis+3,Do-diesis-diesis-diesis+4, Fa-bemolle-bemolle+4, Mi-bemolle+4,Do-diesis-diesis-diesis-diesis+4, Fa-bemolle+4, Re-diesis-diesis+4, Sol-bemolle-bemolle-bemolle+4,Mi-diesis+4, Re-diesis-diesis-diesis+4, Sol-bemolle-bemolle+4,La-bemolle-bemolle-bemolle+4, Mi-diesis-diesis+4, Re-diesis-diesis-diesis-diesis+4, Sol-bemolle+4,Fa-diesis-diesis+4, La-bemolle-bemolle+4, Mi-diesis-diesis-diesis+4,Fa-diesis-diesis-diesis+4, La-bemolle+4, Si-bemolle-bemolle-bemolle+4,Do-bemolle-bemolle-bemolle+5, Fa-diesis-diesis-diesis-diesis+4, Si-bemolle-bemolle+4, Sol-diesis-diesis+4,Do-bemolle-bemolle+5, Si-bemolle+4, Sol-diesis-diesis-diesis+4,Do-bemolle+5, La-diesis-diesis+4, Re-bemolle-bemolle-bemolle+5, Sol-diesis-diesis-diesis-diesis+4,La-diesis-diesis-diesis+4, Re-bemolle-bemolle+5, Si-diesis+4,La-diesis-diesis-diesis-diesis+4, Mi-bemolle-bemolle-bemolle+5, Re-bemolle+5, Si-diesis-diesis+4,Do-diesis-diesis+5, Fa-bemolle-bemolle-bemolle+5, Mi-bemolle-bemolle+5, Si-diesis-diesis-diesis+4,Do-diesis-diesis-diesis+5, Fa-bemolle-bemolle+5, Mi-bemolle+5,Do-diesis-diesis-diesis-diesis+5, Fa-bemolle+5, Re-diesis-diesis+5, Sol-bemolle-bemolle-bemolle+5,Mi-diesis+5, Re-diesis-diesis-diesis+5, Sol-bemolle-bemolle+5,La-bemolle-bemolle-bemolle+5, Mi-diesis-diesis+5, Re-diesis-diesis-diesis-diesis+5, Sol-bemolle+5,Fa-diesis-diesis+5, La-bemolle-bemolle+5, Mi-diesis-diesis-diesis+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "La-diesis-diesis-diesis------, Re-bemolle-bemolle-----, Si-diesis------,La-diesis-diesis-diesis-diesis------, Mi-bemolle-bemolle-bemolle-----, Re-bemolle-----, Si-diesis-diesis------,Do-diesis-diesis-----, Fa-bemolle-bemolle-bemolle-----, Mi-bemolle-bemolle-----, Si-diesis-diesis-diesis------,Do-diesis-diesis-diesis-----, Fa-bemolle-bemolle-----, Mi-bemolle-----,Do-diesis-diesis-diesis-diesis-----, Fa-bemolle-----, Re-diesis-diesis-----, Sol-bemolle-bemolle-bemolle-----,Mi-diesis-----, Re-diesis-diesis-diesis-----, Sol-bemolle-bemolle-----,La-bemolle-bemolle-bemolle-----, Mi-diesis-diesis-----, Re-diesis-diesis-diesis-diesis-----, Sol-bemolle-----,Fa-diesis-diesis-----, La-bemolle-bemolle-----, Mi-diesis-diesis-diesis-----,Fa-diesis-diesis-diesis-----, La-bemolle-----, Si-bemolle-bemolle-bemolle-----,Do-bemolle-bemolle-bemolle----, Fa-diesis-diesis-diesis-diesis-----, Si-bemolle-bemolle-----, Sol-diesis-diesis-----,Do-bemolle-bemolle----, Si-bemolle-----, Sol-diesis-diesis-diesis-----,Do-bemolle----, La-diesis-diesis-----, Re-bemolle-bemolle-bemolle----, Sol-diesis-diesis-diesis-diesis-----,La-diesis-diesis-diesis-----, Re-bemolle-bemolle----, Si-diesis-----,La-diesis-diesis-diesis-diesis-----, Mi-bemolle-bemolle-bemolle----, Re-bemolle----, Si-diesis-diesis-----,Do-diesis-diesis----, Fa-bemolle-bemolle-bemolle----, Mi-bemolle-bemolle----, Si-diesis-diesis-diesis-----,Do-diesis-diesis-diesis----, Fa-bemolle-bemolle----, Mi-bemolle----,Do-diesis-diesis-diesis-diesis----, Fa-bemolle----, Re-diesis-diesis----, Sol-bemolle-bemolle-bemolle----,Mi-diesis----, Re-diesis-diesis-diesis----, Sol-bemolle-bemolle----,La-bemolle-bemolle-bemolle----, Mi-diesis-diesis----, Re-diesis-diesis-diesis-diesis----, Sol-bemolle----,Fa-diesis-diesis----, La-bemolle-bemolle----, Mi-diesis-diesis-diesis----,Fa-diesis-diesis-diesis----, La-bemolle----, Si-bemolle-bemolle-bemolle----,Do-bemolle-bemolle-bemolle---, Fa-diesis-diesis-diesis-diesis----, Si-bemolle-bemolle----, Sol-diesis-diesis----,Do-bemolle-bemolle---, Si-bemolle----, Sol-diesis-diesis-diesis----,Do-bemolle---, La-diesis-diesis----, Re-bemolle-bemolle-bemolle---, Sol-diesis-diesis-diesis-diesis----,La-diesis-diesis-diesis----, Re-bemolle-bemolle---, Si-diesis----,La-diesis-diesis-diesis-diesis----, Mi-bemolle-bemolle-bemolle---, Re-bemolle---, Si-diesis-diesis----,Do-diesis-diesis---, Fa-bemolle-bemolle-bemolle---, Mi-bemolle-bemolle---, Si-diesis-diesis-diesis----,Do-diesis-diesis-diesis---, Fa-bemolle-bemolle---, Mi-bemolle---,Do-diesis-diesis-diesis-diesis---, Fa-bemolle---, Re-diesis-diesis---, Sol-bemolle-bemolle-bemolle---,Mi-diesis---, Re-diesis-diesis-diesis---, Sol-bemolle-bemolle---,La-bemolle-bemolle-bemolle---, Mi-diesis-diesis---, Re-diesis-diesis-diesis-diesis---, Sol-bemolle---,Fa-diesis-diesis---, La-bemolle-bemolle---, Mi-diesis-diesis-diesis---,Fa-diesis-diesis-diesis---, La-bemolle---, Si-bemolle-bemolle-bemolle---,Do-bemolle-bemolle-bemolle--, Fa-diesis-diesis-diesis-diesis---, Si-bemolle-bemolle---, Sol-diesis-diesis---,Do-bemolle-bemolle--, Si-bemolle---, Sol-diesis-diesis-diesis---,Do-bemolle--, La-diesis-diesis---, Re-bemolle-bemolle-bemolle--, Sol-diesis-diesis-diesis-diesis---,La-diesis-diesis-diesis---, Re-bemolle-bemolle--, Si-diesis---,La-diesis-diesis-diesis-diesis---, Mi-bemolle-bemolle-bemolle--, Re-bemolle--, Si-diesis-diesis---,Do-diesis-diesis--, Fa-bemolle-bemolle-bemolle--, Mi-bemolle-bemolle--, Si-diesis-diesis-diesis---,Do-diesis-diesis-diesis--, Fa-bemolle-bemolle--, Mi-bemolle--,Do-diesis-diesis-diesis-diesis--, Fa-bemolle--, Re-diesis-diesis--, Sol-bemolle-bemolle-bemolle--,Mi-diesis--, Re-diesis-diesis-diesis--, Sol-bemolle-bemolle--,La-bemolle-bemolle-bemolle--, Mi-diesis-diesis--, Re-diesis-diesis-diesis-diesis--, Sol-bemolle--,Fa-diesis-diesis--, La-bemolle-bemolle--, Mi-diesis-diesis-diesis--,Fa-diesis-diesis-diesis--, La-bemolle--, Si-bemolle-bemolle-bemolle--,Do-bemolle-bemolle-bemolle-, Fa-diesis-diesis-diesis-diesis--, Si-bemolle-bemolle--, Sol-diesis-diesis--,Do-bemolle-bemolle-, Si-bemolle--, Sol-diesis-diesis-diesis--,Do-bemolle-, La-diesis-diesis--, Re-bemolle-bemolle-bemolle-, Sol-diesis-diesis-diesis-diesis--,La-diesis-diesis-diesis--, Re-bemolle-bemolle-, Si-diesis--,La-diesis-diesis-diesis-diesis--, Mi-bemolle-bemolle-bemolle-, Re-bemolle-, Si-diesis-diesis--,Do-diesis-diesis-, Fa-bemolle-bemolle-bemolle-, Mi-bemolle-bemolle-, Si-diesis-diesis-diesis--,Do-diesis-diesis-diesis-, Fa-bemolle-bemolle-, Mi-bemolle-,Do-diesis-diesis-diesis-diesis-, Fa-bemolle-, Re-diesis-diesis-, Sol-bemolle-bemolle-bemolle-,Mi-diesis-, Re-diesis-diesis-diesis-, Sol-bemolle-bemolle-,La-bemolle-bemolle-bemolle-, Mi-diesis-diesis-, Re-diesis-diesis-diesis-diesis-, Sol-bemolle-,Fa-diesis-diesis-, La-bemolle-bemolle-, Mi-diesis-diesis-diesis-,Fa-diesis-diesis-diesis-, La-bemolle-, Si-bemolle-bemolle-bemolle-,Do-bemolle-bemolle-bemolle, Fa-diesis-diesis-diesis-diesis-, Si-bemolle-bemolle-, Sol-diesis-diesis-,Do-bemolle-bemolle, Si-bemolle-, Sol-diesis-diesis-diesis-,Do-bemolle, La-diesis-diesis-, Re-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-diesis-,La-diesis-diesis-diesis-, Re-bemolle-bemolle, Si-diesis-,La-diesis-diesis-diesis-diesis-, Mi-bemolle-bemolle-bemolle, Re-bemolle, Si-diesis-diesis-,Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis-,Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Mi-bemolle,Do-diesis-diesis-diesis-diesis, Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,La-bemolle-bemolle-bemolle, Mi-diesis-diesis, Re-diesis-diesis-diesis-diesis, Sol-bemolle,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis,Fa-diesis-diesis-diesis, La-bemolle, Si-bemolle-bemolle-bemolle,Do-bemolle-bemolle-bemolle+, Fa-diesis-diesis-diesis-diesis, Si-bemolle-bemolle, Sol-diesis-diesis,Do-bemolle-bemolle+, Si-bemolle, Sol-diesis-diesis-diesis,Do-bemolle+, La-diesis-diesis, Re-bemolle-bemolle-bemolle+, Sol-diesis-diesis-diesis-diesis,La-diesis-diesis-diesis, Re-bemolle-bemolle+, Si-diesis,La-diesis-diesis-diesis-diesis, Mi-bemolle-bemolle-bemolle+, Re-bemolle+, Si-diesis-diesis,Do-diesis-diesis+, Fa-bemolle-bemolle-bemolle+, Mi-bemolle-bemolle+, Si-diesis-diesis-diesis,Do-diesis-diesis-diesis+, Fa-bemolle-bemolle+, Mi-bemolle+,Do-diesis-diesis-diesis-diesis+, Fa-bemolle+, Re-diesis-diesis+, Sol-bemolle-bemolle-bemolle+,Mi-diesis+, Re-diesis-diesis-diesis+, Sol-bemolle-bemolle+,La-bemolle-bemolle-bemolle+, Mi-diesis-diesis+, Re-diesis-diesis-diesis-diesis+, Sol-bemolle+,Fa-diesis-diesis+, La-bemolle-bemolle+, Mi-diesis-diesis-diesis+,Fa-diesis-diesis-diesis+, La-bemolle+, Si-bemolle-bemolle-bemolle+,Do-bemolle-bemolle-bemolle++, Fa-diesis-diesis-diesis-diesis+, Si-bemolle-bemolle+, Sol-diesis-diesis+,Do-bemolle-bemolle++, Si-bemolle+, Sol-diesis-diesis-diesis+,Do-bemolle++, La-diesis-diesis+, Re-bemolle-bemolle-bemolle++, Sol-diesis-diesis-diesis-diesis+,La-diesis-diesis-diesis+, Re-bemolle-bemolle++, Si-diesis+,La-diesis-diesis-diesis-diesis+, Mi-bemolle-bemolle-bemolle++, Re-bemolle++, Si-diesis-diesis+,Do-diesis-diesis++, Fa-bemolle-bemolle-bemolle++, Mi-bemolle-bemolle++, Si-diesis-diesis-diesis+,Do-diesis-diesis-diesis++, Fa-bemolle-bemolle++, Mi-bemolle++,Do-diesis-diesis-diesis-diesis++, Fa-bemolle++, Re-diesis-diesis++, Sol-bemolle-bemolle-bemolle++,Mi-diesis++, Re-diesis-diesis-diesis++, Sol-bemolle-bemolle++,La-bemolle-bemolle-bemolle++, Mi-diesis-diesis++, Re-diesis-diesis-diesis-diesis++, Sol-bemolle++,Fa-diesis-diesis++, La-bemolle-bemolle++, Mi-diesis-diesis-diesis++,Fa-diesis-diesis-diesis++, La-bemolle++, Si-bemolle-bemolle-bemolle++,Do-bemolle-bemolle-bemolle+++, Fa-diesis-diesis-diesis-diesis++, Si-bemolle-bemolle++, Sol-diesis-diesis++,Do-bemolle-bemolle+++, Si-bemolle++, Sol-diesis-diesis-diesis++,Do-bemolle+++, La-diesis-diesis++, Re-bemolle-bemolle-bemolle+++, Sol-diesis-diesis-diesis-diesis++,La-diesis-diesis-diesis++, Re-bemolle-bemolle+++, Si-diesis++,La-diesis-diesis-diesis-diesis++, Mi-bemolle-bemolle-bemolle+++, Re-bemolle+++, Si-diesis-diesis++,Do-diesis-diesis+++, Fa-bemolle-bemolle-bemolle+++, Mi-bemolle-bemolle+++, Si-diesis-diesis-diesis++,Do-diesis-diesis-diesis+++, Fa-bemolle-bemolle+++, Mi-bemolle+++,Do-diesis-diesis-diesis-diesis+++, Fa-bemolle+++, Re-diesis-diesis+++, Sol-bemolle-bemolle-bemolle+++,Mi-diesis+++, Re-diesis-diesis-diesis+++, Sol-bemolle-bemolle+++,La-bemolle-bemolle-bemolle+++, Mi-diesis-diesis+++, Re-diesis-diesis-diesis-diesis+++, Sol-bemolle+++,Fa-diesis-diesis+++, La-bemolle-bemolle+++, Mi-diesis-diesis-diesis+++,Fa-diesis-diesis-diesis+++, La-bemolle+++, Si-bemolle-bemolle-bemolle+++,Do-bemolle-bemolle-bemolle++++, Fa-diesis-diesis-diesis-diesis+++, Si-bemolle-bemolle+++, Sol-diesis-diesis+++,Do-bemolle-bemolle++++, Si-bemolle+++, Sol-diesis-diesis-diesis+++,Do-bemolle++++, La-diesis-diesis+++, Re-bemolle-bemolle-bemolle++++, Sol-diesis-diesis-diesis-diesis+++,La-diesis-diesis-diesis+++, Re-bemolle-bemolle++++, Si-diesis+++,La-diesis-diesis-diesis-diesis+++, Mi-bemolle-bemolle-bemolle++++, Re-bemolle++++, Si-diesis-diesis+++,Do-diesis-diesis++++, Fa-bemolle-bemolle-bemolle++++, Mi-bemolle-bemolle++++, Si-diesis-diesis-diesis+++,Do-diesis-diesis-diesis++++, Fa-bemolle-bemolle++++, Mi-bemolle++++,Do-diesis-diesis-diesis-diesis++++, Fa-bemolle++++, Re-diesis-diesis++++, Sol-bemolle-bemolle-bemolle++++,Mi-diesis++++, Re-diesis-diesis-diesis++++, Sol-bemolle-bemolle++++,La-bemolle-bemolle-bemolle++++, Mi-diesis-diesis++++, Re-diesis-diesis-diesis-diesis++++, Sol-bemolle++++,Fa-diesis-diesis++++, La-bemolle-bemolle++++, Mi-diesis-diesis-diesis++++,Fa-diesis-diesis-diesis++++, La-bemolle++++, Si-bemolle-bemolle-bemolle++++,Do-bemolle-bemolle-bemolle+++++, Fa-diesis-diesis-diesis-diesis++++, Si-bemolle-bemolle++++, Sol-diesis-diesis++++,Do-bemolle-bemolle+++++, Si-bemolle++++, Sol-diesis-diesis-diesis++++,Do-bemolle+++++, La-diesis-diesis++++, Re-bemolle-bemolle-bemolle+++++, Sol-diesis-diesis-diesis-diesis++++,La-diesis-diesis-diesis++++, Re-bemolle-bemolle+++++, Si-diesis++++,La-diesis-diesis-diesis-diesis++++, Mi-bemolle-bemolle-bemolle+++++, Re-bemolle+++++, Si-diesis-diesis++++,Do-diesis-diesis+++++, Fa-bemolle-bemolle-bemolle+++++, Mi-bemolle-bemolle+++++, Si-diesis-diesis-diesis++++,Do-diesis-diesis-diesis+++++, Fa-bemolle-bemolle+++++, Mi-bemolle+++++,Do-diesis-diesis-diesis-diesis+++++, Fa-bemolle+++++, Re-diesis-diesis+++++, Sol-bemolle-bemolle-bemolle+++++,Mi-diesis+++++, Re-diesis-diesis-diesis+++++, Sol-bemolle-bemolle+++++,La-bemolle-bemolle-bemolle+++++, Mi-diesis-diesis+++++, Re-diesis-diesis-diesis-diesis+++++, Sol-bemolle+++++,Fa-diesis-diesis+++++, La-bemolle-bemolle+++++, Mi-diesis-diesis-diesis+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "La-diesis-diesis-diesis-2, Re-bemolle-bemolle-1, Si-diesis-2,La-diesis-diesis-diesis-diesis-2, Mi-bemolle-bemolle-bemolle-1, Re-bemolle-1, Si-diesis-diesis-2,Do-diesis-diesis-1, Fa-bemolle-bemolle-bemolle-1, Mi-bemolle-bemolle-1, Si-diesis-diesis-diesis-2,Do-diesis-diesis-diesis-1, Fa-bemolle-bemolle-1, Mi-bemolle-1,Do-diesis-diesis-diesis-diesis-1, Fa-bemolle-1, Re-diesis-diesis-1, Sol-bemolle-bemolle-bemolle-1,Mi-diesis-1, Re-diesis-diesis-diesis-1, Sol-bemolle-bemolle-1,La-bemolle-bemolle-bemolle-1, Mi-diesis-diesis-1, Re-diesis-diesis-diesis-diesis-1, Sol-bemolle-1,Fa-diesis-diesis-1, La-bemolle-bemolle-1, Mi-diesis-diesis-diesis-1,Fa-diesis-diesis-diesis-1, La-bemolle-1, Si-bemolle-bemolle-bemolle-1,Do-bemolle-bemolle-bemolle0, Fa-diesis-diesis-diesis-diesis-1, Si-bemolle-bemolle-1, Sol-diesis-diesis-1,Do-bemolle-bemolle0, Si-bemolle-1, Sol-diesis-diesis-diesis-1,Do-bemolle0, La-diesis-diesis-1, Re-bemolle-bemolle-bemolle0, Sol-diesis-diesis-diesis-diesis-1,La-diesis-diesis-diesis-1, Re-bemolle-bemolle0, Si-diesis-1,La-diesis-diesis-diesis-diesis-1, Mi-bemolle-bemolle-bemolle0, Re-bemolle0, Si-diesis-diesis-1,Do-diesis-diesis0, Fa-bemolle-bemolle-bemolle0, Mi-bemolle-bemolle0, Si-diesis-diesis-diesis-1,Do-diesis-diesis-diesis0, Fa-bemolle-bemolle0, Mi-bemolle0,Do-diesis-diesis-diesis-diesis0, Fa-bemolle0, Re-diesis-diesis0, Sol-bemolle-bemolle-bemolle0,Mi-diesis0, Re-diesis-diesis-diesis0, Sol-bemolle-bemolle0,La-bemolle-bemolle-bemolle0, Mi-diesis-diesis0, Re-diesis-diesis-diesis-diesis0, Sol-bemolle0,Fa-diesis-diesis0, La-bemolle-bemolle0, Mi-diesis-diesis-diesis0,Fa-diesis-diesis-diesis0, La-bemolle0, Si-bemolle-bemolle-bemolle0,Do-bemolle-bemolle-bemolle1, Fa-diesis-diesis-diesis-diesis0, Si-bemolle-bemolle0, Sol-diesis-diesis0,Do-bemolle-bemolle1, Si-bemolle0, Sol-diesis-diesis-diesis0,Do-bemolle1, La-diesis-diesis0, Re-bemolle-bemolle-bemolle1, Sol-diesis-diesis-diesis-diesis0,La-diesis-diesis-diesis0, Re-bemolle-bemolle1, Si-diesis0,La-diesis-diesis-diesis-diesis0, Mi-bemolle-bemolle-bemolle1, Re-bemolle1, Si-diesis-diesis0,Do-diesis-diesis1, Fa-bemolle-bemolle-bemolle1, Mi-bemolle-bemolle1, Si-diesis-diesis-diesis0,Do-diesis-diesis-diesis1, Fa-bemolle-bemolle1, Mi-bemolle1,Do-diesis-diesis-diesis-diesis1, Fa-bemolle1, Re-diesis-diesis1, Sol-bemolle-bemolle-bemolle1,Mi-diesis1, Re-diesis-diesis-diesis1, Sol-bemolle-bemolle1,La-bemolle-bemolle-bemolle1, Mi-diesis-diesis1, Re-diesis-diesis-diesis-diesis1, Sol-bemolle1,Fa-diesis-diesis1, La-bemolle-bemolle1, Mi-diesis-diesis-diesis1,Fa-diesis-diesis-diesis1, La-bemolle1, Si-bemolle-bemolle-bemolle1,Do-bemolle-bemolle-bemolle2, Fa-diesis-diesis-diesis-diesis1, Si-bemolle-bemolle1, Sol-diesis-diesis1,Do-bemolle-bemolle2, Si-bemolle1, Sol-diesis-diesis-diesis1,Do-bemolle2, La-diesis-diesis1, Re-bemolle-bemolle-bemolle2, Sol-diesis-diesis-diesis-diesis1,La-diesis-diesis-diesis1, Re-bemolle-bemolle2, Si-diesis1,La-diesis-diesis-diesis-diesis1, Mi-bemolle-bemolle-bemolle2, Re-bemolle2, Si-diesis-diesis1,Do-diesis-diesis2, Fa-bemolle-bemolle-bemolle2, Mi-bemolle-bemolle2, Si-diesis-diesis-diesis1,Do-diesis-diesis-diesis2, Fa-bemolle-bemolle2, Mi-bemolle2,Do-diesis-diesis-diesis-diesis2, Fa-bemolle2, Re-diesis-diesis2, Sol-bemolle-bemolle-bemolle2,Mi-diesis2, Re-diesis-diesis-diesis2, Sol-bemolle-bemolle2,La-bemolle-bemolle-bemolle2, Mi-diesis-diesis2, Re-diesis-diesis-diesis-diesis2, Sol-bemolle2,Fa-diesis-diesis2, La-bemolle-bemolle2, Mi-diesis-diesis-diesis2,Fa-diesis-diesis-diesis2, La-bemolle2, Si-bemolle-bemolle-bemolle2,Do-bemolle-bemolle-bemolle3, Fa-diesis-diesis-diesis-diesis2, Si-bemolle-bemolle2, Sol-diesis-diesis2,Do-bemolle-bemolle3, Si-bemolle2, Sol-diesis-diesis-diesis2,Do-bemolle3, La-diesis-diesis2, Re-bemolle-bemolle-bemolle3, Sol-diesis-diesis-diesis-diesis2,La-diesis-diesis-diesis2, Re-bemolle-bemolle3, Si-diesis2,La-diesis-diesis-diesis-diesis2, Mi-bemolle-bemolle-bemolle3, Re-bemolle3, Si-diesis-diesis2,Do-diesis-diesis3, Fa-bemolle-bemolle-bemolle3, Mi-bemolle-bemolle3, Si-diesis-diesis-diesis2,Do-diesis-diesis-diesis3, Fa-bemolle-bemolle3, Mi-bemolle3,Do-diesis-diesis-diesis-diesis3, Fa-bemolle3, Re-diesis-diesis3, Sol-bemolle-bemolle-bemolle3,Mi-diesis3, Re-diesis-diesis-diesis3, Sol-bemolle-bemolle3,La-bemolle-bemolle-bemolle3, Mi-diesis-diesis3, Re-diesis-diesis-diesis-diesis3, Sol-bemolle3,Fa-diesis-diesis3, La-bemolle-bemolle3, Mi-diesis-diesis-diesis3,Fa-diesis-diesis-diesis3, La-bemolle3, Si-bemolle-bemolle-bemolle3,Do-bemolle-bemolle-bemolle4, Fa-diesis-diesis-diesis-diesis3, Si-bemolle-bemolle3, Sol-diesis-diesis3,Do-bemolle-bemolle4, Si-bemolle3, Sol-diesis-diesis-diesis3,Do-bemolle4, La-diesis-diesis3, Re-bemolle-bemolle-bemolle4, Sol-diesis-diesis-diesis-diesis3,La-diesis-diesis-diesis3, Re-bemolle-bemolle4, Si-diesis3,La-diesis-diesis-diesis-diesis3, Mi-bemolle-bemolle-bemolle4, Re-bemolle4, Si-diesis-diesis3,Do-diesis-diesis4, Fa-bemolle-bemolle-bemolle4, Mi-bemolle-bemolle4, Si-diesis-diesis-diesis3,Do-diesis-diesis-diesis4, Fa-bemolle-bemolle4, Mi-bemolle4,Do-diesis-diesis-diesis-diesis4, Fa-bemolle4, Re-diesis-diesis4, Sol-bemolle-bemolle-bemolle4,Mi-diesis4, Re-diesis-diesis-diesis4, Sol-bemolle-bemolle4,La-bemolle-bemolle-bemolle4, Mi-diesis-diesis4, Re-diesis-diesis-diesis-diesis4, Sol-bemolle4,Fa-diesis-diesis4, La-bemolle-bemolle4, Mi-diesis-diesis-diesis4,Fa-diesis-diesis-diesis4, La-bemolle4, Si-bemolle-bemolle-bemolle4,Do-bemolle-bemolle-bemolle5, Fa-diesis-diesis-diesis-diesis4, Si-bemolle-bemolle4, Sol-diesis-diesis4,Do-bemolle-bemolle5, Si-bemolle4, Sol-diesis-diesis-diesis4,Do-bemolle5, La-diesis-diesis4, Re-bemolle-bemolle-bemolle5, Sol-diesis-diesis-diesis-diesis4,La-diesis-diesis-diesis4, Re-bemolle-bemolle5, Si-diesis4,La-diesis-diesis-diesis-diesis4, Mi-bemolle-bemolle-bemolle5, Re-bemolle5, Si-diesis-diesis4,Do-diesis-diesis5, Fa-bemolle-bemolle-bemolle5, Mi-bemolle-bemolle5, Si-diesis-diesis-diesis4,Do-diesis-diesis-diesis5, Fa-bemolle-bemolle5, Mi-bemolle5,Do-diesis-diesis-diesis-diesis5, Fa-bemolle5, Re-diesis-diesis5, Sol-bemolle-bemolle-bemolle5,Mi-diesis5, Re-diesis-diesis-diesis5, Sol-bemolle-bemolle5,La-bemolle-bemolle-bemolle5, Mi-diesis-diesis5, Re-diesis-diesis-diesis-diesis5, Sol-bemolle5,Fa-diesis-diesis5, La-bemolle-bemolle5, Mi-diesis-diesis-diesis5,Fa-diesis-diesis-diesis5, La-bemolle5, Si-bemolle-bemolle-bemolle5,Do-bemolle-bemolle-bemolle6, Fa-diesis-diesis-diesis-diesis5, Si-bemolle-bemolle5, Sol-diesis-diesis5,Do-bemolle-bemolle6, Si-bemolle5, Sol-diesis-diesis-diesis5,Do-bemolle6, La-diesis-diesis5, Re-bemolle-bemolle-bemolle6, Sol-diesis-diesis-diesis-diesis5,La-diesis-diesis-diesis5, Re-bemolle-bemolle6, Si-diesis5,La-diesis-diesis-diesis-diesis5, Mi-bemolle-bemolle-bemolle6, Re-bemolle6, Si-diesis-diesis5,Do-diesis-diesis6, Fa-bemolle-bemolle-bemolle6, Mi-bemolle-bemolle6, Si-diesis-diesis-diesis5,Do-diesis-diesis-diesis6, Fa-bemolle-bemolle6, Mi-bemolle6,Do-diesis-diesis-diesis-diesis6, Fa-bemolle6, Re-diesis-diesis6, Sol-bemolle-bemolle-bemolle6,Mi-diesis6, Re-diesis-diesis-diesis6, Sol-bemolle-bemolle6,La-bemolle-bemolle-bemolle6, Mi-diesis-diesis6, Re-diesis-diesis-diesis-diesis6, Sol-bemolle6,Fa-diesis-diesis6, La-bemolle-bemolle6, Mi-diesis-diesis-diesis6,Fa-diesis-diesis-diesis6, La-bemolle6, Si-bemolle-bemolle-bemolle6,Do-bemolle-bemolle-bemolle7, Fa-diesis-diesis-diesis-diesis6, Si-bemolle-bemolle6, Sol-diesis-diesis6,Do-bemolle-bemolle7, Si-bemolle6, Sol-diesis-diesis-diesis6,Do-bemolle7, La-diesis-diesis6, Re-bemolle-bemolle-bemolle7, Sol-diesis-diesis-diesis-diesis6,La-diesis-diesis-diesis6, Re-bemolle-bemolle7, Si-diesis6,La-diesis-diesis-diesis-diesis6, Mi-bemolle-bemolle-bemolle7, Re-bemolle7, Si-diesis-diesis6,Do-diesis-diesis7, Fa-bemolle-bemolle-bemolle7, Mi-bemolle-bemolle7, Si-diesis-diesis-diesis6,Do-diesis-diesis-diesis7, Fa-bemolle-bemolle7, Mi-bemolle7,Do-diesis-diesis-diesis-diesis7, Fa-bemolle7, Re-diesis-diesis7, Sol-bemolle-bemolle-bemolle7,Mi-diesis7, Re-diesis-diesis-diesis7, Sol-bemolle-bemolle7,La-bemolle-bemolle-bemolle7, Mi-diesis-diesis7, Re-diesis-diesis-diesis-diesis7, Sol-bemolle7,Fa-diesis-diesis7, La-bemolle-bemolle7, Mi-diesis-diesis-diesis7,Fa-diesis-diesis-diesis7, La-bemolle7, Si-bemolle-bemolle-bemolle7,Do-bemolle-bemolle-bemolle8, Fa-diesis-diesis-diesis-diesis7, Si-bemolle-bemolle7, Sol-diesis-diesis7,Do-bemolle-bemolle8, Si-bemolle7, Sol-diesis-diesis-diesis7,Do-bemolle8, La-diesis-diesis7, Re-bemolle-bemolle-bemolle8, Sol-diesis-diesis-diesis-diesis7,La-diesis-diesis-diesis7, Re-bemolle-bemolle8, Si-diesis7,La-diesis-diesis-diesis-diesis7, Mi-bemolle-bemolle-bemolle8, Re-bemolle8, Si-diesis-diesis7,Do-diesis-diesis8, Fa-bemolle-bemolle-bemolle8, Mi-bemolle-bemolle8, Si-diesis-diesis-diesis7,Do-diesis-diesis-diesis8, Fa-bemolle-bemolle8, Mi-bemolle8,Do-diesis-diesis-diesis-diesis8, Fa-bemolle8, Re-diesis-diesis8, Sol-bemolle-bemolle-bemolle8,Mi-diesis8, Re-diesis-diesis-diesis8, Sol-bemolle-bemolle8,La-bemolle-bemolle-bemolle8, Mi-diesis-diesis8, Re-diesis-diesis-diesis-diesis8, Sol-bemolle8,Fa-diesis-diesis8, La-bemolle-bemolle8, Mi-diesis-diesis-diesis8,Fa-diesis-diesis-diesis8, La-bemolle8, Si-bemolle-bemolle-bemolle8,Do-bemolle-bemolle-bemolle9, Fa-diesis-diesis-diesis-diesis8, Si-bemolle-bemolle8, Sol-diesis-diesis8,Do-bemolle-bemolle9, Si-bemolle8, Sol-diesis-diesis-diesis8,Do-bemolle9, La-diesis-diesis8, Re-bemolle-bemolle-bemolle9, Sol-diesis-diesis-diesis-diesis8,La-diesis-diesis-diesis8, Re-bemolle-bemolle9, Si-diesis8,La-diesis-diesis-diesis-diesis8, Mi-bemolle-bemolle-bemolle9, Re-bemolle9, Si-diesis-diesis8,Do-diesis-diesis9, Fa-bemolle-bemolle-bemolle9, Mi-bemolle-bemolle9, Si-diesis-diesis-diesis8,Do-diesis-diesis-diesis9, Fa-bemolle-bemolle9, Mi-bemolle9,Do-diesis-diesis-diesis-diesis9, Fa-bemolle9, Re-diesis-diesis9, Sol-bemolle-bemolle-bemolle9,Mi-diesis9, Re-diesis-diesis-diesis9, Sol-bemolle-bemolle9,La-bemolle-bemolle-bemolle9, Mi-diesis-diesis9, Re-diesis-diesis-diesis-diesis9, Sol-bemolle9,Fa-diesis-diesis9, La-bemolle-bemolle9, Mi-diesis-diesis-diesis9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "La-diesis-diesis-diesis'''', Re-bemolle-bemolle''', Si-diesis'''',La-diesis-diesis-diesis-diesis'''', Mi-bemolle-bemolle-bemolle''', Re-bemolle''', Si-diesis-diesis'''',Do-diesis-diesis''', Fa-bemolle-bemolle-bemolle''', Mi-bemolle-bemolle''', Si-diesis-diesis-diesis'''',Do-diesis-diesis-diesis''', Fa-bemolle-bemolle''', Mi-bemolle''',Do-diesis-diesis-diesis-diesis''', Fa-bemolle''', Re-diesis-diesis''', Sol-bemolle-bemolle-bemolle''',Mi-diesis''', Re-diesis-diesis-diesis''', Sol-bemolle-bemolle''',La-bemolle-bemolle-bemolle''', Mi-diesis-diesis''', Re-diesis-diesis-diesis-diesis''', Sol-bemolle''',Fa-diesis-diesis''', La-bemolle-bemolle''', Mi-diesis-diesis-diesis''',Fa-diesis-diesis-diesis''', La-bemolle''', Si-bemolle-bemolle-bemolle''',Do-bemolle-bemolle-bemolle'', Fa-diesis-diesis-diesis-diesis''', Si-bemolle-bemolle''', Sol-diesis-diesis''',Do-bemolle-bemolle'', Si-bemolle''', Sol-diesis-diesis-diesis''',Do-bemolle'', La-diesis-diesis''', Re-bemolle-bemolle-bemolle'', Sol-diesis-diesis-diesis-diesis''',La-diesis-diesis-diesis''', Re-bemolle-bemolle'', Si-diesis''',La-diesis-diesis-diesis-diesis''', Mi-bemolle-bemolle-bemolle'', Re-bemolle'', Si-diesis-diesis''',Do-diesis-diesis'', Fa-bemolle-bemolle-bemolle'', Mi-bemolle-bemolle'', Si-diesis-diesis-diesis''',Do-diesis-diesis-diesis'', Fa-bemolle-bemolle'', Mi-bemolle'',Do-diesis-diesis-diesis-diesis'', Fa-bemolle'', Re-diesis-diesis'', Sol-bemolle-bemolle-bemolle'',Mi-diesis'', Re-diesis-diesis-diesis'', Sol-bemolle-bemolle'',La-bemolle-bemolle-bemolle'', Mi-diesis-diesis'', Re-diesis-diesis-diesis-diesis'', Sol-bemolle'',Fa-diesis-diesis'', La-bemolle-bemolle'', Mi-diesis-diesis-diesis'',Fa-diesis-diesis-diesis'', La-bemolle'', Si-bemolle-bemolle-bemolle'',Do-bemolle-bemolle-bemolle', Fa-diesis-diesis-diesis-diesis'', Si-bemolle-bemolle'', Sol-diesis-diesis'',Do-bemolle-bemolle', Si-bemolle'', Sol-diesis-diesis-diesis'',Do-bemolle', La-diesis-diesis'', Re-bemolle-bemolle-bemolle', Sol-diesis-diesis-diesis-diesis'',La-diesis-diesis-diesis'', Re-bemolle-bemolle', Si-diesis'',La-diesis-diesis-diesis-diesis'', Mi-bemolle-bemolle-bemolle', Re-bemolle', Si-diesis-diesis'',Do-diesis-diesis', Fa-bemolle-bemolle-bemolle', Mi-bemolle-bemolle', Si-diesis-diesis-diesis'',Do-diesis-diesis-diesis', Fa-bemolle-bemolle', Mi-bemolle',Do-diesis-diesis-diesis-diesis', Fa-bemolle', Re-diesis-diesis', Sol-bemolle-bemolle-bemolle',Mi-diesis', Re-diesis-diesis-diesis', Sol-bemolle-bemolle',La-bemolle-bemolle-bemolle', Mi-diesis-diesis', Re-diesis-diesis-diesis-diesis', Sol-bemolle',Fa-diesis-diesis', La-bemolle-bemolle', Mi-diesis-diesis-diesis',Fa-diesis-diesis-diesis', La-bemolle', Si-bemolle-bemolle-bemolle',Do-bemolle-bemolle-bemolle, Fa-diesis-diesis-diesis-diesis', Si-bemolle-bemolle', Sol-diesis-diesis',Do-bemolle-bemolle, Si-bemolle', Sol-diesis-diesis-diesis',Do-bemolle, La-diesis-diesis', Re-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-diesis',La-diesis-diesis-diesis', Re-bemolle-bemolle, Si-diesis',La-diesis-diesis-diesis-diesis', Mi-bemolle-bemolle-bemolle, Re-bemolle, Si-diesis-diesis',Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis',Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Mi-bemolle,Do-diesis-diesis-diesis-diesis, Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,La-bemolle-bemolle-bemolle, Mi-diesis-diesis, Re-diesis-diesis-diesis-diesis, Sol-bemolle,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis,Fa-diesis-diesis-diesis, La-bemolle, Si-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis-diesis, Si-bemolle-bemolle, Sol-diesis-diesis, do-bemolle-bemolle-bemolle,Si-bemolle, Sol-diesis-diesis-diesis, do-bemolle-bemolle,La-diesis-diesis, Sol-diesis-diesis-diesis-diesis, do-bemolle, re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis, Si-diesis, re-bemolle-bemolle,La-diesis-diesis-diesis-diesis, Si-diesis-diesis, mi-bemolle-bemolle-bemolle, re-bemolle,Si-diesis-diesis-diesis, do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle,do-diesis-diesis-diesis, fa-bemolle-bemolle, mi-bemolle,do-diesis-diesis-diesis-diesis, fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,la-bemolle-bemolle-bemolle, mi-diesis-diesis, re-diesis-diesis-diesis-diesis, sol-bemolle,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis,fa-diesis-diesis-diesis, la-bemolle, si-bemolle-bemolle-bemolle,do-bemolle-bemolle-bemolle', fa-diesis-diesis-diesis-diesis, si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle', si-bemolle, sol-diesis-diesis-diesis,do-bemolle', la-diesis-diesis, re-bemolle-bemolle-bemolle', sol-diesis-diesis-diesis-diesis,la-diesis-diesis-diesis, re-bemolle-bemolle', si-diesis,la-diesis-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle', re-bemolle', si-diesis-diesis,do-diesis-diesis', fa-bemolle-bemolle-bemolle', mi-bemolle-bemolle', si-diesis-diesis-diesis,do-diesis-diesis-diesis', fa-bemolle-bemolle', mi-bemolle',do-diesis-diesis-diesis-diesis', fa-bemolle', re-diesis-diesis', sol-bemolle-bemolle-bemolle',mi-diesis', re-diesis-diesis-diesis', sol-bemolle-bemolle',la-bemolle-bemolle-bemolle', mi-diesis-diesis', re-diesis-diesis-diesis-diesis', sol-bemolle',fa-diesis-diesis', la-bemolle-bemolle', mi-diesis-diesis-diesis',fa-diesis-diesis-diesis', la-bemolle', si-bemolle-bemolle-bemolle',do-bemolle-bemolle-bemolle'', fa-diesis-diesis-diesis-diesis', si-bemolle-bemolle', sol-diesis-diesis',do-bemolle-bemolle'', si-bemolle', sol-diesis-diesis-diesis',do-bemolle'', la-diesis-diesis', re-bemolle-bemolle-bemolle'', sol-diesis-diesis-diesis-diesis',la-diesis-diesis-diesis', re-bemolle-bemolle'', si-diesis',la-diesis-diesis-diesis-diesis', mi-bemolle-bemolle-bemolle'', re-bemolle'', si-diesis-diesis',do-diesis-diesis'', fa-bemolle-bemolle-bemolle'', mi-bemolle-bemolle'', si-diesis-diesis-diesis',do-diesis-diesis-diesis'', fa-bemolle-bemolle'', mi-bemolle'',do-diesis-diesis-diesis-diesis'', fa-bemolle'', re-diesis-diesis'', sol-bemolle-bemolle-bemolle'',mi-diesis'', re-diesis-diesis-diesis'', sol-bemolle-bemolle'',la-bemolle-bemolle-bemolle'', mi-diesis-diesis'', re-diesis-diesis-diesis-diesis'', sol-bemolle'',fa-diesis-diesis'', la-bemolle-bemolle'', mi-diesis-diesis-diesis'',fa-diesis-diesis-diesis'', la-bemolle'', si-bemolle-bemolle-bemolle'',do-bemolle-bemolle-bemolle''', fa-diesis-diesis-diesis-diesis'', si-bemolle-bemolle'', sol-diesis-diesis'',do-bemolle-bemolle''', si-bemolle'', sol-diesis-diesis-diesis'',do-bemolle''', la-diesis-diesis'', re-bemolle-bemolle-bemolle''', sol-diesis-diesis-diesis-diesis'',la-diesis-diesis-diesis'', re-bemolle-bemolle''', si-diesis'',la-diesis-diesis-diesis-diesis'', mi-bemolle-bemolle-bemolle''', re-bemolle''', si-diesis-diesis'',do-diesis-diesis''', fa-bemolle-bemolle-bemolle''', mi-bemolle-bemolle''', si-diesis-diesis-diesis'',do-diesis-diesis-diesis''', fa-bemolle-bemolle''', mi-bemolle''',do-diesis-diesis-diesis-diesis''', fa-bemolle''', re-diesis-diesis''', sol-bemolle-bemolle-bemolle''',mi-diesis''', re-diesis-diesis-diesis''', sol-bemolle-bemolle''',la-bemolle-bemolle-bemolle''', mi-diesis-diesis''', re-diesis-diesis-diesis-diesis''', sol-bemolle''',fa-diesis-diesis''', la-bemolle-bemolle''', mi-diesis-diesis-diesis''',fa-diesis-diesis-diesis''', la-bemolle''', si-bemolle-bemolle-bemolle''',do-bemolle-bemolle-bemolle'''', fa-diesis-diesis-diesis-diesis''', si-bemolle-bemolle''', sol-diesis-diesis''',do-bemolle-bemolle'''', si-bemolle''', sol-diesis-diesis-diesis''',do-bemolle'''', la-diesis-diesis''', re-bemolle-bemolle-bemolle'''', sol-diesis-diesis-diesis-diesis''',la-diesis-diesis-diesis''', re-bemolle-bemolle'''', si-diesis''',la-diesis-diesis-diesis-diesis''', mi-bemolle-bemolle-bemolle'''', re-bemolle'''', si-diesis-diesis''',do-diesis-diesis'''', fa-bemolle-bemolle-bemolle'''', mi-bemolle-bemolle'''', si-diesis-diesis-diesis''',do-diesis-diesis-diesis'''', fa-bemolle-bemolle'''', mi-bemolle'''',do-diesis-diesis-diesis-diesis'''', fa-bemolle'''', re-diesis-diesis'''', sol-bemolle-bemolle-bemolle'''',mi-diesis'''', re-diesis-diesis-diesis'''', sol-bemolle-bemolle'''',la-bemolle-bemolle-bemolle'''', mi-diesis-diesis'''', re-diesis-diesis-diesis-diesis'''', sol-bemolle'''',fa-diesis-diesis'''', la-bemolle-bemolle'''', mi-diesis-diesis-diesis'''',fa-diesis-diesis-diesis'''', la-bemolle'''', si-bemolle-bemolle-bemolle'''',do-bemolle-bemolle-bemolle''''', fa-diesis-diesis-diesis-diesis'''', si-bemolle-bemolle'''', sol-diesis-diesis'''',do-bemolle-bemolle''''', si-bemolle'''', sol-diesis-diesis-diesis'''',do-bemolle''''', la-diesis-diesis'''', re-bemolle-bemolle-bemolle''''', sol-diesis-diesis-diesis-diesis'''',la-diesis-diesis-diesis'''', re-bemolle-bemolle''''', si-diesis'''',la-diesis-diesis-diesis-diesis'''', mi-bemolle-bemolle-bemolle''''', re-bemolle''''', si-diesis-diesis'''',do-diesis-diesis''''', fa-bemolle-bemolle-bemolle''''', mi-bemolle-bemolle''''', si-diesis-diesis-diesis'''',do-diesis-diesis-diesis''''', fa-bemolle-bemolle''''', mi-bemolle''''',do-diesis-diesis-diesis-diesis''''', fa-bemolle''''', re-diesis-diesis''''', sol-bemolle-bemolle-bemolle''''',mi-diesis''''', re-diesis-diesis-diesis''''', sol-bemolle-bemolle''''',la-bemolle-bemolle-bemolle''''', mi-diesis-diesis''''', re-diesis-diesis-diesis-diesis''''', sol-bemolle''''',fa-diesis-diesis''''', la-bemolle-bemolle''''', mi-diesis-diesis-diesis''''',fa-diesis-diesis-diesis''''', la-bemolle''''', si-bemolle-bemolle-bemolle''''',do-bemolle-bemolle-bemolle'''''', fa-diesis-diesis-diesis-diesis''''', si-bemolle-bemolle''''', sol-diesis-diesis''''',do-bemolle-bemolle'''''', si-bemolle''''', sol-diesis-diesis-diesis''''',do-bemolle'''''', la-diesis-diesis''''', re-bemolle-bemolle-bemolle'''''', sol-diesis-diesis-diesis-diesis''''',la-diesis-diesis-diesis''''', re-bemolle-bemolle'''''', si-diesis''''',la-diesis-diesis-diesis-diesis''''', mi-bemolle-bemolle-bemolle'''''', re-bemolle'''''', si-diesis-diesis''''',do-diesis-diesis'''''', fa-bemolle-bemolle-bemolle'''''', mi-bemolle-bemolle'''''', si-diesis-diesis-diesis''''',do-diesis-diesis-diesis'''''', fa-bemolle-bemolle'''''', mi-bemolle'''''',do-diesis-diesis-diesis-diesis'''''', fa-bemolle'''''', re-diesis-diesis'''''', sol-bemolle-bemolle-bemolle'''''',mi-diesis'''''', re-diesis-diesis-diesis'''''', sol-bemolle-bemolle'''''',la-bemolle-bemolle-bemolle'''''', mi-diesis-diesis'''''', re-diesis-diesis-diesis-diesis'''''', sol-bemolle'''''',fa-diesis-diesis'''''', la-bemolle-bemolle'''''', mi-diesis-diesis-diesis''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "La-diesis-diesis-diesis-6, Mi-bemolle-bemolle-bemolle-bemolle-5, Re-bemolle-bemolle-5, Si-diesis-6,Do-diesis-5, Mi-bemolle-bemolle-bemolle-5, Si-diesis-diesis-6,Do-diesis-diesis-5, Fa-bemolle-bemolle-bemolle-5, Mi-bemolle-bemolle-5, Si-diesis-diesis-diesis-6,Do-diesis-diesis-diesis-5, Fa-bemolle-bemolle-5, Re-diesis-5, Sol-bemolle-bemolle-bemolle-bemolle-5,Fa-bemolle-5, Re-diesis-diesis-5, Sol-bemolle-bemolle-bemolle-5,La-bemolle-bemolle-bemolle-bemolle-5, Mi-diesis-5, Re-diesis-diesis-diesis-5, Sol-bemolle-bemolle-5,Fa-diesis-5, La-bemolle-bemolle-bemolle-5, Mi-diesis-diesis-5,Fa-diesis-diesis-5, La-bemolle-bemolle-5, Mi-diesis-diesis-diesis-5, Si-bemolle-bemolle-bemolle-bemolle-5,Fa-diesis-diesis-diesis-5, Si-bemolle-bemolle-bemolle-5, Sol-diesis-5,Do-bemolle-bemolle-bemolle-4, Si-bemolle-bemolle-5, Sol-diesis-diesis-5,Do-bemolle-bemolle-4, La-diesis-5, Re-bemolle-bemolle-bemolle-bemolle-4, Sol-diesis-diesis-diesis-5,Do-bemolle-4, La-diesis-diesis-5, Re-bemolle-bemolle-bemolle-4,La-diesis-diesis-diesis-5, Mi-bemolle-bemolle-bemolle-bemolle-4, Re-bemolle-bemolle-4, Si-diesis-5,Do-diesis-4, Mi-bemolle-bemolle-bemolle-4, Si-diesis-diesis-5,Do-diesis-diesis-4, Fa-bemolle-bemolle-bemolle-4, Mi-bemolle-bemolle-4, Si-diesis-diesis-diesis-5,Do-diesis-diesis-diesis-4, Fa-bemolle-bemolle-4, Re-diesis-4, Sol-bemolle-bemolle-bemolle-bemolle-4,Fa-bemolle-4, Re-diesis-diesis-4, Sol-bemolle-bemolle-bemolle-4,La-bemolle-bemolle-bemolle-bemolle-4, Mi-diesis-4, Re-diesis-diesis-diesis-4, Sol-bemolle-bemolle-4,Fa-diesis-4, La-bemolle-bemolle-bemolle-4, Mi-diesis-diesis-4,Fa-diesis-diesis-4, La-bemolle-bemolle-4, Mi-diesis-diesis-diesis-4, Si-bemolle-bemolle-bemolle-bemolle-4,Fa-diesis-diesis-diesis-4, Si-bemolle-bemolle-bemolle-4, Sol-diesis-4,Do-bemolle-bemolle-bemolle-3, Si-bemolle-bemolle-4, Sol-diesis-diesis-4,Do-bemolle-bemolle-3, La-diesis-4, Re-bemolle-bemolle-bemolle-bemolle-3, Sol-diesis-diesis-diesis-4,Do-bemolle-3, La-diesis-diesis-4, Re-bemolle-bemolle-bemolle-3,La-diesis-diesis-diesis-4, Mi-bemolle-bemolle-bemolle-bemolle-3, Re-bemolle-bemolle-3, Si-diesis-4,Do-diesis-3, Mi-bemolle-bemolle-bemolle-3, Si-diesis-diesis-4,Do-diesis-diesis-3, Fa-bemolle-bemolle-bemolle-3, Mi-bemolle-bemolle-3, Si-diesis-diesis-diesis-4,Do-diesis-diesis-diesis-3, Fa-bemolle-bemolle-3, Re-diesis-3, Sol-bemolle-bemolle-bemolle-bemolle-3,Fa-bemolle-3, Re-diesis-diesis-3, Sol-bemolle-bemolle-bemolle-3,La-bemolle-bemolle-bemolle-bemolle-3, Mi-diesis-3, Re-diesis-diesis-diesis-3, Sol-bemolle-bemolle-3,Fa-diesis-3, La-bemolle-bemolle-bemolle-3, Mi-diesis-diesis-3,Fa-diesis-diesis-3, La-bemolle-bemolle-3, Mi-diesis-diesis-diesis-3, Si-bemolle-bemolle-bemolle-bemolle-3,Fa-diesis-diesis-diesis-3, Si-bemolle-bemolle-bemolle-3, Sol-diesis-3,Do-bemolle-bemolle-bemolle-2, Si-bemolle-bemolle-3, Sol-diesis-diesis-3,Do-bemolle-bemolle-2, La-diesis-3, Re-bemolle-bemolle-bemolle-bemolle-2, Sol-diesis-diesis-diesis-3,Do-bemolle-2, La-diesis-diesis-3, Re-bemolle-bemolle-bemolle-2,La-diesis-diesis-diesis-3, Mi-bemolle-bemolle-bemolle-bemolle-2, Re-bemolle-bemolle-2, Si-diesis-3,Do-diesis-2, Mi-bemolle-bemolle-bemolle-2, Si-diesis-diesis-3,Do-diesis-diesis-2, Fa-bemolle-bemolle-bemolle-2, Mi-bemolle-bemolle-2, Si-diesis-diesis-diesis-3,Do-diesis-diesis-diesis-2, Fa-bemolle-bemolle-2, Re-diesis-2, Sol-bemolle-bemolle-bemolle-bemolle-2,Fa-bemolle-2, Re-diesis-diesis-2, Sol-bemolle-bemolle-bemolle-2,La-bemolle-bemolle-bemolle-bemolle-2, Mi-diesis-2, Re-diesis-diesis-diesis-2, Sol-bemolle-bemolle-2,Fa-diesis-2, La-bemolle-bemolle-bemolle-2, Mi-diesis-diesis-2,Fa-diesis-diesis-2, La-bemolle-bemolle-2, Mi-diesis-diesis-diesis-2, Si-bemolle-bemolle-bemolle-bemolle-2,Fa-diesis-diesis-diesis-2, Si-bemolle-bemolle-bemolle-2, Sol-diesis-2,Do-bemolle-bemolle-bemolle-, Si-bemolle-bemolle-2, Sol-diesis-diesis-2,Do-bemolle-bemolle-, La-diesis-2, Re-bemolle-bemolle-bemolle-bemolle-, Sol-diesis-diesis-diesis-2,Do-bemolle-, La-diesis-diesis-2, Re-bemolle-bemolle-bemolle-,La-diesis-diesis-diesis-2, Mi-bemolle-bemolle-bemolle-bemolle-, Re-bemolle-bemolle-, Si-diesis-2,Do-diesis-, Mi-bemolle-bemolle-bemolle-, Si-diesis-diesis-2,Do-diesis-diesis-, Fa-bemolle-bemolle-bemolle-, Mi-bemolle-bemolle-, Si-diesis-diesis-diesis-2,Do-diesis-diesis-diesis-, Fa-bemolle-bemolle-, Re-diesis-, Sol-bemolle-bemolle-bemolle-bemolle-,Fa-bemolle-, Re-diesis-diesis-, Sol-bemolle-bemolle-bemolle-,La-bemolle-bemolle-bemolle-bemolle-, Mi-diesis-, Re-diesis-diesis-diesis-, Sol-bemolle-bemolle-,Fa-diesis-, La-bemolle-bemolle-bemolle-, Mi-diesis-diesis-,Fa-diesis-diesis-, La-bemolle-bemolle-, Mi-diesis-diesis-diesis-, Si-bemolle-bemolle-bemolle-bemolle-,Fa-diesis-diesis-diesis-, Si-bemolle-bemolle-bemolle-, Sol-diesis-,Do-bemolle-bemolle-bemolle, Si-bemolle-bemolle-, Sol-diesis-diesis-,Do-bemolle-bemolle, La-diesis-, Re-bemolle-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-,Do-bemolle, La-diesis-diesis-, Re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis-, Mi-bemolle-bemolle-bemolle-bemolle, Re-bemolle-bemolle, Si-diesis-,Do-diesis, Mi-bemolle-bemolle-bemolle, Si-diesis-diesis-,Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis-,Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Re-diesis, Sol-bemolle-bemolle-bemolle-bemolle,Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,La-bemolle-bemolle-bemolle-bemolle, Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,Fa-diesis, La-bemolle-bemolle-bemolle, Mi-diesis-diesis,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle, Sol-diesis,Do-bemolle-bemolle-bemolle+, Si-bemolle-bemolle, Sol-diesis-diesis,Do-bemolle-bemolle+, La-diesis, Re-bemolle-bemolle-bemolle-bemolle+, Sol-diesis-diesis-diesis,Do-bemolle+, La-diesis-diesis, Re-bemolle-bemolle-bemolle+,La-diesis-diesis-diesis, Mi-bemolle-bemolle-bemolle-bemolle+, Re-bemolle-bemolle+, Si-diesis,Do-diesis+, Mi-bemolle-bemolle-bemolle+, Si-diesis-diesis,Do-diesis-diesis+, Fa-bemolle-bemolle-bemolle+, Mi-bemolle-bemolle+, Si-diesis-diesis-diesis,Do-diesis-diesis-diesis+, Fa-bemolle-bemolle+, Re-diesis+, Sol-bemolle-bemolle-bemolle-bemolle+,Fa-bemolle+, Re-diesis-diesis+, Sol-bemolle-bemolle-bemolle+,La-bemolle-bemolle-bemolle-bemolle+, Mi-diesis+, Re-diesis-diesis-diesis+, Sol-bemolle-bemolle+,Fa-diesis+, La-bemolle-bemolle-bemolle+, Mi-diesis-diesis+,Fa-diesis-diesis+, La-bemolle-bemolle+, Mi-diesis-diesis-diesis+, Si-bemolle-bemolle-bemolle-bemolle+,Fa-diesis-diesis-diesis+, Si-bemolle-bemolle-bemolle+, Sol-diesis+,Do-bemolle-bemolle-bemolle+2, Si-bemolle-bemolle+, Sol-diesis-diesis+,Do-bemolle-bemolle+2, La-diesis+, Re-bemolle-bemolle-bemolle-bemolle+2, Sol-diesis-diesis-diesis+,Do-bemolle+2, La-diesis-diesis+, Re-bemolle-bemolle-bemolle+2,La-diesis-diesis-diesis+, Mi-bemolle-bemolle-bemolle-bemolle+2, Re-bemolle-bemolle+2, Si-diesis+,Do-diesis+2, Mi-bemolle-bemolle-bemolle+2, Si-diesis-diesis+,Do-diesis-diesis+2, Fa-bemolle-bemolle-bemolle+2, Mi-bemolle-bemolle+2, Si-diesis-diesis-diesis+,Do-diesis-diesis-diesis+2, Fa-bemolle-bemolle+2, Re-diesis+2, Sol-bemolle-bemolle-bemolle-bemolle+2,Fa-bemolle+2, Re-diesis-diesis+2, Sol-bemolle-bemolle-bemolle+2,La-bemolle-bemolle-bemolle-bemolle+2, Mi-diesis+2, Re-diesis-diesis-diesis+2, Sol-bemolle-bemolle+2,Fa-diesis+2, La-bemolle-bemolle-bemolle+2, Mi-diesis-diesis+2,Fa-diesis-diesis+2, La-bemolle-bemolle+2, Mi-diesis-diesis-diesis+2, Si-bemolle-bemolle-bemolle-bemolle+2,Fa-diesis-diesis-diesis+2, Si-bemolle-bemolle-bemolle+2, Sol-diesis+2,Do-bemolle-bemolle-bemolle+3, Si-bemolle-bemolle+2, Sol-diesis-diesis+2,Do-bemolle-bemolle+3, La-diesis+2, Re-bemolle-bemolle-bemolle-bemolle+3, Sol-diesis-diesis-diesis+2,Do-bemolle+3, La-diesis-diesis+2, Re-bemolle-bemolle-bemolle+3,La-diesis-diesis-diesis+2, Mi-bemolle-bemolle-bemolle-bemolle+3, Re-bemolle-bemolle+3, Si-diesis+2,Do-diesis+3, Mi-bemolle-bemolle-bemolle+3, Si-diesis-diesis+2,Do-diesis-diesis+3, Fa-bemolle-bemolle-bemolle+3, Mi-bemolle-bemolle+3, Si-diesis-diesis-diesis+2,Do-diesis-diesis-diesis+3, Fa-bemolle-bemolle+3, Re-diesis+3, Sol-bemolle-bemolle-bemolle-bemolle+3,Fa-bemolle+3, Re-diesis-diesis+3, Sol-bemolle-bemolle-bemolle+3,La-bemolle-bemolle-bemolle-bemolle+3, Mi-diesis+3, Re-diesis-diesis-diesis+3, Sol-bemolle-bemolle+3,Fa-diesis+3, La-bemolle-bemolle-bemolle+3, Mi-diesis-diesis+3,Fa-diesis-diesis+3, La-bemolle-bemolle+3, Mi-diesis-diesis-diesis+3, Si-bemolle-bemolle-bemolle-bemolle+3,Fa-diesis-diesis-diesis+3, Si-bemolle-bemolle-bemolle+3, Sol-diesis+3,Do-bemolle-bemolle-bemolle+4, Si-bemolle-bemolle+3, Sol-diesis-diesis+3,Do-bemolle-bemolle+4, La-diesis+3, Re-bemolle-bemolle-bemolle-bemolle+4, Sol-diesis-diesis-diesis+3,Do-bemolle+4, La-diesis-diesis+3, Re-bemolle-bemolle-bemolle+4,La-diesis-diesis-diesis+3, Mi-bemolle-bemolle-bemolle-bemolle+4, Re-bemolle-bemolle+4, Si-diesis+3,Do-diesis+4, Mi-bemolle-bemolle-bemolle+4, Si-diesis-diesis+3,Do-diesis-diesis+4, Fa-bemolle-bemolle-bemolle+4, Mi-bemolle-bemolle+4, Si-diesis-diesis-diesis+3,Do-diesis-diesis-diesis+4, Fa-bemolle-bemolle+4, Re-diesis+4, Sol-bemolle-bemolle-bemolle-bemolle+4,Fa-bemolle+4, Re-diesis-diesis+4, Sol-bemolle-bemolle-bemolle+4,La-bemolle-bemolle-bemolle-bemolle+4, Mi-diesis+4, Re-diesis-diesis-diesis+4, Sol-bemolle-bemolle+4,Fa-diesis+4, La-bemolle-bemolle-bemolle+4, Mi-diesis-diesis+4,Fa-diesis-diesis+4, La-bemolle-bemolle+4, Mi-diesis-diesis-diesis+4, Si-bemolle-bemolle-bemolle-bemolle+4,Fa-diesis-diesis-diesis+4, Si-bemolle-bemolle-bemolle+4, Sol-diesis+4,Do-bemolle-bemolle-bemolle+5, Si-bemolle-bemolle+4, Sol-diesis-diesis+4,Do-bemolle-bemolle+5, La-diesis+4, Re-bemolle-bemolle-bemolle-bemolle+5, Sol-diesis-diesis-diesis+4,Do-bemolle+5, La-diesis-diesis+4, Re-bemolle-bemolle-bemolle+5,La-diesis-diesis-diesis+4, Mi-bemolle-bemolle-bemolle-bemolle+5, Re-bemolle-bemolle+5, Si-diesis+4,Do-diesis+5, Mi-bemolle-bemolle-bemolle+5, Si-diesis-diesis+4,Do-diesis-diesis+5, Fa-bemolle-bemolle-bemolle+5, Mi-bemolle-bemolle+5, Si-diesis-diesis-diesis+4,Do-diesis-diesis-diesis+5, Fa-bemolle-bemolle+5, Re-diesis+5, Sol-bemolle-bemolle-bemolle-bemolle+5,Fa-bemolle+5, Re-diesis-diesis+5, Sol-bemolle-bemolle-bemolle+5,La-bemolle-bemolle-bemolle-bemolle+5, Mi-diesis+5, Re-diesis-diesis-diesis+5, Sol-bemolle-bemolle+5,Fa-diesis+5, La-bemolle-bemolle-bemolle+5, Mi-diesis-diesis+5,Fa-diesis-diesis+5, La-bemolle-bemolle+5, Mi-diesis-diesis-diesis+5, Si-bemolle-bemolle-bemolle-bemolle+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "La-diesis-diesis-diesis------, Mi-bemolle-bemolle-bemolle-bemolle-----, Re-bemolle-bemolle-----, Si-diesis------,Do-diesis-----, Mi-bemolle-bemolle-bemolle-----, Si-diesis-diesis------,Do-diesis-diesis-----, Fa-bemolle-bemolle-bemolle-----, Mi-bemolle-bemolle-----, Si-diesis-diesis-diesis------,Do-diesis-diesis-diesis-----, Fa-bemolle-bemolle-----, Re-diesis-----, Sol-bemolle-bemolle-bemolle-bemolle-----,Fa-bemolle-----, Re-diesis-diesis-----, Sol-bemolle-bemolle-bemolle-----,La-bemolle-bemolle-bemolle-bemolle-----, Mi-diesis-----, Re-diesis-diesis-diesis-----, Sol-bemolle-bemolle-----,Fa-diesis-----, La-bemolle-bemolle-bemolle-----, Mi-diesis-diesis-----,Fa-diesis-diesis-----, La-bemolle-bemolle-----, Mi-diesis-diesis-diesis-----, Si-bemolle-bemolle-bemolle-bemolle-----,Fa-diesis-diesis-diesis-----, Si-bemolle-bemolle-bemolle-----, Sol-diesis-----,Do-bemolle-bemolle-bemolle----, Si-bemolle-bemolle-----, Sol-diesis-diesis-----,Do-bemolle-bemolle----, La-diesis-----, Re-bemolle-bemolle-bemolle-bemolle----, Sol-diesis-diesis-diesis-----,Do-bemolle----, La-diesis-diesis-----, Re-bemolle-bemolle-bemolle----,La-diesis-diesis-diesis-----, Mi-bemolle-bemolle-bemolle-bemolle----, Re-bemolle-bemolle----, Si-diesis-----,Do-diesis----, Mi-bemolle-bemolle-bemolle----, Si-diesis-diesis-----,Do-diesis-diesis----, Fa-bemolle-bemolle-bemolle----, Mi-bemolle-bemolle----, Si-diesis-diesis-diesis-----,Do-diesis-diesis-diesis----, Fa-bemolle-bemolle----, Re-diesis----, Sol-bemolle-bemolle-bemolle-bemolle----,Fa-bemolle----, Re-diesis-diesis----, Sol-bemolle-bemolle-bemolle----,La-bemolle-bemolle-bemolle-bemolle----, Mi-diesis----, Re-diesis-diesis-diesis----, Sol-bemolle-bemolle----,Fa-diesis----, La-bemolle-bemolle-bemolle----, Mi-diesis-diesis----,Fa-diesis-diesis----, La-bemolle-bemolle----, Mi-diesis-diesis-diesis----, Si-bemolle-bemolle-bemolle-bemolle----,Fa-diesis-diesis-diesis----, Si-bemolle-bemolle-bemolle----, Sol-diesis----,Do-bemolle-bemolle-bemolle---, Si-bemolle-bemolle----, Sol-diesis-diesis----,Do-bemolle-bemolle---, La-diesis----, Re-bemolle-bemolle-bemolle-bemolle---, Sol-diesis-diesis-diesis----,Do-bemolle---, La-diesis-diesis----, Re-bemolle-bemolle-bemolle---,La-diesis-diesis-diesis----, Mi-bemolle-bemolle-bemolle-bemolle---, Re-bemolle-bemolle---, Si-diesis----,Do-diesis---, Mi-bemolle-bemolle-bemolle---, Si-diesis-diesis----,Do-diesis-diesis---, Fa-bemolle-bemolle-bemolle---, Mi-bemolle-bemolle---, Si-diesis-diesis-diesis----,Do-diesis-diesis-diesis---, Fa-bemolle-bemolle---, Re-diesis---, Sol-bemolle-bemolle-bemolle-bemolle---,Fa-bemolle---, Re-diesis-diesis---, Sol-bemolle-bemolle-bemolle---,La-bemolle-bemolle-bemolle-bemolle---, Mi-diesis---, Re-diesis-diesis-diesis---, Sol-bemolle-bemolle---,Fa-diesis---, La-bemolle-bemolle-bemolle---, Mi-diesis-diesis---,Fa-diesis-diesis---, La-bemolle-bemolle---, Mi-diesis-diesis-diesis---, Si-bemolle-bemolle-bemolle-bemolle---,Fa-diesis-diesis-diesis---, Si-bemolle-bemolle-bemolle---, Sol-diesis---,Do-bemolle-bemolle-bemolle--, Si-bemolle-bemolle---, Sol-diesis-diesis---,Do-bemolle-bemolle--, La-diesis---, Re-bemolle-bemolle-bemolle-bemolle--, Sol-diesis-diesis-diesis---,Do-bemolle--, La-diesis-diesis---, Re-bemolle-bemolle-bemolle--,La-diesis-diesis-diesis---, Mi-bemolle-bemolle-bemolle-bemolle--, Re-bemolle-bemolle--, Si-diesis---,Do-diesis--, Mi-bemolle-bemolle-bemolle--, Si-diesis-diesis---,Do-diesis-diesis--, Fa-bemolle-bemolle-bemolle--, Mi-bemolle-bemolle--, Si-diesis-diesis-diesis---,Do-diesis-diesis-diesis--, Fa-bemolle-bemolle--, Re-diesis--, Sol-bemolle-bemolle-bemolle-bemolle--,Fa-bemolle--, Re-diesis-diesis--, Sol-bemolle-bemolle-bemolle--,La-bemolle-bemolle-bemolle-bemolle--, Mi-diesis--, Re-diesis-diesis-diesis--, Sol-bemolle-bemolle--,Fa-diesis--, La-bemolle-bemolle-bemolle--, Mi-diesis-diesis--,Fa-diesis-diesis--, La-bemolle-bemolle--, Mi-diesis-diesis-diesis--, Si-bemolle-bemolle-bemolle-bemolle--,Fa-diesis-diesis-diesis--, Si-bemolle-bemolle-bemolle--, Sol-diesis--,Do-bemolle-bemolle-bemolle-, Si-bemolle-bemolle--, Sol-diesis-diesis--,Do-bemolle-bemolle-, La-diesis--, Re-bemolle-bemolle-bemolle-bemolle-, Sol-diesis-diesis-diesis--,Do-bemolle-, La-diesis-diesis--, Re-bemolle-bemolle-bemolle-,La-diesis-diesis-diesis--, Mi-bemolle-bemolle-bemolle-bemolle-, Re-bemolle-bemolle-, Si-diesis--,Do-diesis-, Mi-bemolle-bemolle-bemolle-, Si-diesis-diesis--,Do-diesis-diesis-, Fa-bemolle-bemolle-bemolle-, Mi-bemolle-bemolle-, Si-diesis-diesis-diesis--,Do-diesis-diesis-diesis-, Fa-bemolle-bemolle-, Re-diesis-, Sol-bemolle-bemolle-bemolle-bemolle-,Fa-bemolle-, Re-diesis-diesis-, Sol-bemolle-bemolle-bemolle-,La-bemolle-bemolle-bemolle-bemolle-, Mi-diesis-, Re-diesis-diesis-diesis-, Sol-bemolle-bemolle-,Fa-diesis-, La-bemolle-bemolle-bemolle-, Mi-diesis-diesis-,Fa-diesis-diesis-, La-bemolle-bemolle-, Mi-diesis-diesis-diesis-, Si-bemolle-bemolle-bemolle-bemolle-,Fa-diesis-diesis-diesis-, Si-bemolle-bemolle-bemolle-, Sol-diesis-,Do-bemolle-bemolle-bemolle, Si-bemolle-bemolle-, Sol-diesis-diesis-,Do-bemolle-bemolle, La-diesis-, Re-bemolle-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis-,Do-bemolle, La-diesis-diesis-, Re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis-, Mi-bemolle-bemolle-bemolle-bemolle, Re-bemolle-bemolle, Si-diesis-,Do-diesis, Mi-bemolle-bemolle-bemolle, Si-diesis-diesis-,Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis-,Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Re-diesis, Sol-bemolle-bemolle-bemolle-bemolle,Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,La-bemolle-bemolle-bemolle-bemolle, Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,Fa-diesis, La-bemolle-bemolle-bemolle, Mi-diesis-diesis,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle, Sol-diesis,Do-bemolle-bemolle-bemolle+, Si-bemolle-bemolle, Sol-diesis-diesis,Do-bemolle-bemolle+, La-diesis, Re-bemolle-bemolle-bemolle-bemolle+, Sol-diesis-diesis-diesis,Do-bemolle+, La-diesis-diesis, Re-bemolle-bemolle-bemolle+,La-diesis-diesis-diesis, Mi-bemolle-bemolle-bemolle-bemolle+, Re-bemolle-bemolle+, Si-diesis,Do-diesis+, Mi-bemolle-bemolle-bemolle+, Si-diesis-diesis,Do-diesis-diesis+, Fa-bemolle-bemolle-bemolle+, Mi-bemolle-bemolle+, Si-diesis-diesis-diesis,Do-diesis-diesis-diesis+, Fa-bemolle-bemolle+, Re-diesis+, Sol-bemolle-bemolle-bemolle-bemolle+,Fa-bemolle+, Re-diesis-diesis+, Sol-bemolle-bemolle-bemolle+,La-bemolle-bemolle-bemolle-bemolle+, Mi-diesis+, Re-diesis-diesis-diesis+, Sol-bemolle-bemolle+,Fa-diesis+, La-bemolle-bemolle-bemolle+, Mi-diesis-diesis+,Fa-diesis-diesis+, La-bemolle-bemolle+, Mi-diesis-diesis-diesis+, Si-bemolle-bemolle-bemolle-bemolle+,Fa-diesis-diesis-diesis+, Si-bemolle-bemolle-bemolle+, Sol-diesis+,Do-bemolle-bemolle-bemolle++, Si-bemolle-bemolle+, Sol-diesis-diesis+,Do-bemolle-bemolle++, La-diesis+, Re-bemolle-bemolle-bemolle-bemolle++, Sol-diesis-diesis-diesis+,Do-bemolle++, La-diesis-diesis+, Re-bemolle-bemolle-bemolle++,La-diesis-diesis-diesis+, Mi-bemolle-bemolle-bemolle-bemolle++, Re-bemolle-bemolle++, Si-diesis+,Do-diesis++, Mi-bemolle-bemolle-bemolle++, Si-diesis-diesis+,Do-diesis-diesis++, Fa-bemolle-bemolle-bemolle++, Mi-bemolle-bemolle++, Si-diesis-diesis-diesis+,Do-diesis-diesis-diesis++, Fa-bemolle-bemolle++, Re-diesis++, Sol-bemolle-bemolle-bemolle-bemolle++,Fa-bemolle++, Re-diesis-diesis++, Sol-bemolle-bemolle-bemolle++,La-bemolle-bemolle-bemolle-bemolle++, Mi-diesis++, Re-diesis-diesis-diesis++, Sol-bemolle-bemolle++,Fa-diesis++, La-bemolle-bemolle-bemolle++, Mi-diesis-diesis++,Fa-diesis-diesis++, La-bemolle-bemolle++, Mi-diesis-diesis-diesis++, Si-bemolle-bemolle-bemolle-bemolle++,Fa-diesis-diesis-diesis++, Si-bemolle-bemolle-bemolle++, Sol-diesis++,Do-bemolle-bemolle-bemolle+++, Si-bemolle-bemolle++, Sol-diesis-diesis++,Do-bemolle-bemolle+++, La-diesis++, Re-bemolle-bemolle-bemolle-bemolle+++, Sol-diesis-diesis-diesis++,Do-bemolle+++, La-diesis-diesis++, Re-bemolle-bemolle-bemolle+++,La-diesis-diesis-diesis++, Mi-bemolle-bemolle-bemolle-bemolle+++, Re-bemolle-bemolle+++, Si-diesis++,Do-diesis+++, Mi-bemolle-bemolle-bemolle+++, Si-diesis-diesis++,Do-diesis-diesis+++, Fa-bemolle-bemolle-bemolle+++, Mi-bemolle-bemolle+++, Si-diesis-diesis-diesis++,Do-diesis-diesis-diesis+++, Fa-bemolle-bemolle+++, Re-diesis+++, Sol-bemolle-bemolle-bemolle-bemolle+++,Fa-bemolle+++, Re-diesis-diesis+++, Sol-bemolle-bemolle-bemolle+++,La-bemolle-bemolle-bemolle-bemolle+++, Mi-diesis+++, Re-diesis-diesis-diesis+++, Sol-bemolle-bemolle+++,Fa-diesis+++, La-bemolle-bemolle-bemolle+++, Mi-diesis-diesis+++,Fa-diesis-diesis+++, La-bemolle-bemolle+++, Mi-diesis-diesis-diesis+++, Si-bemolle-bemolle-bemolle-bemolle+++,Fa-diesis-diesis-diesis+++, Si-bemolle-bemolle-bemolle+++, Sol-diesis+++,Do-bemolle-bemolle-bemolle++++, Si-bemolle-bemolle+++, Sol-diesis-diesis+++,Do-bemolle-bemolle++++, La-diesis+++, Re-bemolle-bemolle-bemolle-bemolle++++, Sol-diesis-diesis-diesis+++,Do-bemolle++++, La-diesis-diesis+++, Re-bemolle-bemolle-bemolle++++,La-diesis-diesis-diesis+++, Mi-bemolle-bemolle-bemolle-bemolle++++, Re-bemolle-bemolle++++, Si-diesis+++,Do-diesis++++, Mi-bemolle-bemolle-bemolle++++, Si-diesis-diesis+++,Do-diesis-diesis++++, Fa-bemolle-bemolle-bemolle++++, Mi-bemolle-bemolle++++, Si-diesis-diesis-diesis+++,Do-diesis-diesis-diesis++++, Fa-bemolle-bemolle++++, Re-diesis++++, Sol-bemolle-bemolle-bemolle-bemolle++++,Fa-bemolle++++, Re-diesis-diesis++++, Sol-bemolle-bemolle-bemolle++++,La-bemolle-bemolle-bemolle-bemolle++++, Mi-diesis++++, Re-diesis-diesis-diesis++++, Sol-bemolle-bemolle++++,Fa-diesis++++, La-bemolle-bemolle-bemolle++++, Mi-diesis-diesis++++,Fa-diesis-diesis++++, La-bemolle-bemolle++++, Mi-diesis-diesis-diesis++++, Si-bemolle-bemolle-bemolle-bemolle++++,Fa-diesis-diesis-diesis++++, Si-bemolle-bemolle-bemolle++++, Sol-diesis++++,Do-bemolle-bemolle-bemolle+++++, Si-bemolle-bemolle++++, Sol-diesis-diesis++++,Do-bemolle-bemolle+++++, La-diesis++++, Re-bemolle-bemolle-bemolle-bemolle+++++, Sol-diesis-diesis-diesis++++,Do-bemolle+++++, La-diesis-diesis++++, Re-bemolle-bemolle-bemolle+++++,La-diesis-diesis-diesis++++, Mi-bemolle-bemolle-bemolle-bemolle+++++, Re-bemolle-bemolle+++++, Si-diesis++++,Do-diesis+++++, Mi-bemolle-bemolle-bemolle+++++, Si-diesis-diesis++++,Do-diesis-diesis+++++, Fa-bemolle-bemolle-bemolle+++++, Mi-bemolle-bemolle+++++, Si-diesis-diesis-diesis++++,Do-diesis-diesis-diesis+++++, Fa-bemolle-bemolle+++++, Re-diesis+++++, Sol-bemolle-bemolle-bemolle-bemolle+++++,Fa-bemolle+++++, Re-diesis-diesis+++++, Sol-bemolle-bemolle-bemolle+++++,La-bemolle-bemolle-bemolle-bemolle+++++, Mi-diesis+++++, Re-diesis-diesis-diesis+++++, Sol-bemolle-bemolle+++++,Fa-diesis+++++, La-bemolle-bemolle-bemolle+++++, Mi-diesis-diesis+++++,Fa-diesis-diesis+++++, La-bemolle-bemolle+++++, Mi-diesis-diesis-diesis+++++, Si-bemolle-bemolle-bemolle-bemolle+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "La-diesis-diesis-diesis-2, Mi-bemolle-bemolle-bemolle-bemolle-1, Re-bemolle-bemolle-1, Si-diesis-2,Do-diesis-1, Mi-bemolle-bemolle-bemolle-1, Si-diesis-diesis-2,Do-diesis-diesis-1, Fa-bemolle-bemolle-bemolle-1, Mi-bemolle-bemolle-1, Si-diesis-diesis-diesis-2,Do-diesis-diesis-diesis-1, Fa-bemolle-bemolle-1, Re-diesis-1, Sol-bemolle-bemolle-bemolle-bemolle-1,Fa-bemolle-1, Re-diesis-diesis-1, Sol-bemolle-bemolle-bemolle-1,La-bemolle-bemolle-bemolle-bemolle-1, Mi-diesis-1, Re-diesis-diesis-diesis-1, Sol-bemolle-bemolle-1,Fa-diesis-1, La-bemolle-bemolle-bemolle-1, Mi-diesis-diesis-1,Fa-diesis-diesis-1, La-bemolle-bemolle-1, Mi-diesis-diesis-diesis-1, Si-bemolle-bemolle-bemolle-bemolle-1,Fa-diesis-diesis-diesis-1, Si-bemolle-bemolle-bemolle-1, Sol-diesis-1,Do-bemolle-bemolle-bemolle0, Si-bemolle-bemolle-1, Sol-diesis-diesis-1,Do-bemolle-bemolle0, La-diesis-1, Re-bemolle-bemolle-bemolle-bemolle0, Sol-diesis-diesis-diesis-1,Do-bemolle0, La-diesis-diesis-1, Re-bemolle-bemolle-bemolle0,La-diesis-diesis-diesis-1, Mi-bemolle-bemolle-bemolle-bemolle0, Re-bemolle-bemolle0, Si-diesis-1,Do-diesis0, Mi-bemolle-bemolle-bemolle0, Si-diesis-diesis-1,Do-diesis-diesis0, Fa-bemolle-bemolle-bemolle0, Mi-bemolle-bemolle0, Si-diesis-diesis-diesis-1,Do-diesis-diesis-diesis0, Fa-bemolle-bemolle0, Re-diesis0, Sol-bemolle-bemolle-bemolle-bemolle0,Fa-bemolle0, Re-diesis-diesis0, Sol-bemolle-bemolle-bemolle0,La-bemolle-bemolle-bemolle-bemolle0, Mi-diesis0, Re-diesis-diesis-diesis0, Sol-bemolle-bemolle0,Fa-diesis0, La-bemolle-bemolle-bemolle0, Mi-diesis-diesis0,Fa-diesis-diesis0, La-bemolle-bemolle0, Mi-diesis-diesis-diesis0, Si-bemolle-bemolle-bemolle-bemolle0,Fa-diesis-diesis-diesis0, Si-bemolle-bemolle-bemolle0, Sol-diesis0,Do-bemolle-bemolle-bemolle1, Si-bemolle-bemolle0, Sol-diesis-diesis0,Do-bemolle-bemolle1, La-diesis0, Re-bemolle-bemolle-bemolle-bemolle1, Sol-diesis-diesis-diesis0,Do-bemolle1, La-diesis-diesis0, Re-bemolle-bemolle-bemolle1,La-diesis-diesis-diesis0, Mi-bemolle-bemolle-bemolle-bemolle1, Re-bemolle-bemolle1, Si-diesis0,Do-diesis1, Mi-bemolle-bemolle-bemolle1, Si-diesis-diesis0,Do-diesis-diesis1, Fa-bemolle-bemolle-bemolle1, Mi-bemolle-bemolle1, Si-diesis-diesis-diesis0,Do-diesis-diesis-diesis1, Fa-bemolle-bemolle1, Re-diesis1, Sol-bemolle-bemolle-bemolle-bemolle1,Fa-bemolle1, Re-diesis-diesis1, Sol-bemolle-bemolle-bemolle1,La-bemolle-bemolle-bemolle-bemolle1, Mi-diesis1, Re-diesis-diesis-diesis1, Sol-bemolle-bemolle1,Fa-diesis1, La-bemolle-bemolle-bemolle1, Mi-diesis-diesis1,Fa-diesis-diesis1, La-bemolle-bemolle1, Mi-diesis-diesis-diesis1, Si-bemolle-bemolle-bemolle-bemolle1,Fa-diesis-diesis-diesis1, Si-bemolle-bemolle-bemolle1, Sol-diesis1,Do-bemolle-bemolle-bemolle2, Si-bemolle-bemolle1, Sol-diesis-diesis1,Do-bemolle-bemolle2, La-diesis1, Re-bemolle-bemolle-bemolle-bemolle2, Sol-diesis-diesis-diesis1,Do-bemolle2, La-diesis-diesis1, Re-bemolle-bemolle-bemolle2,La-diesis-diesis-diesis1, Mi-bemolle-bemolle-bemolle-bemolle2, Re-bemolle-bemolle2, Si-diesis1,Do-diesis2, Mi-bemolle-bemolle-bemolle2, Si-diesis-diesis1,Do-diesis-diesis2, Fa-bemolle-bemolle-bemolle2, Mi-bemolle-bemolle2, Si-diesis-diesis-diesis1,Do-diesis-diesis-diesis2, Fa-bemolle-bemolle2, Re-diesis2, Sol-bemolle-bemolle-bemolle-bemolle2,Fa-bemolle2, Re-diesis-diesis2, Sol-bemolle-bemolle-bemolle2,La-bemolle-bemolle-bemolle-bemolle2, Mi-diesis2, Re-diesis-diesis-diesis2, Sol-bemolle-bemolle2,Fa-diesis2, La-bemolle-bemolle-bemolle2, Mi-diesis-diesis2,Fa-diesis-diesis2, La-bemolle-bemolle2, Mi-diesis-diesis-diesis2, Si-bemolle-bemolle-bemolle-bemolle2,Fa-diesis-diesis-diesis2, Si-bemolle-bemolle-bemolle2, Sol-diesis2,Do-bemolle-bemolle-bemolle3, Si-bemolle-bemolle2, Sol-diesis-diesis2,Do-bemolle-bemolle3, La-diesis2, Re-bemolle-bemolle-bemolle-bemolle3, Sol-diesis-diesis-diesis2,Do-bemolle3, La-diesis-diesis2, Re-bemolle-bemolle-bemolle3,La-diesis-diesis-diesis2, Mi-bemolle-bemolle-bemolle-bemolle3, Re-bemolle-bemolle3, Si-diesis2,Do-diesis3, Mi-bemolle-bemolle-bemolle3, Si-diesis-diesis2,Do-diesis-diesis3, Fa-bemolle-bemolle-bemolle3, Mi-bemolle-bemolle3, Si-diesis-diesis-diesis2,Do-diesis-diesis-diesis3, Fa-bemolle-bemolle3, Re-diesis3, Sol-bemolle-bemolle-bemolle-bemolle3,Fa-bemolle3, Re-diesis-diesis3, Sol-bemolle-bemolle-bemolle3,La-bemolle-bemolle-bemolle-bemolle3, Mi-diesis3, Re-diesis-diesis-diesis3, Sol-bemolle-bemolle3,Fa-diesis3, La-bemolle-bemolle-bemolle3, Mi-diesis-diesis3,Fa-diesis-diesis3, La-bemolle-bemolle3, Mi-diesis-diesis-diesis3, Si-bemolle-bemolle-bemolle-bemolle3,Fa-diesis-diesis-diesis3, Si-bemolle-bemolle-bemolle3, Sol-diesis3,Do-bemolle-bemolle-bemolle4, Si-bemolle-bemolle3, Sol-diesis-diesis3,Do-bemolle-bemolle4, La-diesis3, Re-bemolle-bemolle-bemolle-bemolle4, Sol-diesis-diesis-diesis3,Do-bemolle4, La-diesis-diesis3, Re-bemolle-bemolle-bemolle4,La-diesis-diesis-diesis3, Mi-bemolle-bemolle-bemolle-bemolle4, Re-bemolle-bemolle4, Si-diesis3,Do-diesis4, Mi-bemolle-bemolle-bemolle4, Si-diesis-diesis3,Do-diesis-diesis4, Fa-bemolle-bemolle-bemolle4, Mi-bemolle-bemolle4, Si-diesis-diesis-diesis3,Do-diesis-diesis-diesis4, Fa-bemolle-bemolle4, Re-diesis4, Sol-bemolle-bemolle-bemolle-bemolle4,Fa-bemolle4, Re-diesis-diesis4, Sol-bemolle-bemolle-bemolle4,La-bemolle-bemolle-bemolle-bemolle4, Mi-diesis4, Re-diesis-diesis-diesis4, Sol-bemolle-bemolle4,Fa-diesis4, La-bemolle-bemolle-bemolle4, Mi-diesis-diesis4,Fa-diesis-diesis4, La-bemolle-bemolle4, Mi-diesis-diesis-diesis4, Si-bemolle-bemolle-bemolle-bemolle4,Fa-diesis-diesis-diesis4, Si-bemolle-bemolle-bemolle4, Sol-diesis4,Do-bemolle-bemolle-bemolle5, Si-bemolle-bemolle4, Sol-diesis-diesis4,Do-bemolle-bemolle5, La-diesis4, Re-bemolle-bemolle-bemolle-bemolle5, Sol-diesis-diesis-diesis4,Do-bemolle5, La-diesis-diesis4, Re-bemolle-bemolle-bemolle5,La-diesis-diesis-diesis4, Mi-bemolle-bemolle-bemolle-bemolle5, Re-bemolle-bemolle5, Si-diesis4,Do-diesis5, Mi-bemolle-bemolle-bemolle5, Si-diesis-diesis4,Do-diesis-diesis5, Fa-bemolle-bemolle-bemolle5, Mi-bemolle-bemolle5, Si-diesis-diesis-diesis4,Do-diesis-diesis-diesis5, Fa-bemolle-bemolle5, Re-diesis5, Sol-bemolle-bemolle-bemolle-bemolle5,Fa-bemolle5, Re-diesis-diesis5, Sol-bemolle-bemolle-bemolle5,La-bemolle-bemolle-bemolle-bemolle5, Mi-diesis5, Re-diesis-diesis-diesis5, Sol-bemolle-bemolle5,Fa-diesis5, La-bemolle-bemolle-bemolle5, Mi-diesis-diesis5,Fa-diesis-diesis5, La-bemolle-bemolle5, Mi-diesis-diesis-diesis5, Si-bemolle-bemolle-bemolle-bemolle5,Fa-diesis-diesis-diesis5, Si-bemolle-bemolle-bemolle5, Sol-diesis5,Do-bemolle-bemolle-bemolle6, Si-bemolle-bemolle5, Sol-diesis-diesis5,Do-bemolle-bemolle6, La-diesis5, Re-bemolle-bemolle-bemolle-bemolle6, Sol-diesis-diesis-diesis5,Do-bemolle6, La-diesis-diesis5, Re-bemolle-bemolle-bemolle6,La-diesis-diesis-diesis5, Mi-bemolle-bemolle-bemolle-bemolle6, Re-bemolle-bemolle6, Si-diesis5,Do-diesis6, Mi-bemolle-bemolle-bemolle6, Si-diesis-diesis5,Do-diesis-diesis6, Fa-bemolle-bemolle-bemolle6, Mi-bemolle-bemolle6, Si-diesis-diesis-diesis5,Do-diesis-diesis-diesis6, Fa-bemolle-bemolle6, Re-diesis6, Sol-bemolle-bemolle-bemolle-bemolle6,Fa-bemolle6, Re-diesis-diesis6, Sol-bemolle-bemolle-bemolle6,La-bemolle-bemolle-bemolle-bemolle6, Mi-diesis6, Re-diesis-diesis-diesis6, Sol-bemolle-bemolle6,Fa-diesis6, La-bemolle-bemolle-bemolle6, Mi-diesis-diesis6,Fa-diesis-diesis6, La-bemolle-bemolle6, Mi-diesis-diesis-diesis6, Si-bemolle-bemolle-bemolle-bemolle6,Fa-diesis-diesis-diesis6, Si-bemolle-bemolle-bemolle6, Sol-diesis6,Do-bemolle-bemolle-bemolle7, Si-bemolle-bemolle6, Sol-diesis-diesis6,Do-bemolle-bemolle7, La-diesis6, Re-bemolle-bemolle-bemolle-bemolle7, Sol-diesis-diesis-diesis6,Do-bemolle7, La-diesis-diesis6, Re-bemolle-bemolle-bemolle7,La-diesis-diesis-diesis6, Mi-bemolle-bemolle-bemolle-bemolle7, Re-bemolle-bemolle7, Si-diesis6,Do-diesis7, Mi-bemolle-bemolle-bemolle7, Si-diesis-diesis6,Do-diesis-diesis7, Fa-bemolle-bemolle-bemolle7, Mi-bemolle-bemolle7, Si-diesis-diesis-diesis6,Do-diesis-diesis-diesis7, Fa-bemolle-bemolle7, Re-diesis7, Sol-bemolle-bemolle-bemolle-bemolle7,Fa-bemolle7, Re-diesis-diesis7, Sol-bemolle-bemolle-bemolle7,La-bemolle-bemolle-bemolle-bemolle7, Mi-diesis7, Re-diesis-diesis-diesis7, Sol-bemolle-bemolle7,Fa-diesis7, La-bemolle-bemolle-bemolle7, Mi-diesis-diesis7,Fa-diesis-diesis7, La-bemolle-bemolle7, Mi-diesis-diesis-diesis7, Si-bemolle-bemolle-bemolle-bemolle7,Fa-diesis-diesis-diesis7, Si-bemolle-bemolle-bemolle7, Sol-diesis7,Do-bemolle-bemolle-bemolle8, Si-bemolle-bemolle7, Sol-diesis-diesis7,Do-bemolle-bemolle8, La-diesis7, Re-bemolle-bemolle-bemolle-bemolle8, Sol-diesis-diesis-diesis7,Do-bemolle8, La-diesis-diesis7, Re-bemolle-bemolle-bemolle8,La-diesis-diesis-diesis7, Mi-bemolle-bemolle-bemolle-bemolle8, Re-bemolle-bemolle8, Si-diesis7,Do-diesis8, Mi-bemolle-bemolle-bemolle8, Si-diesis-diesis7,Do-diesis-diesis8, Fa-bemolle-bemolle-bemolle8, Mi-bemolle-bemolle8, Si-diesis-diesis-diesis7,Do-diesis-diesis-diesis8, Fa-bemolle-bemolle8, Re-diesis8, Sol-bemolle-bemolle-bemolle-bemolle8,Fa-bemolle8, Re-diesis-diesis8, Sol-bemolle-bemolle-bemolle8,La-bemolle-bemolle-bemolle-bemolle8, Mi-diesis8, Re-diesis-diesis-diesis8, Sol-bemolle-bemolle8,Fa-diesis8, La-bemolle-bemolle-bemolle8, Mi-diesis-diesis8,Fa-diesis-diesis8, La-bemolle-bemolle8, Mi-diesis-diesis-diesis8, Si-bemolle-bemolle-bemolle-bemolle8,Fa-diesis-diesis-diesis8, Si-bemolle-bemolle-bemolle8, Sol-diesis8,Do-bemolle-bemolle-bemolle9, Si-bemolle-bemolle8, Sol-diesis-diesis8,Do-bemolle-bemolle9, La-diesis8, Re-bemolle-bemolle-bemolle-bemolle9, Sol-diesis-diesis-diesis8,Do-bemolle9, La-diesis-diesis8, Re-bemolle-bemolle-bemolle9,La-diesis-diesis-diesis8, Mi-bemolle-bemolle-bemolle-bemolle9, Re-bemolle-bemolle9, Si-diesis8,Do-diesis9, Mi-bemolle-bemolle-bemolle9, Si-diesis-diesis8,Do-diesis-diesis9, Fa-bemolle-bemolle-bemolle9, Mi-bemolle-bemolle9, Si-diesis-diesis-diesis8,Do-diesis-diesis-diesis9, Fa-bemolle-bemolle9, Re-diesis9, Sol-bemolle-bemolle-bemolle-bemolle9,Fa-bemolle9, Re-diesis-diesis9, Sol-bemolle-bemolle-bemolle9,La-bemolle-bemolle-bemolle-bemolle9, Mi-diesis9, Re-diesis-diesis-diesis9, Sol-bemolle-bemolle9,Fa-diesis9, La-bemolle-bemolle-bemolle9, Mi-diesis-diesis9,Fa-diesis-diesis9, La-bemolle-bemolle9, Mi-diesis-diesis-diesis9, Si-bemolle-bemolle-bemolle-bemolle9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "La-diesis-diesis-diesis'''', Mi-bemolle-bemolle-bemolle-bemolle''', Re-bemolle-bemolle''', Si-diesis'''',Do-diesis''', Mi-bemolle-bemolle-bemolle''', Si-diesis-diesis'''',Do-diesis-diesis''', Fa-bemolle-bemolle-bemolle''', Mi-bemolle-bemolle''', Si-diesis-diesis-diesis'''',Do-diesis-diesis-diesis''', Fa-bemolle-bemolle''', Re-diesis''', Sol-bemolle-bemolle-bemolle-bemolle''',Fa-bemolle''', Re-diesis-diesis''', Sol-bemolle-bemolle-bemolle''',La-bemolle-bemolle-bemolle-bemolle''', Mi-diesis''', Re-diesis-diesis-diesis''', Sol-bemolle-bemolle''',Fa-diesis''', La-bemolle-bemolle-bemolle''', Mi-diesis-diesis''',Fa-diesis-diesis''', La-bemolle-bemolle''', Mi-diesis-diesis-diesis''', Si-bemolle-bemolle-bemolle-bemolle''',Fa-diesis-diesis-diesis''', Si-bemolle-bemolle-bemolle''', Sol-diesis''',Do-bemolle-bemolle-bemolle'', Si-bemolle-bemolle''', Sol-diesis-diesis''',Do-bemolle-bemolle'', La-diesis''', Re-bemolle-bemolle-bemolle-bemolle'', Sol-diesis-diesis-diesis''',Do-bemolle'', La-diesis-diesis''', Re-bemolle-bemolle-bemolle'',La-diesis-diesis-diesis''', Mi-bemolle-bemolle-bemolle-bemolle'', Re-bemolle-bemolle'', Si-diesis''',Do-diesis'', Mi-bemolle-bemolle-bemolle'', Si-diesis-diesis''',Do-diesis-diesis'', Fa-bemolle-bemolle-bemolle'', Mi-bemolle-bemolle'', Si-diesis-diesis-diesis''',Do-diesis-diesis-diesis'', Fa-bemolle-bemolle'', Re-diesis'', Sol-bemolle-bemolle-bemolle-bemolle'',Fa-bemolle'', Re-diesis-diesis'', Sol-bemolle-bemolle-bemolle'',La-bemolle-bemolle-bemolle-bemolle'', Mi-diesis'', Re-diesis-diesis-diesis'', Sol-bemolle-bemolle'',Fa-diesis'', La-bemolle-bemolle-bemolle'', Mi-diesis-diesis'',Fa-diesis-diesis'', La-bemolle-bemolle'', Mi-diesis-diesis-diesis'', Si-bemolle-bemolle-bemolle-bemolle'',Fa-diesis-diesis-diesis'', Si-bemolle-bemolle-bemolle'', Sol-diesis'',Do-bemolle-bemolle-bemolle', Si-bemolle-bemolle'', Sol-diesis-diesis'',Do-bemolle-bemolle', La-diesis'', Re-bemolle-bemolle-bemolle-bemolle', Sol-diesis-diesis-diesis'',Do-bemolle', La-diesis-diesis'', Re-bemolle-bemolle-bemolle',La-diesis-diesis-diesis'', Mi-bemolle-bemolle-bemolle-bemolle', Re-bemolle-bemolle', Si-diesis'',Do-diesis', Mi-bemolle-bemolle-bemolle', Si-diesis-diesis'',Do-diesis-diesis', Fa-bemolle-bemolle-bemolle', Mi-bemolle-bemolle', Si-diesis-diesis-diesis'',Do-diesis-diesis-diesis', Fa-bemolle-bemolle', Re-diesis', Sol-bemolle-bemolle-bemolle-bemolle',Fa-bemolle', Re-diesis-diesis', Sol-bemolle-bemolle-bemolle',La-bemolle-bemolle-bemolle-bemolle', Mi-diesis', Re-diesis-diesis-diesis', Sol-bemolle-bemolle',Fa-diesis', La-bemolle-bemolle-bemolle', Mi-diesis-diesis',Fa-diesis-diesis', La-bemolle-bemolle', Mi-diesis-diesis-diesis', Si-bemolle-bemolle-bemolle-bemolle',Fa-diesis-diesis-diesis', Si-bemolle-bemolle-bemolle', Sol-diesis',Do-bemolle-bemolle-bemolle, Si-bemolle-bemolle', Sol-diesis-diesis',Do-bemolle-bemolle, La-diesis', Re-bemolle-bemolle-bemolle-bemolle, Sol-diesis-diesis-diesis',Do-bemolle, La-diesis-diesis', Re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis', Mi-bemolle-bemolle-bemolle-bemolle, Re-bemolle-bemolle, Si-diesis',Do-diesis, Mi-bemolle-bemolle-bemolle, Si-diesis-diesis',Do-diesis-diesis, Fa-bemolle-bemolle-bemolle, Mi-bemolle-bemolle, Si-diesis-diesis-diesis',Do-diesis-diesis-diesis, Fa-bemolle-bemolle, Re-diesis, Sol-bemolle-bemolle-bemolle-bemolle,Fa-bemolle, Re-diesis-diesis, Sol-bemolle-bemolle-bemolle,La-bemolle-bemolle-bemolle-bemolle, Mi-diesis, Re-diesis-diesis-diesis, Sol-bemolle-bemolle,Fa-diesis, La-bemolle-bemolle-bemolle, Mi-diesis-diesis,Fa-diesis-diesis, La-bemolle-bemolle, Mi-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle-bemolle,Fa-diesis-diesis-diesis, Si-bemolle-bemolle-bemolle, Sol-diesis,Si-bemolle-bemolle, Sol-diesis-diesis, do-bemolle-bemolle-bemolle,La-diesis, Sol-diesis-diesis-diesis, do-bemolle-bemolle, re-bemolle-bemolle-bemolle-bemolle,La-diesis-diesis, do-bemolle, re-bemolle-bemolle-bemolle,La-diesis-diesis-diesis, Si-diesis, mi-bemolle-bemolle-bemolle-bemolle, re-bemolle-bemolle,Si-diesis-diesis, do-diesis, mi-bemolle-bemolle-bemolle,Si-diesis-diesis-diesis, do-diesis-diesis, fa-bemolle-bemolle-bemolle, mi-bemolle-bemolle,do-diesis-diesis-diesis, fa-bemolle-bemolle, re-diesis, sol-bemolle-bemolle-bemolle-bemolle,fa-bemolle, re-diesis-diesis, sol-bemolle-bemolle-bemolle,la-bemolle-bemolle-bemolle-bemolle, mi-diesis, re-diesis-diesis-diesis, sol-bemolle-bemolle,fa-diesis, la-bemolle-bemolle-bemolle, mi-diesis-diesis,fa-diesis-diesis, la-bemolle-bemolle, mi-diesis-diesis-diesis, si-bemolle-bemolle-bemolle-bemolle,fa-diesis-diesis-diesis, si-bemolle-bemolle-bemolle, sol-diesis,do-bemolle-bemolle-bemolle', si-bemolle-bemolle, sol-diesis-diesis,do-bemolle-bemolle', la-diesis, re-bemolle-bemolle-bemolle-bemolle', sol-diesis-diesis-diesis,do-bemolle', la-diesis-diesis, re-bemolle-bemolle-bemolle',la-diesis-diesis-diesis, mi-bemolle-bemolle-bemolle-bemolle', re-bemolle-bemolle', si-diesis,do-diesis', mi-bemolle-bemolle-bemolle', si-diesis-diesis,do-diesis-diesis', fa-bemolle-bemolle-bemolle', mi-bemolle-bemolle', si-diesis-diesis-diesis,do-diesis-diesis-diesis', fa-bemolle-bemolle', re-diesis', sol-bemolle-bemolle-bemolle-bemolle',fa-bemolle', re-diesis-diesis', sol-bemolle-bemolle-bemolle',la-bemolle-bemolle-bemolle-bemolle', mi-diesis', re-diesis-diesis-diesis', sol-bemolle-bemolle',fa-diesis', la-bemolle-bemolle-bemolle', mi-diesis-diesis',fa-diesis-diesis', la-bemolle-bemolle', mi-diesis-diesis-diesis', si-bemolle-bemolle-bemolle-bemolle',fa-diesis-diesis-diesis', si-bemolle-bemolle-bemolle', sol-diesis',do-bemolle-bemolle-bemolle'', si-bemolle-bemolle', sol-diesis-diesis',do-bemolle-bemolle'', la-diesis', re-bemolle-bemolle-bemolle-bemolle'', sol-diesis-diesis-diesis',do-bemolle'', la-diesis-diesis', re-bemolle-bemolle-bemolle'',la-diesis-diesis-diesis', mi-bemolle-bemolle-bemolle-bemolle'', re-bemolle-bemolle'', si-diesis',do-diesis'', mi-bemolle-bemolle-bemolle'', si-diesis-diesis',do-diesis-diesis'', fa-bemolle-bemolle-bemolle'', mi-bemolle-bemolle'', si-diesis-diesis-diesis',do-diesis-diesis-diesis'', fa-bemolle-bemolle'', re-diesis'', sol-bemolle-bemolle-bemolle-bemolle'',fa-bemolle'', re-diesis-diesis'', sol-bemolle-bemolle-bemolle'',la-bemolle-bemolle-bemolle-bemolle'', mi-diesis'', re-diesis-diesis-diesis'', sol-bemolle-bemolle'',fa-diesis'', la-bemolle-bemolle-bemolle'', mi-diesis-diesis'',fa-diesis-diesis'', la-bemolle-bemolle'', mi-diesis-diesis-diesis'', si-bemolle-bemolle-bemolle-bemolle'',fa-diesis-diesis-diesis'', si-bemolle-bemolle-bemolle'', sol-diesis'',do-bemolle-bemolle-bemolle''', si-bemolle-bemolle'', sol-diesis-diesis'',do-bemolle-bemolle''', la-diesis'', re-bemolle-bemolle-bemolle-bemolle''', sol-diesis-diesis-diesis'',do-bemolle''', la-diesis-diesis'', re-bemolle-bemolle-bemolle''',la-diesis-diesis-diesis'', mi-bemolle-bemolle-bemolle-bemolle''', re-bemolle-bemolle''', si-diesis'',do-diesis''', mi-bemolle-bemolle-bemolle''', si-diesis-diesis'',do-diesis-diesis''', fa-bemolle-bemolle-bemolle''', mi-bemolle-bemolle''', si-diesis-diesis-diesis'',do-diesis-diesis-diesis''', fa-bemolle-bemolle''', re-diesis''', sol-bemolle-bemolle-bemolle-bemolle''',fa-bemolle''', re-diesis-diesis''', sol-bemolle-bemolle-bemolle''',la-bemolle-bemolle-bemolle-bemolle''', mi-diesis''', re-diesis-diesis-diesis''', sol-bemolle-bemolle''',fa-diesis''', la-bemolle-bemolle-bemolle''', mi-diesis-diesis''',fa-diesis-diesis''', la-bemolle-bemolle''', mi-diesis-diesis-diesis''', si-bemolle-bemolle-bemolle-bemolle''',fa-diesis-diesis-diesis''', si-bemolle-bemolle-bemolle''', sol-diesis''',do-bemolle-bemolle-bemolle'''', si-bemolle-bemolle''', sol-diesis-diesis''',do-bemolle-bemolle'''', la-diesis''', re-bemolle-bemolle-bemolle-bemolle'''', sol-diesis-diesis-diesis''',do-bemolle'''', la-diesis-diesis''', re-bemolle-bemolle-bemolle'''',la-diesis-diesis-diesis''', mi-bemolle-bemolle-bemolle-bemolle'''', re-bemolle-bemolle'''', si-diesis''',do-diesis'''', mi-bemolle-bemolle-bemolle'''', si-diesis-diesis''',do-diesis-diesis'''', fa-bemolle-bemolle-bemolle'''', mi-bemolle-bemolle'''', si-diesis-diesis-diesis''',do-diesis-diesis-diesis'''', fa-bemolle-bemolle'''', re-diesis'''', sol-bemolle-bemolle-bemolle-bemolle'''',fa-bemolle'''', re-diesis-diesis'''', sol-bemolle-bemolle-bemolle'''',la-bemolle-bemolle-bemolle-bemolle'''', mi-diesis'''', re-diesis-diesis-diesis'''', sol-bemolle-bemolle'''',fa-diesis'''', la-bemolle-bemolle-bemolle'''', mi-diesis-diesis'''',fa-diesis-diesis'''', la-bemolle-bemolle'''', mi-diesis-diesis-diesis'''', si-bemolle-bemolle-bemolle-bemolle'''',fa-diesis-diesis-diesis'''', si-bemolle-bemolle-bemolle'''', sol-diesis'''',do-bemolle-bemolle-bemolle''''', si-bemolle-bemolle'''', sol-diesis-diesis'''',do-bemolle-bemolle''''', la-diesis'''', re-bemolle-bemolle-bemolle-bemolle''''', sol-diesis-diesis-diesis'''',do-bemolle''''', la-diesis-diesis'''', re-bemolle-bemolle-bemolle''''',la-diesis-diesis-diesis'''', mi-bemolle-bemolle-bemolle-bemolle''''', re-bemolle-bemolle''''', si-diesis'''',do-diesis''''', mi-bemolle-bemolle-bemolle''''', si-diesis-diesis'''',do-diesis-diesis''''', fa-bemolle-bemolle-bemolle''''', mi-bemolle-bemolle''''', si-diesis-diesis-diesis'''',do-diesis-diesis-diesis''''', fa-bemolle-bemolle''''', re-diesis''''', sol-bemolle-bemolle-bemolle-bemolle''''',fa-bemolle''''', re-diesis-diesis''''', sol-bemolle-bemolle-bemolle''''',la-bemolle-bemolle-bemolle-bemolle''''', mi-diesis''''', re-diesis-diesis-diesis''''', sol-bemolle-bemolle''''',fa-diesis''''', la-bemolle-bemolle-bemolle''''', mi-diesis-diesis''''',fa-diesis-diesis''''', la-bemolle-bemolle''''', mi-diesis-diesis-diesis''''', si-bemolle-bemolle-bemolle-bemolle''''',fa-diesis-diesis-diesis''''', si-bemolle-bemolle-bemolle''''', sol-diesis''''',do-bemolle-bemolle-bemolle'''''', si-bemolle-bemolle''''', sol-diesis-diesis''''',do-bemolle-bemolle'''''', la-diesis''''', re-bemolle-bemolle-bemolle-bemolle'''''', sol-diesis-diesis-diesis''''',do-bemolle'''''', la-diesis-diesis''''', re-bemolle-bemolle-bemolle'''''',la-diesis-diesis-diesis''''', mi-bemolle-bemolle-bemolle-bemolle'''''', re-bemolle-bemolle'''''', si-diesis''''',do-diesis'''''', mi-bemolle-bemolle-bemolle'''''', si-diesis-diesis''''',do-diesis-diesis'''''', fa-bemolle-bemolle-bemolle'''''', mi-bemolle-bemolle'''''', si-diesis-diesis-diesis''''',do-diesis-diesis-diesis'''''', fa-bemolle-bemolle'''''', re-diesis'''''', sol-bemolle-bemolle-bemolle-bemolle'''''',fa-bemolle'''''', re-diesis-diesis'''''', sol-bemolle-bemolle-bemolle'''''',la-bemolle-bemolle-bemolle-bemolle'''''', mi-diesis'''''', re-diesis-diesis-diesis'''''', sol-bemolle-bemolle'''''',fa-diesis'''''', la-bemolle-bemolle-bemolle'''''', mi-diesis-diesis'''''',fa-diesis-diesis'''''', la-bemolle-bemolle'''''', mi-diesis-diesis-diesis'''''', si-bemolle-bemolle-bemolle-bemolle''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Laisisis-6, Reeses-5, Siis-6,Laisisisis-6, Mieseses-5, Rees-5, Siisis-6,Doisis-5, Faeseses-5, Mieses-5, Siisisis-6,Doisisis-5, Faeses-5, Mies-5,Doisisisis-5, Faes-5, Reisis-5, Soleseses-5,Miis-5, Reisisis-5, Soleses-5,Laeseses-5, Miisis-5, Reisisisis-5, Soles-5,Faisis-5, Laeses-5, Miisisis-5,Faisisis-5, Laes-5, Sieseses-5,Doeseses-4, Faisisisis-5, Sieses-5, Solisis-5,Doeses-4, Sies-5, Solisisis-5,Does-4, Laisis-5, Reeseses-4, Solisisisis-5,Laisisis-5, Reeses-4, Siis-5,Laisisisis-5, Mieseses-4, Rees-4, Siisis-5,Doisis-4, Faeseses-4, Mieses-4, Siisisis-5,Doisisis-4, Faeses-4, Mies-4,Doisisisis-4, Faes-4, Reisis-4, Soleseses-4,Miis-4, Reisisis-4, Soleses-4,Laeseses-4, Miisis-4, Reisisisis-4, Soles-4,Faisis-4, Laeses-4, Miisisis-4,Faisisis-4, Laes-4, Sieseses-4,Doeseses-3, Faisisisis-4, Sieses-4, Solisis-4,Doeses-3, Sies-4, Solisisis-4,Does-3, Laisis-4, Reeseses-3, Solisisisis-4,Laisisis-4, Reeses-3, Siis-4,Laisisisis-4, Mieseses-3, Rees-3, Siisis-4,Doisis-3, Faeseses-3, Mieses-3, Siisisis-4,Doisisis-3, Faeses-3, Mies-3,Doisisisis-3, Faes-3, Reisis-3, Soleseses-3,Miis-3, Reisisis-3, Soleses-3,Laeseses-3, Miisis-3, Reisisisis-3, Soles-3,Faisis-3, Laeses-3, Miisisis-3,Faisisis-3, Laes-3, Sieseses-3,Doeseses-2, Faisisisis-3, Sieses-3, Solisis-3,Doeses-2, Sies-3, Solisisis-3,Does-2, Laisis-3, Reeseses-2, Solisisisis-3,Laisisis-3, Reeses-2, Siis-3,Laisisisis-3, Mieseses-2, Rees-2, Siisis-3,Doisis-2, Faeseses-2, Mieses-2, Siisisis-3,Doisisis-2, Faeses-2, Mies-2,Doisisisis-2, Faes-2, Reisis-2, Soleseses-2,Miis-2, Reisisis-2, Soleses-2,Laeseses-2, Miisis-2, Reisisisis-2, Soles-2,Faisis-2, Laeses-2, Miisisis-2,Faisisis-2, Laes-2, Sieseses-2,Doeseses-, Faisisisis-2, Sieses-2, Solisis-2,Doeses-, Sies-2, Solisisis-2,Does-, Laisis-2, Reeseses-, Solisisisis-2,Laisisis-2, Reeses-, Siis-2,Laisisisis-2, Mieseses-, Rees-, Siisis-2,Doisis-, Faeseses-, Mieses-, Siisisis-2,Doisisis-, Faeses-, Mies-,Doisisisis-, Faes-, Reisis-, Soleseses-,Miis-, Reisisis-, Soleses-,Laeseses-, Miisis-, Reisisisis-, Soles-,Faisis-, Laeses-, Miisisis-,Faisisis-, Laes-, Sieseses-,Doeseses, Faisisisis-, Sieses-, Solisis-,Doeses, Sies-, Solisisis-,Does, Laisis-, Reeseses, Solisisisis-,Laisisis-, Reeses, Siis-,Laisisisis-, Mieseses, Rees, Siisis-,Doisis, Faeseses, Mieses, Siisisis-,Doisisis, Faeses, Mies,Doisisisis, Faes, Reisis, Soleseses,Miis, Reisisis, Soleses,Laeseses, Miisis, Reisisisis, Soles,Faisis, Laeses, Miisisis,Faisisis, Laes, Sieseses,Doeseses+, Faisisisis, Sieses, Solisis,Doeses+, Sies, Solisisis,Does+, Laisis, Reeseses+, Solisisisis,Laisisis, Reeses+, Siis,Laisisisis, Mieseses+, Rees+, Siisis,Doisis+, Faeseses+, Mieses+, Siisisis,Doisisis+, Faeses+, Mies+,Doisisisis+, Faes+, Reisis+, Soleseses+,Miis+, Reisisis+, Soleses+,Laeseses+, Miisis+, Reisisisis+, Soles+,Faisis+, Laeses+, Miisisis+,Faisisis+, Laes+, Sieseses+,Doeseses+2, Faisisisis+, Sieses+, Solisis+,Doeses+2, Sies+, Solisisis+,Does+2, Laisis+, Reeseses+2, Solisisisis+,Laisisis+, Reeses+2, Siis+,Laisisisis+, Mieseses+2, Rees+2, Siisis+,Doisis+2, Faeseses+2, Mieses+2, Siisisis+,Doisisis+2, Faeses+2, Mies+2,Doisisisis+2, Faes+2, Reisis+2, Soleseses+2,Miis+2, Reisisis+2, Soleses+2,Laeseses+2, Miisis+2, Reisisisis+2, Soles+2,Faisis+2, Laeses+2, Miisisis+2,Faisisis+2, Laes+2, Sieseses+2,Doeseses+3, Faisisisis+2, Sieses+2, Solisis+2,Doeses+3, Sies+2, Solisisis+2,Does+3, Laisis+2, Reeseses+3, Solisisisis+2,Laisisis+2, Reeses+3, Siis+2,Laisisisis+2, Mieseses+3, Rees+3, Siisis+2,Doisis+3, Faeseses+3, Mieses+3, Siisisis+2,Doisisis+3, Faeses+3, Mies+3,Doisisisis+3, Faes+3, Reisis+3, Soleseses+3,Miis+3, Reisisis+3, Soleses+3,Laeseses+3, Miisis+3, Reisisisis+3, Soles+3,Faisis+3, Laeses+3, Miisisis+3,Faisisis+3, Laes+3, Sieseses+3,Doeseses+4, Faisisisis+3, Sieses+3, Solisis+3,Doeses+4, Sies+3, Solisisis+3,Does+4, Laisis+3, Reeseses+4, Solisisisis+3,Laisisis+3, Reeses+4, Siis+3,Laisisisis+3, Mieseses+4, Rees+4, Siisis+3,Doisis+4, Faeseses+4, Mieses+4, Siisisis+3,Doisisis+4, Faeses+4, Mies+4,Doisisisis+4, Faes+4, Reisis+4, Soleseses+4,Miis+4, Reisisis+4, Soleses+4,Laeseses+4, Miisis+4, Reisisisis+4, Soles+4,Faisis+4, Laeses+4, Miisisis+4,Faisisis+4, Laes+4, Sieseses+4,Doeseses+5, Faisisisis+4, Sieses+4, Solisis+4,Doeses+5, Sies+4, Solisisis+4,Does+5, Laisis+4, Reeseses+5, Solisisisis+4,Laisisis+4, Reeses+5, Siis+4,Laisisisis+4, Mieseses+5, Rees+5, Siisis+4,Doisis+5, Faeseses+5, Mieses+5, Siisisis+4,Doisisis+5, Faeses+5, Mies+5,Doisisisis+5, Faes+5, Reisis+5, Soleseses+5,Miis+5, Reisisis+5, Soleses+5,Laeseses+5, Miisis+5, Reisisisis+5, Soles+5,Faisis+5, Laeses+5, Miisisis+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Laisisis------, Reeses-----, Siis------,Laisisisis------, Mieseses-----, Rees-----, Siisis------,Doisis-----, Faeseses-----, Mieses-----, Siisisis------,Doisisis-----, Faeses-----, Mies-----,Doisisisis-----, Faes-----, Reisis-----, Soleseses-----,Miis-----, Reisisis-----, Soleses-----,Laeseses-----, Miisis-----, Reisisisis-----, Soles-----,Faisis-----, Laeses-----, Miisisis-----,Faisisis-----, Laes-----, Sieseses-----,Doeseses----, Faisisisis-----, Sieses-----, Solisis-----,Doeses----, Sies-----, Solisisis-----,Does----, Laisis-----, Reeseses----, Solisisisis-----,Laisisis-----, Reeses----, Siis-----,Laisisisis-----, Mieseses----, Rees----, Siisis-----,Doisis----, Faeseses----, Mieses----, Siisisis-----,Doisisis----, Faeses----, Mies----,Doisisisis----, Faes----, Reisis----, Soleseses----,Miis----, Reisisis----, Soleses----,Laeseses----, Miisis----, Reisisisis----, Soles----,Faisis----, Laeses----, Miisisis----,Faisisis----, Laes----, Sieseses----,Doeseses---, Faisisisis----, Sieses----, Solisis----,Doeses---, Sies----, Solisisis----,Does---, Laisis----, Reeseses---, Solisisisis----,Laisisis----, Reeses---, Siis----,Laisisisis----, Mieseses---, Rees---, Siisis----,Doisis---, Faeseses---, Mieses---, Siisisis----,Doisisis---, Faeses---, Mies---,Doisisisis---, Faes---, Reisis---, Soleseses---,Miis---, Reisisis---, Soleses---,Laeseses---, Miisis---, Reisisisis---, Soles---,Faisis---, Laeses---, Miisisis---,Faisisis---, Laes---, Sieseses---,Doeseses--, Faisisisis---, Sieses---, Solisis---,Doeses--, Sies---, Solisisis---,Does--, Laisis---, Reeseses--, Solisisisis---,Laisisis---, Reeses--, Siis---,Laisisisis---, Mieseses--, Rees--, Siisis---,Doisis--, Faeseses--, Mieses--, Siisisis---,Doisisis--, Faeses--, Mies--,Doisisisis--, Faes--, Reisis--, Soleseses--,Miis--, Reisisis--, Soleses--,Laeseses--, Miisis--, Reisisisis--, Soles--,Faisis--, Laeses--, Miisisis--,Faisisis--, Laes--, Sieseses--,Doeseses-, Faisisisis--, Sieses--, Solisis--,Doeses-, Sies--, Solisisis--,Does-, Laisis--, Reeseses-, Solisisisis--,Laisisis--, Reeses-, Siis--,Laisisisis--, Mieseses-, Rees-, Siisis--,Doisis-, Faeseses-, Mieses-, Siisisis--,Doisisis-, Faeses-, Mies-,Doisisisis-, Faes-, Reisis-, Soleseses-,Miis-, Reisisis-, Soleses-,Laeseses-, Miisis-, Reisisisis-, Soles-,Faisis-, Laeses-, Miisisis-,Faisisis-, Laes-, Sieseses-,Doeseses, Faisisisis-, Sieses-, Solisis-,Doeses, Sies-, Solisisis-,Does, Laisis-, Reeseses, Solisisisis-,Laisisis-, Reeses, Siis-,Laisisisis-, Mieseses, Rees, Siisis-,Doisis, Faeseses, Mieses, Siisisis-,Doisisis, Faeses, Mies,Doisisisis, Faes, Reisis, Soleseses,Miis, Reisisis, Soleses,Laeseses, Miisis, Reisisisis, Soles,Faisis, Laeses, Miisisis,Faisisis, Laes, Sieseses,Doeseses+, Faisisisis, Sieses, Solisis,Doeses+, Sies, Solisisis,Does+, Laisis, Reeseses+, Solisisisis,Laisisis, Reeses+, Siis,Laisisisis, Mieseses+, Rees+, Siisis,Doisis+, Faeseses+, Mieses+, Siisisis,Doisisis+, Faeses+, Mies+,Doisisisis+, Faes+, Reisis+, Soleseses+,Miis+, Reisisis+, Soleses+,Laeseses+, Miisis+, Reisisisis+, Soles+,Faisis+, Laeses+, Miisisis+,Faisisis+, Laes+, Sieseses+,Doeseses++, Faisisisis+, Sieses+, Solisis+,Doeses++, Sies+, Solisisis+,Does++, Laisis+, Reeseses++, Solisisisis+,Laisisis+, Reeses++, Siis+,Laisisisis+, Mieseses++, Rees++, Siisis+,Doisis++, Faeseses++, Mieses++, Siisisis+,Doisisis++, Faeses++, Mies++,Doisisisis++, Faes++, Reisis++, Soleseses++,Miis++, Reisisis++, Soleses++,Laeseses++, Miisis++, Reisisisis++, Soles++,Faisis++, Laeses++, Miisisis++,Faisisis++, Laes++, Sieseses++,Doeseses+++, Faisisisis++, Sieses++, Solisis++,Doeses+++, Sies++, Solisisis++,Does+++, Laisis++, Reeseses+++, Solisisisis++,Laisisis++, Reeses+++, Siis++,Laisisisis++, Mieseses+++, Rees+++, Siisis++,Doisis+++, Faeseses+++, Mieses+++, Siisisis++,Doisisis+++, Faeses+++, Mies+++,Doisisisis+++, Faes+++, Reisis+++, Soleseses+++,Miis+++, Reisisis+++, Soleses+++,Laeseses+++, Miisis+++, Reisisisis+++, Soles+++,Faisis+++, Laeses+++, Miisisis+++,Faisisis+++, Laes+++, Sieseses+++,Doeseses++++, Faisisisis+++, Sieses+++, Solisis+++,Doeses++++, Sies+++, Solisisis+++,Does++++, Laisis+++, Reeseses++++, Solisisisis+++,Laisisis+++, Reeses++++, Siis+++,Laisisisis+++, Mieseses++++, Rees++++, Siisis+++,Doisis++++, Faeseses++++, Mieses++++, Siisisis+++,Doisisis++++, Faeses++++, Mies++++,Doisisisis++++, Faes++++, Reisis++++, Soleseses++++,Miis++++, Reisisis++++, Soleses++++,Laeseses++++, Miisis++++, Reisisisis++++, Soles++++,Faisis++++, Laeses++++, Miisisis++++,Faisisis++++, Laes++++, Sieseses++++,Doeseses+++++, Faisisisis++++, Sieses++++, Solisis++++,Doeses+++++, Sies++++, Solisisis++++,Does+++++, Laisis++++, Reeseses+++++, Solisisisis++++,Laisisis++++, Reeses+++++, Siis++++,Laisisisis++++, Mieseses+++++, Rees+++++, Siisis++++,Doisis+++++, Faeseses+++++, Mieses+++++, Siisisis++++,Doisisis+++++, Faeses+++++, Mies+++++,Doisisisis+++++, Faes+++++, Reisis+++++, Soleseses+++++,Miis+++++, Reisisis+++++, Soleses+++++,Laeseses+++++, Miisis+++++, Reisisisis+++++, Soles+++++,Faisis+++++, Laeses+++++, Miisisis+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Laisisis-2, Reeses-1, Siis-2,Laisisisis-2, Mieseses-1, Rees-1, Siisis-2,Doisis-1, Faeseses-1, Mieses-1, Siisisis-2,Doisisis-1, Faeses-1, Mies-1,Doisisisis-1, Faes-1, Reisis-1, Soleseses-1,Miis-1, Reisisis-1, Soleses-1,Laeseses-1, Miisis-1, Reisisisis-1, Soles-1,Faisis-1, Laeses-1, Miisisis-1,Faisisis-1, Laes-1, Sieseses-1,Doeseses0, Faisisisis-1, Sieses-1, Solisis-1,Doeses0, Sies-1, Solisisis-1,Does0, Laisis-1, Reeseses0, Solisisisis-1,Laisisis-1, Reeses0, Siis-1,Laisisisis-1, Mieseses0, Rees0, Siisis-1,Doisis0, Faeseses0, Mieses0, Siisisis-1,Doisisis0, Faeses0, Mies0,Doisisisis0, Faes0, Reisis0, Soleseses0,Miis0, Reisisis0, Soleses0,Laeseses0, Miisis0, Reisisisis0, Soles0,Faisis0, Laeses0, Miisisis0,Faisisis0, Laes0, Sieseses0,Doeseses1, Faisisisis0, Sieses0, Solisis0,Doeses1, Sies0, Solisisis0,Does1, Laisis0, Reeseses1, Solisisisis0,Laisisis0, Reeses1, Siis0,Laisisisis0, Mieseses1, Rees1, Siisis0,Doisis1, Faeseses1, Mieses1, Siisisis0,Doisisis1, Faeses1, Mies1,Doisisisis1, Faes1, Reisis1, Soleseses1,Miis1, Reisisis1, Soleses1,Laeseses1, Miisis1, Reisisisis1, Soles1,Faisis1, Laeses1, Miisisis1,Faisisis1, Laes1, Sieseses1,Doeseses2, Faisisisis1, Sieses1, Solisis1,Doeses2, Sies1, Solisisis1,Does2, Laisis1, Reeseses2, Solisisisis1,Laisisis1, Reeses2, Siis1,Laisisisis1, Mieseses2, Rees2, Siisis1,Doisis2, Faeseses2, Mieses2, Siisisis1,Doisisis2, Faeses2, Mies2,Doisisisis2, Faes2, Reisis2, Soleseses2,Miis2, Reisisis2, Soleses2,Laeseses2, Miisis2, Reisisisis2, Soles2,Faisis2, Laeses2, Miisisis2,Faisisis2, Laes2, Sieseses2,Doeseses3, Faisisisis2, Sieses2, Solisis2,Doeses3, Sies2, Solisisis2,Does3, Laisis2, Reeseses3, Solisisisis2,Laisisis2, Reeses3, Siis2,Laisisisis2, Mieseses3, Rees3, Siisis2,Doisis3, Faeseses3, Mieses3, Siisisis2,Doisisis3, Faeses3, Mies3,Doisisisis3, Faes3, Reisis3, Soleseses3,Miis3, Reisisis3, Soleses3,Laeseses3, Miisis3, Reisisisis3, Soles3,Faisis3, Laeses3, Miisisis3,Faisisis3, Laes3, Sieseses3,Doeseses4, Faisisisis3, Sieses3, Solisis3,Doeses4, Sies3, Solisisis3,Does4, Laisis3, Reeseses4, Solisisisis3,Laisisis3, Reeses4, Siis3,Laisisisis3, Mieseses4, Rees4, Siisis3,Doisis4, Faeseses4, Mieses4, Siisisis3,Doisisis4, Faeses4, Mies4,Doisisisis4, Faes4, Reisis4, Soleseses4,Miis4, Reisisis4, Soleses4,Laeseses4, Miisis4, Reisisisis4, Soles4,Faisis4, Laeses4, Miisisis4,Faisisis4, Laes4, Sieseses4,Doeseses5, Faisisisis4, Sieses4, Solisis4,Doeses5, Sies4, Solisisis4,Does5, Laisis4, Reeseses5, Solisisisis4,Laisisis4, Reeses5, Siis4,Laisisisis4, Mieseses5, Rees5, Siisis4,Doisis5, Faeseses5, Mieses5, Siisisis4,Doisisis5, Faeses5, Mies5,Doisisisis5, Faes5, Reisis5, Soleseses5,Miis5, Reisisis5, Soleses5,Laeseses5, Miisis5, Reisisisis5, Soles5,Faisis5, Laeses5, Miisisis5,Faisisis5, Laes5, Sieseses5,Doeseses6, Faisisisis5, Sieses5, Solisis5,Doeses6, Sies5, Solisisis5,Does6, Laisis5, Reeseses6, Solisisisis5,Laisisis5, Reeses6, Siis5,Laisisisis5, Mieseses6, Rees6, Siisis5,Doisis6, Faeseses6, Mieses6, Siisisis5,Doisisis6, Faeses6, Mies6,Doisisisis6, Faes6, Reisis6, Soleseses6,Miis6, Reisisis6, Soleses6,Laeseses6, Miisis6, Reisisisis6, Soles6,Faisis6, Laeses6, Miisisis6,Faisisis6, Laes6, Sieseses6,Doeseses7, Faisisisis6, Sieses6, Solisis6,Doeses7, Sies6, Solisisis6,Does7, Laisis6, Reeseses7, Solisisisis6,Laisisis6, Reeses7, Siis6,Laisisisis6, Mieseses7, Rees7, Siisis6,Doisis7, Faeseses7, Mieses7, Siisisis6,Doisisis7, Faeses7, Mies7,Doisisisis7, Faes7, Reisis7, Soleseses7,Miis7, Reisisis7, Soleses7,Laeseses7, Miisis7, Reisisisis7, Soles7,Faisis7, Laeses7, Miisisis7,Faisisis7, Laes7, Sieseses7,Doeseses8, Faisisisis7, Sieses7, Solisis7,Doeses8, Sies7, Solisisis7,Does8, Laisis7, Reeseses8, Solisisisis7,Laisisis7, Reeses8, Siis7,Laisisisis7, Mieseses8, Rees8, Siisis7,Doisis8, Faeseses8, Mieses8, Siisisis7,Doisisis8, Faeses8, Mies8,Doisisisis8, Faes8, Reisis8, Soleseses8,Miis8, Reisisis8, Soleses8,Laeseses8, Miisis8, Reisisisis8, Soles8,Faisis8, Laeses8, Miisisis8,Faisisis8, Laes8, Sieseses8,Doeseses9, Faisisisis8, Sieses8, Solisis8,Doeses9, Sies8, Solisisis8,Does9, Laisis8, Reeseses9, Solisisisis8,Laisisis8, Reeses9, Siis8,Laisisisis8, Mieseses9, Rees9, Siisis8,Doisis9, Faeseses9, Mieses9, Siisisis8,Doisisis9, Faeses9, Mies9,Doisisisis9, Faes9, Reisis9, Soleseses9,Miis9, Reisisis9, Soleses9,Laeseses9, Miisis9, Reisisisis9, Soles9,Faisis9, Laeses9, Miisisis9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Laisisis'''', Reeses''', Siis'''',Laisisisis'''', Mieseses''', Rees''', Siisis'''',Doisis''', Faeseses''', Mieses''', Siisisis'''',Doisisis''', Faeses''', Mies''',Doisisisis''', Faes''', Reisis''', Soleseses''',Miis''', Reisisis''', Soleses''',Laeseses''', Miisis''', Reisisisis''', Soles''',Faisis''', Laeses''', Miisisis''',Faisisis''', Laes''', Sieseses''',Doeseses'', Faisisisis''', Sieses''', Solisis''',Doeses'', Sies''', Solisisis''',Does'', Laisis''', Reeseses'', Solisisisis''',Laisisis''', Reeses'', Siis''',Laisisisis''', Mieseses'', Rees'', Siisis''',Doisis'', Faeseses'', Mieses'', Siisisis''',Doisisis'', Faeses'', Mies'',Doisisisis'', Faes'', Reisis'', Soleseses'',Miis'', Reisisis'', Soleses'',Laeseses'', Miisis'', Reisisisis'', Soles'',Faisis'', Laeses'', Miisisis'',Faisisis'', Laes'', Sieseses'',Doeseses', Faisisisis'', Sieses'', Solisis'',Doeses', Sies'', Solisisis'',Does', Laisis'', Reeseses', Solisisisis'',Laisisis'', Reeses', Siis'',Laisisisis'', Mieseses', Rees', Siisis'',Doisis', Faeseses', Mieses', Siisisis'',Doisisis', Faeses', Mies',Doisisisis', Faes', Reisis', Soleseses',Miis', Reisisis', Soleses',Laeseses', Miisis', Reisisisis', Soles',Faisis', Laeses', Miisisis',Faisisis', Laes', Sieseses',Doeseses, Faisisisis', Sieses', Solisis',Doeses, Sies', Solisisis',Does, Laisis', Reeseses, Solisisisis',Laisisis', Reeses, Siis',Laisisisis', Mieseses, Rees, Siisis',Doisis, Faeseses, Mieses, Siisisis',Doisisis, Faeses, Mies,Doisisisis, Faes, Reisis, Soleseses,Miis, Reisisis, Soleses,Laeseses, Miisis, Reisisisis, Soles,Faisis, Laeses, Miisisis,Faisisis, Laes, Sieseses,Faisisisis, Sieses, Solisis, doeseses,Sies, Solisisis, doeses,Laisis, Solisisisis, does, reeseses,Laisisis, Siis, reeses,Laisisisis, Siisis, mieseses, rees,Siisisis, doisis, faeseses, mieses,doisisis, faeses, mies,doisisisis, faes, reisis, soleseses,miis, reisisis, soleses,laeseses, miisis, reisisisis, soles,faisis, laeses, miisisis,faisisis, laes, sieseses,doeseses', faisisisis, sieses, solisis,doeses', sies, solisisis,does', laisis, reeseses', solisisisis,laisisis, reeses', siis,laisisisis, mieseses', rees', siisis,doisis', faeseses', mieses', siisisis,doisisis', faeses', mies',doisisisis', faes', reisis', soleseses',miis', reisisis', soleses',laeseses', miisis', reisisisis', soles',faisis', laeses', miisisis',faisisis', laes', sieseses',doeseses'', faisisisis', sieses', solisis',doeses'', sies', solisisis',does'', laisis', reeseses'', solisisisis',laisisis', reeses'', siis',laisisisis', mieseses'', rees'', siisis',doisis'', faeseses'', mieses'', siisisis',doisisis'', faeses'', mies'',doisisisis'', faes'', reisis'', soleseses'',miis'', reisisis'', soleses'',laeseses'', miisis'', reisisisis'', soles'',faisis'', laeses'', miisisis'',faisisis'', laes'', sieseses'',doeseses''', faisisisis'', sieses'', solisis'',doeses''', sies'', solisisis'',does''', laisis'', reeseses''', solisisisis'',laisisis'', reeses''', siis'',laisisisis'', mieseses''', rees''', siisis'',doisis''', faeseses''', mieses''', siisisis'',doisisis''', faeses''', mies''',doisisisis''', faes''', reisis''', soleseses''',miis''', reisisis''', soleses''',laeseses''', miisis''', reisisisis''', soles''',faisis''', laeses''', miisisis''',faisisis''', laes''', sieseses''',doeseses'''', faisisisis''', sieses''', solisis''',doeses'''', sies''', solisisis''',does'''', laisis''', reeseses'''', solisisisis''',laisisis''', reeses'''', siis''',laisisisis''', mieseses'''', rees'''', siisis''',doisis'''', faeseses'''', mieses'''', siisisis''',doisisis'''', faeses'''', mies'''',doisisisis'''', faes'''', reisis'''', soleseses'''',miis'''', reisisis'''', soleses'''',laeseses'''', miisis'''', reisisisis'''', soles'''',faisis'''', laeses'''', miisisis'''',faisisis'''', laes'''', sieseses'''',doeseses''''', faisisisis'''', sieses'''', solisis'''',doeses''''', sies'''', solisisis'''',does''''', laisis'''', reeseses''''', solisisisis'''',laisisis'''', reeses''''', siis'''',laisisisis'''', mieseses''''', rees''''', siisis'''',doisis''''', faeseses''''', mieses''''', siisisis'''',doisisis''''', faeses''''', mies''''',doisisisis''''', faes''''', reisis''''', soleseses''''',miis''''', reisisis''''', soleses''''',laeseses''''', miisis''''', reisisisis''''', soles''''',faisis''''', laeses''''', miisisis''''',faisisis''''', laes''''', sieseses''''',doeseses'''''', faisisisis''''', sieses''''', solisis''''',doeses'''''', sies''''', solisisis''''',does'''''', laisis''''', reeseses'''''', solisisisis''''',laisisis''''', reeses'''''', siis''''',laisisisis''''', mieseses'''''', rees'''''', siisis''''',doisis'''''', faeseses'''''', mieses'''''', siisisis''''',doisisis'''''', faeses'''''', mies'''''',doisisisis'''''', faes'''''', reisis'''''', soleseses'''''',miis'''''', reisisis'''''', soleses'''''',laeseses'''''', miisis'''''', reisisisis'''''', soles'''''',faisis'''''', laeses'''''', miisisis''''''\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Laisisis-6, Mieseseses-5, Reeses-5, Siis-6,Dois-5, Mieseses-5, Siisis-6,Doisis-5, Faeseses-5, Mieses-5, Siisisis-6,Doisisis-5, Faeses-5, Reis-5, Soleseseses-5,Faes-5, Reisis-5, Soleseses-5,Laeseseses-5, Miis-5, Reisisis-5, Soleses-5,Fais-5, Laeseses-5, Miisis-5,Faisis-5, Laeses-5, Miisisis-5, Sieseseses-5,Faisisis-5, Sieseses-5, Solis-5,Doeseses-4, Sieses-5, Solisis-5,Doeses-4, Lais-5, Reeseseses-4, Solisisis-5,Does-4, Laisis-5, Reeseses-4,Laisisis-5, Mieseseses-4, Reeses-4, Siis-5,Dois-4, Mieseses-4, Siisis-5,Doisis-4, Faeseses-4, Mieses-4, Siisisis-5,Doisisis-4, Faeses-4, Reis-4, Soleseseses-4,Faes-4, Reisis-4, Soleseses-4,Laeseseses-4, Miis-4, Reisisis-4, Soleses-4,Fais-4, Laeseses-4, Miisis-4,Faisis-4, Laeses-4, Miisisis-4, Sieseseses-4,Faisisis-4, Sieseses-4, Solis-4,Doeseses-3, Sieses-4, Solisis-4,Doeses-3, Lais-4, Reeseseses-3, Solisisis-4,Does-3, Laisis-4, Reeseses-3,Laisisis-4, Mieseseses-3, Reeses-3, Siis-4,Dois-3, Mieseses-3, Siisis-4,Doisis-3, Faeseses-3, Mieses-3, Siisisis-4,Doisisis-3, Faeses-3, Reis-3, Soleseseses-3,Faes-3, Reisis-3, Soleseses-3,Laeseseses-3, Miis-3, Reisisis-3, Soleses-3,Fais-3, Laeseses-3, Miisis-3,Faisis-3, Laeses-3, Miisisis-3, Sieseseses-3,Faisisis-3, Sieseses-3, Solis-3,Doeseses-2, Sieses-3, Solisis-3,Doeses-2, Lais-3, Reeseseses-2, Solisisis-3,Does-2, Laisis-3, Reeseses-2,Laisisis-3, Mieseseses-2, Reeses-2, Siis-3,Dois-2, Mieseses-2, Siisis-3,Doisis-2, Faeseses-2, Mieses-2, Siisisis-3,Doisisis-2, Faeses-2, Reis-2, Soleseseses-2,Faes-2, Reisis-2, Soleseses-2,Laeseseses-2, Miis-2, Reisisis-2, Soleses-2,Fais-2, Laeseses-2, Miisis-2,Faisis-2, Laeses-2, Miisisis-2, Sieseseses-2,Faisisis-2, Sieseses-2, Solis-2,Doeseses-, Sieses-2, Solisis-2,Doeses-, Lais-2, Reeseseses-, Solisisis-2,Does-, Laisis-2, Reeseses-,Laisisis-2, Mieseseses-, Reeses-, Siis-2,Dois-, Mieseses-, Siisis-2,Doisis-, Faeseses-, Mieses-, Siisisis-2,Doisisis-, Faeses-, Reis-, Soleseseses-,Faes-, Reisis-, Soleseses-,Laeseseses-, Miis-, Reisisis-, Soleses-,Fais-, Laeseses-, Miisis-,Faisis-, Laeses-, Miisisis-, Sieseseses-,Faisisis-, Sieseses-, Solis-,Doeseses, Sieses-, Solisis-,Doeses, Lais-, Reeseseses, Solisisis-,Does, Laisis-, Reeseses,Laisisis-, Mieseseses, Reeses, Siis-,Dois, Mieseses, Siisis-,Doisis, Faeseses, Mieses, Siisisis-,Doisisis, Faeses, Reis, Soleseseses,Faes, Reisis, Soleseses,Laeseseses, Miis, Reisisis, Soleses,Fais, Laeseses, Miisis,Faisis, Laeses, Miisisis, Sieseseses,Faisisis, Sieseses, Solis,Doeseses+, Sieses, Solisis,Doeses+, Lais, Reeseseses+, Solisisis,Does+, Laisis, Reeseses+,Laisisis, Mieseseses+, Reeses+, Siis,Dois+, Mieseses+, Siisis,Doisis+, Faeseses+, Mieses+, Siisisis,Doisisis+, Faeses+, Reis+, Soleseseses+,Faes+, Reisis+, Soleseses+,Laeseseses+, Miis+, Reisisis+, Soleses+,Fais+, Laeseses+, Miisis+,Faisis+, Laeses+, Miisisis+, Sieseseses+,Faisisis+, Sieseses+, Solis+,Doeseses+2, Sieses+, Solisis+,Doeses+2, Lais+, Reeseseses+2, Solisisis+,Does+2, Laisis+, Reeseses+2,Laisisis+, Mieseseses+2, Reeses+2, Siis+,Dois+2, Mieseses+2, Siisis+,Doisis+2, Faeseses+2, Mieses+2, Siisisis+,Doisisis+2, Faeses+2, Reis+2, Soleseseses+2,Faes+2, Reisis+2, Soleseses+2,Laeseseses+2, Miis+2, Reisisis+2, Soleses+2,Fais+2, Laeseses+2, Miisis+2,Faisis+2, Laeses+2, Miisisis+2, Sieseseses+2,Faisisis+2, Sieseses+2, Solis+2,Doeseses+3, Sieses+2, Solisis+2,Doeses+3, Lais+2, Reeseseses+3, Solisisis+2,Does+3, Laisis+2, Reeseses+3,Laisisis+2, Mieseseses+3, Reeses+3, Siis+2,Dois+3, Mieseses+3, Siisis+2,Doisis+3, Faeseses+3, Mieses+3, Siisisis+2,Doisisis+3, Faeses+3, Reis+3, Soleseseses+3,Faes+3, Reisis+3, Soleseses+3,Laeseseses+3, Miis+3, Reisisis+3, Soleses+3,Fais+3, Laeseses+3, Miisis+3,Faisis+3, Laeses+3, Miisisis+3, Sieseseses+3,Faisisis+3, Sieseses+3, Solis+3,Doeseses+4, Sieses+3, Solisis+3,Doeses+4, Lais+3, Reeseseses+4, Solisisis+3,Does+4, Laisis+3, Reeseses+4,Laisisis+3, Mieseseses+4, Reeses+4, Siis+3,Dois+4, Mieseses+4, Siisis+3,Doisis+4, Faeseses+4, Mieses+4, Siisisis+3,Doisisis+4, Faeses+4, Reis+4, Soleseseses+4,Faes+4, Reisis+4, Soleseses+4,Laeseseses+4, Miis+4, Reisisis+4, Soleses+4,Fais+4, Laeseses+4, Miisis+4,Faisis+4, Laeses+4, Miisisis+4, Sieseseses+4,Faisisis+4, Sieseses+4, Solis+4,Doeseses+5, Sieses+4, Solisis+4,Doeses+5, Lais+4, Reeseseses+5, Solisisis+4,Does+5, Laisis+4, Reeseses+5,Laisisis+4, Mieseseses+5, Reeses+5, Siis+4,Dois+5, Mieseses+5, Siisis+4,Doisis+5, Faeseses+5, Mieses+5, Siisisis+4,Doisisis+5, Faeses+5, Reis+5, Soleseseses+5,Faes+5, Reisis+5, Soleseses+5,Laeseseses+5, Miis+5, Reisisis+5, Soleses+5,Fais+5, Laeseses+5, Miisis+5,Faisis+5, Laeses+5, Miisisis+5, Sieseseses+5\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Laisisis------, Mieseseses-----, Reeses-----, Siis------,Dois-----, Mieseses-----, Siisis------,Doisis-----, Faeseses-----, Mieses-----, Siisisis------,Doisisis-----, Faeses-----, Reis-----, Soleseseses-----,Faes-----, Reisis-----, Soleseses-----,Laeseseses-----, Miis-----, Reisisis-----, Soleses-----,Fais-----, Laeseses-----, Miisis-----,Faisis-----, Laeses-----, Miisisis-----, Sieseseses-----,Faisisis-----, Sieseses-----, Solis-----,Doeseses----, Sieses-----, Solisis-----,Doeses----, Lais-----, Reeseseses----, Solisisis-----,Does----, Laisis-----, Reeseses----,Laisisis-----, Mieseseses----, Reeses----, Siis-----,Dois----, Mieseses----, Siisis-----,Doisis----, Faeseses----, Mieses----, Siisisis-----,Doisisis----, Faeses----, Reis----, Soleseseses----,Faes----, Reisis----, Soleseses----,Laeseseses----, Miis----, Reisisis----, Soleses----,Fais----, Laeseses----, Miisis----,Faisis----, Laeses----, Miisisis----, Sieseseses----,Faisisis----, Sieseses----, Solis----,Doeseses---, Sieses----, Solisis----,Doeses---, Lais----, Reeseseses---, Solisisis----,Does---, Laisis----, Reeseses---,Laisisis----, Mieseseses---, Reeses---, Siis----,Dois---, Mieseses---, Siisis----,Doisis---, Faeseses---, Mieses---, Siisisis----,Doisisis---, Faeses---, Reis---, Soleseseses---,Faes---, Reisis---, Soleseses---,Laeseseses---, Miis---, Reisisis---, Soleses---,Fais---, Laeseses---, Miisis---,Faisis---, Laeses---, Miisisis---, Sieseseses---,Faisisis---, Sieseses---, Solis---,Doeseses--, Sieses---, Solisis---,Doeses--, Lais---, Reeseseses--, Solisisis---,Does--, Laisis---, Reeseses--,Laisisis---, Mieseseses--, Reeses--, Siis---,Dois--, Mieseses--, Siisis---,Doisis--, Faeseses--, Mieses--, Siisisis---,Doisisis--, Faeses--, Reis--, Soleseseses--,Faes--, Reisis--, Soleseses--,Laeseseses--, Miis--, Reisisis--, Soleses--,Fais--, Laeseses--, Miisis--,Faisis--, Laeses--, Miisisis--, Sieseseses--,Faisisis--, Sieseses--, Solis--,Doeseses-, Sieses--, Solisis--,Doeses-, Lais--, Reeseseses-, Solisisis--,Does-, Laisis--, Reeseses-,Laisisis--, Mieseseses-, Reeses-, Siis--,Dois-, Mieseses-, Siisis--,Doisis-, Faeseses-, Mieses-, Siisisis--,Doisisis-, Faeses-, Reis-, Soleseseses-,Faes-, Reisis-, Soleseses-,Laeseseses-, Miis-, Reisisis-, Soleses-,Fais-, Laeseses-, Miisis-,Faisis-, Laeses-, Miisisis-, Sieseseses-,Faisisis-, Sieseses-, Solis-,Doeseses, Sieses-, Solisis-,Doeses, Lais-, Reeseseses, Solisisis-,Does, Laisis-, Reeseses,Laisisis-, Mieseseses, Reeses, Siis-,Dois, Mieseses, Siisis-,Doisis, Faeseses, Mieses, Siisisis-,Doisisis, Faeses, Reis, Soleseseses,Faes, Reisis, Soleseses,Laeseseses, Miis, Reisisis, Soleses,Fais, Laeseses, Miisis,Faisis, Laeses, Miisisis, Sieseseses,Faisisis, Sieseses, Solis,Doeseses+, Sieses, Solisis,Doeses+, Lais, Reeseseses+, Solisisis,Does+, Laisis, Reeseses+,Laisisis, Mieseseses+, Reeses+, Siis,Dois+, Mieseses+, Siisis,Doisis+, Faeseses+, Mieses+, Siisisis,Doisisis+, Faeses+, Reis+, Soleseseses+,Faes+, Reisis+, Soleseses+,Laeseseses+, Miis+, Reisisis+, Soleses+,Fais+, Laeseses+, Miisis+,Faisis+, Laeses+, Miisisis+, Sieseseses+,Faisisis+, Sieseses+, Solis+,Doeseses++, Sieses+, Solisis+,Doeses++, Lais+, Reeseseses++, Solisisis+,Does++, Laisis+, Reeseses++,Laisisis+, Mieseseses++, Reeses++, Siis+,Dois++, Mieseses++, Siisis+,Doisis++, Faeseses++, Mieses++, Siisisis+,Doisisis++, Faeses++, Reis++, Soleseseses++,Faes++, Reisis++, Soleseses++,Laeseseses++, Miis++, Reisisis++, Soleses++,Fais++, Laeseses++, Miisis++,Faisis++, Laeses++, Miisisis++, Sieseseses++,Faisisis++, Sieseses++, Solis++,Doeseses+++, Sieses++, Solisis++,Doeses+++, Lais++, Reeseseses+++, Solisisis++,Does+++, Laisis++, Reeseses+++,Laisisis++, Mieseseses+++, Reeses+++, Siis++,Dois+++, Mieseses+++, Siisis++,Doisis+++, Faeseses+++, Mieses+++, Siisisis++,Doisisis+++, Faeses+++, Reis+++, Soleseseses+++,Faes+++, Reisis+++, Soleseses+++,Laeseseses+++, Miis+++, Reisisis+++, Soleses+++,Fais+++, Laeseses+++, Miisis+++,Faisis+++, Laeses+++, Miisisis+++, Sieseseses+++,Faisisis+++, Sieseses+++, Solis+++,Doeseses++++, Sieses+++, Solisis+++,Doeses++++, Lais+++, Reeseseses++++, Solisisis+++,Does++++, Laisis+++, Reeseses++++,Laisisis+++, Mieseseses++++, Reeses++++, Siis+++,Dois++++, Mieseses++++, Siisis+++,Doisis++++, Faeseses++++, Mieses++++, Siisisis+++,Doisisis++++, Faeses++++, Reis++++, Soleseseses++++,Faes++++, Reisis++++, Soleseses++++,Laeseseses++++, Miis++++, Reisisis++++, Soleses++++,Fais++++, Laeseses++++, Miisis++++,Faisis++++, Laeses++++, Miisisis++++, Sieseseses++++,Faisisis++++, Sieseses++++, Solis++++,Doeseses+++++, Sieses++++, Solisis++++,Doeses+++++, Lais++++, Reeseseses+++++, Solisisis++++,Does+++++, Laisis++++, Reeseses+++++,Laisisis++++, Mieseseses+++++, Reeses+++++, Siis++++,Dois+++++, Mieseses+++++, Siisis++++,Doisis+++++, Faeseses+++++, Mieses+++++, Siisisis++++,Doisisis+++++, Faeses+++++, Reis+++++, Soleseseses+++++,Faes+++++, Reisis+++++, Soleseses+++++,Laeseseses+++++, Miis+++++, Reisisis+++++, Soleses+++++,Fais+++++, Laeseses+++++, Miisis+++++,Faisis+++++, Laeses+++++, Miisisis+++++, Sieseseses+++++\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Laisisis-2, Mieseseses-1, Reeses-1, Siis-2,Dois-1, Mieseses-1, Siisis-2,Doisis-1, Faeseses-1, Mieses-1, Siisisis-2,Doisisis-1, Faeses-1, Reis-1, Soleseseses-1,Faes-1, Reisis-1, Soleseses-1,Laeseseses-1, Miis-1, Reisisis-1, Soleses-1,Fais-1, Laeseses-1, Miisis-1,Faisis-1, Laeses-1, Miisisis-1, Sieseseses-1,Faisisis-1, Sieseses-1, Solis-1,Doeseses0, Sieses-1, Solisis-1,Doeses0, Lais-1, Reeseseses0, Solisisis-1,Does0, Laisis-1, Reeseses0,Laisisis-1, Mieseseses0, Reeses0, Siis-1,Dois0, Mieseses0, Siisis-1,Doisis0, Faeseses0, Mieses0, Siisisis-1,Doisisis0, Faeses0, Reis0, Soleseseses0,Faes0, Reisis0, Soleseses0,Laeseseses0, Miis0, Reisisis0, Soleses0,Fais0, Laeseses0, Miisis0,Faisis0, Laeses0, Miisisis0, Sieseseses0,Faisisis0, Sieseses0, Solis0,Doeseses1, Sieses0, Solisis0,Doeses1, Lais0, Reeseseses1, Solisisis0,Does1, Laisis0, Reeseses1,Laisisis0, Mieseseses1, Reeses1, Siis0,Dois1, Mieseses1, Siisis0,Doisis1, Faeseses1, Mieses1, Siisisis0,Doisisis1, Faeses1, Reis1, Soleseseses1,Faes1, Reisis1, Soleseses1,Laeseseses1, Miis1, Reisisis1, Soleses1,Fais1, Laeseses1, Miisis1,Faisis1, Laeses1, Miisisis1, Sieseseses1,Faisisis1, Sieseses1, Solis1,Doeseses2, Sieses1, Solisis1,Doeses2, Lais1, Reeseseses2, Solisisis1,Does2, Laisis1, Reeseses2,Laisisis1, Mieseseses2, Reeses2, Siis1,Dois2, Mieseses2, Siisis1,Doisis2, Faeseses2, Mieses2, Siisisis1,Doisisis2, Faeses2, Reis2, Soleseseses2,Faes2, Reisis2, Soleseses2,Laeseseses2, Miis2, Reisisis2, Soleses2,Fais2, Laeseses2, Miisis2,Faisis2, Laeses2, Miisisis2, Sieseseses2,Faisisis2, Sieseses2, Solis2,Doeseses3, Sieses2, Solisis2,Doeses3, Lais2, Reeseseses3, Solisisis2,Does3, Laisis2, Reeseses3,Laisisis2, Mieseseses3, Reeses3, Siis2,Dois3, Mieseses3, Siisis2,Doisis3, Faeseses3, Mieses3, Siisisis2,Doisisis3, Faeses3, Reis3, Soleseseses3,Faes3, Reisis3, Soleseses3,Laeseseses3, Miis3, Reisisis3, Soleses3,Fais3, Laeseses3, Miisis3,Faisis3, Laeses3, Miisisis3, Sieseseses3,Faisisis3, Sieseses3, Solis3,Doeseses4, Sieses3, Solisis3,Doeses4, Lais3, Reeseseses4, Solisisis3,Does4, Laisis3, Reeseses4,Laisisis3, Mieseseses4, Reeses4, Siis3,Dois4, Mieseses4, Siisis3,Doisis4, Faeseses4, Mieses4, Siisisis3,Doisisis4, Faeses4, Reis4, Soleseseses4,Faes4, Reisis4, Soleseses4,Laeseseses4, Miis4, Reisisis4, Soleses4,Fais4, Laeseses4, Miisis4,Faisis4, Laeses4, Miisisis4, Sieseseses4,Faisisis4, Sieseses4, Solis4,Doeseses5, Sieses4, Solisis4,Doeses5, Lais4, Reeseseses5, Solisisis4,Does5, Laisis4, Reeseses5,Laisisis4, Mieseseses5, Reeses5, Siis4,Dois5, Mieseses5, Siisis4,Doisis5, Faeseses5, Mieses5, Siisisis4,Doisisis5, Faeses5, Reis5, Soleseseses5,Faes5, Reisis5, Soleseses5,Laeseseses5, Miis5, Reisisis5, Soleses5,Fais5, Laeseses5, Miisis5,Faisis5, Laeses5, Miisisis5, Sieseseses5,Faisisis5, Sieseses5, Solis5,Doeseses6, Sieses5, Solisis5,Doeses6, Lais5, Reeseseses6, Solisisis5,Does6, Laisis5, Reeseses6,Laisisis5, Mieseseses6, Reeses6, Siis5,Dois6, Mieseses6, Siisis5,Doisis6, Faeseses6, Mieses6, Siisisis5,Doisisis6, Faeses6, Reis6, Soleseseses6,Faes6, Reisis6, Soleseses6,Laeseseses6, Miis6, Reisisis6, Soleses6,Fais6, Laeseses6, Miisis6,Faisis6, Laeses6, Miisisis6, Sieseseses6,Faisisis6, Sieseses6, Solis6,Doeseses7, Sieses6, Solisis6,Doeses7, Lais6, Reeseseses7, Solisisis6,Does7, Laisis6, Reeseses7,Laisisis6, Mieseseses7, Reeses7, Siis6,Dois7, Mieseses7, Siisis6,Doisis7, Faeseses7, Mieses7, Siisisis6,Doisisis7, Faeses7, Reis7, Soleseseses7,Faes7, Reisis7, Soleseses7,Laeseseses7, Miis7, Reisisis7, Soleses7,Fais7, Laeseses7, Miisis7,Faisis7, Laeses7, Miisisis7, Sieseseses7,Faisisis7, Sieseses7, Solis7,Doeseses8, Sieses7, Solisis7,Doeses8, Lais7, Reeseseses8, Solisisis7,Does8, Laisis7, Reeseses8,Laisisis7, Mieseseses8, Reeses8, Siis7,Dois8, Mieseses8, Siisis7,Doisis8, Faeseses8, Mieses8, Siisisis7,Doisisis8, Faeses8, Reis8, Soleseseses8,Faes8, Reisis8, Soleseses8,Laeseseses8, Miis8, Reisisis8, Soleses8,Fais8, Laeseses8, Miisis8,Faisis8, Laeses8, Miisisis8, Sieseseses8,Faisisis8, Sieseses8, Solis8,Doeseses9, Sieses8, Solisis8,Doeses9, Lais8, Reeseseses9, Solisisis8,Does9, Laisis8, Reeseses9,Laisisis8, Mieseseses9, Reeses9, Siis8,Dois9, Mieseses9, Siisis8,Doisis9, Faeseses9, Mieses9, Siisisis8,Doisisis9, Faeses9, Reis9, Soleseseses9,Faes9, Reisis9, Soleseses9,Laeseseses9, Miis9, Reisisis9, Soleses9,Fais9, Laeseses9, Miisis9,Faisis9, Laeses9, Miisisis9, Sieseseses9\n"
			+ "cbx_note_id_italian_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Laisisis'''', Mieseseses''', Reeses''', Siis'''',Dois''', Mieseses''', Siisis'''',Doisis''', Faeseses''', Mieses''', Siisisis'''',Doisisis''', Faeses''', Reis''', Soleseseses''',Faes''', Reisis''', Soleseses''',Laeseseses''', Miis''', Reisisis''', Soleses''',Fais''', Laeseses''', Miisis''',Faisis''', Laeses''', Miisisis''', Sieseseses''',Faisisis''', Sieseses''', Solis''',Doeseses'', Sieses''', Solisis''',Doeses'', Lais''', Reeseseses'', Solisisis''',Does'', Laisis''', Reeseses'',Laisisis''', Mieseseses'', Reeses'', Siis''',Dois'', Mieseses'', Siisis''',Doisis'', Faeseses'', Mieses'', Siisisis''',Doisisis'', Faeses'', Reis'', Soleseseses'',Faes'', Reisis'', Soleseses'',Laeseseses'', Miis'', Reisisis'', Soleses'',Fais'', Laeseses'', Miisis'',Faisis'', Laeses'', Miisisis'', Sieseseses'',Faisisis'', Sieseses'', Solis'',Doeseses', Sieses'', Solisis'',Doeses', Lais'', Reeseseses', Solisisis'',Does', Laisis'', Reeseses',Laisisis'', Mieseseses', Reeses', Siis'',Dois', Mieseses', Siisis'',Doisis', Faeseses', Mieses', Siisisis'',Doisisis', Faeses', Reis', Soleseseses',Faes', Reisis', Soleseses',Laeseseses', Miis', Reisisis', Soleses',Fais', Laeseses', Miisis',Faisis', Laeses', Miisisis', Sieseseses',Faisisis', Sieseses', Solis',Doeseses, Sieses', Solisis',Doeses, Lais', Reeseseses, Solisisis',Does, Laisis', Reeseses,Laisisis', Mieseseses, Reeses, Siis',Dois, Mieseses, Siisis',Doisis, Faeseses, Mieses, Siisisis',Doisisis, Faeses, Reis, Soleseseses,Faes, Reisis, Soleseses,Laeseseses, Miis, Reisisis, Soleses,Fais, Laeseses, Miisis,Faisis, Laeses, Miisisis, Sieseseses,Faisisis, Sieseses, Solis,Sieses, Solisis, doeseses,Lais, Solisisis, doeses, reeseseses,Laisis, does, reeseses,Laisisis, Siis, mieseseses, reeses,Siisis, dois, mieseses,Siisisis, doisis, faeseses, mieses,doisisis, faeses, reis, soleseseses,faes, reisis, soleseses,laeseseses, miis, reisisis, soleses,fais, laeseses, miisis,faisis, laeses, miisisis, sieseseses,faisisis, sieseses, solis,doeseses', sieses, solisis,doeses', lais, reeseseses', solisisis,does', laisis, reeseses',laisisis, mieseseses', reeses', siis,dois', mieseses', siisis,doisis', faeseses', mieses', siisisis,doisisis', faeses', reis', soleseseses',faes', reisis', soleseses',laeseseses', miis', reisisis', soleses',fais', laeseses', miisis',faisis', laeses', miisisis', sieseseses',faisisis', sieseses', solis',doeseses'', sieses', solisis',doeses'', lais', reeseseses'', solisisis',does'', laisis', reeseses'',laisisis', mieseseses'', reeses'', siis',dois'', mieseses'', siisis',doisis'', faeseses'', mieses'', siisisis',doisisis'', faeses'', reis'', soleseseses'',faes'', reisis'', soleseses'',laeseseses'', miis'', reisisis'', soleses'',fais'', laeseses'', miisis'',faisis'', laeses'', miisisis'', sieseseses'',faisisis'', sieseses'', solis'',doeseses''', sieses'', solisis'',doeses''', lais'', reeseseses''', solisisis'',does''', laisis'', reeseses''',laisisis'', mieseseses''', reeses''', siis'',dois''', mieseses''', siisis'',doisis''', faeseses''', mieses''', siisisis'',doisisis''', faeses''', reis''', soleseseses''',faes''', reisis''', soleseses''',laeseseses''', miis''', reisisis''', soleses''',fais''', laeseses''', miisis''',faisis''', laeses''', miisisis''', sieseseses''',faisisis''', sieseses''', solis''',doeseses'''', sieses''', solisis''',doeses'''', lais''', reeseseses'''', solisisis''',does'''', laisis''', reeseses'''',laisisis''', mieseseses'''', reeses'''', siis''',dois'''', mieseses'''', siisis''',doisis'''', faeseses'''', mieses'''', siisisis''',doisisis'''', faeses'''', reis'''', soleseseses'''',faes'''', reisis'''', soleseses'''',laeseseses'''', miis'''', reisisis'''', soleses'''',fais'''', laeseses'''', miisis'''',faisis'''', laeses'''', miisisis'''', sieseseses'''',faisisis'''', sieseses'''', solis'''',doeseses''''', sieses'''', solisis'''',doeses''''', lais'''', reeseseses''''', solisisis'''',does''''', laisis'''', reeseses''''',laisisis'''', mieseseses''''', reeses''''', siis'''',dois''''', mieseses''''', siisis'''',doisis''''', faeseses''''', mieses''''', siisisis'''',doisisis''''', faeses''''', reis''''', soleseseses''''',faes''''', reisis''''', soleseses''''',laeseseses''''', miis''''', reisisis''''', soleses''''',fais''''', laeseses''''', miisis''''',faisis''''', laeses''''', miisisis''''', sieseseses''''',faisisis''''', sieseses''''', solis''''',doeseses'''''', sieses''''', solisis''''',doeses'''''', lais''''', reeseseses'''''', solisisis''''',does'''''', laisis''''', reeseses'''''',laisisis''''', mieseseses'''''', reeses'''''', siis''''',dois'''''', mieseses'''''', siisis''''',doisis'''''', faeseses'''''', mieses'''''', siisisis''''',doisisis'''''', faeses'''''', reis'''''', soleseseses'''''',faes'''''', reisis'''''', soleseses'''''',laeseseses'''''', miis'''''', reisisis'''''', soleses'''''',fais'''''', laeseses'''''', miisis'''''',faisis'''''', laeses'''''', miisisis'''''', sieseseses''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "a###-6, b##-6, dbb-5, h#-6,b###-6, db-5, ebbb-5, h##-6,c##-5, ebb-5, fbbb-5, h###-6,c###-5, eb-5, fbb-5,c####-5, d##-5, fb-5, gbbb-5,d###-5, e#-5, gbb-5,abbb-5, d####-5, e##-5, gb-5,abb-5, bbbb-5, e###-5, f##-5,ab-5, bbb-5, f###-5,bb-5, cbbb-4, f####-5, g##-5,a#-5, cbb-4, g###-5,a##-5, b#-5, cb-4, dbbb-4, g####-5,a###-5, b##-5, dbb-4, h#-5,b###-5, db-4, ebbb-4, h##-5,c##-4, ebb-4, fbbb-4, h###-5,c###-4, eb-4, fbb-4,c####-4, d##-4, fb-4, gbbb-4,d###-4, e#-4, gbb-4,abbb-4, d####-4, e##-4, gb-4,abb-4, bbbb-4, e###-4, f##-4,ab-4, bbb-4, f###-4,bb-4, cbbb-3, f####-4, g##-4,a#-4, cbb-3, g###-4,a##-4, b#-4, cb-3, dbbb-3, g####-4,a###-4, b##-4, dbb-3, h#-4,b###-4, db-3, ebbb-3, h##-4,c##-3, ebb-3, fbbb-3, h###-4,c###-3, eb-3, fbb-3,c####-3, d##-3, fb-3, gbbb-3,d###-3, e#-3, gbb-3,abbb-3, d####-3, e##-3, gb-3,abb-3, bbbb-3, e###-3, f##-3,ab-3, bbb-3, f###-3,bb-3, cbbb-2, f####-3, g##-3,a#-3, cbb-2, g###-3,a##-3, b#-3, cb-2, dbbb-2, g####-3,a###-3, b##-3, dbb-2, h#-3,b###-3, db-2, ebbb-2, h##-3,c##-2, ebb-2, fbbb-2, h###-3,c###-2, eb-2, fbb-2,c####-2, d##-2, fb-2, gbbb-2,d###-2, e#-2, gbb-2,abbb-2, d####-2, e##-2, gb-2,abb-2, bbbb-2, e###-2, f##-2,ab-2, bbb-2, f###-2,bb-2, cbbb-, f####-2, g##-2,a#-2, cbb-, g###-2,a##-2, b#-2, cb-, dbbb-, g####-2,a###-2, b##-2, dbb-, h#-2,b###-2, db-, ebbb-, h##-2,c##-, ebb-, fbbb-, h###-2,c###-, eb-, fbb-,c####-, d##-, fb-, gbbb-,d###-, e#-, gbb-,abbb-, d####-, e##-, gb-,abb-, bbbb-, e###-, f##-,ab-, bbb-, f###-,bb-, cbbb, f####-, g##-,a#-, cbb, g###-,a##-, b#-, cb, dbbb, g####-,a###-, b##-, dbb, h#-,b###-, db, ebbb, h##-,c##, ebb, fbbb, h###-,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, bbbb, e###, f##,ab, bbb, f###,bb, cbbb+, f####, g##,a#, cbb+, g###,a##, b#, cb+, dbbb+, g####,a###, b##, dbb+, h#,b###, db+, ebbb+, h##,c##+, ebb+, fbbb+, h###,c###+, eb+, fbb+,c####+, d##+, fb+, gbbb+,d###+, e#+, gbb+,abbb+, d####+, e##+, gb+,abb+, bbbb+, e###+, f##+,ab+, bbb+, f###+,bb+, cbbb+2, f####+, g##+,a#+, cbb+2, g###+,a##+, b#+, cb+2, dbbb+2, g####+,a###+, b##+, dbb+2, h#+,b###+, db+2, ebbb+2, h##+,c##+2, ebb+2, fbbb+2, h###+,c###+2, eb+2, fbb+2,c####+2, d##+2, fb+2, gbbb+2,d###+2, e#+2, gbb+2,abbb+2, d####+2, e##+2, gb+2,abb+2, bbbb+2, e###+2, f##+2,ab+2, bbb+2, f###+2,bb+2, cbbb+3, f####+2, g##+2,a#+2, cbb+3, g###+2,a##+2, b#+2, cb+3, dbbb+3, g####+2,a###+2, b##+2, dbb+3, h#+2,b###+2, db+3, ebbb+3, h##+2,c##+3, ebb+3, fbbb+3, h###+2,c###+3, eb+3, fbb+3,c####+3, d##+3, fb+3, gbbb+3,d###+3, e#+3, gbb+3,abbb+3, d####+3, e##+3, gb+3,abb+3, bbbb+3, e###+3, f##+3,ab+3, bbb+3, f###+3,bb+3, cbbb+4, f####+3, g##+3,a#+3, cbb+4, g###+3,a##+3, b#+3, cb+4, dbbb+4, g####+3,a###+3, b##+3, dbb+4, h#+3,b###+3, db+4, ebbb+4, h##+3,c##+4, ebb+4, fbbb+4, h###+3,c###+4, eb+4, fbb+4,c####+4, d##+4, fb+4, gbbb+4,d###+4, e#+4, gbb+4,abbb+4, d####+4, e##+4, gb+4,abb+4, bbbb+4, e###+4, f##+4,ab+4, bbb+4, f###+4,bb+4, cbbb+5, f####+4, g##+4,a#+4, cbb+5, g###+4,a##+4, b#+4, cb+5, dbbb+5, g####+4,a###+4, b##+4, dbb+5, h#+4,b###+4, db+5, ebbb+5, h##+4,c##+5, ebb+5, fbbb+5, h###+4,c###+5, eb+5, fbb+5,c####+5, d##+5, fb+5, gbbb+5,d###+5, e#+5, gbb+5,abbb+5, d####+5, e##+5, gb+5,abb+5, bbbb+5, e###+5, f##+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "a###------, b##------, dbb-----, h#------,b###------, db-----, ebbb-----, h##------,c##-----, ebb-----, fbbb-----, h###------,c###-----, eb-----, fbb-----,c####-----, d##-----, fb-----, gbbb-----,d###-----, e#-----, gbb-----,abbb-----, d####-----, e##-----, gb-----,abb-----, bbbb-----, e###-----, f##-----,ab-----, bbb-----, f###-----,bb-----, cbbb----, f####-----, g##-----,a#-----, cbb----, g###-----,a##-----, b#-----, cb----, dbbb----, g####-----,a###-----, b##-----, dbb----, h#-----,b###-----, db----, ebbb----, h##-----,c##----, ebb----, fbbb----, h###-----,c###----, eb----, fbb----,c####----, d##----, fb----, gbbb----,d###----, e#----, gbb----,abbb----, d####----, e##----, gb----,abb----, bbbb----, e###----, f##----,ab----, bbb----, f###----,bb----, cbbb---, f####----, g##----,a#----, cbb---, g###----,a##----, b#----, cb---, dbbb---, g####----,a###----, b##----, dbb---, h#----,b###----, db---, ebbb---, h##----,c##---, ebb---, fbbb---, h###----,c###---, eb---, fbb---,c####---, d##---, fb---, gbbb---,d###---, e#---, gbb---,abbb---, d####---, e##---, gb---,abb---, bbbb---, e###---, f##---,ab---, bbb---, f###---,bb---, cbbb--, f####---, g##---,a#---, cbb--, g###---,a##---, b#---, cb--, dbbb--, g####---,a###---, b##---, dbb--, h#---,b###---, db--, ebbb--, h##---,c##--, ebb--, fbbb--, h###---,c###--, eb--, fbb--,c####--, d##--, fb--, gbbb--,d###--, e#--, gbb--,abbb--, d####--, e##--, gb--,abb--, bbbb--, e###--, f##--,ab--, bbb--, f###--,bb--, cbbb-, f####--, g##--,a#--, cbb-, g###--,a##--, b#--, cb-, dbbb-, g####--,a###--, b##--, dbb-, h#--,b###--, db-, ebbb-, h##--,c##-, ebb-, fbbb-, h###--,c###-, eb-, fbb-,c####-, d##-, fb-, gbbb-,d###-, e#-, gbb-,abbb-, d####-, e##-, gb-,abb-, bbbb-, e###-, f##-,ab-, bbb-, f###-,bb-, cbbb, f####-, g##-,a#-, cbb, g###-,a##-, b#-, cb, dbbb, g####-,a###-, b##-, dbb, h#-,b###-, db, ebbb, h##-,c##, ebb, fbbb, h###-,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, bbbb, e###, f##,ab, bbb, f###,bb, cbbb+, f####, g##,a#, cbb+, g###,a##, b#, cb+, dbbb+, g####,a###, b##, dbb+, h#,b###, db+, ebbb+, h##,c##+, ebb+, fbbb+, h###,c###+, eb+, fbb+,c####+, d##+, fb+, gbbb+,d###+, e#+, gbb+,abbb+, d####+, e##+, gb+,abb+, bbbb+, e###+, f##+,ab+, bbb+, f###+,bb+, cbbb++, f####+, g##+,a#+, cbb++, g###+,a##+, b#+, cb++, dbbb++, g####+,a###+, b##+, dbb++, h#+,b###+, db++, ebbb++, h##+,c##++, ebb++, fbbb++, h###+,c###++, eb++, fbb++,c####++, d##++, fb++, gbbb++,d###++, e#++, gbb++,abbb++, d####++, e##++, gb++,abb++, bbbb++, e###++, f##++,ab++, bbb++, f###++,bb++, cbbb+++, f####++, g##++,a#++, cbb+++, g###++,a##++, b#++, cb+++, dbbb+++, g####++,a###++, b##++, dbb+++, h#++,b###++, db+++, ebbb+++, h##++,c##+++, ebb+++, fbbb+++, h###++,c###+++, eb+++, fbb+++,c####+++, d##+++, fb+++, gbbb+++,d###+++, e#+++, gbb+++,abbb+++, d####+++, e##+++, gb+++,abb+++, bbbb+++, e###+++, f##+++,ab+++, bbb+++, f###+++,bb+++, cbbb++++, f####+++, g##+++,a#+++, cbb++++, g###+++,a##+++, b#+++, cb++++, dbbb++++, g####+++,a###+++, b##+++, dbb++++, h#+++,b###+++, db++++, ebbb++++, h##+++,c##++++, ebb++++, fbbb++++, h###+++,c###++++, eb++++, fbb++++,c####++++, d##++++, fb++++, gbbb++++,d###++++, e#++++, gbb++++,abbb++++, d####++++, e##++++, gb++++,abb++++, bbbb++++, e###++++, f##++++,ab++++, bbb++++, f###++++,bb++++, cbbb+++++, f####++++, g##++++,a#++++, cbb+++++, g###++++,a##++++, b#++++, cb+++++, dbbb+++++, g####++++,a###++++, b##++++, dbb+++++, h#++++,b###++++, db+++++, ebbb+++++, h##++++,c##+++++, ebb+++++, fbbb+++++, h###++++,c###+++++, eb+++++, fbb+++++,c####+++++, d##+++++, fb+++++, gbbb+++++,d###+++++, e#+++++, gbb+++++,abbb+++++, d####+++++, e##+++++, gb+++++,abb+++++, bbbb+++++, e###+++++, f##+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "a###-2, b##-2, dbb-1, h#-2,b###-2, db-1, ebbb-1, h##-2,c##-1, ebb-1, fbbb-1, h###-2,c###-1, eb-1, fbb-1,c####-1, d##-1, fb-1, gbbb-1,d###-1, e#-1, gbb-1,abbb-1, d####-1, e##-1, gb-1,abb-1, bbbb-1, e###-1, f##-1,ab-1, bbb-1, f###-1,bb-1, cbbb0, f####-1, g##-1,a#-1, cbb0, g###-1,a##-1, b#-1, cb0, dbbb0, g####-1,a###-1, b##-1, dbb0, h#-1,b###-1, db0, ebbb0, h##-1,c##0, ebb0, fbbb0, h###-1,c###0, eb0, fbb0,c####0, d##0, fb0, gbbb0,d###0, e#0, gbb0,abbb0, d####0, e##0, gb0,abb0, bbbb0, e###0, f##0,ab0, bbb0, f###0,bb0, cbbb1, f####0, g##0,a#0, cbb1, g###0,a##0, b#0, cb1, dbbb1, g####0,a###0, b##0, dbb1, h#0,b###0, db1, ebbb1, h##0,c##1, ebb1, fbbb1, h###0,c###1, eb1, fbb1,c####1, d##1, fb1, gbbb1,d###1, e#1, gbb1,abbb1, d####1, e##1, gb1,abb1, bbbb1, e###1, f##1,ab1, bbb1, f###1,bb1, cbbb2, f####1, g##1,a#1, cbb2, g###1,a##1, b#1, cb2, dbbb2, g####1,a###1, b##1, dbb2, h#1,b###1, db2, ebbb2, h##1,c##2, ebb2, fbbb2, h###1,c###2, eb2, fbb2,c####2, d##2, fb2, gbbb2,d###2, e#2, gbb2,abbb2, d####2, e##2, gb2,abb2, bbbb2, e###2, f##2,ab2, bbb2, f###2,bb2, cbbb3, f####2, g##2,a#2, cbb3, g###2,a##2, b#2, cb3, dbbb3, g####2,a###2, b##2, dbb3, h#2,b###2, db3, ebbb3, h##2,c##3, ebb3, fbbb3, h###2,c###3, eb3, fbb3,c####3, d##3, fb3, gbbb3,d###3, e#3, gbb3,abbb3, d####3, e##3, gb3,abb3, bbbb3, e###3, f##3,ab3, bbb3, f###3,bb3, cbbb4, f####3, g##3,a#3, cbb4, g###3,a##3, b#3, cb4, dbbb4, g####3,a###3, b##3, dbb4, h#3,b###3, db4, ebbb4, h##3,c##4, ebb4, fbbb4, h###3,c###4, eb4, fbb4,c####4, d##4, fb4, gbbb4,d###4, e#4, gbb4,abbb4, d####4, e##4, gb4,abb4, bbbb4, e###4, f##4,ab4, bbb4, f###4,bb4, cbbb5, f####4, g##4,a#4, cbb5, g###4,a##4, b#4, cb5, dbbb5, g####4,a###4, b##4, dbb5, h#4,b###4, db5, ebbb5, h##4,c##5, ebb5, fbbb5, h###4,c###5, eb5, fbb5,c####5, d##5, fb5, gbbb5,d###5, e#5, gbb5,abbb5, d####5, e##5, gb5,abb5, bbbb5, e###5, f##5,ab5, bbb5, f###5,bb5, cbbb6, f####5, g##5,a#5, cbb6, g###5,a##5, b#5, cb6, dbbb6, g####5,a###5, b##5, dbb6, h#5,b###5, db6, ebbb6, h##5,c##6, ebb6, fbbb6, h###5,c###6, eb6, fbb6,c####6, d##6, fb6, gbbb6,d###6, e#6, gbb6,abbb6, d####6, e##6, gb6,abb6, bbbb6, e###6, f##6,ab6, bbb6, f###6,bb6, cbbb7, f####6, g##6,a#6, cbb7, g###6,a##6, b#6, cb7, dbbb7, g####6,a###6, b##6, dbb7, h#6,b###6, db7, ebbb7, h##6,c##7, ebb7, fbbb7, h###6,c###7, eb7, fbb7,c####7, d##7, fb7, gbbb7,d###7, e#7, gbb7,abbb7, d####7, e##7, gb7,abb7, bbbb7, e###7, f##7,ab7, bbb7, f###7,bb7, cbbb8, f####7, g##7,a#7, cbb8, g###7,a##7, b#7, cb8, dbbb8, g####7,a###7, b##7, dbb8, h#7,b###7, db8, ebbb8, h##7,c##8, ebb8, fbbb8, h###7,c###8, eb8, fbb8,c####8, d##8, fb8, gbbb8,d###8, e#8, gbb8,abbb8, d####8, e##8, gb8,abb8, bbbb8, e###8, f##8,ab8, bbb8, f###8,bb8, cbbb9, f####8, g##8,a#8, cbb9, g###8,a##8, b#8, cb9, dbbb9, g####8,a###8, b##8, dbb9, h#8,b###8, db9, ebbb9, h##8,c##9, ebb9, fbbb9, h###8,c###9, eb9, fbb9,c####9, d##9, fb9, gbbb9,d###9, e#9, gbb9,abbb9, d####9, e##9, gb9,abb9, bbbb9, e###9, f##9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A###'''', B##'''', Dbb''', H#'''',B###'''', Db''', Ebbb''', H##'''',C##''', Ebb''', Fbbb''', H###'''',C###''', Eb''', Fbb''',C####''', D##''', Fb''', Gbbb''',D###''', E#''', Gbb''',Abbb''', D####''', E##''', Gb''',Abb''', Bbbb''', E###''', F##''',Ab''', Bbb''', F###''',Bb''', Cbbb'', F####''', G##''',A#''', Cbb'', G###''',A##''', B#''', Cb'', Dbbb'', G####''',A###''', B##''', Dbb'', H#''',B###''', Db'', Ebbb'', H##''',C##'', Ebb'', Fbbb'', H###''',C###'', Eb'', Fbb'',C####'', D##'', Fb'', Gbbb'',D###'', E#'', Gbb'',Abbb'', D####'', E##'', Gb'',Abb'', Bbbb'', E###'', F##'',Ab'', Bbb'', F###'',Bb'', Cbbb', F####'', G##'',A#'', Cbb', G###'',A##'', B#'', Cb', Dbbb', G####'',A###'', B##'', Dbb', H#'',B###'', Db', Ebbb', H##'',C##', Ebb', Fbbb', H###'',C###', Eb', Fbb',C####', D##', Fb', Gbbb',D###', E#', Gbb',Abbb', D####', E##', Gb',Abb', Bbbb', E###', F##',Ab', Bbb', F###',Bb', Cbbb, F####', G##',A#', Cbb, G###',A##', B#', Cb, Dbbb, G####',A###', B##', Dbb, H#',B###', Db, Ebbb, H##',C##, Ebb, Fbbb, H###',C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, Bbbb, E###, F##,Ab, Bbb, F###,Bb, F####, G##, cbbb,A#, G###, cbb,A##, B#, G####, cb, dbbb,A###, B##, H#, dbb,B###, H##, db, ebbb,H###, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, bbbb, e###, f##,ab, bbb, f###,bb, cbbb', f####, g##,a#, cbb', g###,a##, b#, cb', dbbb', g####,a###, b##, dbb', h#,b###, db', ebbb', h##,c##', ebb', fbbb', h###,c###', eb', fbb',c####', d##', fb', gbbb',d###', e#', gbb',abbb', d####', e##', gb',abb', bbbb', e###', f##',ab', bbb', f###',bb', cbbb'', f####', g##',a#', cbb'', g###',a##', b#', cb'', dbbb'', g####',a###', b##', dbb'', h#',b###', db'', ebbb'', h##',c##'', ebb'', fbbb'', h###',c###'', eb'', fbb'',c####'', d##'', fb'', gbbb'',d###'', e#'', gbb'',abbb'', d####'', e##'', gb'',abb'', bbbb'', e###'', f##'',ab'', bbb'', f###'',bb'', cbbb''', f####'', g##'',a#'', cbb''', g###'',a##'', b#'', cb''', dbbb''', g####'',a###'', b##'', dbb''', h#'',b###'', db''', ebbb''', h##'',c##''', ebb''', fbbb''', h###'',c###''', eb''', fbb''',c####''', d##''', fb''', gbbb''',d###''', e#''', gbb''',abbb''', d####''', e##''', gb''',abb''', bbbb''', e###''', f##''',ab''', bbb''', f###''',bb''', cbbb'''', f####''', g##''',a#''', cbb'''', g###''',a##''', b#''', cb'''', dbbb'''', g####''',a###''', b##''', dbb'''', h#''',b###''', db'''', ebbb'''', h##''',c##'''', ebb'''', fbbb'''', h###''',c###'''', eb'''', fbb'''',c####'''', d##'''', fb'''', gbbb'''',d###'''', e#'''', gbb'''',abbb'''', d####'''', e##'''', gb'''',abb'''', bbbb'''', e###'''', f##'''',ab'''', bbb'''', f###'''',bb'''', cbbb''''', f####'''', g##'''',a#'''', cbb''''', g###'''',a##'''', b#'''', cb''''', dbbb''''', g####'''',a###'''', b##'''', dbb''''', h#'''',b###'''', db''''', ebbb''''', h##'''',c##''''', ebb''''', fbbb''''', h###'''',c###''''', eb''''', fbb''''',c####''''', d##''''', fb''''', gbbb''''',d###''''', e#''''', gbb''''',abbb''''', d####''''', e##''''', gb''''',abb''''', bbbb''''', e###''''', f##''''',ab''''', bbb''''', f###''''',bb''''', cbbb'''''', f####''''', g##''''',a#''''', cbb'''''', g###''''',a##''''', b#''''', cb'''''', dbbb'''''', g####''''',a###''''', b##''''', dbb'''''', h#''''',b###''''', db'''''', ebbb'''''', h##''''',c##'''''', ebb'''''', fbbb'''''', h###''''',c###'''''', eb'''''', fbb'''''',c####'''''', d##'''''', fb'''''', gbbb'''''',d###'''''', e#'''''', gbb'''''',abbb'''''', d####'''''', e##'''''', gb'''''',abb'''''', bbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "a###-6, b##-6, dbb-5, ebbbb-5, h#-6,b###-6, c#-5, ebbb-5, h##-6,c##-5, ebb-5, fbbb-5, h###-6,c###-5, d#-5, fbb-5, gbbbb-5,d##-5, fb-5, gbbb-5,abbbb-5, d###-5, e#-5, gbb-5,abbb-5, e##-5, f#-5,abb-5, bbbb-5, e###-5, f##-5,bbb-5, f###-5, g#-5,bb-5, cbbb-4, g##-5,a#-5, cbb-4, dbbbb-4, g###-5,a##-5, b#-5, cb-4, dbbb-4,a###-5, b##-5, dbb-4, ebbbb-4, h#-5,b###-5, c#-4, ebbb-4, h##-5,c##-4, ebb-4, fbbb-4, h###-5,c###-4, d#-4, fbb-4, gbbbb-4,d##-4, fb-4, gbbb-4,abbbb-4, d###-4, e#-4, gbb-4,abbb-4, e##-4, f#-4,abb-4, bbbb-4, e###-4, f##-4,bbb-4, f###-4, g#-4,bb-4, cbbb-3, g##-4,a#-4, cbb-3, dbbbb-3, g###-4,a##-4, b#-4, cb-3, dbbb-3,a###-4, b##-4, dbb-3, ebbbb-3, h#-4,b###-4, c#-3, ebbb-3, h##-4,c##-3, ebb-3, fbbb-3, h###-4,c###-3, d#-3, fbb-3, gbbbb-3,d##-3, fb-3, gbbb-3,abbbb-3, d###-3, e#-3, gbb-3,abbb-3, e##-3, f#-3,abb-3, bbbb-3, e###-3, f##-3,bbb-3, f###-3, g#-3,bb-3, cbbb-2, g##-3,a#-3, cbb-2, dbbbb-2, g###-3,a##-3, b#-3, cb-2, dbbb-2,a###-3, b##-3, dbb-2, ebbbb-2, h#-3,b###-3, c#-2, ebbb-2, h##-3,c##-2, ebb-2, fbbb-2, h###-3,c###-2, d#-2, fbb-2, gbbbb-2,d##-2, fb-2, gbbb-2,abbbb-2, d###-2, e#-2, gbb-2,abbb-2, e##-2, f#-2,abb-2, bbbb-2, e###-2, f##-2,bbb-2, f###-2, g#-2,bb-2, cbbb-, g##-2,a#-2, cbb-, dbbbb-, g###-2,a##-2, b#-2, cb-, dbbb-,a###-2, b##-2, dbb-, ebbbb-, h#-2,b###-2, c#-, ebbb-, h##-2,c##-, ebb-, fbbb-, h###-2,c###-, d#-, fbb-, gbbbb-,d##-, fb-, gbbb-,abbbb-, d###-, e#-, gbb-,abbb-, e##-, f#-,abb-, bbbb-, e###-, f##-,bbb-, f###-, g#-,bb-, cbbb, g##-,a#-, cbb, dbbbb, g###-,a##-, b#-, cb, dbbb,a###-, b##-, dbb, ebbbb, h#-,b###-, c#, ebbb, h##-,c##, ebb, fbbb, h###-,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbb, e###, f##,bbb, f###, g#,bb, cbbb+, g##,a#, cbb+, dbbbb+, g###,a##, b#, cb+, dbbb+,a###, b##, dbb+, ebbbb+, h#,b###, c#+, ebbb+, h##,c##+, ebb+, fbbb+, h###,c###+, d#+, fbb+, gbbbb+,d##+, fb+, gbbb+,abbbb+, d###+, e#+, gbb+,abbb+, e##+, f#+,abb+, bbbb+, e###+, f##+,bbb+, f###+, g#+,bb+, cbbb+2, g##+,a#+, cbb+2, dbbbb+2, g###+,a##+, b#+, cb+2, dbbb+2,a###+, b##+, dbb+2, ebbbb+2, h#+,b###+, c#+2, ebbb+2, h##+,c##+2, ebb+2, fbbb+2, h###+,c###+2, d#+2, fbb+2, gbbbb+2,d##+2, fb+2, gbbb+2,abbbb+2, d###+2, e#+2, gbb+2,abbb+2, e##+2, f#+2,abb+2, bbbb+2, e###+2, f##+2,bbb+2, f###+2, g#+2,bb+2, cbbb+3, g##+2,a#+2, cbb+3, dbbbb+3, g###+2,a##+2, b#+2, cb+3, dbbb+3,a###+2, b##+2, dbb+3, ebbbb+3, h#+2,b###+2, c#+3, ebbb+3, h##+2,c##+3, ebb+3, fbbb+3, h###+2,c###+3, d#+3, fbb+3, gbbbb+3,d##+3, fb+3, gbbb+3,abbbb+3, d###+3, e#+3, gbb+3,abbb+3, e##+3, f#+3,abb+3, bbbb+3, e###+3, f##+3,bbb+3, f###+3, g#+3,bb+3, cbbb+4, g##+3,a#+3, cbb+4, dbbbb+4, g###+3,a##+3, b#+3, cb+4, dbbb+4,a###+3, b##+3, dbb+4, ebbbb+4, h#+3,b###+3, c#+4, ebbb+4, h##+3,c##+4, ebb+4, fbbb+4, h###+3,c###+4, d#+4, fbb+4, gbbbb+4,d##+4, fb+4, gbbb+4,abbbb+4, d###+4, e#+4, gbb+4,abbb+4, e##+4, f#+4,abb+4, bbbb+4, e###+4, f##+4,bbb+4, f###+4, g#+4,bb+4, cbbb+5, g##+4,a#+4, cbb+5, dbbbb+5, g###+4,a##+4, b#+4, cb+5, dbbb+5,a###+4, b##+4, dbb+5, ebbbb+5, h#+4,b###+4, c#+5, ebbb+5, h##+4,c##+5, ebb+5, fbbb+5, h###+4,c###+5, d#+5, fbb+5, gbbbb+5,d##+5, fb+5, gbbb+5,abbbb+5, d###+5, e#+5, gbb+5,abbb+5, e##+5, f#+5,abb+5, bbbb+5, e###+5, f##+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "a###------, b##------, dbb-----, ebbbb-----, h#------,b###------, c#-----, ebbb-----, h##------,c##-----, ebb-----, fbbb-----, h###------,c###-----, d#-----, fbb-----, gbbbb-----,d##-----, fb-----, gbbb-----,abbbb-----, d###-----, e#-----, gbb-----,abbb-----, e##-----, f#-----,abb-----, bbbb-----, e###-----, f##-----,bbb-----, f###-----, g#-----,bb-----, cbbb----, g##-----,a#-----, cbb----, dbbbb----, g###-----,a##-----, b#-----, cb----, dbbb----,a###-----, b##-----, dbb----, ebbbb----, h#-----,b###-----, c#----, ebbb----, h##-----,c##----, ebb----, fbbb----, h###-----,c###----, d#----, fbb----, gbbbb----,d##----, fb----, gbbb----,abbbb----, d###----, e#----, gbb----,abbb----, e##----, f#----,abb----, bbbb----, e###----, f##----,bbb----, f###----, g#----,bb----, cbbb---, g##----,a#----, cbb---, dbbbb---, g###----,a##----, b#----, cb---, dbbb---,a###----, b##----, dbb---, ebbbb---, h#----,b###----, c#---, ebbb---, h##----,c##---, ebb---, fbbb---, h###----,c###---, d#---, fbb---, gbbbb---,d##---, fb---, gbbb---,abbbb---, d###---, e#---, gbb---,abbb---, e##---, f#---,abb---, bbbb---, e###---, f##---,bbb---, f###---, g#---,bb---, cbbb--, g##---,a#---, cbb--, dbbbb--, g###---,a##---, b#---, cb--, dbbb--,a###---, b##---, dbb--, ebbbb--, h#---,b###---, c#--, ebbb--, h##---,c##--, ebb--, fbbb--, h###---,c###--, d#--, fbb--, gbbbb--,d##--, fb--, gbbb--,abbbb--, d###--, e#--, gbb--,abbb--, e##--, f#--,abb--, bbbb--, e###--, f##--,bbb--, f###--, g#--,bb--, cbbb-, g##--,a#--, cbb-, dbbbb-, g###--,a##--, b#--, cb-, dbbb-,a###--, b##--, dbb-, ebbbb-, h#--,b###--, c#-, ebbb-, h##--,c##-, ebb-, fbbb-, h###--,c###-, d#-, fbb-, gbbbb-,d##-, fb-, gbbb-,abbbb-, d###-, e#-, gbb-,abbb-, e##-, f#-,abb-, bbbb-, e###-, f##-,bbb-, f###-, g#-,bb-, cbbb, g##-,a#-, cbb, dbbbb, g###-,a##-, b#-, cb, dbbb,a###-, b##-, dbb, ebbbb, h#-,b###-, c#, ebbb, h##-,c##, ebb, fbbb, h###-,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbb, e###, f##,bbb, f###, g#,bb, cbbb+, g##,a#, cbb+, dbbbb+, g###,a##, b#, cb+, dbbb+,a###, b##, dbb+, ebbbb+, h#,b###, c#+, ebbb+, h##,c##+, ebb+, fbbb+, h###,c###+, d#+, fbb+, gbbbb+,d##+, fb+, gbbb+,abbbb+, d###+, e#+, gbb+,abbb+, e##+, f#+,abb+, bbbb+, e###+, f##+,bbb+, f###+, g#+,bb+, cbbb++, g##+,a#+, cbb++, dbbbb++, g###+,a##+, b#+, cb++, dbbb++,a###+, b##+, dbb++, ebbbb++, h#+,b###+, c#++, ebbb++, h##+,c##++, ebb++, fbbb++, h###+,c###++, d#++, fbb++, gbbbb++,d##++, fb++, gbbb++,abbbb++, d###++, e#++, gbb++,abbb++, e##++, f#++,abb++, bbbb++, e###++, f##++,bbb++, f###++, g#++,bb++, cbbb+++, g##++,a#++, cbb+++, dbbbb+++, g###++,a##++, b#++, cb+++, dbbb+++,a###++, b##++, dbb+++, ebbbb+++, h#++,b###++, c#+++, ebbb+++, h##++,c##+++, ebb+++, fbbb+++, h###++,c###+++, d#+++, fbb+++, gbbbb+++,d##+++, fb+++, gbbb+++,abbbb+++, d###+++, e#+++, gbb+++,abbb+++, e##+++, f#+++,abb+++, bbbb+++, e###+++, f##+++,bbb+++, f###+++, g#+++,bb+++, cbbb++++, g##+++,a#+++, cbb++++, dbbbb++++, g###+++,a##+++, b#+++, cb++++, dbbb++++,a###+++, b##+++, dbb++++, ebbbb++++, h#+++,b###+++, c#++++, ebbb++++, h##+++,c##++++, ebb++++, fbbb++++, h###+++,c###++++, d#++++, fbb++++, gbbbb++++,d##++++, fb++++, gbbb++++,abbbb++++, d###++++, e#++++, gbb++++,abbb++++, e##++++, f#++++,abb++++, bbbb++++, e###++++, f##++++,bbb++++, f###++++, g#++++,bb++++, cbbb+++++, g##++++,a#++++, cbb+++++, dbbbb+++++, g###++++,a##++++, b#++++, cb+++++, dbbb+++++,a###++++, b##++++, dbb+++++, ebbbb+++++, h#++++,b###++++, c#+++++, ebbb+++++, h##++++,c##+++++, ebb+++++, fbbb+++++, h###++++,c###+++++, d#+++++, fbb+++++, gbbbb+++++,d##+++++, fb+++++, gbbb+++++,abbbb+++++, d###+++++, e#+++++, gbb+++++,abbb+++++, e##+++++, f#+++++,abb+++++, bbbb+++++, e###+++++, f##+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "a###-2, b##-2, dbb-1, ebbbb-1, h#-2,b###-2, c#-1, ebbb-1, h##-2,c##-1, ebb-1, fbbb-1, h###-2,c###-1, d#-1, fbb-1, gbbbb-1,d##-1, fb-1, gbbb-1,abbbb-1, d###-1, e#-1, gbb-1,abbb-1, e##-1, f#-1,abb-1, bbbb-1, e###-1, f##-1,bbb-1, f###-1, g#-1,bb-1, cbbb0, g##-1,a#-1, cbb0, dbbbb0, g###-1,a##-1, b#-1, cb0, dbbb0,a###-1, b##-1, dbb0, ebbbb0, h#-1,b###-1, c#0, ebbb0, h##-1,c##0, ebb0, fbbb0, h###-1,c###0, d#0, fbb0, gbbbb0,d##0, fb0, gbbb0,abbbb0, d###0, e#0, gbb0,abbb0, e##0, f#0,abb0, bbbb0, e###0, f##0,bbb0, f###0, g#0,bb0, cbbb1, g##0,a#0, cbb1, dbbbb1, g###0,a##0, b#0, cb1, dbbb1,a###0, b##0, dbb1, ebbbb1, h#0,b###0, c#1, ebbb1, h##0,c##1, ebb1, fbbb1, h###0,c###1, d#1, fbb1, gbbbb1,d##1, fb1, gbbb1,abbbb1, d###1, e#1, gbb1,abbb1, e##1, f#1,abb1, bbbb1, e###1, f##1,bbb1, f###1, g#1,bb1, cbbb2, g##1,a#1, cbb2, dbbbb2, g###1,a##1, b#1, cb2, dbbb2,a###1, b##1, dbb2, ebbbb2, h#1,b###1, c#2, ebbb2, h##1,c##2, ebb2, fbbb2, h###1,c###2, d#2, fbb2, gbbbb2,d##2, fb2, gbbb2,abbbb2, d###2, e#2, gbb2,abbb2, e##2, f#2,abb2, bbbb2, e###2, f##2,bbb2, f###2, g#2,bb2, cbbb3, g##2,a#2, cbb3, dbbbb3, g###2,a##2, b#2, cb3, dbbb3,a###2, b##2, dbb3, ebbbb3, h#2,b###2, c#3, ebbb3, h##2,c##3, ebb3, fbbb3, h###2,c###3, d#3, fbb3, gbbbb3,d##3, fb3, gbbb3,abbbb3, d###3, e#3, gbb3,abbb3, e##3, f#3,abb3, bbbb3, e###3, f##3,bbb3, f###3, g#3,bb3, cbbb4, g##3,a#3, cbb4, dbbbb4, g###3,a##3, b#3, cb4, dbbb4,a###3, b##3, dbb4, ebbbb4, h#3,b###3, c#4, ebbb4, h##3,c##4, ebb4, fbbb4, h###3,c###4, d#4, fbb4, gbbbb4,d##4, fb4, gbbb4,abbbb4, d###4, e#4, gbb4,abbb4, e##4, f#4,abb4, bbbb4, e###4, f##4,bbb4, f###4, g#4,bb4, cbbb5, g##4,a#4, cbb5, dbbbb5, g###4,a##4, b#4, cb5, dbbb5,a###4, b##4, dbb5, ebbbb5, h#4,b###4, c#5, ebbb5, h##4,c##5, ebb5, fbbb5, h###4,c###5, d#5, fbb5, gbbbb5,d##5, fb5, gbbb5,abbbb5, d###5, e#5, gbb5,abbb5, e##5, f#5,abb5, bbbb5, e###5, f##5,bbb5, f###5, g#5,bb5, cbbb6, g##5,a#5, cbb6, dbbbb6, g###5,a##5, b#5, cb6, dbbb6,a###5, b##5, dbb6, ebbbb6, h#5,b###5, c#6, ebbb6, h##5,c##6, ebb6, fbbb6, h###5,c###6, d#6, fbb6, gbbbb6,d##6, fb6, gbbb6,abbbb6, d###6, e#6, gbb6,abbb6, e##6, f#6,abb6, bbbb6, e###6, f##6,bbb6, f###6, g#6,bb6, cbbb7, g##6,a#6, cbb7, dbbbb7, g###6,a##6, b#6, cb7, dbbb7,a###6, b##6, dbb7, ebbbb7, h#6,b###6, c#7, ebbb7, h##6,c##7, ebb7, fbbb7, h###6,c###7, d#7, fbb7, gbbbb7,d##7, fb7, gbbb7,abbbb7, d###7, e#7, gbb7,abbb7, e##7, f#7,abb7, bbbb7, e###7, f##7,bbb7, f###7, g#7,bb7, cbbb8, g##7,a#7, cbb8, dbbbb8, g###7,a##7, b#7, cb8, dbbb8,a###7, b##7, dbb8, ebbbb8, h#7,b###7, c#8, ebbb8, h##7,c##8, ebb8, fbbb8, h###7,c###8, d#8, fbb8, gbbbb8,d##8, fb8, gbbb8,abbbb8, d###8, e#8, gbb8,abbb8, e##8, f#8,abb8, bbbb8, e###8, f##8,bbb8, f###8, g#8,bb8, cbbb9, g##8,a#8, cbb9, dbbbb9, g###8,a##8, b#8, cb9, dbbb9,a###8, b##8, dbb9, ebbbb9, h#8,b###8, c#9, ebbb9, h##8,c##9, ebb9, fbbb9, h###8,c###9, d#9, fbb9, gbbbb9,d##9, fb9, gbbb9,abbbb9, d###9, e#9, gbb9,abbb9, e##9, f#9,abb9, bbbb9, e###9, f##9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A###'''', B##'''', Dbb''', Ebbbb''', H#'''',B###'''', C#''', Ebbb''', H##'''',C##''', Ebb''', Fbbb''', H###'''',C###''', D#''', Fbb''', Gbbbb''',D##''', Fb''', Gbbb''',Abbbb''', D###''', E#''', Gbb''',Abbb''', E##''', F#''',Abb''', Bbbb''', E###''', F##''',Bbb''', F###''', G#''',Bb''', Cbbb'', G##''',A#''', Cbb'', Dbbbb'', G###''',A##''', B#''', Cb'', Dbbb'',A###''', B##''', Dbb'', Ebbbb'', H#''',B###''', C#'', Ebbb'', H##''',C##'', Ebb'', Fbbb'', H###''',C###'', D#'', Fbb'', Gbbbb'',D##'', Fb'', Gbbb'',Abbbb'', D###'', E#'', Gbb'',Abbb'', E##'', F#'',Abb'', Bbbb'', E###'', F##'',Bbb'', F###'', G#'',Bb'', Cbbb', G##'',A#'', Cbb', Dbbbb', G###'',A##'', B#'', Cb', Dbbb',A###'', B##'', Dbb', Ebbbb', H#'',B###'', C#', Ebbb', H##'',C##', Ebb', Fbbb', H###'',C###', D#', Fbb', Gbbbb',D##', Fb', Gbbb',Abbbb', D###', E#', Gbb',Abbb', E##', F#',Abb', Bbbb', E###', F##',Bbb', F###', G#',Bb', Cbbb, G##',A#', Cbb, Dbbbb, G###',A##', B#', Cb, Dbbb,A###', B##', Dbb, Ebbbb, H#',B###', C#, Ebbb, H##',C##, Ebb, Fbbb, H###',C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbb, E###, F##,Bbb, F###, G#,Bb, G##, cbbb,A#, G###, cbb, dbbbb,A##, B#, cb, dbbb,A###, B##, H#, dbb, ebbbb,B###, H##, c#, ebbb,H###, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbb, e###, f##,bbb, f###, g#,bb, cbbb', g##,a#, cbb', dbbbb', g###,a##, b#, cb', dbbb',a###, b##, dbb', ebbbb', h#,b###, c#', ebbb', h##,c##', ebb', fbbb', h###,c###', d#', fbb', gbbbb',d##', fb', gbbb',abbbb', d###', e#', gbb',abbb', e##', f#',abb', bbbb', e###', f##',bbb', f###', g#',bb', cbbb'', g##',a#', cbb'', dbbbb'', g###',a##', b#', cb'', dbbb'',a###', b##', dbb'', ebbbb'', h#',b###', c#'', ebbb'', h##',c##'', ebb'', fbbb'', h###',c###'', d#'', fbb'', gbbbb'',d##'', fb'', gbbb'',abbbb'', d###'', e#'', gbb'',abbb'', e##'', f#'',abb'', bbbb'', e###'', f##'',bbb'', f###'', g#'',bb'', cbbb''', g##'',a#'', cbb''', dbbbb''', g###'',a##'', b#'', cb''', dbbb''',a###'', b##'', dbb''', ebbbb''', h#'',b###'', c#''', ebbb''', h##'',c##''', ebb''', fbbb''', h###'',c###''', d#''', fbb''', gbbbb''',d##''', fb''', gbbb''',abbbb''', d###''', e#''', gbb''',abbb''', e##''', f#''',abb''', bbbb''', e###''', f##''',bbb''', f###''', g#''',bb''', cbbb'''', g##''',a#''', cbb'''', dbbbb'''', g###''',a##''', b#''', cb'''', dbbb'''',a###''', b##''', dbb'''', ebbbb'''', h#''',b###''', c#'''', ebbb'''', h##''',c##'''', ebb'''', fbbb'''', h###''',c###'''', d#'''', fbb'''', gbbbb'''',d##'''', fb'''', gbbb'''',abbbb'''', d###'''', e#'''', gbb'''',abbb'''', e##'''', f#'''',abb'''', bbbb'''', e###'''', f##'''',bbb'''', f###'''', g#'''',bb'''', cbbb''''', g##'''',a#'''', cbb''''', dbbbb''''', g###'''',a##'''', b#'''', cb''''', dbbb''''',a###'''', b##'''', dbb''''', ebbbb''''', h#'''',b###'''', c#''''', ebbb''''', h##'''',c##''''', ebb''''', fbbb''''', h###'''',c###''''', d#''''', fbb''''', gbbbb''''',d##''''', fb''''', gbbb''''',abbbb''''', d###''''', e#''''', gbb''''',abbb''''', e##''''', f#''''',abb''''', bbbb''''', e###''''', f##''''',bbb''''', f###''''', g#''''',bb''''', cbbb'''''', g##''''',a#''''', cbb'''''', dbbbb'''''', g###''''',a##''''', b#''''', cb'''''', dbbb'''''',a###''''', b##''''', dbb'''''', ebbbb'''''', h#''''',b###''''', c#'''''', ebbb'''''', h##''''',c##'''''', ebb'''''', fbbb'''''', h###''''',c###'''''', d#'''''', fbb'''''', gbbbb'''''',d##'''''', fb'''''', gbbb'''''',abbbb'''''', d###'''''', e#'''''', gbb'''''',abbb'''''', e##'''''', f#'''''',abb'''''', bbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "a-diesis-diesis-diesis-6, b-diesis-diesis-6, d-bemolle-bemolle-5, h-diesis-6,b-diesis-diesis-diesis-6, d-bemolle-5, e-bemolle-bemolle-bemolle-5, h-diesis-diesis-6,c-diesis-diesis-5, e-bemolle-bemolle-5, f-bemolle-bemolle-bemolle-5, h-diesis-diesis-diesis-6,c-diesis-diesis-diesis-5, e-bemolle-5, f-bemolle-bemolle-5,c-diesis-diesis-diesis-diesis-5, d-diesis-diesis-5, f-bemolle-5, g-bemolle-bemolle-bemolle-5,d-diesis-diesis-diesis-5, e-diesis-5, g-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-5, d-diesis-diesis-diesis-diesis-5, e-diesis-diesis-5, g-bemolle-5,a-bemolle-bemolle-5, b-bemolle-bemolle-bemolle-5, e-diesis-diesis-diesis-5, f-diesis-diesis-5,a-bemolle-5, b-bemolle-bemolle-5, f-diesis-diesis-diesis-5, h-bemolle-bemolle-bemolle-5,b-bemolle-5, c-bemolle-bemolle-bemolle-4, f-diesis-diesis-diesis-diesis-5, g-diesis-diesis-5, h-bemolle-bemolle-5,a-diesis-5, c-bemolle-bemolle-4, g-diesis-diesis-diesis-5, h-bemolle-5,a-diesis-diesis-5, b-diesis-5, c-bemolle-4, d-bemolle-bemolle-bemolle-4, g-diesis-diesis-diesis-diesis-5,a-diesis-diesis-diesis-5, b-diesis-diesis-5, d-bemolle-bemolle-4, h-diesis-5,b-diesis-diesis-diesis-5, d-bemolle-4, e-bemolle-bemolle-bemolle-4, h-diesis-diesis-5,c-diesis-diesis-4, e-bemolle-bemolle-4, f-bemolle-bemolle-bemolle-4, h-diesis-diesis-diesis-5,c-diesis-diesis-diesis-4, e-bemolle-4, f-bemolle-bemolle-4,c-diesis-diesis-diesis-diesis-4, d-diesis-diesis-4, f-bemolle-4, g-bemolle-bemolle-bemolle-4,d-diesis-diesis-diesis-4, e-diesis-4, g-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-4, d-diesis-diesis-diesis-diesis-4, e-diesis-diesis-4, g-bemolle-4,a-bemolle-bemolle-4, b-bemolle-bemolle-bemolle-4, e-diesis-diesis-diesis-4, f-diesis-diesis-4,a-bemolle-4, b-bemolle-bemolle-4, f-diesis-diesis-diesis-4, h-bemolle-bemolle-bemolle-4,b-bemolle-4, c-bemolle-bemolle-bemolle-3, f-diesis-diesis-diesis-diesis-4, g-diesis-diesis-4, h-bemolle-bemolle-4,a-diesis-4, c-bemolle-bemolle-3, g-diesis-diesis-diesis-4, h-bemolle-4,a-diesis-diesis-4, b-diesis-4, c-bemolle-3, d-bemolle-bemolle-bemolle-3, g-diesis-diesis-diesis-diesis-4,a-diesis-diesis-diesis-4, b-diesis-diesis-4, d-bemolle-bemolle-3, h-diesis-4,b-diesis-diesis-diesis-4, d-bemolle-3, e-bemolle-bemolle-bemolle-3, h-diesis-diesis-4,c-diesis-diesis-3, e-bemolle-bemolle-3, f-bemolle-bemolle-bemolle-3, h-diesis-diesis-diesis-4,c-diesis-diesis-diesis-3, e-bemolle-3, f-bemolle-bemolle-3,c-diesis-diesis-diesis-diesis-3, d-diesis-diesis-3, f-bemolle-3, g-bemolle-bemolle-bemolle-3,d-diesis-diesis-diesis-3, e-diesis-3, g-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-3, d-diesis-diesis-diesis-diesis-3, e-diesis-diesis-3, g-bemolle-3,a-bemolle-bemolle-3, b-bemolle-bemolle-bemolle-3, e-diesis-diesis-diesis-3, f-diesis-diesis-3,a-bemolle-3, b-bemolle-bemolle-3, f-diesis-diesis-diesis-3, h-bemolle-bemolle-bemolle-3,b-bemolle-3, c-bemolle-bemolle-bemolle-2, f-diesis-diesis-diesis-diesis-3, g-diesis-diesis-3, h-bemolle-bemolle-3,a-diesis-3, c-bemolle-bemolle-2, g-diesis-diesis-diesis-3, h-bemolle-3,a-diesis-diesis-3, b-diesis-3, c-bemolle-2, d-bemolle-bemolle-bemolle-2, g-diesis-diesis-diesis-diesis-3,a-diesis-diesis-diesis-3, b-diesis-diesis-3, d-bemolle-bemolle-2, h-diesis-3,b-diesis-diesis-diesis-3, d-bemolle-2, e-bemolle-bemolle-bemolle-2, h-diesis-diesis-3,c-diesis-diesis-2, e-bemolle-bemolle-2, f-bemolle-bemolle-bemolle-2, h-diesis-diesis-diesis-3,c-diesis-diesis-diesis-2, e-bemolle-2, f-bemolle-bemolle-2,c-diesis-diesis-diesis-diesis-2, d-diesis-diesis-2, f-bemolle-2, g-bemolle-bemolle-bemolle-2,d-diesis-diesis-diesis-2, e-diesis-2, g-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-2, d-diesis-diesis-diesis-diesis-2, e-diesis-diesis-2, g-bemolle-2,a-bemolle-bemolle-2, b-bemolle-bemolle-bemolle-2, e-diesis-diesis-diesis-2, f-diesis-diesis-2,a-bemolle-2, b-bemolle-bemolle-2, f-diesis-diesis-diesis-2, h-bemolle-bemolle-bemolle-2,b-bemolle-2, c-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-diesis-2, g-diesis-diesis-2, h-bemolle-bemolle-2,a-diesis-2, c-bemolle-bemolle-, g-diesis-diesis-diesis-2, h-bemolle-2,a-diesis-diesis-2, b-diesis-2, c-bemolle-, d-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-diesis-2,a-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-bemolle-, h-diesis-2,b-diesis-diesis-diesis-2, d-bemolle-, e-bemolle-bemolle-bemolle-, h-diesis-diesis-2,c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-, h-diesis-diesis-diesis-2,c-diesis-diesis-diesis-, e-bemolle-, f-bemolle-bemolle-,c-diesis-diesis-diesis-diesis-, d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-diesis-, e-diesis-diesis-, g-bemolle-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,a-bemolle-, b-bemolle-bemolle-, f-diesis-diesis-diesis-, h-bemolle-bemolle-bemolle-,b-bemolle-, c-bemolle-bemolle-bemolle, f-diesis-diesis-diesis-diesis-, g-diesis-diesis-, h-bemolle-bemolle-,a-diesis-, c-bemolle-bemolle, g-diesis-diesis-diesis-, h-bemolle-,a-diesis-diesis-, b-diesis-, c-bemolle, d-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-diesis-,a-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle-bemolle, h-diesis-,b-diesis-diesis-diesis-, d-bemolle, e-bemolle-bemolle-bemolle, h-diesis-diesis-,c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle, h-diesis-diesis-diesis-,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle, f-diesis-diesis-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis-diesis, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle+, g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle+, h-diesis,b-diesis-diesis-diesis, d-bemolle+, e-bemolle-bemolle-bemolle+, h-diesis-diesis,c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+, h-diesis-diesis-diesis,c-diesis-diesis-diesis+, e-bemolle+, f-bemolle-bemolle+,c-diesis-diesis-diesis-diesis+, d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis-diesis+, e-diesis-diesis+, g-bemolle+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,a-bemolle+, b-bemolle-bemolle+, f-diesis-diesis-diesis+, h-bemolle-bemolle-bemolle+,b-bemolle+, c-bemolle-bemolle-bemolle+2, f-diesis-diesis-diesis-diesis+, g-diesis-diesis+, h-bemolle-bemolle+,a-diesis+, c-bemolle-bemolle+2, g-diesis-diesis-diesis+, h-bemolle+,a-diesis-diesis+, b-diesis+, c-bemolle+2, d-bemolle-bemolle-bemolle+2, g-diesis-diesis-diesis-diesis+,a-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle-bemolle+2, h-diesis+,b-diesis-diesis-diesis+, d-bemolle+2, e-bemolle-bemolle-bemolle+2, h-diesis-diesis+,c-diesis-diesis+2, e-bemolle-bemolle+2, f-bemolle-bemolle-bemolle+2, h-diesis-diesis-diesis+,c-diesis-diesis-diesis+2, e-bemolle+2, f-bemolle-bemolle+2,c-diesis-diesis-diesis-diesis+2, d-diesis-diesis+2, f-bemolle+2, g-bemolle-bemolle-bemolle+2,d-diesis-diesis-diesis+2, e-diesis+2, g-bemolle-bemolle+2,a-bemolle-bemolle-bemolle+2, d-diesis-diesis-diesis-diesis+2, e-diesis-diesis+2, g-bemolle+2,a-bemolle-bemolle+2, b-bemolle-bemolle-bemolle+2, e-diesis-diesis-diesis+2, f-diesis-diesis+2,a-bemolle+2, b-bemolle-bemolle+2, f-diesis-diesis-diesis+2, h-bemolle-bemolle-bemolle+2,b-bemolle+2, c-bemolle-bemolle-bemolle+3, f-diesis-diesis-diesis-diesis+2, g-diesis-diesis+2, h-bemolle-bemolle+2,a-diesis+2, c-bemolle-bemolle+3, g-diesis-diesis-diesis+2, h-bemolle+2,a-diesis-diesis+2, b-diesis+2, c-bemolle+3, d-bemolle-bemolle-bemolle+3, g-diesis-diesis-diesis-diesis+2,a-diesis-diesis-diesis+2, b-diesis-diesis+2, d-bemolle-bemolle+3, h-diesis+2,b-diesis-diesis-diesis+2, d-bemolle+3, e-bemolle-bemolle-bemolle+3, h-diesis-diesis+2,c-diesis-diesis+3, e-bemolle-bemolle+3, f-bemolle-bemolle-bemolle+3, h-diesis-diesis-diesis+2,c-diesis-diesis-diesis+3, e-bemolle+3, f-bemolle-bemolle+3,c-diesis-diesis-diesis-diesis+3, d-diesis-diesis+3, f-bemolle+3, g-bemolle-bemolle-bemolle+3,d-diesis-diesis-diesis+3, e-diesis+3, g-bemolle-bemolle+3,a-bemolle-bemolle-bemolle+3, d-diesis-diesis-diesis-diesis+3, e-diesis-diesis+3, g-bemolle+3,a-bemolle-bemolle+3, b-bemolle-bemolle-bemolle+3, e-diesis-diesis-diesis+3, f-diesis-diesis+3,a-bemolle+3, b-bemolle-bemolle+3, f-diesis-diesis-diesis+3, h-bemolle-bemolle-bemolle+3,b-bemolle+3, c-bemolle-bemolle-bemolle+4, f-diesis-diesis-diesis-diesis+3, g-diesis-diesis+3, h-bemolle-bemolle+3,a-diesis+3, c-bemolle-bemolle+4, g-diesis-diesis-diesis+3, h-bemolle+3,a-diesis-diesis+3, b-diesis+3, c-bemolle+4, d-bemolle-bemolle-bemolle+4, g-diesis-diesis-diesis-diesis+3,a-diesis-diesis-diesis+3, b-diesis-diesis+3, d-bemolle-bemolle+4, h-diesis+3,b-diesis-diesis-diesis+3, d-bemolle+4, e-bemolle-bemolle-bemolle+4, h-diesis-diesis+3,c-diesis-diesis+4, e-bemolle-bemolle+4, f-bemolle-bemolle-bemolle+4, h-diesis-diesis-diesis+3,c-diesis-diesis-diesis+4, e-bemolle+4, f-bemolle-bemolle+4,c-diesis-diesis-diesis-diesis+4, d-diesis-diesis+4, f-bemolle+4, g-bemolle-bemolle-bemolle+4,d-diesis-diesis-diesis+4, e-diesis+4, g-bemolle-bemolle+4,a-bemolle-bemolle-bemolle+4, d-diesis-diesis-diesis-diesis+4, e-diesis-diesis+4, g-bemolle+4,a-bemolle-bemolle+4, b-bemolle-bemolle-bemolle+4, e-diesis-diesis-diesis+4, f-diesis-diesis+4,a-bemolle+4, b-bemolle-bemolle+4, f-diesis-diesis-diesis+4, h-bemolle-bemolle-bemolle+4,b-bemolle+4, c-bemolle-bemolle-bemolle+5, f-diesis-diesis-diesis-diesis+4, g-diesis-diesis+4, h-bemolle-bemolle+4,a-diesis+4, c-bemolle-bemolle+5, g-diesis-diesis-diesis+4, h-bemolle+4,a-diesis-diesis+4, b-diesis+4, c-bemolle+5, d-bemolle-bemolle-bemolle+5, g-diesis-diesis-diesis-diesis+4,a-diesis-diesis-diesis+4, b-diesis-diesis+4, d-bemolle-bemolle+5, h-diesis+4,b-diesis-diesis-diesis+4, d-bemolle+5, e-bemolle-bemolle-bemolle+5, h-diesis-diesis+4,c-diesis-diesis+5, e-bemolle-bemolle+5, f-bemolle-bemolle-bemolle+5, h-diesis-diesis-diesis+4,c-diesis-diesis-diesis+5, e-bemolle+5, f-bemolle-bemolle+5,c-diesis-diesis-diesis-diesis+5, d-diesis-diesis+5, f-bemolle+5, g-bemolle-bemolle-bemolle+5,d-diesis-diesis-diesis+5, e-diesis+5, g-bemolle-bemolle+5,a-bemolle-bemolle-bemolle+5, d-diesis-diesis-diesis-diesis+5, e-diesis-diesis+5, g-bemolle+5,a-bemolle-bemolle+5, b-bemolle-bemolle-bemolle+5, e-diesis-diesis-diesis+5, f-diesis-diesis+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "a-diesis-diesis-diesis------, b-diesis-diesis------, d-bemolle-bemolle-----, h-diesis------,b-diesis-diesis-diesis------, d-bemolle-----, e-bemolle-bemolle-bemolle-----, h-diesis-diesis------,c-diesis-diesis-----, e-bemolle-bemolle-----, f-bemolle-bemolle-bemolle-----, h-diesis-diesis-diesis------,c-diesis-diesis-diesis-----, e-bemolle-----, f-bemolle-bemolle-----,c-diesis-diesis-diesis-diesis-----, d-diesis-diesis-----, f-bemolle-----, g-bemolle-bemolle-bemolle-----,d-diesis-diesis-diesis-----, e-diesis-----, g-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-----, d-diesis-diesis-diesis-diesis-----, e-diesis-diesis-----, g-bemolle-----,a-bemolle-bemolle-----, b-bemolle-bemolle-bemolle-----, e-diesis-diesis-diesis-----, f-diesis-diesis-----,a-bemolle-----, b-bemolle-bemolle-----, f-diesis-diesis-diesis-----, h-bemolle-bemolle-bemolle-----,b-bemolle-----, c-bemolle-bemolle-bemolle----, f-diesis-diesis-diesis-diesis-----, g-diesis-diesis-----, h-bemolle-bemolle-----,a-diesis-----, c-bemolle-bemolle----, g-diesis-diesis-diesis-----, h-bemolle-----,a-diesis-diesis-----, b-diesis-----, c-bemolle----, d-bemolle-bemolle-bemolle----, g-diesis-diesis-diesis-diesis-----,a-diesis-diesis-diesis-----, b-diesis-diesis-----, d-bemolle-bemolle----, h-diesis-----,b-diesis-diesis-diesis-----, d-bemolle----, e-bemolle-bemolle-bemolle----, h-diesis-diesis-----,c-diesis-diesis----, e-bemolle-bemolle----, f-bemolle-bemolle-bemolle----, h-diesis-diesis-diesis-----,c-diesis-diesis-diesis----, e-bemolle----, f-bemolle-bemolle----,c-diesis-diesis-diesis-diesis----, d-diesis-diesis----, f-bemolle----, g-bemolle-bemolle-bemolle----,d-diesis-diesis-diesis----, e-diesis----, g-bemolle-bemolle----,a-bemolle-bemolle-bemolle----, d-diesis-diesis-diesis-diesis----, e-diesis-diesis----, g-bemolle----,a-bemolle-bemolle----, b-bemolle-bemolle-bemolle----, e-diesis-diesis-diesis----, f-diesis-diesis----,a-bemolle----, b-bemolle-bemolle----, f-diesis-diesis-diesis----, h-bemolle-bemolle-bemolle----,b-bemolle----, c-bemolle-bemolle-bemolle---, f-diesis-diesis-diesis-diesis----, g-diesis-diesis----, h-bemolle-bemolle----,a-diesis----, c-bemolle-bemolle---, g-diesis-diesis-diesis----, h-bemolle----,a-diesis-diesis----, b-diesis----, c-bemolle---, d-bemolle-bemolle-bemolle---, g-diesis-diesis-diesis-diesis----,a-diesis-diesis-diesis----, b-diesis-diesis----, d-bemolle-bemolle---, h-diesis----,b-diesis-diesis-diesis----, d-bemolle---, e-bemolle-bemolle-bemolle---, h-diesis-diesis----,c-diesis-diesis---, e-bemolle-bemolle---, f-bemolle-bemolle-bemolle---, h-diesis-diesis-diesis----,c-diesis-diesis-diesis---, e-bemolle---, f-bemolle-bemolle---,c-diesis-diesis-diesis-diesis---, d-diesis-diesis---, f-bemolle---, g-bemolle-bemolle-bemolle---,d-diesis-diesis-diesis---, e-diesis---, g-bemolle-bemolle---,a-bemolle-bemolle-bemolle---, d-diesis-diesis-diesis-diesis---, e-diesis-diesis---, g-bemolle---,a-bemolle-bemolle---, b-bemolle-bemolle-bemolle---, e-diesis-diesis-diesis---, f-diesis-diesis---,a-bemolle---, b-bemolle-bemolle---, f-diesis-diesis-diesis---, h-bemolle-bemolle-bemolle---,b-bemolle---, c-bemolle-bemolle-bemolle--, f-diesis-diesis-diesis-diesis---, g-diesis-diesis---, h-bemolle-bemolle---,a-diesis---, c-bemolle-bemolle--, g-diesis-diesis-diesis---, h-bemolle---,a-diesis-diesis---, b-diesis---, c-bemolle--, d-bemolle-bemolle-bemolle--, g-diesis-diesis-diesis-diesis---,a-diesis-diesis-diesis---, b-diesis-diesis---, d-bemolle-bemolle--, h-diesis---,b-diesis-diesis-diesis---, d-bemolle--, e-bemolle-bemolle-bemolle--, h-diesis-diesis---,c-diesis-diesis--, e-bemolle-bemolle--, f-bemolle-bemolle-bemolle--, h-diesis-diesis-diesis---,c-diesis-diesis-diesis--, e-bemolle--, f-bemolle-bemolle--,c-diesis-diesis-diesis-diesis--, d-diesis-diesis--, f-bemolle--, g-bemolle-bemolle-bemolle--,d-diesis-diesis-diesis--, e-diesis--, g-bemolle-bemolle--,a-bemolle-bemolle-bemolle--, d-diesis-diesis-diesis-diesis--, e-diesis-diesis--, g-bemolle--,a-bemolle-bemolle--, b-bemolle-bemolle-bemolle--, e-diesis-diesis-diesis--, f-diesis-diesis--,a-bemolle--, b-bemolle-bemolle--, f-diesis-diesis-diesis--, h-bemolle-bemolle-bemolle--,b-bemolle--, c-bemolle-bemolle-bemolle-, f-diesis-diesis-diesis-diesis--, g-diesis-diesis--, h-bemolle-bemolle--,a-diesis--, c-bemolle-bemolle-, g-diesis-diesis-diesis--, h-bemolle--,a-diesis-diesis--, b-diesis--, c-bemolle-, d-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-diesis--,a-diesis-diesis-diesis--, b-diesis-diesis--, d-bemolle-bemolle-, h-diesis--,b-diesis-diesis-diesis--, d-bemolle-, e-bemolle-bemolle-bemolle-, h-diesis-diesis--,c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-, h-diesis-diesis-diesis--,c-diesis-diesis-diesis-, e-bemolle-, f-bemolle-bemolle-,c-diesis-diesis-diesis-diesis-, d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-diesis-, e-diesis-diesis-, g-bemolle-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,a-bemolle-, b-bemolle-bemolle-, f-diesis-diesis-diesis-, h-bemolle-bemolle-bemolle-,b-bemolle-, c-bemolle-bemolle-bemolle, f-diesis-diesis-diesis-diesis-, g-diesis-diesis-, h-bemolle-bemolle-,a-diesis-, c-bemolle-bemolle, g-diesis-diesis-diesis-, h-bemolle-,a-diesis-diesis-, b-diesis-, c-bemolle, d-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-diesis-,a-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle-bemolle, h-diesis-,b-diesis-diesis-diesis-, d-bemolle, e-bemolle-bemolle-bemolle, h-diesis-diesis-,c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle, h-diesis-diesis-diesis-,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle, f-diesis-diesis-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle+, f-diesis-diesis-diesis-diesis, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle+, g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle+, h-diesis,b-diesis-diesis-diesis, d-bemolle+, e-bemolle-bemolle-bemolle+, h-diesis-diesis,c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+, h-diesis-diesis-diesis,c-diesis-diesis-diesis+, e-bemolle+, f-bemolle-bemolle+,c-diesis-diesis-diesis-diesis+, d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis-diesis+, e-diesis-diesis+, g-bemolle+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,a-bemolle+, b-bemolle-bemolle+, f-diesis-diesis-diesis+, h-bemolle-bemolle-bemolle+,b-bemolle+, c-bemolle-bemolle-bemolle++, f-diesis-diesis-diesis-diesis+, g-diesis-diesis+, h-bemolle-bemolle+,a-diesis+, c-bemolle-bemolle++, g-diesis-diesis-diesis+, h-bemolle+,a-diesis-diesis+, b-diesis+, c-bemolle++, d-bemolle-bemolle-bemolle++, g-diesis-diesis-diesis-diesis+,a-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle-bemolle++, h-diesis+,b-diesis-diesis-diesis+, d-bemolle++, e-bemolle-bemolle-bemolle++, h-diesis-diesis+,c-diesis-diesis++, e-bemolle-bemolle++, f-bemolle-bemolle-bemolle++, h-diesis-diesis-diesis+,c-diesis-diesis-diesis++, e-bemolle++, f-bemolle-bemolle++,c-diesis-diesis-diesis-diesis++, d-diesis-diesis++, f-bemolle++, g-bemolle-bemolle-bemolle++,d-diesis-diesis-diesis++, e-diesis++, g-bemolle-bemolle++,a-bemolle-bemolle-bemolle++, d-diesis-diesis-diesis-diesis++, e-diesis-diesis++, g-bemolle++,a-bemolle-bemolle++, b-bemolle-bemolle-bemolle++, e-diesis-diesis-diesis++, f-diesis-diesis++,a-bemolle++, b-bemolle-bemolle++, f-diesis-diesis-diesis++, h-bemolle-bemolle-bemolle++,b-bemolle++, c-bemolle-bemolle-bemolle+++, f-diesis-diesis-diesis-diesis++, g-diesis-diesis++, h-bemolle-bemolle++,a-diesis++, c-bemolle-bemolle+++, g-diesis-diesis-diesis++, h-bemolle++,a-diesis-diesis++, b-diesis++, c-bemolle+++, d-bemolle-bemolle-bemolle+++, g-diesis-diesis-diesis-diesis++,a-diesis-diesis-diesis++, b-diesis-diesis++, d-bemolle-bemolle+++, h-diesis++,b-diesis-diesis-diesis++, d-bemolle+++, e-bemolle-bemolle-bemolle+++, h-diesis-diesis++,c-diesis-diesis+++, e-bemolle-bemolle+++, f-bemolle-bemolle-bemolle+++, h-diesis-diesis-diesis++,c-diesis-diesis-diesis+++, e-bemolle+++, f-bemolle-bemolle+++,c-diesis-diesis-diesis-diesis+++, d-diesis-diesis+++, f-bemolle+++, g-bemolle-bemolle-bemolle+++,d-diesis-diesis-diesis+++, e-diesis+++, g-bemolle-bemolle+++,a-bemolle-bemolle-bemolle+++, d-diesis-diesis-diesis-diesis+++, e-diesis-diesis+++, g-bemolle+++,a-bemolle-bemolle+++, b-bemolle-bemolle-bemolle+++, e-diesis-diesis-diesis+++, f-diesis-diesis+++,a-bemolle+++, b-bemolle-bemolle+++, f-diesis-diesis-diesis+++, h-bemolle-bemolle-bemolle+++,b-bemolle+++, c-bemolle-bemolle-bemolle++++, f-diesis-diesis-diesis-diesis+++, g-diesis-diesis+++, h-bemolle-bemolle+++,a-diesis+++, c-bemolle-bemolle++++, g-diesis-diesis-diesis+++, h-bemolle+++,a-diesis-diesis+++, b-diesis+++, c-bemolle++++, d-bemolle-bemolle-bemolle++++, g-diesis-diesis-diesis-diesis+++,a-diesis-diesis-diesis+++, b-diesis-diesis+++, d-bemolle-bemolle++++, h-diesis+++,b-diesis-diesis-diesis+++, d-bemolle++++, e-bemolle-bemolle-bemolle++++, h-diesis-diesis+++,c-diesis-diesis++++, e-bemolle-bemolle++++, f-bemolle-bemolle-bemolle++++, h-diesis-diesis-diesis+++,c-diesis-diesis-diesis++++, e-bemolle++++, f-bemolle-bemolle++++,c-diesis-diesis-diesis-diesis++++, d-diesis-diesis++++, f-bemolle++++, g-bemolle-bemolle-bemolle++++,d-diesis-diesis-diesis++++, e-diesis++++, g-bemolle-bemolle++++,a-bemolle-bemolle-bemolle++++, d-diesis-diesis-diesis-diesis++++, e-diesis-diesis++++, g-bemolle++++,a-bemolle-bemolle++++, b-bemolle-bemolle-bemolle++++, e-diesis-diesis-diesis++++, f-diesis-diesis++++,a-bemolle++++, b-bemolle-bemolle++++, f-diesis-diesis-diesis++++, h-bemolle-bemolle-bemolle++++,b-bemolle++++, c-bemolle-bemolle-bemolle+++++, f-diesis-diesis-diesis-diesis++++, g-diesis-diesis++++, h-bemolle-bemolle++++,a-diesis++++, c-bemolle-bemolle+++++, g-diesis-diesis-diesis++++, h-bemolle++++,a-diesis-diesis++++, b-diesis++++, c-bemolle+++++, d-bemolle-bemolle-bemolle+++++, g-diesis-diesis-diesis-diesis++++,a-diesis-diesis-diesis++++, b-diesis-diesis++++, d-bemolle-bemolle+++++, h-diesis++++,b-diesis-diesis-diesis++++, d-bemolle+++++, e-bemolle-bemolle-bemolle+++++, h-diesis-diesis++++,c-diesis-diesis+++++, e-bemolle-bemolle+++++, f-bemolle-bemolle-bemolle+++++, h-diesis-diesis-diesis++++,c-diesis-diesis-diesis+++++, e-bemolle+++++, f-bemolle-bemolle+++++,c-diesis-diesis-diesis-diesis+++++, d-diesis-diesis+++++, f-bemolle+++++, g-bemolle-bemolle-bemolle+++++,d-diesis-diesis-diesis+++++, e-diesis+++++, g-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle+++++, d-diesis-diesis-diesis-diesis+++++, e-diesis-diesis+++++, g-bemolle+++++,a-bemolle-bemolle+++++, b-bemolle-bemolle-bemolle+++++, e-diesis-diesis-diesis+++++, f-diesis-diesis+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "a-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-bemolle-1, h-diesis-2,b-diesis-diesis-diesis-2, d-bemolle-1, e-bemolle-bemolle-bemolle-1, h-diesis-diesis-2,c-diesis-diesis-1, e-bemolle-bemolle-1, f-bemolle-bemolle-bemolle-1, h-diesis-diesis-diesis-2,c-diesis-diesis-diesis-1, e-bemolle-1, f-bemolle-bemolle-1,c-diesis-diesis-diesis-diesis-1, d-diesis-diesis-1, f-bemolle-1, g-bemolle-bemolle-bemolle-1,d-diesis-diesis-diesis-1, e-diesis-1, g-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-1, d-diesis-diesis-diesis-diesis-1, e-diesis-diesis-1, g-bemolle-1,a-bemolle-bemolle-1, b-bemolle-bemolle-bemolle-1, e-diesis-diesis-diesis-1, f-diesis-diesis-1,a-bemolle-1, b-bemolle-bemolle-1, f-diesis-diesis-diesis-1, h-bemolle-bemolle-bemolle-1,b-bemolle-1, c-bemolle-bemolle-bemolle0, f-diesis-diesis-diesis-diesis-1, g-diesis-diesis-1, h-bemolle-bemolle-1,a-diesis-1, c-bemolle-bemolle0, g-diesis-diesis-diesis-1, h-bemolle-1,a-diesis-diesis-1, b-diesis-1, c-bemolle0, d-bemolle-bemolle-bemolle0, g-diesis-diesis-diesis-diesis-1,a-diesis-diesis-diesis-1, b-diesis-diesis-1, d-bemolle-bemolle0, h-diesis-1,b-diesis-diesis-diesis-1, d-bemolle0, e-bemolle-bemolle-bemolle0, h-diesis-diesis-1,c-diesis-diesis0, e-bemolle-bemolle0, f-bemolle-bemolle-bemolle0, h-diesis-diesis-diesis-1,c-diesis-diesis-diesis0, e-bemolle0, f-bemolle-bemolle0,c-diesis-diesis-diesis-diesis0, d-diesis-diesis0, f-bemolle0, g-bemolle-bemolle-bemolle0,d-diesis-diesis-diesis0, e-diesis0, g-bemolle-bemolle0,a-bemolle-bemolle-bemolle0, d-diesis-diesis-diesis-diesis0, e-diesis-diesis0, g-bemolle0,a-bemolle-bemolle0, b-bemolle-bemolle-bemolle0, e-diesis-diesis-diesis0, f-diesis-diesis0,a-bemolle0, b-bemolle-bemolle0, f-diesis-diesis-diesis0, h-bemolle-bemolle-bemolle0,b-bemolle0, c-bemolle-bemolle-bemolle1, f-diesis-diesis-diesis-diesis0, g-diesis-diesis0, h-bemolle-bemolle0,a-diesis0, c-bemolle-bemolle1, g-diesis-diesis-diesis0, h-bemolle0,a-diesis-diesis0, b-diesis0, c-bemolle1, d-bemolle-bemolle-bemolle1, g-diesis-diesis-diesis-diesis0,a-diesis-diesis-diesis0, b-diesis-diesis0, d-bemolle-bemolle1, h-diesis0,b-diesis-diesis-diesis0, d-bemolle1, e-bemolle-bemolle-bemolle1, h-diesis-diesis0,c-diesis-diesis1, e-bemolle-bemolle1, f-bemolle-bemolle-bemolle1, h-diesis-diesis-diesis0,c-diesis-diesis-diesis1, e-bemolle1, f-bemolle-bemolle1,c-diesis-diesis-diesis-diesis1, d-diesis-diesis1, f-bemolle1, g-bemolle-bemolle-bemolle1,d-diesis-diesis-diesis1, e-diesis1, g-bemolle-bemolle1,a-bemolle-bemolle-bemolle1, d-diesis-diesis-diesis-diesis1, e-diesis-diesis1, g-bemolle1,a-bemolle-bemolle1, b-bemolle-bemolle-bemolle1, e-diesis-diesis-diesis1, f-diesis-diesis1,a-bemolle1, b-bemolle-bemolle1, f-diesis-diesis-diesis1, h-bemolle-bemolle-bemolle1,b-bemolle1, c-bemolle-bemolle-bemolle2, f-diesis-diesis-diesis-diesis1, g-diesis-diesis1, h-bemolle-bemolle1,a-diesis1, c-bemolle-bemolle2, g-diesis-diesis-diesis1, h-bemolle1,a-diesis-diesis1, b-diesis1, c-bemolle2, d-bemolle-bemolle-bemolle2, g-diesis-diesis-diesis-diesis1,a-diesis-diesis-diesis1, b-diesis-diesis1, d-bemolle-bemolle2, h-diesis1,b-diesis-diesis-diesis1, d-bemolle2, e-bemolle-bemolle-bemolle2, h-diesis-diesis1,c-diesis-diesis2, e-bemolle-bemolle2, f-bemolle-bemolle-bemolle2, h-diesis-diesis-diesis1,c-diesis-diesis-diesis2, e-bemolle2, f-bemolle-bemolle2,c-diesis-diesis-diesis-diesis2, d-diesis-diesis2, f-bemolle2, g-bemolle-bemolle-bemolle2,d-diesis-diesis-diesis2, e-diesis2, g-bemolle-bemolle2,a-bemolle-bemolle-bemolle2, d-diesis-diesis-diesis-diesis2, e-diesis-diesis2, g-bemolle2,a-bemolle-bemolle2, b-bemolle-bemolle-bemolle2, e-diesis-diesis-diesis2, f-diesis-diesis2,a-bemolle2, b-bemolle-bemolle2, f-diesis-diesis-diesis2, h-bemolle-bemolle-bemolle2,b-bemolle2, c-bemolle-bemolle-bemolle3, f-diesis-diesis-diesis-diesis2, g-diesis-diesis2, h-bemolle-bemolle2,a-diesis2, c-bemolle-bemolle3, g-diesis-diesis-diesis2, h-bemolle2,a-diesis-diesis2, b-diesis2, c-bemolle3, d-bemolle-bemolle-bemolle3, g-diesis-diesis-diesis-diesis2,a-diesis-diesis-diesis2, b-diesis-diesis2, d-bemolle-bemolle3, h-diesis2,b-diesis-diesis-diesis2, d-bemolle3, e-bemolle-bemolle-bemolle3, h-diesis-diesis2,c-diesis-diesis3, e-bemolle-bemolle3, f-bemolle-bemolle-bemolle3, h-diesis-diesis-diesis2,c-diesis-diesis-diesis3, e-bemolle3, f-bemolle-bemolle3,c-diesis-diesis-diesis-diesis3, d-diesis-diesis3, f-bemolle3, g-bemolle-bemolle-bemolle3,d-diesis-diesis-diesis3, e-diesis3, g-bemolle-bemolle3,a-bemolle-bemolle-bemolle3, d-diesis-diesis-diesis-diesis3, e-diesis-diesis3, g-bemolle3,a-bemolle-bemolle3, b-bemolle-bemolle-bemolle3, e-diesis-diesis-diesis3, f-diesis-diesis3,a-bemolle3, b-bemolle-bemolle3, f-diesis-diesis-diesis3, h-bemolle-bemolle-bemolle3,b-bemolle3, c-bemolle-bemolle-bemolle4, f-diesis-diesis-diesis-diesis3, g-diesis-diesis3, h-bemolle-bemolle3,a-diesis3, c-bemolle-bemolle4, g-diesis-diesis-diesis3, h-bemolle3,a-diesis-diesis3, b-diesis3, c-bemolle4, d-bemolle-bemolle-bemolle4, g-diesis-diesis-diesis-diesis3,a-diesis-diesis-diesis3, b-diesis-diesis3, d-bemolle-bemolle4, h-diesis3,b-diesis-diesis-diesis3, d-bemolle4, e-bemolle-bemolle-bemolle4, h-diesis-diesis3,c-diesis-diesis4, e-bemolle-bemolle4, f-bemolle-bemolle-bemolle4, h-diesis-diesis-diesis3,c-diesis-diesis-diesis4, e-bemolle4, f-bemolle-bemolle4,c-diesis-diesis-diesis-diesis4, d-diesis-diesis4, f-bemolle4, g-bemolle-bemolle-bemolle4,d-diesis-diesis-diesis4, e-diesis4, g-bemolle-bemolle4,a-bemolle-bemolle-bemolle4, d-diesis-diesis-diesis-diesis4, e-diesis-diesis4, g-bemolle4,a-bemolle-bemolle4, b-bemolle-bemolle-bemolle4, e-diesis-diesis-diesis4, f-diesis-diesis4,a-bemolle4, b-bemolle-bemolle4, f-diesis-diesis-diesis4, h-bemolle-bemolle-bemolle4,b-bemolle4, c-bemolle-bemolle-bemolle5, f-diesis-diesis-diesis-diesis4, g-diesis-diesis4, h-bemolle-bemolle4,a-diesis4, c-bemolle-bemolle5, g-diesis-diesis-diesis4, h-bemolle4,a-diesis-diesis4, b-diesis4, c-bemolle5, d-bemolle-bemolle-bemolle5, g-diesis-diesis-diesis-diesis4,a-diesis-diesis-diesis4, b-diesis-diesis4, d-bemolle-bemolle5, h-diesis4,b-diesis-diesis-diesis4, d-bemolle5, e-bemolle-bemolle-bemolle5, h-diesis-diesis4,c-diesis-diesis5, e-bemolle-bemolle5, f-bemolle-bemolle-bemolle5, h-diesis-diesis-diesis4,c-diesis-diesis-diesis5, e-bemolle5, f-bemolle-bemolle5,c-diesis-diesis-diesis-diesis5, d-diesis-diesis5, f-bemolle5, g-bemolle-bemolle-bemolle5,d-diesis-diesis-diesis5, e-diesis5, g-bemolle-bemolle5,a-bemolle-bemolle-bemolle5, d-diesis-diesis-diesis-diesis5, e-diesis-diesis5, g-bemolle5,a-bemolle-bemolle5, b-bemolle-bemolle-bemolle5, e-diesis-diesis-diesis5, f-diesis-diesis5,a-bemolle5, b-bemolle-bemolle5, f-diesis-diesis-diesis5, h-bemolle-bemolle-bemolle5,b-bemolle5, c-bemolle-bemolle-bemolle6, f-diesis-diesis-diesis-diesis5, g-diesis-diesis5, h-bemolle-bemolle5,a-diesis5, c-bemolle-bemolle6, g-diesis-diesis-diesis5, h-bemolle5,a-diesis-diesis5, b-diesis5, c-bemolle6, d-bemolle-bemolle-bemolle6, g-diesis-diesis-diesis-diesis5,a-diesis-diesis-diesis5, b-diesis-diesis5, d-bemolle-bemolle6, h-diesis5,b-diesis-diesis-diesis5, d-bemolle6, e-bemolle-bemolle-bemolle6, h-diesis-diesis5,c-diesis-diesis6, e-bemolle-bemolle6, f-bemolle-bemolle-bemolle6, h-diesis-diesis-diesis5,c-diesis-diesis-diesis6, e-bemolle6, f-bemolle-bemolle6,c-diesis-diesis-diesis-diesis6, d-diesis-diesis6, f-bemolle6, g-bemolle-bemolle-bemolle6,d-diesis-diesis-diesis6, e-diesis6, g-bemolle-bemolle6,a-bemolle-bemolle-bemolle6, d-diesis-diesis-diesis-diesis6, e-diesis-diesis6, g-bemolle6,a-bemolle-bemolle6, b-bemolle-bemolle-bemolle6, e-diesis-diesis-diesis6, f-diesis-diesis6,a-bemolle6, b-bemolle-bemolle6, f-diesis-diesis-diesis6, h-bemolle-bemolle-bemolle6,b-bemolle6, c-bemolle-bemolle-bemolle7, f-diesis-diesis-diesis-diesis6, g-diesis-diesis6, h-bemolle-bemolle6,a-diesis6, c-bemolle-bemolle7, g-diesis-diesis-diesis6, h-bemolle6,a-diesis-diesis6, b-diesis6, c-bemolle7, d-bemolle-bemolle-bemolle7, g-diesis-diesis-diesis-diesis6,a-diesis-diesis-diesis6, b-diesis-diesis6, d-bemolle-bemolle7, h-diesis6,b-diesis-diesis-diesis6, d-bemolle7, e-bemolle-bemolle-bemolle7, h-diesis-diesis6,c-diesis-diesis7, e-bemolle-bemolle7, f-bemolle-bemolle-bemolle7, h-diesis-diesis-diesis6,c-diesis-diesis-diesis7, e-bemolle7, f-bemolle-bemolle7,c-diesis-diesis-diesis-diesis7, d-diesis-diesis7, f-bemolle7, g-bemolle-bemolle-bemolle7,d-diesis-diesis-diesis7, e-diesis7, g-bemolle-bemolle7,a-bemolle-bemolle-bemolle7, d-diesis-diesis-diesis-diesis7, e-diesis-diesis7, g-bemolle7,a-bemolle-bemolle7, b-bemolle-bemolle-bemolle7, e-diesis-diesis-diesis7, f-diesis-diesis7,a-bemolle7, b-bemolle-bemolle7, f-diesis-diesis-diesis7, h-bemolle-bemolle-bemolle7,b-bemolle7, c-bemolle-bemolle-bemolle8, f-diesis-diesis-diesis-diesis7, g-diesis-diesis7, h-bemolle-bemolle7,a-diesis7, c-bemolle-bemolle8, g-diesis-diesis-diesis7, h-bemolle7,a-diesis-diesis7, b-diesis7, c-bemolle8, d-bemolle-bemolle-bemolle8, g-diesis-diesis-diesis-diesis7,a-diesis-diesis-diesis7, b-diesis-diesis7, d-bemolle-bemolle8, h-diesis7,b-diesis-diesis-diesis7, d-bemolle8, e-bemolle-bemolle-bemolle8, h-diesis-diesis7,c-diesis-diesis8, e-bemolle-bemolle8, f-bemolle-bemolle-bemolle8, h-diesis-diesis-diesis7,c-diesis-diesis-diesis8, e-bemolle8, f-bemolle-bemolle8,c-diesis-diesis-diesis-diesis8, d-diesis-diesis8, f-bemolle8, g-bemolle-bemolle-bemolle8,d-diesis-diesis-diesis8, e-diesis8, g-bemolle-bemolle8,a-bemolle-bemolle-bemolle8, d-diesis-diesis-diesis-diesis8, e-diesis-diesis8, g-bemolle8,a-bemolle-bemolle8, b-bemolle-bemolle-bemolle8, e-diesis-diesis-diesis8, f-diesis-diesis8,a-bemolle8, b-bemolle-bemolle8, f-diesis-diesis-diesis8, h-bemolle-bemolle-bemolle8,b-bemolle8, c-bemolle-bemolle-bemolle9, f-diesis-diesis-diesis-diesis8, g-diesis-diesis8, h-bemolle-bemolle8,a-diesis8, c-bemolle-bemolle9, g-diesis-diesis-diesis8, h-bemolle8,a-diesis-diesis8, b-diesis8, c-bemolle9, d-bemolle-bemolle-bemolle9, g-diesis-diesis-diesis-diesis8,a-diesis-diesis-diesis8, b-diesis-diesis8, d-bemolle-bemolle9, h-diesis8,b-diesis-diesis-diesis8, d-bemolle9, e-bemolle-bemolle-bemolle9, h-diesis-diesis8,c-diesis-diesis9, e-bemolle-bemolle9, f-bemolle-bemolle-bemolle9, h-diesis-diesis-diesis8,c-diesis-diesis-diesis9, e-bemolle9, f-bemolle-bemolle9,c-diesis-diesis-diesis-diesis9, d-diesis-diesis9, f-bemolle9, g-bemolle-bemolle-bemolle9,d-diesis-diesis-diesis9, e-diesis9, g-bemolle-bemolle9,a-bemolle-bemolle-bemolle9, d-diesis-diesis-diesis-diesis9, e-diesis-diesis9, g-bemolle9,a-bemolle-bemolle9, b-bemolle-bemolle-bemolle9, e-diesis-diesis-diesis9, f-diesis-diesis9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle-bemolle''', H-diesis'''',B-diesis-diesis-diesis'''', D-bemolle''', E-bemolle-bemolle-bemolle''', H-diesis-diesis'''',C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''', H-diesis-diesis-diesis'''',C-diesis-diesis-diesis''', E-bemolle''', F-bemolle-bemolle''',C-diesis-diesis-diesis-diesis''', D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis-diesis''', E-diesis-diesis''', G-bemolle''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',A-bemolle''', B-bemolle-bemolle''', F-diesis-diesis-diesis''', H-bemolle-bemolle-bemolle''',B-bemolle''', C-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis-diesis''', G-diesis-diesis''', H-bemolle-bemolle''',A-diesis''', C-bemolle-bemolle'', G-diesis-diesis-diesis''', H-bemolle''',A-diesis-diesis''', B-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis-diesis''',A-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle-bemolle'', H-diesis''',B-diesis-diesis-diesis''', D-bemolle'', E-bemolle-bemolle-bemolle'', H-diesis-diesis''',C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'', H-diesis-diesis-diesis''',C-diesis-diesis-diesis'', E-bemolle'', F-bemolle-bemolle'',C-diesis-diesis-diesis-diesis'', D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis-diesis'', E-diesis-diesis'', G-bemolle'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',A-bemolle'', B-bemolle-bemolle'', F-diesis-diesis-diesis'', H-bemolle-bemolle-bemolle'',B-bemolle'', C-bemolle-bemolle-bemolle', F-diesis-diesis-diesis-diesis'', G-diesis-diesis'', H-bemolle-bemolle'',A-diesis'', C-bemolle-bemolle', G-diesis-diesis-diesis'', H-bemolle'',A-diesis-diesis'', B-diesis'', C-bemolle', D-bemolle-bemolle-bemolle', G-diesis-diesis-diesis-diesis'',A-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle-bemolle', H-diesis'',B-diesis-diesis-diesis'', D-bemolle', E-bemolle-bemolle-bemolle', H-diesis-diesis'',C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle', H-diesis-diesis-diesis'',C-diesis-diesis-diesis', E-bemolle', F-bemolle-bemolle',C-diesis-diesis-diesis-diesis', D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', D-diesis-diesis-diesis-diesis', E-diesis-diesis', G-bemolle',A-bemolle-bemolle', B-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',A-bemolle', B-bemolle-bemolle', F-diesis-diesis-diesis', H-bemolle-bemolle-bemolle',B-bemolle', C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis', G-diesis-diesis', H-bemolle-bemolle',A-diesis', C-bemolle-bemolle, G-diesis-diesis-diesis', H-bemolle',A-diesis-diesis', B-diesis', C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis',A-diesis-diesis-diesis', B-diesis-diesis', D-bemolle-bemolle, H-diesis',B-diesis-diesis-diesis', D-bemolle, E-bemolle-bemolle-bemolle, H-diesis-diesis',C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis',C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle, F-diesis-diesis-diesis, H-bemolle-bemolle-bemolle,B-bemolle, F-diesis-diesis-diesis-diesis, G-diesis-diesis, H-bemolle-bemolle, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, H-bemolle, c-bemolle-bemolle,A-diesis-diesis, B-diesis, G-diesis-diesis-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis-diesis, H-diesis, d-bemolle-bemolle,B-diesis-diesis-diesis, H-diesis-diesis, d-bemolle, e-bemolle-bemolle-bemolle,H-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle, f-diesis-diesis-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle', f-diesis-diesis-diesis-diesis, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle', g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle', d-bemolle-bemolle-bemolle', g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle', h-diesis,b-diesis-diesis-diesis, d-bemolle', e-bemolle-bemolle-bemolle', h-diesis-diesis,c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle', h-diesis-diesis-diesis,c-diesis-diesis-diesis', e-bemolle', f-bemolle-bemolle',c-diesis-diesis-diesis-diesis', d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', d-diesis-diesis-diesis-diesis', e-diesis-diesis', g-bemolle',a-bemolle-bemolle', b-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',a-bemolle', b-bemolle-bemolle', f-diesis-diesis-diesis', h-bemolle-bemolle-bemolle',b-bemolle', c-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis-diesis', g-diesis-diesis', h-bemolle-bemolle',a-diesis', c-bemolle-bemolle'', g-diesis-diesis-diesis', h-bemolle',a-diesis-diesis', b-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis-diesis',a-diesis-diesis-diesis', b-diesis-diesis', d-bemolle-bemolle'', h-diesis',b-diesis-diesis-diesis', d-bemolle'', e-bemolle-bemolle-bemolle'', h-diesis-diesis',c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'', h-diesis-diesis-diesis',c-diesis-diesis-diesis'', e-bemolle'', f-bemolle-bemolle'',c-diesis-diesis-diesis-diesis'', d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis-diesis'', e-diesis-diesis'', g-bemolle'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',a-bemolle'', b-bemolle-bemolle'', f-diesis-diesis-diesis'', h-bemolle-bemolle-bemolle'',b-bemolle'', c-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis-diesis'', g-diesis-diesis'', h-bemolle-bemolle'',a-diesis'', c-bemolle-bemolle''', g-diesis-diesis-diesis'', h-bemolle'',a-diesis-diesis'', b-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis-diesis'',a-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle-bemolle''', h-diesis'',b-diesis-diesis-diesis'', d-bemolle''', e-bemolle-bemolle-bemolle''', h-diesis-diesis'',c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''', h-diesis-diesis-diesis'',c-diesis-diesis-diesis''', e-bemolle''', f-bemolle-bemolle''',c-diesis-diesis-diesis-diesis''', d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis-diesis''', e-diesis-diesis''', g-bemolle''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',a-bemolle''', b-bemolle-bemolle''', f-diesis-diesis-diesis''', h-bemolle-bemolle-bemolle''',b-bemolle''', c-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis-diesis''', g-diesis-diesis''', h-bemolle-bemolle''',a-diesis''', c-bemolle-bemolle'''', g-diesis-diesis-diesis''', h-bemolle''',a-diesis-diesis''', b-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis-diesis''',a-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle-bemolle'''', h-diesis''',b-diesis-diesis-diesis''', d-bemolle'''', e-bemolle-bemolle-bemolle'''', h-diesis-diesis''',c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''', h-diesis-diesis-diesis''',c-diesis-diesis-diesis'''', e-bemolle'''', f-bemolle-bemolle'''',c-diesis-diesis-diesis-diesis'''', d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis-diesis'''', e-diesis-diesis'''', g-bemolle'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',a-bemolle'''', b-bemolle-bemolle'''', f-diesis-diesis-diesis'''', h-bemolle-bemolle-bemolle'''',b-bemolle'''', c-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis-diesis'''', g-diesis-diesis'''', h-bemolle-bemolle'''',a-diesis'''', c-bemolle-bemolle''''', g-diesis-diesis-diesis'''', h-bemolle'''',a-diesis-diesis'''', b-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis-diesis'''',a-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle-bemolle''''', h-diesis'''',b-diesis-diesis-diesis'''', d-bemolle''''', e-bemolle-bemolle-bemolle''''', h-diesis-diesis'''',c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''', h-diesis-diesis-diesis'''',c-diesis-diesis-diesis''''', e-bemolle''''', f-bemolle-bemolle''''',c-diesis-diesis-diesis-diesis''''', d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis-diesis''''', e-diesis-diesis''''', g-bemolle''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',a-bemolle''''', b-bemolle-bemolle''''', f-diesis-diesis-diesis''''', h-bemolle-bemolle-bemolle''''',b-bemolle''''', c-bemolle-bemolle-bemolle'''''', f-diesis-diesis-diesis-diesis''''', g-diesis-diesis''''', h-bemolle-bemolle''''',a-diesis''''', c-bemolle-bemolle'''''', g-diesis-diesis-diesis''''', h-bemolle''''',a-diesis-diesis''''', b-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis-diesis''''',a-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle-bemolle'''''', h-diesis''''',b-diesis-diesis-diesis''''', d-bemolle'''''', e-bemolle-bemolle-bemolle'''''', h-diesis-diesis''''',c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''', h-diesis-diesis-diesis''''',c-diesis-diesis-diesis'''''', e-bemolle'''''', f-bemolle-bemolle'''''',c-diesis-diesis-diesis-diesis'''''', d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis-diesis'''''', e-diesis-diesis'''''', g-bemolle'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "a-diesis-diesis-diesis-6, b-diesis-diesis-6, d-bemolle-bemolle-5, e-bemolle-bemolle-bemolle-bemolle-5, h-diesis-6,b-diesis-diesis-diesis-6, c-diesis-5, e-bemolle-bemolle-bemolle-5, h-diesis-diesis-6,c-diesis-diesis-5, e-bemolle-bemolle-5, f-bemolle-bemolle-bemolle-5, h-diesis-diesis-diesis-6,c-diesis-diesis-diesis-5, d-diesis-5, f-bemolle-bemolle-5, g-bemolle-bemolle-bemolle-bemolle-5,d-diesis-diesis-5, f-bemolle-5, g-bemolle-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-bemolle-5, d-diesis-diesis-diesis-5, e-diesis-5, g-bemolle-bemolle-5,a-bemolle-bemolle-bemolle-5, e-diesis-diesis-5, f-diesis-5,a-bemolle-bemolle-5, b-bemolle-bemolle-bemolle-5, e-diesis-diesis-diesis-5, f-diesis-diesis-5,b-bemolle-bemolle-5, f-diesis-diesis-diesis-5, g-diesis-5, h-bemolle-bemolle-bemolle-5,b-bemolle-5, c-bemolle-bemolle-bemolle-4, g-diesis-diesis-5, h-bemolle-bemolle-5,a-diesis-5, c-bemolle-bemolle-4, d-bemolle-bemolle-bemolle-bemolle-4, g-diesis-diesis-diesis-5, h-bemolle-5,a-diesis-diesis-5, b-diesis-5, c-bemolle-4, d-bemolle-bemolle-bemolle-4,a-diesis-diesis-diesis-5, b-diesis-diesis-5, d-bemolle-bemolle-4, e-bemolle-bemolle-bemolle-bemolle-4, h-diesis-5,b-diesis-diesis-diesis-5, c-diesis-4, e-bemolle-bemolle-bemolle-4, h-diesis-diesis-5,c-diesis-diesis-4, e-bemolle-bemolle-4, f-bemolle-bemolle-bemolle-4, h-diesis-diesis-diesis-5,c-diesis-diesis-diesis-4, d-diesis-4, f-bemolle-bemolle-4, g-bemolle-bemolle-bemolle-bemolle-4,d-diesis-diesis-4, f-bemolle-4, g-bemolle-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-bemolle-4, d-diesis-diesis-diesis-4, e-diesis-4, g-bemolle-bemolle-4,a-bemolle-bemolle-bemolle-4, e-diesis-diesis-4, f-diesis-4,a-bemolle-bemolle-4, b-bemolle-bemolle-bemolle-4, e-diesis-diesis-diesis-4, f-diesis-diesis-4,b-bemolle-bemolle-4, f-diesis-diesis-diesis-4, g-diesis-4, h-bemolle-bemolle-bemolle-4,b-bemolle-4, c-bemolle-bemolle-bemolle-3, g-diesis-diesis-4, h-bemolle-bemolle-4,a-diesis-4, c-bemolle-bemolle-3, d-bemolle-bemolle-bemolle-bemolle-3, g-diesis-diesis-diesis-4, h-bemolle-4,a-diesis-diesis-4, b-diesis-4, c-bemolle-3, d-bemolle-bemolle-bemolle-3,a-diesis-diesis-diesis-4, b-diesis-diesis-4, d-bemolle-bemolle-3, e-bemolle-bemolle-bemolle-bemolle-3, h-diesis-4,b-diesis-diesis-diesis-4, c-diesis-3, e-bemolle-bemolle-bemolle-3, h-diesis-diesis-4,c-diesis-diesis-3, e-bemolle-bemolle-3, f-bemolle-bemolle-bemolle-3, h-diesis-diesis-diesis-4,c-diesis-diesis-diesis-3, d-diesis-3, f-bemolle-bemolle-3, g-bemolle-bemolle-bemolle-bemolle-3,d-diesis-diesis-3, f-bemolle-3, g-bemolle-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-bemolle-3, d-diesis-diesis-diesis-3, e-diesis-3, g-bemolle-bemolle-3,a-bemolle-bemolle-bemolle-3, e-diesis-diesis-3, f-diesis-3,a-bemolle-bemolle-3, b-bemolle-bemolle-bemolle-3, e-diesis-diesis-diesis-3, f-diesis-diesis-3,b-bemolle-bemolle-3, f-diesis-diesis-diesis-3, g-diesis-3, h-bemolle-bemolle-bemolle-3,b-bemolle-3, c-bemolle-bemolle-bemolle-2, g-diesis-diesis-3, h-bemolle-bemolle-3,a-diesis-3, c-bemolle-bemolle-2, d-bemolle-bemolle-bemolle-bemolle-2, g-diesis-diesis-diesis-3, h-bemolle-3,a-diesis-diesis-3, b-diesis-3, c-bemolle-2, d-bemolle-bemolle-bemolle-2,a-diesis-diesis-diesis-3, b-diesis-diesis-3, d-bemolle-bemolle-2, e-bemolle-bemolle-bemolle-bemolle-2, h-diesis-3,b-diesis-diesis-diesis-3, c-diesis-2, e-bemolle-bemolle-bemolle-2, h-diesis-diesis-3,c-diesis-diesis-2, e-bemolle-bemolle-2, f-bemolle-bemolle-bemolle-2, h-diesis-diesis-diesis-3,c-diesis-diesis-diesis-2, d-diesis-2, f-bemolle-bemolle-2, g-bemolle-bemolle-bemolle-bemolle-2,d-diesis-diesis-2, f-bemolle-2, g-bemolle-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-bemolle-2, d-diesis-diesis-diesis-2, e-diesis-2, g-bemolle-bemolle-2,a-bemolle-bemolle-bemolle-2, e-diesis-diesis-2, f-diesis-2,a-bemolle-bemolle-2, b-bemolle-bemolle-bemolle-2, e-diesis-diesis-diesis-2, f-diesis-diesis-2,b-bemolle-bemolle-2, f-diesis-diesis-diesis-2, g-diesis-2, h-bemolle-bemolle-bemolle-2,b-bemolle-2, c-bemolle-bemolle-bemolle-, g-diesis-diesis-2, h-bemolle-bemolle-2,a-diesis-2, c-bemolle-bemolle-, d-bemolle-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis-2, h-bemolle-2,a-diesis-diesis-2, b-diesis-2, c-bemolle-, d-bemolle-bemolle-bemolle-,a-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-bemolle-, e-bemolle-bemolle-bemolle-bemolle-, h-diesis-2,b-diesis-diesis-diesis-2, c-diesis-, e-bemolle-bemolle-bemolle-, h-diesis-diesis-2,c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-, h-diesis-diesis-diesis-2,c-diesis-diesis-diesis-, d-diesis-, f-bemolle-bemolle-, g-bemolle-bemolle-bemolle-bemolle-,d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,a-bemolle-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, e-diesis-diesis-, f-diesis-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,b-bemolle-bemolle-, f-diesis-diesis-diesis-, g-diesis-, h-bemolle-bemolle-bemolle-,b-bemolle-, c-bemolle-bemolle-bemolle, g-diesis-diesis-, h-bemolle-bemolle-,a-diesis-, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-, h-bemolle-,a-diesis-diesis-, b-diesis-, c-bemolle, d-bemolle-bemolle-bemolle,a-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle, h-diesis-,b-diesis-diesis-diesis-, c-diesis, e-bemolle-bemolle-bemolle, h-diesis-diesis-,c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle, h-diesis-diesis-diesis-,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle+, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle+, d-bemolle-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle+, e-bemolle-bemolle-bemolle-bemolle+, h-diesis,b-diesis-diesis-diesis, c-diesis+, e-bemolle-bemolle-bemolle+, h-diesis-diesis,c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+, h-diesis-diesis-diesis,c-diesis-diesis-diesis+, d-diesis+, f-bemolle-bemolle+, g-bemolle-bemolle-bemolle-bemolle+,d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,a-bemolle-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, e-diesis-diesis+, f-diesis+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,b-bemolle-bemolle+, f-diesis-diesis-diesis+, g-diesis+, h-bemolle-bemolle-bemolle+,b-bemolle+, c-bemolle-bemolle-bemolle+2, g-diesis-diesis+, h-bemolle-bemolle+,a-diesis+, c-bemolle-bemolle+2, d-bemolle-bemolle-bemolle-bemolle+2, g-diesis-diesis-diesis+, h-bemolle+,a-diesis-diesis+, b-diesis+, c-bemolle+2, d-bemolle-bemolle-bemolle+2,a-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle-bemolle+2, e-bemolle-bemolle-bemolle-bemolle+2, h-diesis+,b-diesis-diesis-diesis+, c-diesis+2, e-bemolle-bemolle-bemolle+2, h-diesis-diesis+,c-diesis-diesis+2, e-bemolle-bemolle+2, f-bemolle-bemolle-bemolle+2, h-diesis-diesis-diesis+,c-diesis-diesis-diesis+2, d-diesis+2, f-bemolle-bemolle+2, g-bemolle-bemolle-bemolle-bemolle+2,d-diesis-diesis+2, f-bemolle+2, g-bemolle-bemolle-bemolle+2,a-bemolle-bemolle-bemolle-bemolle+2, d-diesis-diesis-diesis+2, e-diesis+2, g-bemolle-bemolle+2,a-bemolle-bemolle-bemolle+2, e-diesis-diesis+2, f-diesis+2,a-bemolle-bemolle+2, b-bemolle-bemolle-bemolle+2, e-diesis-diesis-diesis+2, f-diesis-diesis+2,b-bemolle-bemolle+2, f-diesis-diesis-diesis+2, g-diesis+2, h-bemolle-bemolle-bemolle+2,b-bemolle+2, c-bemolle-bemolle-bemolle+3, g-diesis-diesis+2, h-bemolle-bemolle+2,a-diesis+2, c-bemolle-bemolle+3, d-bemolle-bemolle-bemolle-bemolle+3, g-diesis-diesis-diesis+2, h-bemolle+2,a-diesis-diesis+2, b-diesis+2, c-bemolle+3, d-bemolle-bemolle-bemolle+3,a-diesis-diesis-diesis+2, b-diesis-diesis+2, d-bemolle-bemolle+3, e-bemolle-bemolle-bemolle-bemolle+3, h-diesis+2,b-diesis-diesis-diesis+2, c-diesis+3, e-bemolle-bemolle-bemolle+3, h-diesis-diesis+2,c-diesis-diesis+3, e-bemolle-bemolle+3, f-bemolle-bemolle-bemolle+3, h-diesis-diesis-diesis+2,c-diesis-diesis-diesis+3, d-diesis+3, f-bemolle-bemolle+3, g-bemolle-bemolle-bemolle-bemolle+3,d-diesis-diesis+3, f-bemolle+3, g-bemolle-bemolle-bemolle+3,a-bemolle-bemolle-bemolle-bemolle+3, d-diesis-diesis-diesis+3, e-diesis+3, g-bemolle-bemolle+3,a-bemolle-bemolle-bemolle+3, e-diesis-diesis+3, f-diesis+3,a-bemolle-bemolle+3, b-bemolle-bemolle-bemolle+3, e-diesis-diesis-diesis+3, f-diesis-diesis+3,b-bemolle-bemolle+3, f-diesis-diesis-diesis+3, g-diesis+3, h-bemolle-bemolle-bemolle+3,b-bemolle+3, c-bemolle-bemolle-bemolle+4, g-diesis-diesis+3, h-bemolle-bemolle+3,a-diesis+3, c-bemolle-bemolle+4, d-bemolle-bemolle-bemolle-bemolle+4, g-diesis-diesis-diesis+3, h-bemolle+3,a-diesis-diesis+3, b-diesis+3, c-bemolle+4, d-bemolle-bemolle-bemolle+4,a-diesis-diesis-diesis+3, b-diesis-diesis+3, d-bemolle-bemolle+4, e-bemolle-bemolle-bemolle-bemolle+4, h-diesis+3,b-diesis-diesis-diesis+3, c-diesis+4, e-bemolle-bemolle-bemolle+4, h-diesis-diesis+3,c-diesis-diesis+4, e-bemolle-bemolle+4, f-bemolle-bemolle-bemolle+4, h-diesis-diesis-diesis+3,c-diesis-diesis-diesis+4, d-diesis+4, f-bemolle-bemolle+4, g-bemolle-bemolle-bemolle-bemolle+4,d-diesis-diesis+4, f-bemolle+4, g-bemolle-bemolle-bemolle+4,a-bemolle-bemolle-bemolle-bemolle+4, d-diesis-diesis-diesis+4, e-diesis+4, g-bemolle-bemolle+4,a-bemolle-bemolle-bemolle+4, e-diesis-diesis+4, f-diesis+4,a-bemolle-bemolle+4, b-bemolle-bemolle-bemolle+4, e-diesis-diesis-diesis+4, f-diesis-diesis+4,b-bemolle-bemolle+4, f-diesis-diesis-diesis+4, g-diesis+4, h-bemolle-bemolle-bemolle+4,b-bemolle+4, c-bemolle-bemolle-bemolle+5, g-diesis-diesis+4, h-bemolle-bemolle+4,a-diesis+4, c-bemolle-bemolle+5, d-bemolle-bemolle-bemolle-bemolle+5, g-diesis-diesis-diesis+4, h-bemolle+4,a-diesis-diesis+4, b-diesis+4, c-bemolle+5, d-bemolle-bemolle-bemolle+5,a-diesis-diesis-diesis+4, b-diesis-diesis+4, d-bemolle-bemolle+5, e-bemolle-bemolle-bemolle-bemolle+5, h-diesis+4,b-diesis-diesis-diesis+4, c-diesis+5, e-bemolle-bemolle-bemolle+5, h-diesis-diesis+4,c-diesis-diesis+5, e-bemolle-bemolle+5, f-bemolle-bemolle-bemolle+5, h-diesis-diesis-diesis+4,c-diesis-diesis-diesis+5, d-diesis+5, f-bemolle-bemolle+5, g-bemolle-bemolle-bemolle-bemolle+5,d-diesis-diesis+5, f-bemolle+5, g-bemolle-bemolle-bemolle+5,a-bemolle-bemolle-bemolle-bemolle+5, d-diesis-diesis-diesis+5, e-diesis+5, g-bemolle-bemolle+5,a-bemolle-bemolle-bemolle+5, e-diesis-diesis+5, f-diesis+5,a-bemolle-bemolle+5, b-bemolle-bemolle-bemolle+5, e-diesis-diesis-diesis+5, f-diesis-diesis+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "a-diesis-diesis-diesis------, b-diesis-diesis------, d-bemolle-bemolle-----, e-bemolle-bemolle-bemolle-bemolle-----, h-diesis------,b-diesis-diesis-diesis------, c-diesis-----, e-bemolle-bemolle-bemolle-----, h-diesis-diesis------,c-diesis-diesis-----, e-bemolle-bemolle-----, f-bemolle-bemolle-bemolle-----, h-diesis-diesis-diesis------,c-diesis-diesis-diesis-----, d-diesis-----, f-bemolle-bemolle-----, g-bemolle-bemolle-bemolle-bemolle-----,d-diesis-diesis-----, f-bemolle-----, g-bemolle-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-bemolle-----, d-diesis-diesis-diesis-----, e-diesis-----, g-bemolle-bemolle-----,a-bemolle-bemolle-bemolle-----, e-diesis-diesis-----, f-diesis-----,a-bemolle-bemolle-----, b-bemolle-bemolle-bemolle-----, e-diesis-diesis-diesis-----, f-diesis-diesis-----,b-bemolle-bemolle-----, f-diesis-diesis-diesis-----, g-diesis-----, h-bemolle-bemolle-bemolle-----,b-bemolle-----, c-bemolle-bemolle-bemolle----, g-diesis-diesis-----, h-bemolle-bemolle-----,a-diesis-----, c-bemolle-bemolle----, d-bemolle-bemolle-bemolle-bemolle----, g-diesis-diesis-diesis-----, h-bemolle-----,a-diesis-diesis-----, b-diesis-----, c-bemolle----, d-bemolle-bemolle-bemolle----,a-diesis-diesis-diesis-----, b-diesis-diesis-----, d-bemolle-bemolle----, e-bemolle-bemolle-bemolle-bemolle----, h-diesis-----,b-diesis-diesis-diesis-----, c-diesis----, e-bemolle-bemolle-bemolle----, h-diesis-diesis-----,c-diesis-diesis----, e-bemolle-bemolle----, f-bemolle-bemolle-bemolle----, h-diesis-diesis-diesis-----,c-diesis-diesis-diesis----, d-diesis----, f-bemolle-bemolle----, g-bemolle-bemolle-bemolle-bemolle----,d-diesis-diesis----, f-bemolle----, g-bemolle-bemolle-bemolle----,a-bemolle-bemolle-bemolle-bemolle----, d-diesis-diesis-diesis----, e-diesis----, g-bemolle-bemolle----,a-bemolle-bemolle-bemolle----, e-diesis-diesis----, f-diesis----,a-bemolle-bemolle----, b-bemolle-bemolle-bemolle----, e-diesis-diesis-diesis----, f-diesis-diesis----,b-bemolle-bemolle----, f-diesis-diesis-diesis----, g-diesis----, h-bemolle-bemolle-bemolle----,b-bemolle----, c-bemolle-bemolle-bemolle---, g-diesis-diesis----, h-bemolle-bemolle----,a-diesis----, c-bemolle-bemolle---, d-bemolle-bemolle-bemolle-bemolle---, g-diesis-diesis-diesis----, h-bemolle----,a-diesis-diesis----, b-diesis----, c-bemolle---, d-bemolle-bemolle-bemolle---,a-diesis-diesis-diesis----, b-diesis-diesis----, d-bemolle-bemolle---, e-bemolle-bemolle-bemolle-bemolle---, h-diesis----,b-diesis-diesis-diesis----, c-diesis---, e-bemolle-bemolle-bemolle---, h-diesis-diesis----,c-diesis-diesis---, e-bemolle-bemolle---, f-bemolle-bemolle-bemolle---, h-diesis-diesis-diesis----,c-diesis-diesis-diesis---, d-diesis---, f-bemolle-bemolle---, g-bemolle-bemolle-bemolle-bemolle---,d-diesis-diesis---, f-bemolle---, g-bemolle-bemolle-bemolle---,a-bemolle-bemolle-bemolle-bemolle---, d-diesis-diesis-diesis---, e-diesis---, g-bemolle-bemolle---,a-bemolle-bemolle-bemolle---, e-diesis-diesis---, f-diesis---,a-bemolle-bemolle---, b-bemolle-bemolle-bemolle---, e-diesis-diesis-diesis---, f-diesis-diesis---,b-bemolle-bemolle---, f-diesis-diesis-diesis---, g-diesis---, h-bemolle-bemolle-bemolle---,b-bemolle---, c-bemolle-bemolle-bemolle--, g-diesis-diesis---, h-bemolle-bemolle---,a-diesis---, c-bemolle-bemolle--, d-bemolle-bemolle-bemolle-bemolle--, g-diesis-diesis-diesis---, h-bemolle---,a-diesis-diesis---, b-diesis---, c-bemolle--, d-bemolle-bemolle-bemolle--,a-diesis-diesis-diesis---, b-diesis-diesis---, d-bemolle-bemolle--, e-bemolle-bemolle-bemolle-bemolle--, h-diesis---,b-diesis-diesis-diesis---, c-diesis--, e-bemolle-bemolle-bemolle--, h-diesis-diesis---,c-diesis-diesis--, e-bemolle-bemolle--, f-bemolle-bemolle-bemolle--, h-diesis-diesis-diesis---,c-diesis-diesis-diesis--, d-diesis--, f-bemolle-bemolle--, g-bemolle-bemolle-bemolle-bemolle--,d-diesis-diesis--, f-bemolle--, g-bemolle-bemolle-bemolle--,a-bemolle-bemolle-bemolle-bemolle--, d-diesis-diesis-diesis--, e-diesis--, g-bemolle-bemolle--,a-bemolle-bemolle-bemolle--, e-diesis-diesis--, f-diesis--,a-bemolle-bemolle--, b-bemolle-bemolle-bemolle--, e-diesis-diesis-diesis--, f-diesis-diesis--,b-bemolle-bemolle--, f-diesis-diesis-diesis--, g-diesis--, h-bemolle-bemolle-bemolle--,b-bemolle--, c-bemolle-bemolle-bemolle-, g-diesis-diesis--, h-bemolle-bemolle--,a-diesis--, c-bemolle-bemolle-, d-bemolle-bemolle-bemolle-bemolle-, g-diesis-diesis-diesis--, h-bemolle--,a-diesis-diesis--, b-diesis--, c-bemolle-, d-bemolle-bemolle-bemolle-,a-diesis-diesis-diesis--, b-diesis-diesis--, d-bemolle-bemolle-, e-bemolle-bemolle-bemolle-bemolle-, h-diesis--,b-diesis-diesis-diesis--, c-diesis-, e-bemolle-bemolle-bemolle-, h-diesis-diesis--,c-diesis-diesis-, e-bemolle-bemolle-, f-bemolle-bemolle-bemolle-, h-diesis-diesis-diesis--,c-diesis-diesis-diesis-, d-diesis-, f-bemolle-bemolle-, g-bemolle-bemolle-bemolle-bemolle-,d-diesis-diesis-, f-bemolle-, g-bemolle-bemolle-bemolle-,a-bemolle-bemolle-bemolle-bemolle-, d-diesis-diesis-diesis-, e-diesis-, g-bemolle-bemolle-,a-bemolle-bemolle-bemolle-, e-diesis-diesis-, f-diesis-,a-bemolle-bemolle-, b-bemolle-bemolle-bemolle-, e-diesis-diesis-diesis-, f-diesis-diesis-,b-bemolle-bemolle-, f-diesis-diesis-diesis-, g-diesis-, h-bemolle-bemolle-bemolle-,b-bemolle-, c-bemolle-bemolle-bemolle, g-diesis-diesis-, h-bemolle-bemolle-,a-diesis-, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle, g-diesis-diesis-diesis-, h-bemolle-,a-diesis-diesis-, b-diesis-, c-bemolle, d-bemolle-bemolle-bemolle,a-diesis-diesis-diesis-, b-diesis-diesis-, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle, h-diesis-,b-diesis-diesis-diesis-, c-diesis, e-bemolle-bemolle-bemolle, h-diesis-diesis-,c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle, h-diesis-diesis-diesis-,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle+, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle+, d-bemolle-bemolle-bemolle-bemolle+, g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle+, d-bemolle-bemolle-bemolle+,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle+, e-bemolle-bemolle-bemolle-bemolle+, h-diesis,b-diesis-diesis-diesis, c-diesis+, e-bemolle-bemolle-bemolle+, h-diesis-diesis,c-diesis-diesis+, e-bemolle-bemolle+, f-bemolle-bemolle-bemolle+, h-diesis-diesis-diesis,c-diesis-diesis-diesis+, d-diesis+, f-bemolle-bemolle+, g-bemolle-bemolle-bemolle-bemolle+,d-diesis-diesis+, f-bemolle+, g-bemolle-bemolle-bemolle+,a-bemolle-bemolle-bemolle-bemolle+, d-diesis-diesis-diesis+, e-diesis+, g-bemolle-bemolle+,a-bemolle-bemolle-bemolle+, e-diesis-diesis+, f-diesis+,a-bemolle-bemolle+, b-bemolle-bemolle-bemolle+, e-diesis-diesis-diesis+, f-diesis-diesis+,b-bemolle-bemolle+, f-diesis-diesis-diesis+, g-diesis+, h-bemolle-bemolle-bemolle+,b-bemolle+, c-bemolle-bemolle-bemolle++, g-diesis-diesis+, h-bemolle-bemolle+,a-diesis+, c-bemolle-bemolle++, d-bemolle-bemolle-bemolle-bemolle++, g-diesis-diesis-diesis+, h-bemolle+,a-diesis-diesis+, b-diesis+, c-bemolle++, d-bemolle-bemolle-bemolle++,a-diesis-diesis-diesis+, b-diesis-diesis+, d-bemolle-bemolle++, e-bemolle-bemolle-bemolle-bemolle++, h-diesis+,b-diesis-diesis-diesis+, c-diesis++, e-bemolle-bemolle-bemolle++, h-diesis-diesis+,c-diesis-diesis++, e-bemolle-bemolle++, f-bemolle-bemolle-bemolle++, h-diesis-diesis-diesis+,c-diesis-diesis-diesis++, d-diesis++, f-bemolle-bemolle++, g-bemolle-bemolle-bemolle-bemolle++,d-diesis-diesis++, f-bemolle++, g-bemolle-bemolle-bemolle++,a-bemolle-bemolle-bemolle-bemolle++, d-diesis-diesis-diesis++, e-diesis++, g-bemolle-bemolle++,a-bemolle-bemolle-bemolle++, e-diesis-diesis++, f-diesis++,a-bemolle-bemolle++, b-bemolle-bemolle-bemolle++, e-diesis-diesis-diesis++, f-diesis-diesis++,b-bemolle-bemolle++, f-diesis-diesis-diesis++, g-diesis++, h-bemolle-bemolle-bemolle++,b-bemolle++, c-bemolle-bemolle-bemolle+++, g-diesis-diesis++, h-bemolle-bemolle++,a-diesis++, c-bemolle-bemolle+++, d-bemolle-bemolle-bemolle-bemolle+++, g-diesis-diesis-diesis++, h-bemolle++,a-diesis-diesis++, b-diesis++, c-bemolle+++, d-bemolle-bemolle-bemolle+++,a-diesis-diesis-diesis++, b-diesis-diesis++, d-bemolle-bemolle+++, e-bemolle-bemolle-bemolle-bemolle+++, h-diesis++,b-diesis-diesis-diesis++, c-diesis+++, e-bemolle-bemolle-bemolle+++, h-diesis-diesis++,c-diesis-diesis+++, e-bemolle-bemolle+++, f-bemolle-bemolle-bemolle+++, h-diesis-diesis-diesis++,c-diesis-diesis-diesis+++, d-diesis+++, f-bemolle-bemolle+++, g-bemolle-bemolle-bemolle-bemolle+++,d-diesis-diesis+++, f-bemolle+++, g-bemolle-bemolle-bemolle+++,a-bemolle-bemolle-bemolle-bemolle+++, d-diesis-diesis-diesis+++, e-diesis+++, g-bemolle-bemolle+++,a-bemolle-bemolle-bemolle+++, e-diesis-diesis+++, f-diesis+++,a-bemolle-bemolle+++, b-bemolle-bemolle-bemolle+++, e-diesis-diesis-diesis+++, f-diesis-diesis+++,b-bemolle-bemolle+++, f-diesis-diesis-diesis+++, g-diesis+++, h-bemolle-bemolle-bemolle+++,b-bemolle+++, c-bemolle-bemolle-bemolle++++, g-diesis-diesis+++, h-bemolle-bemolle+++,a-diesis+++, c-bemolle-bemolle++++, d-bemolle-bemolle-bemolle-bemolle++++, g-diesis-diesis-diesis+++, h-bemolle+++,a-diesis-diesis+++, b-diesis+++, c-bemolle++++, d-bemolle-bemolle-bemolle++++,a-diesis-diesis-diesis+++, b-diesis-diesis+++, d-bemolle-bemolle++++, e-bemolle-bemolle-bemolle-bemolle++++, h-diesis+++,b-diesis-diesis-diesis+++, c-diesis++++, e-bemolle-bemolle-bemolle++++, h-diesis-diesis+++,c-diesis-diesis++++, e-bemolle-bemolle++++, f-bemolle-bemolle-bemolle++++, h-diesis-diesis-diesis+++,c-diesis-diesis-diesis++++, d-diesis++++, f-bemolle-bemolle++++, g-bemolle-bemolle-bemolle-bemolle++++,d-diesis-diesis++++, f-bemolle++++, g-bemolle-bemolle-bemolle++++,a-bemolle-bemolle-bemolle-bemolle++++, d-diesis-diesis-diesis++++, e-diesis++++, g-bemolle-bemolle++++,a-bemolle-bemolle-bemolle++++, e-diesis-diesis++++, f-diesis++++,a-bemolle-bemolle++++, b-bemolle-bemolle-bemolle++++, e-diesis-diesis-diesis++++, f-diesis-diesis++++,b-bemolle-bemolle++++, f-diesis-diesis-diesis++++, g-diesis++++, h-bemolle-bemolle-bemolle++++,b-bemolle++++, c-bemolle-bemolle-bemolle+++++, g-diesis-diesis++++, h-bemolle-bemolle++++,a-diesis++++, c-bemolle-bemolle+++++, d-bemolle-bemolle-bemolle-bemolle+++++, g-diesis-diesis-diesis++++, h-bemolle++++,a-diesis-diesis++++, b-diesis++++, c-bemolle+++++, d-bemolle-bemolle-bemolle+++++,a-diesis-diesis-diesis++++, b-diesis-diesis++++, d-bemolle-bemolle+++++, e-bemolle-bemolle-bemolle-bemolle+++++, h-diesis++++,b-diesis-diesis-diesis++++, c-diesis+++++, e-bemolle-bemolle-bemolle+++++, h-diesis-diesis++++,c-diesis-diesis+++++, e-bemolle-bemolle+++++, f-bemolle-bemolle-bemolle+++++, h-diesis-diesis-diesis++++,c-diesis-diesis-diesis+++++, d-diesis+++++, f-bemolle-bemolle+++++, g-bemolle-bemolle-bemolle-bemolle+++++,d-diesis-diesis+++++, f-bemolle+++++, g-bemolle-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle-bemolle+++++, d-diesis-diesis-diesis+++++, e-diesis+++++, g-bemolle-bemolle+++++,a-bemolle-bemolle-bemolle+++++, e-diesis-diesis+++++, f-diesis+++++,a-bemolle-bemolle+++++, b-bemolle-bemolle-bemolle+++++, e-diesis-diesis-diesis+++++, f-diesis-diesis+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "a-diesis-diesis-diesis-2, b-diesis-diesis-2, d-bemolle-bemolle-1, e-bemolle-bemolle-bemolle-bemolle-1, h-diesis-2,b-diesis-diesis-diesis-2, c-diesis-1, e-bemolle-bemolle-bemolle-1, h-diesis-diesis-2,c-diesis-diesis-1, e-bemolle-bemolle-1, f-bemolle-bemolle-bemolle-1, h-diesis-diesis-diesis-2,c-diesis-diesis-diesis-1, d-diesis-1, f-bemolle-bemolle-1, g-bemolle-bemolle-bemolle-bemolle-1,d-diesis-diesis-1, f-bemolle-1, g-bemolle-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-bemolle-1, d-diesis-diesis-diesis-1, e-diesis-1, g-bemolle-bemolle-1,a-bemolle-bemolle-bemolle-1, e-diesis-diesis-1, f-diesis-1,a-bemolle-bemolle-1, b-bemolle-bemolle-bemolle-1, e-diesis-diesis-diesis-1, f-diesis-diesis-1,b-bemolle-bemolle-1, f-diesis-diesis-diesis-1, g-diesis-1, h-bemolle-bemolle-bemolle-1,b-bemolle-1, c-bemolle-bemolle-bemolle0, g-diesis-diesis-1, h-bemolle-bemolle-1,a-diesis-1, c-bemolle-bemolle0, d-bemolle-bemolle-bemolle-bemolle0, g-diesis-diesis-diesis-1, h-bemolle-1,a-diesis-diesis-1, b-diesis-1, c-bemolle0, d-bemolle-bemolle-bemolle0,a-diesis-diesis-diesis-1, b-diesis-diesis-1, d-bemolle-bemolle0, e-bemolle-bemolle-bemolle-bemolle0, h-diesis-1,b-diesis-diesis-diesis-1, c-diesis0, e-bemolle-bemolle-bemolle0, h-diesis-diesis-1,c-diesis-diesis0, e-bemolle-bemolle0, f-bemolle-bemolle-bemolle0, h-diesis-diesis-diesis-1,c-diesis-diesis-diesis0, d-diesis0, f-bemolle-bemolle0, g-bemolle-bemolle-bemolle-bemolle0,d-diesis-diesis0, f-bemolle0, g-bemolle-bemolle-bemolle0,a-bemolle-bemolle-bemolle-bemolle0, d-diesis-diesis-diesis0, e-diesis0, g-bemolle-bemolle0,a-bemolle-bemolle-bemolle0, e-diesis-diesis0, f-diesis0,a-bemolle-bemolle0, b-bemolle-bemolle-bemolle0, e-diesis-diesis-diesis0, f-diesis-diesis0,b-bemolle-bemolle0, f-diesis-diesis-diesis0, g-diesis0, h-bemolle-bemolle-bemolle0,b-bemolle0, c-bemolle-bemolle-bemolle1, g-diesis-diesis0, h-bemolle-bemolle0,a-diesis0, c-bemolle-bemolle1, d-bemolle-bemolle-bemolle-bemolle1, g-diesis-diesis-diesis0, h-bemolle0,a-diesis-diesis0, b-diesis0, c-bemolle1, d-bemolle-bemolle-bemolle1,a-diesis-diesis-diesis0, b-diesis-diesis0, d-bemolle-bemolle1, e-bemolle-bemolle-bemolle-bemolle1, h-diesis0,b-diesis-diesis-diesis0, c-diesis1, e-bemolle-bemolle-bemolle1, h-diesis-diesis0,c-diesis-diesis1, e-bemolle-bemolle1, f-bemolle-bemolle-bemolle1, h-diesis-diesis-diesis0,c-diesis-diesis-diesis1, d-diesis1, f-bemolle-bemolle1, g-bemolle-bemolle-bemolle-bemolle1,d-diesis-diesis1, f-bemolle1, g-bemolle-bemolle-bemolle1,a-bemolle-bemolle-bemolle-bemolle1, d-diesis-diesis-diesis1, e-diesis1, g-bemolle-bemolle1,a-bemolle-bemolle-bemolle1, e-diesis-diesis1, f-diesis1,a-bemolle-bemolle1, b-bemolle-bemolle-bemolle1, e-diesis-diesis-diesis1, f-diesis-diesis1,b-bemolle-bemolle1, f-diesis-diesis-diesis1, g-diesis1, h-bemolle-bemolle-bemolle1,b-bemolle1, c-bemolle-bemolle-bemolle2, g-diesis-diesis1, h-bemolle-bemolle1,a-diesis1, c-bemolle-bemolle2, d-bemolle-bemolle-bemolle-bemolle2, g-diesis-diesis-diesis1, h-bemolle1,a-diesis-diesis1, b-diesis1, c-bemolle2, d-bemolle-bemolle-bemolle2,a-diesis-diesis-diesis1, b-diesis-diesis1, d-bemolle-bemolle2, e-bemolle-bemolle-bemolle-bemolle2, h-diesis1,b-diesis-diesis-diesis1, c-diesis2, e-bemolle-bemolle-bemolle2, h-diesis-diesis1,c-diesis-diesis2, e-bemolle-bemolle2, f-bemolle-bemolle-bemolle2, h-diesis-diesis-diesis1,c-diesis-diesis-diesis2, d-diesis2, f-bemolle-bemolle2, g-bemolle-bemolle-bemolle-bemolle2,d-diesis-diesis2, f-bemolle2, g-bemolle-bemolle-bemolle2,a-bemolle-bemolle-bemolle-bemolle2, d-diesis-diesis-diesis2, e-diesis2, g-bemolle-bemolle2,a-bemolle-bemolle-bemolle2, e-diesis-diesis2, f-diesis2,a-bemolle-bemolle2, b-bemolle-bemolle-bemolle2, e-diesis-diesis-diesis2, f-diesis-diesis2,b-bemolle-bemolle2, f-diesis-diesis-diesis2, g-diesis2, h-bemolle-bemolle-bemolle2,b-bemolle2, c-bemolle-bemolle-bemolle3, g-diesis-diesis2, h-bemolle-bemolle2,a-diesis2, c-bemolle-bemolle3, d-bemolle-bemolle-bemolle-bemolle3, g-diesis-diesis-diesis2, h-bemolle2,a-diesis-diesis2, b-diesis2, c-bemolle3, d-bemolle-bemolle-bemolle3,a-diesis-diesis-diesis2, b-diesis-diesis2, d-bemolle-bemolle3, e-bemolle-bemolle-bemolle-bemolle3, h-diesis2,b-diesis-diesis-diesis2, c-diesis3, e-bemolle-bemolle-bemolle3, h-diesis-diesis2,c-diesis-diesis3, e-bemolle-bemolle3, f-bemolle-bemolle-bemolle3, h-diesis-diesis-diesis2,c-diesis-diesis-diesis3, d-diesis3, f-bemolle-bemolle3, g-bemolle-bemolle-bemolle-bemolle3,d-diesis-diesis3, f-bemolle3, g-bemolle-bemolle-bemolle3,a-bemolle-bemolle-bemolle-bemolle3, d-diesis-diesis-diesis3, e-diesis3, g-bemolle-bemolle3,a-bemolle-bemolle-bemolle3, e-diesis-diesis3, f-diesis3,a-bemolle-bemolle3, b-bemolle-bemolle-bemolle3, e-diesis-diesis-diesis3, f-diesis-diesis3,b-bemolle-bemolle3, f-diesis-diesis-diesis3, g-diesis3, h-bemolle-bemolle-bemolle3,b-bemolle3, c-bemolle-bemolle-bemolle4, g-diesis-diesis3, h-bemolle-bemolle3,a-diesis3, c-bemolle-bemolle4, d-bemolle-bemolle-bemolle-bemolle4, g-diesis-diesis-diesis3, h-bemolle3,a-diesis-diesis3, b-diesis3, c-bemolle4, d-bemolle-bemolle-bemolle4,a-diesis-diesis-diesis3, b-diesis-diesis3, d-bemolle-bemolle4, e-bemolle-bemolle-bemolle-bemolle4, h-diesis3,b-diesis-diesis-diesis3, c-diesis4, e-bemolle-bemolle-bemolle4, h-diesis-diesis3,c-diesis-diesis4, e-bemolle-bemolle4, f-bemolle-bemolle-bemolle4, h-diesis-diesis-diesis3,c-diesis-diesis-diesis4, d-diesis4, f-bemolle-bemolle4, g-bemolle-bemolle-bemolle-bemolle4,d-diesis-diesis4, f-bemolle4, g-bemolle-bemolle-bemolle4,a-bemolle-bemolle-bemolle-bemolle4, d-diesis-diesis-diesis4, e-diesis4, g-bemolle-bemolle4,a-bemolle-bemolle-bemolle4, e-diesis-diesis4, f-diesis4,a-bemolle-bemolle4, b-bemolle-bemolle-bemolle4, e-diesis-diesis-diesis4, f-diesis-diesis4,b-bemolle-bemolle4, f-diesis-diesis-diesis4, g-diesis4, h-bemolle-bemolle-bemolle4,b-bemolle4, c-bemolle-bemolle-bemolle5, g-diesis-diesis4, h-bemolle-bemolle4,a-diesis4, c-bemolle-bemolle5, d-bemolle-bemolle-bemolle-bemolle5, g-diesis-diesis-diesis4, h-bemolle4,a-diesis-diesis4, b-diesis4, c-bemolle5, d-bemolle-bemolle-bemolle5,a-diesis-diesis-diesis4, b-diesis-diesis4, d-bemolle-bemolle5, e-bemolle-bemolle-bemolle-bemolle5, h-diesis4,b-diesis-diesis-diesis4, c-diesis5, e-bemolle-bemolle-bemolle5, h-diesis-diesis4,c-diesis-diesis5, e-bemolle-bemolle5, f-bemolle-bemolle-bemolle5, h-diesis-diesis-diesis4,c-diesis-diesis-diesis5, d-diesis5, f-bemolle-bemolle5, g-bemolle-bemolle-bemolle-bemolle5,d-diesis-diesis5, f-bemolle5, g-bemolle-bemolle-bemolle5,a-bemolle-bemolle-bemolle-bemolle5, d-diesis-diesis-diesis5, e-diesis5, g-bemolle-bemolle5,a-bemolle-bemolle-bemolle5, e-diesis-diesis5, f-diesis5,a-bemolle-bemolle5, b-bemolle-bemolle-bemolle5, e-diesis-diesis-diesis5, f-diesis-diesis5,b-bemolle-bemolle5, f-diesis-diesis-diesis5, g-diesis5, h-bemolle-bemolle-bemolle5,b-bemolle5, c-bemolle-bemolle-bemolle6, g-diesis-diesis5, h-bemolle-bemolle5,a-diesis5, c-bemolle-bemolle6, d-bemolle-bemolle-bemolle-bemolle6, g-diesis-diesis-diesis5, h-bemolle5,a-diesis-diesis5, b-diesis5, c-bemolle6, d-bemolle-bemolle-bemolle6,a-diesis-diesis-diesis5, b-diesis-diesis5, d-bemolle-bemolle6, e-bemolle-bemolle-bemolle-bemolle6, h-diesis5,b-diesis-diesis-diesis5, c-diesis6, e-bemolle-bemolle-bemolle6, h-diesis-diesis5,c-diesis-diesis6, e-bemolle-bemolle6, f-bemolle-bemolle-bemolle6, h-diesis-diesis-diesis5,c-diesis-diesis-diesis6, d-diesis6, f-bemolle-bemolle6, g-bemolle-bemolle-bemolle-bemolle6,d-diesis-diesis6, f-bemolle6, g-bemolle-bemolle-bemolle6,a-bemolle-bemolle-bemolle-bemolle6, d-diesis-diesis-diesis6, e-diesis6, g-bemolle-bemolle6,a-bemolle-bemolle-bemolle6, e-diesis-diesis6, f-diesis6,a-bemolle-bemolle6, b-bemolle-bemolle-bemolle6, e-diesis-diesis-diesis6, f-diesis-diesis6,b-bemolle-bemolle6, f-diesis-diesis-diesis6, g-diesis6, h-bemolle-bemolle-bemolle6,b-bemolle6, c-bemolle-bemolle-bemolle7, g-diesis-diesis6, h-bemolle-bemolle6,a-diesis6, c-bemolle-bemolle7, d-bemolle-bemolle-bemolle-bemolle7, g-diesis-diesis-diesis6, h-bemolle6,a-diesis-diesis6, b-diesis6, c-bemolle7, d-bemolle-bemolle-bemolle7,a-diesis-diesis-diesis6, b-diesis-diesis6, d-bemolle-bemolle7, e-bemolle-bemolle-bemolle-bemolle7, h-diesis6,b-diesis-diesis-diesis6, c-diesis7, e-bemolle-bemolle-bemolle7, h-diesis-diesis6,c-diesis-diesis7, e-bemolle-bemolle7, f-bemolle-bemolle-bemolle7, h-diesis-diesis-diesis6,c-diesis-diesis-diesis7, d-diesis7, f-bemolle-bemolle7, g-bemolle-bemolle-bemolle-bemolle7,d-diesis-diesis7, f-bemolle7, g-bemolle-bemolle-bemolle7,a-bemolle-bemolle-bemolle-bemolle7, d-diesis-diesis-diesis7, e-diesis7, g-bemolle-bemolle7,a-bemolle-bemolle-bemolle7, e-diesis-diesis7, f-diesis7,a-bemolle-bemolle7, b-bemolle-bemolle-bemolle7, e-diesis-diesis-diesis7, f-diesis-diesis7,b-bemolle-bemolle7, f-diesis-diesis-diesis7, g-diesis7, h-bemolle-bemolle-bemolle7,b-bemolle7, c-bemolle-bemolle-bemolle8, g-diesis-diesis7, h-bemolle-bemolle7,a-diesis7, c-bemolle-bemolle8, d-bemolle-bemolle-bemolle-bemolle8, g-diesis-diesis-diesis7, h-bemolle7,a-diesis-diesis7, b-diesis7, c-bemolle8, d-bemolle-bemolle-bemolle8,a-diesis-diesis-diesis7, b-diesis-diesis7, d-bemolle-bemolle8, e-bemolle-bemolle-bemolle-bemolle8, h-diesis7,b-diesis-diesis-diesis7, c-diesis8, e-bemolle-bemolle-bemolle8, h-diesis-diesis7,c-diesis-diesis8, e-bemolle-bemolle8, f-bemolle-bemolle-bemolle8, h-diesis-diesis-diesis7,c-diesis-diesis-diesis8, d-diesis8, f-bemolle-bemolle8, g-bemolle-bemolle-bemolle-bemolle8,d-diesis-diesis8, f-bemolle8, g-bemolle-bemolle-bemolle8,a-bemolle-bemolle-bemolle-bemolle8, d-diesis-diesis-diesis8, e-diesis8, g-bemolle-bemolle8,a-bemolle-bemolle-bemolle8, e-diesis-diesis8, f-diesis8,a-bemolle-bemolle8, b-bemolle-bemolle-bemolle8, e-diesis-diesis-diesis8, f-diesis-diesis8,b-bemolle-bemolle8, f-diesis-diesis-diesis8, g-diesis8, h-bemolle-bemolle-bemolle8,b-bemolle8, c-bemolle-bemolle-bemolle9, g-diesis-diesis8, h-bemolle-bemolle8,a-diesis8, c-bemolle-bemolle9, d-bemolle-bemolle-bemolle-bemolle9, g-diesis-diesis-diesis8, h-bemolle8,a-diesis-diesis8, b-diesis8, c-bemolle9, d-bemolle-bemolle-bemolle9,a-diesis-diesis-diesis8, b-diesis-diesis8, d-bemolle-bemolle9, e-bemolle-bemolle-bemolle-bemolle9, h-diesis8,b-diesis-diesis-diesis8, c-diesis9, e-bemolle-bemolle-bemolle9, h-diesis-diesis8,c-diesis-diesis9, e-bemolle-bemolle9, f-bemolle-bemolle-bemolle9, h-diesis-diesis-diesis8,c-diesis-diesis-diesis9, d-diesis9, f-bemolle-bemolle9, g-bemolle-bemolle-bemolle-bemolle9,d-diesis-diesis9, f-bemolle9, g-bemolle-bemolle-bemolle9,a-bemolle-bemolle-bemolle-bemolle9, d-diesis-diesis-diesis9, e-diesis9, g-bemolle-bemolle9,a-bemolle-bemolle-bemolle9, e-diesis-diesis9, f-diesis9,a-bemolle-bemolle9, b-bemolle-bemolle-bemolle9, e-diesis-diesis-diesis9, f-diesis-diesis9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle-bemolle''', E-bemolle-bemolle-bemolle-bemolle''', H-diesis'''',B-diesis-diesis-diesis'''', C-diesis''', E-bemolle-bemolle-bemolle''', H-diesis-diesis'''',C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''', H-diesis-diesis-diesis'''',C-diesis-diesis-diesis''', D-diesis''', F-bemolle-bemolle''', G-bemolle-bemolle-bemolle-bemolle''',D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',A-bemolle-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', E-diesis-diesis''', F-diesis''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',B-bemolle-bemolle''', F-diesis-diesis-diesis''', G-diesis''', H-bemolle-bemolle-bemolle''',B-bemolle''', C-bemolle-bemolle-bemolle'', G-diesis-diesis''', H-bemolle-bemolle''',A-diesis''', C-bemolle-bemolle'', D-bemolle-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis''', H-bemolle''',A-diesis-diesis''', B-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'',A-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle-bemolle'', E-bemolle-bemolle-bemolle-bemolle'', H-diesis''',B-diesis-diesis-diesis''', C-diesis'', E-bemolle-bemolle-bemolle'', H-diesis-diesis''',C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'', H-diesis-diesis-diesis''',C-diesis-diesis-diesis'', D-diesis'', F-bemolle-bemolle'', G-bemolle-bemolle-bemolle-bemolle'',D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',A-bemolle-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', E-diesis-diesis'', F-diesis'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',B-bemolle-bemolle'', F-diesis-diesis-diesis'', G-diesis'', H-bemolle-bemolle-bemolle'',B-bemolle'', C-bemolle-bemolle-bemolle', G-diesis-diesis'', H-bemolle-bemolle'',A-diesis'', C-bemolle-bemolle', D-bemolle-bemolle-bemolle-bemolle', G-diesis-diesis-diesis'', H-bemolle'',A-diesis-diesis'', B-diesis'', C-bemolle', D-bemolle-bemolle-bemolle',A-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle-bemolle', E-bemolle-bemolle-bemolle-bemolle', H-diesis'',B-diesis-diesis-diesis'', C-diesis', E-bemolle-bemolle-bemolle', H-diesis-diesis'',C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle', H-diesis-diesis-diesis'',C-diesis-diesis-diesis', D-diesis', F-bemolle-bemolle', G-bemolle-bemolle-bemolle-bemolle',D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',A-bemolle-bemolle-bemolle-bemolle', D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', E-diesis-diesis', F-diesis',A-bemolle-bemolle', B-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',B-bemolle-bemolle', F-diesis-diesis-diesis', G-diesis', H-bemolle-bemolle-bemolle',B-bemolle', C-bemolle-bemolle-bemolle, G-diesis-diesis', H-bemolle-bemolle',A-diesis', C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis', H-bemolle',A-diesis-diesis', B-diesis', C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis', B-diesis-diesis', D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle, H-diesis',B-diesis-diesis-diesis', C-diesis, E-bemolle-bemolle-bemolle, H-diesis-diesis',C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis',C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis, H-bemolle-bemolle-bemolle,B-bemolle, G-diesis-diesis, H-bemolle-bemolle, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, H-bemolle, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle,A-diesis-diesis, B-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis-diesis, H-diesis, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, H-diesis-diesis, c-diesis, e-bemolle-bemolle-bemolle,H-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle', g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle', d-bemolle-bemolle-bemolle-bemolle', g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle', d-bemolle-bemolle-bemolle',a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle', e-bemolle-bemolle-bemolle-bemolle', h-diesis,b-diesis-diesis-diesis, c-diesis', e-bemolle-bemolle-bemolle', h-diesis-diesis,c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle', h-diesis-diesis-diesis,c-diesis-diesis-diesis', d-diesis', f-bemolle-bemolle', g-bemolle-bemolle-bemolle-bemolle',d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',a-bemolle-bemolle-bemolle-bemolle', d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', e-diesis-diesis', f-diesis',a-bemolle-bemolle', b-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',b-bemolle-bemolle', f-diesis-diesis-diesis', g-diesis', h-bemolle-bemolle-bemolle',b-bemolle', c-bemolle-bemolle-bemolle'', g-diesis-diesis', h-bemolle-bemolle',a-diesis', c-bemolle-bemolle'', d-bemolle-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis', h-bemolle',a-diesis-diesis', b-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'',a-diesis-diesis-diesis', b-diesis-diesis', d-bemolle-bemolle'', e-bemolle-bemolle-bemolle-bemolle'', h-diesis',b-diesis-diesis-diesis', c-diesis'', e-bemolle-bemolle-bemolle'', h-diesis-diesis',c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'', h-diesis-diesis-diesis',c-diesis-diesis-diesis'', d-diesis'', f-bemolle-bemolle'', g-bemolle-bemolle-bemolle-bemolle'',d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',a-bemolle-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', e-diesis-diesis'', f-diesis'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',b-bemolle-bemolle'', f-diesis-diesis-diesis'', g-diesis'', h-bemolle-bemolle-bemolle'',b-bemolle'', c-bemolle-bemolle-bemolle''', g-diesis-diesis'', h-bemolle-bemolle'',a-diesis'', c-bemolle-bemolle''', d-bemolle-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis'', h-bemolle'',a-diesis-diesis'', b-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''',a-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle-bemolle''', e-bemolle-bemolle-bemolle-bemolle''', h-diesis'',b-diesis-diesis-diesis'', c-diesis''', e-bemolle-bemolle-bemolle''', h-diesis-diesis'',c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''', h-diesis-diesis-diesis'',c-diesis-diesis-diesis''', d-diesis''', f-bemolle-bemolle''', g-bemolle-bemolle-bemolle-bemolle''',d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',a-bemolle-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', e-diesis-diesis''', f-diesis''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',b-bemolle-bemolle''', f-diesis-diesis-diesis''', g-diesis''', h-bemolle-bemolle-bemolle''',b-bemolle''', c-bemolle-bemolle-bemolle'''', g-diesis-diesis''', h-bemolle-bemolle''',a-diesis''', c-bemolle-bemolle'''', d-bemolle-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis''', h-bemolle''',a-diesis-diesis''', b-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''',a-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle-bemolle'''', e-bemolle-bemolle-bemolle-bemolle'''', h-diesis''',b-diesis-diesis-diesis''', c-diesis'''', e-bemolle-bemolle-bemolle'''', h-diesis-diesis''',c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''', h-diesis-diesis-diesis''',c-diesis-diesis-diesis'''', d-diesis'''', f-bemolle-bemolle'''', g-bemolle-bemolle-bemolle-bemolle'''',d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',a-bemolle-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', e-diesis-diesis'''', f-diesis'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',b-bemolle-bemolle'''', f-diesis-diesis-diesis'''', g-diesis'''', h-bemolle-bemolle-bemolle'''',b-bemolle'''', c-bemolle-bemolle-bemolle''''', g-diesis-diesis'''', h-bemolle-bemolle'''',a-diesis'''', c-bemolle-bemolle''''', d-bemolle-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis'''', h-bemolle'''',a-diesis-diesis'''', b-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''',a-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle-bemolle''''', e-bemolle-bemolle-bemolle-bemolle''''', h-diesis'''',b-diesis-diesis-diesis'''', c-diesis''''', e-bemolle-bemolle-bemolle''''', h-diesis-diesis'''',c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''', h-diesis-diesis-diesis'''',c-diesis-diesis-diesis''''', d-diesis''''', f-bemolle-bemolle''''', g-bemolle-bemolle-bemolle-bemolle''''',d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',a-bemolle-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', e-diesis-diesis''''', f-diesis''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',b-bemolle-bemolle''''', f-diesis-diesis-diesis''''', g-diesis''''', h-bemolle-bemolle-bemolle''''',b-bemolle''''', c-bemolle-bemolle-bemolle'''''', g-diesis-diesis''''', h-bemolle-bemolle''''',a-diesis''''', c-bemolle-bemolle'''''', d-bemolle-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis''''', h-bemolle''''',a-diesis-diesis''''', b-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''',a-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle-bemolle'''''', e-bemolle-bemolle-bemolle-bemolle'''''', h-diesis''''',b-diesis-diesis-diesis''''', c-diesis'''''', e-bemolle-bemolle-bemolle'''''', h-diesis-diesis''''',c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''', h-diesis-diesis-diesis''''',c-diesis-diesis-diesis'''''', d-diesis'''''', f-bemolle-bemolle'''''', g-bemolle-bemolle-bemolle-bemolle'''''',d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', e-diesis-diesis'''''', f-diesis'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "aisisis-6, bisis-6, deses-5, his-6,bisisis-6, des-5, eseses-5, hisis-6,cisis-5, eses-5, feseses-5, hisisis-6,cisisis-5, es-5, feses-5,cisisisis-5, disis-5, fes-5, geseses-5,disisis-5, eis-5, geses-5,aseses-5, disisisis-5, eisis-5, ges-5,ases-5, beseses-5, eisisis-5, fisis-5,as-5, beses-5, fisisis-5,bes-5, ceseses-4, fisisisis-5, gisis-5,ais-5, ceses-4, gisisis-5,aisis-5, bis-5, ces-4, deseses-4, gisisisis-5,aisisis-5, bisis-5, deses-4, his-5,bisisis-5, des-4, eseses-4, hisis-5,cisis-4, eses-4, feseses-4, hisisis-5,cisisis-4, es-4, feses-4,cisisisis-4, disis-4, fes-4, geseses-4,disisis-4, eis-4, geses-4,aseses-4, disisisis-4, eisis-4, ges-4,ases-4, beseses-4, eisisis-4, fisis-4,as-4, beses-4, fisisis-4,bes-4, ceseses-3, fisisisis-4, gisis-4,ais-4, ceses-3, gisisis-4,aisis-4, bis-4, ces-3, deseses-3, gisisisis-4,aisisis-4, bisis-4, deses-3, his-4,bisisis-4, des-3, eseses-3, hisis-4,cisis-3, eses-3, feseses-3, hisisis-4,cisisis-3, es-3, feses-3,cisisisis-3, disis-3, fes-3, geseses-3,disisis-3, eis-3, geses-3,aseses-3, disisisis-3, eisis-3, ges-3,ases-3, beseses-3, eisisis-3, fisis-3,as-3, beses-3, fisisis-3,bes-3, ceseses-2, fisisisis-3, gisis-3,ais-3, ceses-2, gisisis-3,aisis-3, bis-3, ces-2, deseses-2, gisisisis-3,aisisis-3, bisis-3, deses-2, his-3,bisisis-3, des-2, eseses-2, hisis-3,cisis-2, eses-2, feseses-2, hisisis-3,cisisis-2, es-2, feses-2,cisisisis-2, disis-2, fes-2, geseses-2,disisis-2, eis-2, geses-2,aseses-2, disisisis-2, eisis-2, ges-2,ases-2, beseses-2, eisisis-2, fisis-2,as-2, beses-2, fisisis-2,bes-2, ceseses-, fisisisis-2, gisis-2,ais-2, ceses-, gisisis-2,aisis-2, bis-2, ces-, deseses-, gisisisis-2,aisisis-2, bisis-2, deses-, his-2,bisisis-2, des-, eseses-, hisis-2,cisis-, eses-, feseses-, hisisis-2,cisisis-, es-, feses-,cisisisis-, disis-, fes-, geseses-,disisis-, eis-, geses-,aseses-, disisisis-, eisis-, ges-,ases-, beseses-, eisisis-, fisis-,as-, beses-, fisisis-,bes-, ceseses, fisisisis-, gisis-,ais-, ceses, gisisis-,aisis-, bis-, ces, deseses, gisisisis-,aisisis-, bisis-, deses, his-,bisisis-, des, eseses, hisis-,cisis, eses, feseses, hisisis-,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, beseses, eisisis, fisis,as, beses, fisisis,bes, ceseses+, fisisisis, gisis,ais, ceses+, gisisis,aisis, bis, ces+, deseses+, gisisisis,aisisis, bisis, deses+, his,bisisis, des+, eseses+, hisis,cisis+, eses+, feseses+, hisisis,cisisis+, es+, feses+,cisisisis+, disis+, fes+, geseses+,disisis+, eis+, geses+,aseses+, disisisis+, eisis+, ges+,ases+, beseses+, eisisis+, fisis+,as+, beses+, fisisis+,bes+, ceseses+2, fisisisis+, gisis+,ais+, ceses+2, gisisis+,aisis+, bis+, ces+2, deseses+2, gisisisis+,aisisis+, bisis+, deses+2, his+,bisisis+, des+2, eseses+2, hisis+,cisis+2, eses+2, feseses+2, hisisis+,cisisis+2, es+2, feses+2,cisisisis+2, disis+2, fes+2, geseses+2,disisis+2, eis+2, geses+2,aseses+2, disisisis+2, eisis+2, ges+2,ases+2, beseses+2, eisisis+2, fisis+2,as+2, beses+2, fisisis+2,bes+2, ceseses+3, fisisisis+2, gisis+2,ais+2, ceses+3, gisisis+2,aisis+2, bis+2, ces+3, deseses+3, gisisisis+2,aisisis+2, bisis+2, deses+3, his+2,bisisis+2, des+3, eseses+3, hisis+2,cisis+3, eses+3, feseses+3, hisisis+2,cisisis+3, es+3, feses+3,cisisisis+3, disis+3, fes+3, geseses+3,disisis+3, eis+3, geses+3,aseses+3, disisisis+3, eisis+3, ges+3,ases+3, beseses+3, eisisis+3, fisis+3,as+3, beses+3, fisisis+3,bes+3, ceseses+4, fisisisis+3, gisis+3,ais+3, ceses+4, gisisis+3,aisis+3, bis+3, ces+4, deseses+4, gisisisis+3,aisisis+3, bisis+3, deses+4, his+3,bisisis+3, des+4, eseses+4, hisis+3,cisis+4, eses+4, feseses+4, hisisis+3,cisisis+4, es+4, feses+4,cisisisis+4, disis+4, fes+4, geseses+4,disisis+4, eis+4, geses+4,aseses+4, disisisis+4, eisis+4, ges+4,ases+4, beseses+4, eisisis+4, fisis+4,as+4, beses+4, fisisis+4,bes+4, ceseses+5, fisisisis+4, gisis+4,ais+4, ceses+5, gisisis+4,aisis+4, bis+4, ces+5, deseses+5, gisisisis+4,aisisis+4, bisis+4, deses+5, his+4,bisisis+4, des+5, eseses+5, hisis+4,cisis+5, eses+5, feseses+5, hisisis+4,cisisis+5, es+5, feses+5,cisisisis+5, disis+5, fes+5, geseses+5,disisis+5, eis+5, geses+5,aseses+5, disisisis+5, eisis+5, ges+5,ases+5, beseses+5, eisisis+5, fisis+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "aisisis------, bisis------, deses-----, his------,bisisis------, des-----, eseses-----, hisis------,cisis-----, eses-----, feseses-----, hisisis------,cisisis-----, es-----, feses-----,cisisisis-----, disis-----, fes-----, geseses-----,disisis-----, eis-----, geses-----,aseses-----, disisisis-----, eisis-----, ges-----,ases-----, beseses-----, eisisis-----, fisis-----,as-----, beses-----, fisisis-----,bes-----, ceseses----, fisisisis-----, gisis-----,ais-----, ceses----, gisisis-----,aisis-----, bis-----, ces----, deseses----, gisisisis-----,aisisis-----, bisis-----, deses----, his-----,bisisis-----, des----, eseses----, hisis-----,cisis----, eses----, feseses----, hisisis-----,cisisis----, es----, feses----,cisisisis----, disis----, fes----, geseses----,disisis----, eis----, geses----,aseses----, disisisis----, eisis----, ges----,ases----, beseses----, eisisis----, fisis----,as----, beses----, fisisis----,bes----, ceseses---, fisisisis----, gisis----,ais----, ceses---, gisisis----,aisis----, bis----, ces---, deseses---, gisisisis----,aisisis----, bisis----, deses---, his----,bisisis----, des---, eseses---, hisis----,cisis---, eses---, feseses---, hisisis----,cisisis---, es---, feses---,cisisisis---, disis---, fes---, geseses---,disisis---, eis---, geses---,aseses---, disisisis---, eisis---, ges---,ases---, beseses---, eisisis---, fisis---,as---, beses---, fisisis---,bes---, ceseses--, fisisisis---, gisis---,ais---, ceses--, gisisis---,aisis---, bis---, ces--, deseses--, gisisisis---,aisisis---, bisis---, deses--, his---,bisisis---, des--, eseses--, hisis---,cisis--, eses--, feseses--, hisisis---,cisisis--, es--, feses--,cisisisis--, disis--, fes--, geseses--,disisis--, eis--, geses--,aseses--, disisisis--, eisis--, ges--,ases--, beseses--, eisisis--, fisis--,as--, beses--, fisisis--,bes--, ceseses-, fisisisis--, gisis--,ais--, ceses-, gisisis--,aisis--, bis--, ces-, deseses-, gisisisis--,aisisis--, bisis--, deses-, his--,bisisis--, des-, eseses-, hisis--,cisis-, eses-, feseses-, hisisis--,cisisis-, es-, feses-,cisisisis-, disis-, fes-, geseses-,disisis-, eis-, geses-,aseses-, disisisis-, eisis-, ges-,ases-, beseses-, eisisis-, fisis-,as-, beses-, fisisis-,bes-, ceseses, fisisisis-, gisis-,ais-, ceses, gisisis-,aisis-, bis-, ces, deseses, gisisisis-,aisisis-, bisis-, deses, his-,bisisis-, des, eseses, hisis-,cisis, eses, feseses, hisisis-,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, beseses, eisisis, fisis,as, beses, fisisis,bes, ceseses+, fisisisis, gisis,ais, ceses+, gisisis,aisis, bis, ces+, deseses+, gisisisis,aisisis, bisis, deses+, his,bisisis, des+, eseses+, hisis,cisis+, eses+, feseses+, hisisis,cisisis+, es+, feses+,cisisisis+, disis+, fes+, geseses+,disisis+, eis+, geses+,aseses+, disisisis+, eisis+, ges+,ases+, beseses+, eisisis+, fisis+,as+, beses+, fisisis+,bes+, ceseses++, fisisisis+, gisis+,ais+, ceses++, gisisis+,aisis+, bis+, ces++, deseses++, gisisisis+,aisisis+, bisis+, deses++, his+,bisisis+, des++, eseses++, hisis+,cisis++, eses++, feseses++, hisisis+,cisisis++, es++, feses++,cisisisis++, disis++, fes++, geseses++,disisis++, eis++, geses++,aseses++, disisisis++, eisis++, ges++,ases++, beseses++, eisisis++, fisis++,as++, beses++, fisisis++,bes++, ceseses+++, fisisisis++, gisis++,ais++, ceses+++, gisisis++,aisis++, bis++, ces+++, deseses+++, gisisisis++,aisisis++, bisis++, deses+++, his++,bisisis++, des+++, eseses+++, hisis++,cisis+++, eses+++, feseses+++, hisisis++,cisisis+++, es+++, feses+++,cisisisis+++, disis+++, fes+++, geseses+++,disisis+++, eis+++, geses+++,aseses+++, disisisis+++, eisis+++, ges+++,ases+++, beseses+++, eisisis+++, fisis+++,as+++, beses+++, fisisis+++,bes+++, ceseses++++, fisisisis+++, gisis+++,ais+++, ceses++++, gisisis+++,aisis+++, bis+++, ces++++, deseses++++, gisisisis+++,aisisis+++, bisis+++, deses++++, his+++,bisisis+++, des++++, eseses++++, hisis+++,cisis++++, eses++++, feseses++++, hisisis+++,cisisis++++, es++++, feses++++,cisisisis++++, disis++++, fes++++, geseses++++,disisis++++, eis++++, geses++++,aseses++++, disisisis++++, eisis++++, ges++++,ases++++, beseses++++, eisisis++++, fisis++++,as++++, beses++++, fisisis++++,bes++++, ceseses+++++, fisisisis++++, gisis++++,ais++++, ceses+++++, gisisis++++,aisis++++, bis++++, ces+++++, deseses+++++, gisisisis++++,aisisis++++, bisis++++, deses+++++, his++++,bisisis++++, des+++++, eseses+++++, hisis++++,cisis+++++, eses+++++, feseses+++++, hisisis++++,cisisis+++++, es+++++, feses+++++,cisisisis+++++, disis+++++, fes+++++, geseses+++++,disisis+++++, eis+++++, geses+++++,aseses+++++, disisisis+++++, eisis+++++, ges+++++,ases+++++, beseses+++++, eisisis+++++, fisis+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "aisisis-2, bisis-2, deses-1, his-2,bisisis-2, des-1, eseses-1, hisis-2,cisis-1, eses-1, feseses-1, hisisis-2,cisisis-1, es-1, feses-1,cisisisis-1, disis-1, fes-1, geseses-1,disisis-1, eis-1, geses-1,aseses-1, disisisis-1, eisis-1, ges-1,ases-1, beseses-1, eisisis-1, fisis-1,as-1, beses-1, fisisis-1,bes-1, ceseses0, fisisisis-1, gisis-1,ais-1, ceses0, gisisis-1,aisis-1, bis-1, ces0, deseses0, gisisisis-1,aisisis-1, bisis-1, deses0, his-1,bisisis-1, des0, eseses0, hisis-1,cisis0, eses0, feseses0, hisisis-1,cisisis0, es0, feses0,cisisisis0, disis0, fes0, geseses0,disisis0, eis0, geses0,aseses0, disisisis0, eisis0, ges0,ases0, beseses0, eisisis0, fisis0,as0, beses0, fisisis0,bes0, ceseses1, fisisisis0, gisis0,ais0, ceses1, gisisis0,aisis0, bis0, ces1, deseses1, gisisisis0,aisisis0, bisis0, deses1, his0,bisisis0, des1, eseses1, hisis0,cisis1, eses1, feseses1, hisisis0,cisisis1, es1, feses1,cisisisis1, disis1, fes1, geseses1,disisis1, eis1, geses1,aseses1, disisisis1, eisis1, ges1,ases1, beseses1, eisisis1, fisis1,as1, beses1, fisisis1,bes1, ceseses2, fisisisis1, gisis1,ais1, ceses2, gisisis1,aisis1, bis1, ces2, deseses2, gisisisis1,aisisis1, bisis1, deses2, his1,bisisis1, des2, eseses2, hisis1,cisis2, eses2, feseses2, hisisis1,cisisis2, es2, feses2,cisisisis2, disis2, fes2, geseses2,disisis2, eis2, geses2,aseses2, disisisis2, eisis2, ges2,ases2, beseses2, eisisis2, fisis2,as2, beses2, fisisis2,bes2, ceseses3, fisisisis2, gisis2,ais2, ceses3, gisisis2,aisis2, bis2, ces3, deseses3, gisisisis2,aisisis2, bisis2, deses3, his2,bisisis2, des3, eseses3, hisis2,cisis3, eses3, feseses3, hisisis2,cisisis3, es3, feses3,cisisisis3, disis3, fes3, geseses3,disisis3, eis3, geses3,aseses3, disisisis3, eisis3, ges3,ases3, beseses3, eisisis3, fisis3,as3, beses3, fisisis3,bes3, ceseses4, fisisisis3, gisis3,ais3, ceses4, gisisis3,aisis3, bis3, ces4, deseses4, gisisisis3,aisisis3, bisis3, deses4, his3,bisisis3, des4, eseses4, hisis3,cisis4, eses4, feseses4, hisisis3,cisisis4, es4, feses4,cisisisis4, disis4, fes4, geseses4,disisis4, eis4, geses4,aseses4, disisisis4, eisis4, ges4,ases4, beseses4, eisisis4, fisis4,as4, beses4, fisisis4,bes4, ceseses5, fisisisis4, gisis4,ais4, ceses5, gisisis4,aisis4, bis4, ces5, deseses5, gisisisis4,aisisis4, bisis4, deses5, his4,bisisis4, des5, eseses5, hisis4,cisis5, eses5, feseses5, hisisis4,cisisis5, es5, feses5,cisisisis5, disis5, fes5, geseses5,disisis5, eis5, geses5,aseses5, disisisis5, eisis5, ges5,ases5, beseses5, eisisis5, fisis5,as5, beses5, fisisis5,bes5, ceseses6, fisisisis5, gisis5,ais5, ceses6, gisisis5,aisis5, bis5, ces6, deseses6, gisisisis5,aisisis5, bisis5, deses6, his5,bisisis5, des6, eseses6, hisis5,cisis6, eses6, feseses6, hisisis5,cisisis6, es6, feses6,cisisisis6, disis6, fes6, geseses6,disisis6, eis6, geses6,aseses6, disisisis6, eisis6, ges6,ases6, beseses6, eisisis6, fisis6,as6, beses6, fisisis6,bes6, ceseses7, fisisisis6, gisis6,ais6, ceses7, gisisis6,aisis6, bis6, ces7, deseses7, gisisisis6,aisisis6, bisis6, deses7, his6,bisisis6, des7, eseses7, hisis6,cisis7, eses7, feseses7, hisisis6,cisisis7, es7, feses7,cisisisis7, disis7, fes7, geseses7,disisis7, eis7, geses7,aseses7, disisisis7, eisis7, ges7,ases7, beseses7, eisisis7, fisis7,as7, beses7, fisisis7,bes7, ceseses8, fisisisis7, gisis7,ais7, ceses8, gisisis7,aisis7, bis7, ces8, deseses8, gisisisis7,aisisis7, bisis7, deses8, his7,bisisis7, des8, eseses8, hisis7,cisis8, eses8, feseses8, hisisis7,cisisis8, es8, feses8,cisisisis8, disis8, fes8, geseses8,disisis8, eis8, geses8,aseses8, disisisis8, eisis8, ges8,ases8, beseses8, eisisis8, fisis8,as8, beses8, fisisis8,bes8, ceseses9, fisisisis8, gisis8,ais8, ceses9, gisisis8,aisis8, bis8, ces9, deseses9, gisisisis8,aisisis8, bisis8, deses9, his8,bisisis8, des9, eseses9, hisis8,cisis9, eses9, feseses9, hisisis8,cisisis9, es9, feses9,cisisisis9, disis9, fes9, geseses9,disisis9, eis9, geses9,aseses9, disisisis9, eisis9, ges9,ases9, beseses9, eisisis9, fisis9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Aisisis'''', Bisis'''', Deses''', His'''',Bisisis'''', Des''', Eseses''', Hisis'''',Cisis''', Eses''', Feseses''', Hisisis'''',Cisisis''', Es''', Feses''',Cisisisis''', Disis''', Fes''', Geseses''',Disisis''', Eis''', Geses''',Aseses''', Disisisis''', Eisis''', Ges''',Ases''', Beseses''', Eisisis''', Fisis''',As''', Beses''', Fisisis''',Bes''', Ceseses'', Fisisisis''', Gisis''',Ais''', Ceses'', Gisisis''',Aisis''', Bis''', Ces'', Deseses'', Gisisisis''',Aisisis''', Bisis''', Deses'', His''',Bisisis''', Des'', Eseses'', Hisis''',Cisis'', Eses'', Feseses'', Hisisis''',Cisisis'', Es'', Feses'',Cisisisis'', Disis'', Fes'', Geseses'',Disisis'', Eis'', Geses'',Aseses'', Disisisis'', Eisis'', Ges'',Ases'', Beseses'', Eisisis'', Fisis'',As'', Beses'', Fisisis'',Bes'', Ceseses', Fisisisis'', Gisis'',Ais'', Ceses', Gisisis'',Aisis'', Bis'', Ces', Deseses', Gisisisis'',Aisisis'', Bisis'', Deses', His'',Bisisis'', Des', Eseses', Hisis'',Cisis', Eses', Feseses', Hisisis'',Cisisis', Es', Feses',Cisisisis', Disis', Fes', Geseses',Disisis', Eis', Geses',Aseses', Disisisis', Eisis', Ges',Ases', Beseses', Eisisis', Fisis',As', Beses', Fisisis',Bes', Ceseses, Fisisisis', Gisis',Ais', Ceses, Gisisis',Aisis', Bis', Ces, Deseses, Gisisisis',Aisisis', Bisis', Deses, His',Bisisis', Des, Eseses, Hisis',Cisis, Eses, Feseses, Hisisis',Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Beseses, Eisisis, Fisis,As, Beses, Fisisis,Bes, Fisisisis, Gisis, ceseses,Ais, Gisisis, ceses,Aisis, Bis, Gisisisis, ces, deseses,Aisisis, Bisis, His, deses,Bisisis, Hisis, des, eseses,Hisisis, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, beseses, eisisis, fisis,as, beses, fisisis,bes, ceseses', fisisisis, gisis,ais, ceses', gisisis,aisis, bis, ces', deseses', gisisisis,aisisis, bisis, deses', his,bisisis, des', eseses', hisis,cisis', eses', feseses', hisisis,cisisis', es', feses',cisisisis', disis', fes', geseses',disisis', eis', geses',aseses', disisisis', eisis', ges',ases', beseses', eisisis', fisis',as', beses', fisisis',bes', ceseses'', fisisisis', gisis',ais', ceses'', gisisis',aisis', bis', ces'', deseses'', gisisisis',aisisis', bisis', deses'', his',bisisis', des'', eseses'', hisis',cisis'', eses'', feseses'', hisisis',cisisis'', es'', feses'',cisisisis'', disis'', fes'', geseses'',disisis'', eis'', geses'',aseses'', disisisis'', eisis'', ges'',ases'', beseses'', eisisis'', fisis'',as'', beses'', fisisis'',bes'', ceseses''', fisisisis'', gisis'',ais'', ceses''', gisisis'',aisis'', bis'', ces''', deseses''', gisisisis'',aisisis'', bisis'', deses''', his'',bisisis'', des''', eseses''', hisis'',cisis''', eses''', feseses''', hisisis'',cisisis''', es''', feses''',cisisisis''', disis''', fes''', geseses''',disisis''', eis''', geses''',aseses''', disisisis''', eisis''', ges''',ases''', beseses''', eisisis''', fisis''',as''', beses''', fisisis''',bes''', ceseses'''', fisisisis''', gisis''',ais''', ceses'''', gisisis''',aisis''', bis''', ces'''', deseses'''', gisisisis''',aisisis''', bisis''', deses'''', his''',bisisis''', des'''', eseses'''', hisis''',cisis'''', eses'''', feseses'''', hisisis''',cisisis'''', es'''', feses'''',cisisisis'''', disis'''', fes'''', geseses'''',disisis'''', eis'''', geses'''',aseses'''', disisisis'''', eisis'''', ges'''',ases'''', beseses'''', eisisis'''', fisis'''',as'''', beses'''', fisisis'''',bes'''', ceseses''''', fisisisis'''', gisis'''',ais'''', ceses''''', gisisis'''',aisis'''', bis'''', ces''''', deseses''''', gisisisis'''',aisisis'''', bisis'''', deses''''', his'''',bisisis'''', des''''', eseses''''', hisis'''',cisis''''', eses''''', feseses''''', hisisis'''',cisisis''''', es''''', feses''''',cisisisis''''', disis''''', fes''''', geseses''''',disisis''''', eis''''', geses''''',aseses''''', disisisis''''', eisis''''', ges''''',ases''''', beseses''''', eisisis''''', fisis''''',as''''', beses''''', fisisis''''',bes''''', ceseses'''''', fisisisis''''', gisis''''',ais''''', ceses'''''', gisisis''''',aisis''''', bis''''', ces'''''', deseses'''''', gisisisis''''',aisisis''''', bisis''''', deses'''''', his''''',bisisis''''', des'''''', eseses'''''', hisis''''',cisis'''''', eses'''''', feseses'''''', hisisis''''',cisisis'''''', es'''''', feses'''''',cisisisis'''''', disis'''''', fes'''''', geseses'''''',disisis'''''', eis'''''', geses'''''',aseses'''''', disisisis'''''', eisis'''''', ges'''''',ases'''''', beseses'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "aisisis-6, bisis-6, deses-5, eseseses-5, his-6,bisisis-6, cis-5, eseses-5, hisis-6,cisis-5, eses-5, feseses-5, hisisis-6,cisisis-5, dis-5, feses-5, geseseses-5,disis-5, fes-5, geseses-5,aseseses-5, disisis-5, eis-5, geses-5,aseses-5, eisis-5, fis-5,ases-5, beseses-5, eisisis-5, fisis-5,beses-5, fisisis-5, gis-5,bes-5, ceseses-4, gisis-5,ais-5, ceses-4, deseseses-4, gisisis-5,aisis-5, bis-5, ces-4, deseses-4,aisisis-5, bisis-5, deses-4, eseseses-4, his-5,bisisis-5, cis-4, eseses-4, hisis-5,cisis-4, eses-4, feseses-4, hisisis-5,cisisis-4, dis-4, feses-4, geseseses-4,disis-4, fes-4, geseses-4,aseseses-4, disisis-4, eis-4, geses-4,aseses-4, eisis-4, fis-4,ases-4, beseses-4, eisisis-4, fisis-4,beses-4, fisisis-4, gis-4,bes-4, ceseses-3, gisis-4,ais-4, ceses-3, deseseses-3, gisisis-4,aisis-4, bis-4, ces-3, deseses-3,aisisis-4, bisis-4, deses-3, eseseses-3, his-4,bisisis-4, cis-3, eseses-3, hisis-4,cisis-3, eses-3, feseses-3, hisisis-4,cisisis-3, dis-3, feses-3, geseseses-3,disis-3, fes-3, geseses-3,aseseses-3, disisis-3, eis-3, geses-3,aseses-3, eisis-3, fis-3,ases-3, beseses-3, eisisis-3, fisis-3,beses-3, fisisis-3, gis-3,bes-3, ceseses-2, gisis-3,ais-3, ceses-2, deseseses-2, gisisis-3,aisis-3, bis-3, ces-2, deseses-2,aisisis-3, bisis-3, deses-2, eseseses-2, his-3,bisisis-3, cis-2, eseses-2, hisis-3,cisis-2, eses-2, feseses-2, hisisis-3,cisisis-2, dis-2, feses-2, geseseses-2,disis-2, fes-2, geseses-2,aseseses-2, disisis-2, eis-2, geses-2,aseses-2, eisis-2, fis-2,ases-2, beseses-2, eisisis-2, fisis-2,beses-2, fisisis-2, gis-2,bes-2, ceseses-, gisis-2,ais-2, ceses-, deseseses-, gisisis-2,aisis-2, bis-2, ces-, deseses-,aisisis-2, bisis-2, deses-, eseseses-, his-2,bisisis-2, cis-, eseses-, hisis-2,cisis-, eses-, feseses-, hisisis-2,cisisis-, dis-, feses-, geseseses-,disis-, fes-, geseses-,aseseses-, disisis-, eis-, geses-,aseses-, eisis-, fis-,ases-, beseses-, eisisis-, fisis-,beses-, fisisis-, gis-,bes-, ceseses, gisis-,ais-, ceses, deseseses, gisisis-,aisis-, bis-, ces, deseses,aisisis-, bisis-, deses, eseseses, his-,bisisis-, cis, eseses, hisis-,cisis, eses, feseses, hisisis-,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseses, eisisis, fisis,beses, fisisis, gis,bes, ceseses+, gisis,ais, ceses+, deseseses+, gisisis,aisis, bis, ces+, deseses+,aisisis, bisis, deses+, eseseses+, his,bisisis, cis+, eseses+, hisis,cisis+, eses+, feseses+, hisisis,cisisis+, dis+, feses+, geseseses+,disis+, fes+, geseses+,aseseses+, disisis+, eis+, geses+,aseses+, eisis+, fis+,ases+, beseses+, eisisis+, fisis+,beses+, fisisis+, gis+,bes+, ceseses+2, gisis+,ais+, ceses+2, deseseses+2, gisisis+,aisis+, bis+, ces+2, deseses+2,aisisis+, bisis+, deses+2, eseseses+2, his+,bisisis+, cis+2, eseses+2, hisis+,cisis+2, eses+2, feseses+2, hisisis+,cisisis+2, dis+2, feses+2, geseseses+2,disis+2, fes+2, geseses+2,aseseses+2, disisis+2, eis+2, geses+2,aseses+2, eisis+2, fis+2,ases+2, beseses+2, eisisis+2, fisis+2,beses+2, fisisis+2, gis+2,bes+2, ceseses+3, gisis+2,ais+2, ceses+3, deseseses+3, gisisis+2,aisis+2, bis+2, ces+3, deseses+3,aisisis+2, bisis+2, deses+3, eseseses+3, his+2,bisisis+2, cis+3, eseses+3, hisis+2,cisis+3, eses+3, feseses+3, hisisis+2,cisisis+3, dis+3, feses+3, geseseses+3,disis+3, fes+3, geseses+3,aseseses+3, disisis+3, eis+3, geses+3,aseses+3, eisis+3, fis+3,ases+3, beseses+3, eisisis+3, fisis+3,beses+3, fisisis+3, gis+3,bes+3, ceseses+4, gisis+3,ais+3, ceses+4, deseseses+4, gisisis+3,aisis+3, bis+3, ces+4, deseses+4,aisisis+3, bisis+3, deses+4, eseseses+4, his+3,bisisis+3, cis+4, eseses+4, hisis+3,cisis+4, eses+4, feseses+4, hisisis+3,cisisis+4, dis+4, feses+4, geseseses+4,disis+4, fes+4, geseses+4,aseseses+4, disisis+4, eis+4, geses+4,aseses+4, eisis+4, fis+4,ases+4, beseses+4, eisisis+4, fisis+4,beses+4, fisisis+4, gis+4,bes+4, ceseses+5, gisis+4,ais+4, ceses+5, deseseses+5, gisisis+4,aisis+4, bis+4, ces+5, deseses+5,aisisis+4, bisis+4, deses+5, eseseses+5, his+4,bisisis+4, cis+5, eseses+5, hisis+4,cisis+5, eses+5, feseses+5, hisisis+4,cisisis+5, dis+5, feses+5, geseseses+5,disis+5, fes+5, geseses+5,aseseses+5, disisis+5, eis+5, geses+5,aseses+5, eisis+5, fis+5,ases+5, beseses+5, eisisis+5, fisis+5\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "aisisis------, bisis------, deses-----, eseseses-----, his------,bisisis------, cis-----, eseses-----, hisis------,cisis-----, eses-----, feseses-----, hisisis------,cisisis-----, dis-----, feses-----, geseseses-----,disis-----, fes-----, geseses-----,aseseses-----, disisis-----, eis-----, geses-----,aseses-----, eisis-----, fis-----,ases-----, beseses-----, eisisis-----, fisis-----,beses-----, fisisis-----, gis-----,bes-----, ceseses----, gisis-----,ais-----, ceses----, deseseses----, gisisis-----,aisis-----, bis-----, ces----, deseses----,aisisis-----, bisis-----, deses----, eseseses----, his-----,bisisis-----, cis----, eseses----, hisis-----,cisis----, eses----, feseses----, hisisis-----,cisisis----, dis----, feses----, geseseses----,disis----, fes----, geseses----,aseseses----, disisis----, eis----, geses----,aseses----, eisis----, fis----,ases----, beseses----, eisisis----, fisis----,beses----, fisisis----, gis----,bes----, ceseses---, gisis----,ais----, ceses---, deseseses---, gisisis----,aisis----, bis----, ces---, deseses---,aisisis----, bisis----, deses---, eseseses---, his----,bisisis----, cis---, eseses---, hisis----,cisis---, eses---, feseses---, hisisis----,cisisis---, dis---, feses---, geseseses---,disis---, fes---, geseses---,aseseses---, disisis---, eis---, geses---,aseses---, eisis---, fis---,ases---, beseses---, eisisis---, fisis---,beses---, fisisis---, gis---,bes---, ceseses--, gisis---,ais---, ceses--, deseseses--, gisisis---,aisis---, bis---, ces--, deseses--,aisisis---, bisis---, deses--, eseseses--, his---,bisisis---, cis--, eseses--, hisis---,cisis--, eses--, feseses--, hisisis---,cisisis--, dis--, feses--, geseseses--,disis--, fes--, geseses--,aseseses--, disisis--, eis--, geses--,aseses--, eisis--, fis--,ases--, beseses--, eisisis--, fisis--,beses--, fisisis--, gis--,bes--, ceseses-, gisis--,ais--, ceses-, deseseses-, gisisis--,aisis--, bis--, ces-, deseses-,aisisis--, bisis--, deses-, eseseses-, his--,bisisis--, cis-, eseses-, hisis--,cisis-, eses-, feseses-, hisisis--,cisisis-, dis-, feses-, geseseses-,disis-, fes-, geseses-,aseseses-, disisis-, eis-, geses-,aseses-, eisis-, fis-,ases-, beseses-, eisisis-, fisis-,beses-, fisisis-, gis-,bes-, ceseses, gisis-,ais-, ceses, deseseses, gisisis-,aisis-, bis-, ces, deseses,aisisis-, bisis-, deses, eseseses, his-,bisisis-, cis, eseses, hisis-,cisis, eses, feseses, hisisis-,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseses, eisisis, fisis,beses, fisisis, gis,bes, ceseses+, gisis,ais, ceses+, deseseses+, gisisis,aisis, bis, ces+, deseses+,aisisis, bisis, deses+, eseseses+, his,bisisis, cis+, eseses+, hisis,cisis+, eses+, feseses+, hisisis,cisisis+, dis+, feses+, geseseses+,disis+, fes+, geseses+,aseseses+, disisis+, eis+, geses+,aseses+, eisis+, fis+,ases+, beseses+, eisisis+, fisis+,beses+, fisisis+, gis+,bes+, ceseses++, gisis+,ais+, ceses++, deseseses++, gisisis+,aisis+, bis+, ces++, deseses++,aisisis+, bisis+, deses++, eseseses++, his+,bisisis+, cis++, eseses++, hisis+,cisis++, eses++, feseses++, hisisis+,cisisis++, dis++, feses++, geseseses++,disis++, fes++, geseses++,aseseses++, disisis++, eis++, geses++,aseses++, eisis++, fis++,ases++, beseses++, eisisis++, fisis++,beses++, fisisis++, gis++,bes++, ceseses+++, gisis++,ais++, ceses+++, deseseses+++, gisisis++,aisis++, bis++, ces+++, deseses+++,aisisis++, bisis++, deses+++, eseseses+++, his++,bisisis++, cis+++, eseses+++, hisis++,cisis+++, eses+++, feseses+++, hisisis++,cisisis+++, dis+++, feses+++, geseseses+++,disis+++, fes+++, geseses+++,aseseses+++, disisis+++, eis+++, geses+++,aseses+++, eisis+++, fis+++,ases+++, beseses+++, eisisis+++, fisis+++,beses+++, fisisis+++, gis+++,bes+++, ceseses++++, gisis+++,ais+++, ceses++++, deseseses++++, gisisis+++,aisis+++, bis+++, ces++++, deseses++++,aisisis+++, bisis+++, deses++++, eseseses++++, his+++,bisisis+++, cis++++, eseses++++, hisis+++,cisis++++, eses++++, feseses++++, hisisis+++,cisisis++++, dis++++, feses++++, geseseses++++,disis++++, fes++++, geseses++++,aseseses++++, disisis++++, eis++++, geses++++,aseses++++, eisis++++, fis++++,ases++++, beseses++++, eisisis++++, fisis++++,beses++++, fisisis++++, gis++++,bes++++, ceseses+++++, gisis++++,ais++++, ceses+++++, deseseses+++++, gisisis++++,aisis++++, bis++++, ces+++++, deseses+++++,aisisis++++, bisis++++, deses+++++, eseseses+++++, his++++,bisisis++++, cis+++++, eseses+++++, hisis++++,cisis+++++, eses+++++, feseses+++++, hisisis++++,cisisis+++++, dis+++++, feses+++++, geseseses+++++,disis+++++, fes+++++, geseses+++++,aseseses+++++, disisis+++++, eis+++++, geses+++++,aseses+++++, eisis+++++, fis+++++,ases+++++, beseses+++++, eisisis+++++, fisis+++++\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "aisisis-2, bisis-2, deses-1, eseseses-1, his-2,bisisis-2, cis-1, eseses-1, hisis-2,cisis-1, eses-1, feseses-1, hisisis-2,cisisis-1, dis-1, feses-1, geseseses-1,disis-1, fes-1, geseses-1,aseseses-1, disisis-1, eis-1, geses-1,aseses-1, eisis-1, fis-1,ases-1, beseses-1, eisisis-1, fisis-1,beses-1, fisisis-1, gis-1,bes-1, ceseses0, gisis-1,ais-1, ceses0, deseseses0, gisisis-1,aisis-1, bis-1, ces0, deseses0,aisisis-1, bisis-1, deses0, eseseses0, his-1,bisisis-1, cis0, eseses0, hisis-1,cisis0, eses0, feseses0, hisisis-1,cisisis0, dis0, feses0, geseseses0,disis0, fes0, geseses0,aseseses0, disisis0, eis0, geses0,aseses0, eisis0, fis0,ases0, beseses0, eisisis0, fisis0,beses0, fisisis0, gis0,bes0, ceseses1, gisis0,ais0, ceses1, deseseses1, gisisis0,aisis0, bis0, ces1, deseses1,aisisis0, bisis0, deses1, eseseses1, his0,bisisis0, cis1, eseses1, hisis0,cisis1, eses1, feseses1, hisisis0,cisisis1, dis1, feses1, geseseses1,disis1, fes1, geseses1,aseseses1, disisis1, eis1, geses1,aseses1, eisis1, fis1,ases1, beseses1, eisisis1, fisis1,beses1, fisisis1, gis1,bes1, ceseses2, gisis1,ais1, ceses2, deseseses2, gisisis1,aisis1, bis1, ces2, deseses2,aisisis1, bisis1, deses2, eseseses2, his1,bisisis1, cis2, eseses2, hisis1,cisis2, eses2, feseses2, hisisis1,cisisis2, dis2, feses2, geseseses2,disis2, fes2, geseses2,aseseses2, disisis2, eis2, geses2,aseses2, eisis2, fis2,ases2, beseses2, eisisis2, fisis2,beses2, fisisis2, gis2,bes2, ceseses3, gisis2,ais2, ceses3, deseseses3, gisisis2,aisis2, bis2, ces3, deseses3,aisisis2, bisis2, deses3, eseseses3, his2,bisisis2, cis3, eseses3, hisis2,cisis3, eses3, feseses3, hisisis2,cisisis3, dis3, feses3, geseseses3,disis3, fes3, geseses3,aseseses3, disisis3, eis3, geses3,aseses3, eisis3, fis3,ases3, beseses3, eisisis3, fisis3,beses3, fisisis3, gis3,bes3, ceseses4, gisis3,ais3, ceses4, deseseses4, gisisis3,aisis3, bis3, ces4, deseses4,aisisis3, bisis3, deses4, eseseses4, his3,bisisis3, cis4, eseses4, hisis3,cisis4, eses4, feseses4, hisisis3,cisisis4, dis4, feses4, geseseses4,disis4, fes4, geseses4,aseseses4, disisis4, eis4, geses4,aseses4, eisis4, fis4,ases4, beseses4, eisisis4, fisis4,beses4, fisisis4, gis4,bes4, ceseses5, gisis4,ais4, ceses5, deseseses5, gisisis4,aisis4, bis4, ces5, deseses5,aisisis4, bisis4, deses5, eseseses5, his4,bisisis4, cis5, eseses5, hisis4,cisis5, eses5, feseses5, hisisis4,cisisis5, dis5, feses5, geseseses5,disis5, fes5, geseses5,aseseses5, disisis5, eis5, geses5,aseses5, eisis5, fis5,ases5, beseses5, eisisis5, fisis5,beses5, fisisis5, gis5,bes5, ceseses6, gisis5,ais5, ceses6, deseseses6, gisisis5,aisis5, bis5, ces6, deseses6,aisisis5, bisis5, deses6, eseseses6, his5,bisisis5, cis6, eseses6, hisis5,cisis6, eses6, feseses6, hisisis5,cisisis6, dis6, feses6, geseseses6,disis6, fes6, geseses6,aseseses6, disisis6, eis6, geses6,aseses6, eisis6, fis6,ases6, beseses6, eisisis6, fisis6,beses6, fisisis6, gis6,bes6, ceseses7, gisis6,ais6, ceses7, deseseses7, gisisis6,aisis6, bis6, ces7, deseses7,aisisis6, bisis6, deses7, eseseses7, his6,bisisis6, cis7, eseses7, hisis6,cisis7, eses7, feseses7, hisisis6,cisisis7, dis7, feses7, geseseses7,disis7, fes7, geseses7,aseseses7, disisis7, eis7, geses7,aseses7, eisis7, fis7,ases7, beseses7, eisisis7, fisis7,beses7, fisisis7, gis7,bes7, ceseses8, gisis7,ais7, ceses8, deseseses8, gisisis7,aisis7, bis7, ces8, deseses8,aisisis7, bisis7, deses8, eseseses8, his7,bisisis7, cis8, eseses8, hisis7,cisis8, eses8, feseses8, hisisis7,cisisis8, dis8, feses8, geseseses8,disis8, fes8, geseses8,aseseses8, disisis8, eis8, geses8,aseses8, eisis8, fis8,ases8, beseses8, eisisis8, fisis8,beses8, fisisis8, gis8,bes8, ceseses9, gisis8,ais8, ceses9, deseseses9, gisisis8,aisis8, bis8, ces9, deseses9,aisisis8, bisis8, deses9, eseseses9, his8,bisisis8, cis9, eseses9, hisis8,cisis9, eses9, feseses9, hisisis8,cisisis9, dis9, feses9, geseseses9,disis9, fes9, geseses9,aseseses9, disisis9, eis9, geses9,aseses9, eisis9, fis9,ases9, beseses9, eisisis9, fisis9\n"
			+ "cbx_note_id_german_lc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Aisisis'''', Bisis'''', Deses''', Eseseses''', His'''',Bisisis'''', Cis''', Eseses''', Hisis'''',Cisis''', Eses''', Feseses''', Hisisis'''',Cisisis''', Dis''', Feses''', Geseseses''',Disis''', Fes''', Geseses''',Aseseses''', Disisis''', Eis''', Geses''',Aseses''', Eisis''', Fis''',Ases''', Beseses''', Eisisis''', Fisis''',Beses''', Fisisis''', Gis''',Bes''', Ceseses'', Gisis''',Ais''', Ceses'', Deseseses'', Gisisis''',Aisis''', Bis''', Ces'', Deseses'',Aisisis''', Bisis''', Deses'', Eseseses'', His''',Bisisis''', Cis'', Eseses'', Hisis''',Cisis'', Eses'', Feseses'', Hisisis''',Cisisis'', Dis'', Feses'', Geseseses'',Disis'', Fes'', Geseses'',Aseseses'', Disisis'', Eis'', Geses'',Aseses'', Eisis'', Fis'',Ases'', Beseses'', Eisisis'', Fisis'',Beses'', Fisisis'', Gis'',Bes'', Ceseses', Gisis'',Ais'', Ceses', Deseseses', Gisisis'',Aisis'', Bis'', Ces', Deseses',Aisisis'', Bisis'', Deses', Eseseses', His'',Bisisis'', Cis', Eseses', Hisis'',Cisis', Eses', Feseses', Hisisis'',Cisisis', Dis', Feses', Geseseses',Disis', Fes', Geseses',Aseseses', Disisis', Eis', Geses',Aseses', Eisis', Fis',Ases', Beseses', Eisisis', Fisis',Beses', Fisisis', Gis',Bes', Ceseses, Gisis',Ais', Ceses, Deseseses, Gisisis',Aisis', Bis', Ces, Deseses,Aisisis', Bisis', Deses, Eseseses, His',Bisisis', Cis, Eseses, Hisis',Cisis, Eses, Feseses, Hisisis',Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseses, Eisisis, Fisis,Beses, Fisisis, Gis,Bes, Gisis, ceseses,Ais, Gisisis, ceses, deseseses,Aisis, Bis, ces, deseses,Aisisis, Bisis, His, deses, eseseses,Bisisis, Hisis, cis, eseses,Hisisis, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseses, eisisis, fisis,beses, fisisis, gis,bes, ceseses', gisis,ais, ceses', deseseses', gisisis,aisis, bis, ces', deseses',aisisis, bisis, deses', eseseses', his,bisisis, cis', eseses', hisis,cisis', eses', feseses', hisisis,cisisis', dis', feses', geseseses',disis', fes', geseses',aseseses', disisis', eis', geses',aseses', eisis', fis',ases', beseses', eisisis', fisis',beses', fisisis', gis',bes', ceseses'', gisis',ais', ceses'', deseseses'', gisisis',aisis', bis', ces'', deseses'',aisisis', bisis', deses'', eseseses'', his',bisisis', cis'', eseses'', hisis',cisis'', eses'', feseses'', hisisis',cisisis'', dis'', feses'', geseseses'',disis'', fes'', geseses'',aseseses'', disisis'', eis'', geses'',aseses'', eisis'', fis'',ases'', beseses'', eisisis'', fisis'',beses'', fisisis'', gis'',bes'', ceseses''', gisis'',ais'', ceses''', deseseses''', gisisis'',aisis'', bis'', ces''', deseses''',aisisis'', bisis'', deses''', eseseses''', his'',bisisis'', cis''', eseses''', hisis'',cisis''', eses''', feseses''', hisisis'',cisisis''', dis''', feses''', geseseses''',disis''', fes''', geseses''',aseseses''', disisis''', eis''', geses''',aseses''', eisis''', fis''',ases''', beseses''', eisisis''', fisis''',beses''', fisisis''', gis''',bes''', ceseses'''', gisis''',ais''', ceses'''', deseseses'''', gisisis''',aisis''', bis''', ces'''', deseses'''',aisisis''', bisis''', deses'''', eseseses'''', his''',bisisis''', cis'''', eseses'''', hisis''',cisis'''', eses'''', feseses'''', hisisis''',cisisis'''', dis'''', feses'''', geseseses'''',disis'''', fes'''', geseses'''',aseseses'''', disisis'''', eis'''', geses'''',aseses'''', eisis'''', fis'''',ases'''', beseses'''', eisisis'''', fisis'''',beses'''', fisisis'''', gis'''',bes'''', ceseses''''', gisis'''',ais'''', ceses''''', deseseses''''', gisisis'''',aisis'''', bis'''', ces''''', deseses''''',aisisis'''', bisis'''', deses''''', eseseses''''', his'''',bisisis'''', cis''''', eseses''''', hisis'''',cisis''''', eses''''', feseses''''', hisisis'''',cisisis''''', dis''''', feses''''', geseseses''''',disis''''', fes''''', geseses''''',aseseses''''', disisis''''', eis''''', geses''''',aseses''''', eisis''''', fis''''',ases''''', beseses''''', eisisis''''', fisis''''',beses''''', fisisis''''', gis''''',bes''''', ceseses'''''', gisis''''',ais''''', ceses'''''', deseseses'''''', gisisis''''',aisis''''', bis''''', ces'''''', deseses'''''',aisisis''''', bisis''''', deses'''''', eseseses'''''', his''''',bisisis''''', cis'''''', eseses'''''', hisis''''',cisis'''''', eses'''''', feseses'''''', hisisis''''',cisisis'''''', dis'''''', feses'''''', geseseses'''''',disis'''''', fes'''''', geseses'''''',aseseses'''''', disisis'''''', eis'''''', geses'''''',aseses'''''', eisis'''''', fis'''''',ases'''''', beseses'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "A###-6, B##-6, Dbb-5, H#-6,B###-6, Db-5, Ebbb-5, H##-6,C##-5, Ebb-5, Fbbb-5, H###-6,C###-5, Eb-5, Fbb-5,C####-5, D##-5, Fb-5, Gbbb-5,D###-5, E#-5, Gbb-5,Abbb-5, D####-5, E##-5, Gb-5,Abb-5, Bbbb-5, E###-5, F##-5,Ab-5, Bbb-5, F###-5,Bb-5, Cbbb-4, F####-5, G##-5,A#-5, Cbb-4, G###-5,A##-5, B#-5, Cb-4, Dbbb-4, G####-5,A###-5, B##-5, Dbb-4, H#-5,B###-5, Db-4, Ebbb-4, H##-5,C##-4, Ebb-4, Fbbb-4, H###-5,C###-4, Eb-4, Fbb-4,C####-4, D##-4, Fb-4, Gbbb-4,D###-4, E#-4, Gbb-4,Abbb-4, D####-4, E##-4, Gb-4,Abb-4, Bbbb-4, E###-4, F##-4,Ab-4, Bbb-4, F###-4,Bb-4, Cbbb-3, F####-4, G##-4,A#-4, Cbb-3, G###-4,A##-4, B#-4, Cb-3, Dbbb-3, G####-4,A###-4, B##-4, Dbb-3, H#-4,B###-4, Db-3, Ebbb-3, H##-4,C##-3, Ebb-3, Fbbb-3, H###-4,C###-3, Eb-3, Fbb-3,C####-3, D##-3, Fb-3, Gbbb-3,D###-3, E#-3, Gbb-3,Abbb-3, D####-3, E##-3, Gb-3,Abb-3, Bbbb-3, E###-3, F##-3,Ab-3, Bbb-3, F###-3,Bb-3, Cbbb-2, F####-3, G##-3,A#-3, Cbb-2, G###-3,A##-3, B#-3, Cb-2, Dbbb-2, G####-3,A###-3, B##-3, Dbb-2, H#-3,B###-3, Db-2, Ebbb-2, H##-3,C##-2, Ebb-2, Fbbb-2, H###-3,C###-2, Eb-2, Fbb-2,C####-2, D##-2, Fb-2, Gbbb-2,D###-2, E#-2, Gbb-2,Abbb-2, D####-2, E##-2, Gb-2,Abb-2, Bbbb-2, E###-2, F##-2,Ab-2, Bbb-2, F###-2,Bb-2, Cbbb-, F####-2, G##-2,A#-2, Cbb-, G###-2,A##-2, B#-2, Cb-, Dbbb-, G####-2,A###-2, B##-2, Dbb-, H#-2,B###-2, Db-, Ebbb-, H##-2,C##-, Ebb-, Fbbb-, H###-2,C###-, Eb-, Fbb-,C####-, D##-, Fb-, Gbbb-,D###-, E#-, Gbb-,Abbb-, D####-, E##-, Gb-,Abb-, Bbbb-, E###-, F##-,Ab-, Bbb-, F###-,Bb-, Cbbb, F####-, G##-,A#-, Cbb, G###-,A##-, B#-, Cb, Dbbb, G####-,A###-, B##-, Dbb, H#-,B###-, Db, Ebbb, H##-,C##, Ebb, Fbbb, H###-,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, Bbbb, E###, F##,Ab, Bbb, F###,Bb, Cbbb+, F####, G##,A#, Cbb+, G###,A##, B#, Cb+, Dbbb+, G####,A###, B##, Dbb+, H#,B###, Db+, Ebbb+, H##,C##+, Ebb+, Fbbb+, H###,C###+, Eb+, Fbb+,C####+, D##+, Fb+, Gbbb+,D###+, E#+, Gbb+,Abbb+, D####+, E##+, Gb+,Abb+, Bbbb+, E###+, F##+,Ab+, Bbb+, F###+,Bb+, Cbbb+2, F####+, G##+,A#+, Cbb+2, G###+,A##+, B#+, Cb+2, Dbbb+2, G####+,A###+, B##+, Dbb+2, H#+,B###+, Db+2, Ebbb+2, H##+,C##+2, Ebb+2, Fbbb+2, H###+,C###+2, Eb+2, Fbb+2,C####+2, D##+2, Fb+2, Gbbb+2,D###+2, E#+2, Gbb+2,Abbb+2, D####+2, E##+2, Gb+2,Abb+2, Bbbb+2, E###+2, F##+2,Ab+2, Bbb+2, F###+2,Bb+2, Cbbb+3, F####+2, G##+2,A#+2, Cbb+3, G###+2,A##+2, B#+2, Cb+3, Dbbb+3, G####+2,A###+2, B##+2, Dbb+3, H#+2,B###+2, Db+3, Ebbb+3, H##+2,C##+3, Ebb+3, Fbbb+3, H###+2,C###+3, Eb+3, Fbb+3,C####+3, D##+3, Fb+3, Gbbb+3,D###+3, E#+3, Gbb+3,Abbb+3, D####+3, E##+3, Gb+3,Abb+3, Bbbb+3, E###+3, F##+3,Ab+3, Bbb+3, F###+3,Bb+3, Cbbb+4, F####+3, G##+3,A#+3, Cbb+4, G###+3,A##+3, B#+3, Cb+4, Dbbb+4, G####+3,A###+3, B##+3, Dbb+4, H#+3,B###+3, Db+4, Ebbb+4, H##+3,C##+4, Ebb+4, Fbbb+4, H###+3,C###+4, Eb+4, Fbb+4,C####+4, D##+4, Fb+4, Gbbb+4,D###+4, E#+4, Gbb+4,Abbb+4, D####+4, E##+4, Gb+4,Abb+4, Bbbb+4, E###+4, F##+4,Ab+4, Bbb+4, F###+4,Bb+4, Cbbb+5, F####+4, G##+4,A#+4, Cbb+5, G###+4,A##+4, B#+4, Cb+5, Dbbb+5, G####+4,A###+4, B##+4, Dbb+5, H#+4,B###+4, Db+5, Ebbb+5, H##+4,C##+5, Ebb+5, Fbbb+5, H###+4,C###+5, Eb+5, Fbb+5,C####+5, D##+5, Fb+5, Gbbb+5,D###+5, E#+5, Gbb+5,Abbb+5, D####+5, E##+5, Gb+5,Abb+5, Bbbb+5, E###+5, F##+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "A###------, B##------, Dbb-----, H#------,B###------, Db-----, Ebbb-----, H##------,C##-----, Ebb-----, Fbbb-----, H###------,C###-----, Eb-----, Fbb-----,C####-----, D##-----, Fb-----, Gbbb-----,D###-----, E#-----, Gbb-----,Abbb-----, D####-----, E##-----, Gb-----,Abb-----, Bbbb-----, E###-----, F##-----,Ab-----, Bbb-----, F###-----,Bb-----, Cbbb----, F####-----, G##-----,A#-----, Cbb----, G###-----,A##-----, B#-----, Cb----, Dbbb----, G####-----,A###-----, B##-----, Dbb----, H#-----,B###-----, Db----, Ebbb----, H##-----,C##----, Ebb----, Fbbb----, H###-----,C###----, Eb----, Fbb----,C####----, D##----, Fb----, Gbbb----,D###----, E#----, Gbb----,Abbb----, D####----, E##----, Gb----,Abb----, Bbbb----, E###----, F##----,Ab----, Bbb----, F###----,Bb----, Cbbb---, F####----, G##----,A#----, Cbb---, G###----,A##----, B#----, Cb---, Dbbb---, G####----,A###----, B##----, Dbb---, H#----,B###----, Db---, Ebbb---, H##----,C##---, Ebb---, Fbbb---, H###----,C###---, Eb---, Fbb---,C####---, D##---, Fb---, Gbbb---,D###---, E#---, Gbb---,Abbb---, D####---, E##---, Gb---,Abb---, Bbbb---, E###---, F##---,Ab---, Bbb---, F###---,Bb---, Cbbb--, F####---, G##---,A#---, Cbb--, G###---,A##---, B#---, Cb--, Dbbb--, G####---,A###---, B##---, Dbb--, H#---,B###---, Db--, Ebbb--, H##---,C##--, Ebb--, Fbbb--, H###---,C###--, Eb--, Fbb--,C####--, D##--, Fb--, Gbbb--,D###--, E#--, Gbb--,Abbb--, D####--, E##--, Gb--,Abb--, Bbbb--, E###--, F##--,Ab--, Bbb--, F###--,Bb--, Cbbb-, F####--, G##--,A#--, Cbb-, G###--,A##--, B#--, Cb-, Dbbb-, G####--,A###--, B##--, Dbb-, H#--,B###--, Db-, Ebbb-, H##--,C##-, Ebb-, Fbbb-, H###--,C###-, Eb-, Fbb-,C####-, D##-, Fb-, Gbbb-,D###-, E#-, Gbb-,Abbb-, D####-, E##-, Gb-,Abb-, Bbbb-, E###-, F##-,Ab-, Bbb-, F###-,Bb-, Cbbb, F####-, G##-,A#-, Cbb, G###-,A##-, B#-, Cb, Dbbb, G####-,A###-, B##-, Dbb, H#-,B###-, Db, Ebbb, H##-,C##, Ebb, Fbbb, H###-,C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, Bbbb, E###, F##,Ab, Bbb, F###,Bb, Cbbb+, F####, G##,A#, Cbb+, G###,A##, B#, Cb+, Dbbb+, G####,A###, B##, Dbb+, H#,B###, Db+, Ebbb+, H##,C##+, Ebb+, Fbbb+, H###,C###+, Eb+, Fbb+,C####+, D##+, Fb+, Gbbb+,D###+, E#+, Gbb+,Abbb+, D####+, E##+, Gb+,Abb+, Bbbb+, E###+, F##+,Ab+, Bbb+, F###+,Bb+, Cbbb++, F####+, G##+,A#+, Cbb++, G###+,A##+, B#+, Cb++, Dbbb++, G####+,A###+, B##+, Dbb++, H#+,B###+, Db++, Ebbb++, H##+,C##++, Ebb++, Fbbb++, H###+,C###++, Eb++, Fbb++,C####++, D##++, Fb++, Gbbb++,D###++, E#++, Gbb++,Abbb++, D####++, E##++, Gb++,Abb++, Bbbb++, E###++, F##++,Ab++, Bbb++, F###++,Bb++, Cbbb+++, F####++, G##++,A#++, Cbb+++, G###++,A##++, B#++, Cb+++, Dbbb+++, G####++,A###++, B##++, Dbb+++, H#++,B###++, Db+++, Ebbb+++, H##++,C##+++, Ebb+++, Fbbb+++, H###++,C###+++, Eb+++, Fbb+++,C####+++, D##+++, Fb+++, Gbbb+++,D###+++, E#+++, Gbb+++,Abbb+++, D####+++, E##+++, Gb+++,Abb+++, Bbbb+++, E###+++, F##+++,Ab+++, Bbb+++, F###+++,Bb+++, Cbbb++++, F####+++, G##+++,A#+++, Cbb++++, G###+++,A##+++, B#+++, Cb++++, Dbbb++++, G####+++,A###+++, B##+++, Dbb++++, H#+++,B###+++, Db++++, Ebbb++++, H##+++,C##++++, Ebb++++, Fbbb++++, H###+++,C###++++, Eb++++, Fbb++++,C####++++, D##++++, Fb++++, Gbbb++++,D###++++, E#++++, Gbb++++,Abbb++++, D####++++, E##++++, Gb++++,Abb++++, Bbbb++++, E###++++, F##++++,Ab++++, Bbb++++, F###++++,Bb++++, Cbbb+++++, F####++++, G##++++,A#++++, Cbb+++++, G###++++,A##++++, B#++++, Cb+++++, Dbbb+++++, G####++++,A###++++, B##++++, Dbb+++++, H#++++,B###++++, Db+++++, Ebbb+++++, H##++++,C##+++++, Ebb+++++, Fbbb+++++, H###++++,C###+++++, Eb+++++, Fbb+++++,C####+++++, D##+++++, Fb+++++, Gbbb+++++,D###+++++, E#+++++, Gbb+++++,Abbb+++++, D####+++++, E##+++++, Gb+++++,Abb+++++, Bbbb+++++, E###+++++, F##+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "A###-2, B##-2, Dbb-1, H#-2,B###-2, Db-1, Ebbb-1, H##-2,C##-1, Ebb-1, Fbbb-1, H###-2,C###-1, Eb-1, Fbb-1,C####-1, D##-1, Fb-1, Gbbb-1,D###-1, E#-1, Gbb-1,Abbb-1, D####-1, E##-1, Gb-1,Abb-1, Bbbb-1, E###-1, F##-1,Ab-1, Bbb-1, F###-1,Bb-1, Cbbb0, F####-1, G##-1,A#-1, Cbb0, G###-1,A##-1, B#-1, Cb0, Dbbb0, G####-1,A###-1, B##-1, Dbb0, H#-1,B###-1, Db0, Ebbb0, H##-1,C##0, Ebb0, Fbbb0, H###-1,C###0, Eb0, Fbb0,C####0, D##0, Fb0, Gbbb0,D###0, E#0, Gbb0,Abbb0, D####0, E##0, Gb0,Abb0, Bbbb0, E###0, F##0,Ab0, Bbb0, F###0,Bb0, Cbbb1, F####0, G##0,A#0, Cbb1, G###0,A##0, B#0, Cb1, Dbbb1, G####0,A###0, B##0, Dbb1, H#0,B###0, Db1, Ebbb1, H##0,C##1, Ebb1, Fbbb1, H###0,C###1, Eb1, Fbb1,C####1, D##1, Fb1, Gbbb1,D###1, E#1, Gbb1,Abbb1, D####1, E##1, Gb1,Abb1, Bbbb1, E###1, F##1,Ab1, Bbb1, F###1,Bb1, Cbbb2, F####1, G##1,A#1, Cbb2, G###1,A##1, B#1, Cb2, Dbbb2, G####1,A###1, B##1, Dbb2, H#1,B###1, Db2, Ebbb2, H##1,C##2, Ebb2, Fbbb2, H###1,C###2, Eb2, Fbb2,C####2, D##2, Fb2, Gbbb2,D###2, E#2, Gbb2,Abbb2, D####2, E##2, Gb2,Abb2, Bbbb2, E###2, F##2,Ab2, Bbb2, F###2,Bb2, Cbbb3, F####2, G##2,A#2, Cbb3, G###2,A##2, B#2, Cb3, Dbbb3, G####2,A###2, B##2, Dbb3, H#2,B###2, Db3, Ebbb3, H##2,C##3, Ebb3, Fbbb3, H###2,C###3, Eb3, Fbb3,C####3, D##3, Fb3, Gbbb3,D###3, E#3, Gbb3,Abbb3, D####3, E##3, Gb3,Abb3, Bbbb3, E###3, F##3,Ab3, Bbb3, F###3,Bb3, Cbbb4, F####3, G##3,A#3, Cbb4, G###3,A##3, B#3, Cb4, Dbbb4, G####3,A###3, B##3, Dbb4, H#3,B###3, Db4, Ebbb4, H##3,C##4, Ebb4, Fbbb4, H###3,C###4, Eb4, Fbb4,C####4, D##4, Fb4, Gbbb4,D###4, E#4, Gbb4,Abbb4, D####4, E##4, Gb4,Abb4, Bbbb4, E###4, F##4,Ab4, Bbb4, F###4,Bb4, Cbbb5, F####4, G##4,A#4, Cbb5, G###4,A##4, B#4, Cb5, Dbbb5, G####4,A###4, B##4, Dbb5, H#4,B###4, Db5, Ebbb5, H##4,C##5, Ebb5, Fbbb5, H###4,C###5, Eb5, Fbb5,C####5, D##5, Fb5, Gbbb5,D###5, E#5, Gbb5,Abbb5, D####5, E##5, Gb5,Abb5, Bbbb5, E###5, F##5,Ab5, Bbb5, F###5,Bb5, Cbbb6, F####5, G##5,A#5, Cbb6, G###5,A##5, B#5, Cb6, Dbbb6, G####5,A###5, B##5, Dbb6, H#5,B###5, Db6, Ebbb6, H##5,C##6, Ebb6, Fbbb6, H###5,C###6, Eb6, Fbb6,C####6, D##6, Fb6, Gbbb6,D###6, E#6, Gbb6,Abbb6, D####6, E##6, Gb6,Abb6, Bbbb6, E###6, F##6,Ab6, Bbb6, F###6,Bb6, Cbbb7, F####6, G##6,A#6, Cbb7, G###6,A##6, B#6, Cb7, Dbbb7, G####6,A###6, B##6, Dbb7, H#6,B###6, Db7, Ebbb7, H##6,C##7, Ebb7, Fbbb7, H###6,C###7, Eb7, Fbb7,C####7, D##7, Fb7, Gbbb7,D###7, E#7, Gbb7,Abbb7, D####7, E##7, Gb7,Abb7, Bbbb7, E###7, F##7,Ab7, Bbb7, F###7,Bb7, Cbbb8, F####7, G##7,A#7, Cbb8, G###7,A##7, B#7, Cb8, Dbbb8, G####7,A###7, B##7, Dbb8, H#7,B###7, Db8, Ebbb8, H##7,C##8, Ebb8, Fbbb8, H###7,C###8, Eb8, Fbb8,C####8, D##8, Fb8, Gbbb8,D###8, E#8, Gbb8,Abbb8, D####8, E##8, Gb8,Abb8, Bbbb8, E###8, F##8,Ab8, Bbb8, F###8,Bb8, Cbbb9, F####8, G##8,A#8, Cbb9, G###8,A##8, B#8, Cb9, Dbbb9, G####8,A###8, B##8, Dbb9, H#8,B###8, Db9, Ebbb9, H##8,C##9, Ebb9, Fbbb9, H###8,C###9, Eb9, Fbb9,C####9, D##9, Fb9, Gbbb9,D###9, E#9, Gbb9,Abbb9, D####9, E##9, Gb9,Abb9, Bbbb9, E###9, F##9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A###'''', B##'''', Dbb''', H#'''',B###'''', Db''', Ebbb''', H##'''',C##''', Ebb''', Fbbb''', H###'''',C###''', Eb''', Fbb''',C####''', D##''', Fb''', Gbbb''',D###''', E#''', Gbb''',Abbb''', D####''', E##''', Gb''',Abb''', Bbbb''', E###''', F##''',Ab''', Bbb''', F###''',Bb''', Cbbb'', F####''', G##''',A#''', Cbb'', G###''',A##''', B#''', Cb'', Dbbb'', G####''',A###''', B##''', Dbb'', H#''',B###''', Db'', Ebbb'', H##''',C##'', Ebb'', Fbbb'', H###''',C###'', Eb'', Fbb'',C####'', D##'', Fb'', Gbbb'',D###'', E#'', Gbb'',Abbb'', D####'', E##'', Gb'',Abb'', Bbbb'', E###'', F##'',Ab'', Bbb'', F###'',Bb'', Cbbb', F####'', G##'',A#'', Cbb', G###'',A##'', B#'', Cb', Dbbb', G####'',A###'', B##'', Dbb', H#'',B###'', Db', Ebbb', H##'',C##', Ebb', Fbbb', H###'',C###', Eb', Fbb',C####', D##', Fb', Gbbb',D###', E#', Gbb',Abbb', D####', E##', Gb',Abb', Bbbb', E###', F##',Ab', Bbb', F###',Bb', Cbbb, F####', G##',A#', Cbb, G###',A##', B#', Cb, Dbbb, G####',A###', B##', Dbb, H#',B###', Db, Ebbb, H##',C##, Ebb, Fbbb, H###',C###, Eb, Fbb,C####, D##, Fb, Gbbb,D###, E#, Gbb,Abbb, D####, E##, Gb,Abb, Bbbb, E###, F##,Ab, Bbb, F###,Bb, F####, G##, cbbb,A#, G###, cbb,A##, B#, G####, cb, dbbb,A###, B##, H#, dbb,B###, H##, db, ebbb,H###, c##, ebb, fbbb,c###, eb, fbb,c####, d##, fb, gbbb,d###, e#, gbb,abbb, d####, e##, gb,abb, bbbb, e###, f##,ab, bbb, f###,bb, cbbb', f####, g##,a#, cbb', g###,a##, b#, cb', dbbb', g####,a###, b##, dbb', h#,b###, db', ebbb', h##,c##', ebb', fbbb', h###,c###', eb', fbb',c####', d##', fb', gbbb',d###', e#', gbb',abbb', d####', e##', gb',abb', bbbb', e###', f##',ab', bbb', f###',bb', cbbb'', f####', g##',a#', cbb'', g###',a##', b#', cb'', dbbb'', g####',a###', b##', dbb'', h#',b###', db'', ebbb'', h##',c##'', ebb'', fbbb'', h###',c###'', eb'', fbb'',c####'', d##'', fb'', gbbb'',d###'', e#'', gbb'',abbb'', d####'', e##'', gb'',abb'', bbbb'', e###'', f##'',ab'', bbb'', f###'',bb'', cbbb''', f####'', g##'',a#'', cbb''', g###'',a##'', b#'', cb''', dbbb''', g####'',a###'', b##'', dbb''', h#'',b###'', db''', ebbb''', h##'',c##''', ebb''', fbbb''', h###'',c###''', eb''', fbb''',c####''', d##''', fb''', gbbb''',d###''', e#''', gbb''',abbb''', d####''', e##''', gb''',abb''', bbbb''', e###''', f##''',ab''', bbb''', f###''',bb''', cbbb'''', f####''', g##''',a#''', cbb'''', g###''',a##''', b#''', cb'''', dbbb'''', g####''',a###''', b##''', dbb'''', h#''',b###''', db'''', ebbb'''', h##''',c##'''', ebb'''', fbbb'''', h###''',c###'''', eb'''', fbb'''',c####'''', d##'''', fb'''', gbbb'''',d###'''', e#'''', gbb'''',abbb'''', d####'''', e##'''', gb'''',abb'''', bbbb'''', e###'''', f##'''',ab'''', bbb'''', f###'''',bb'''', cbbb''''', f####'''', g##'''',a#'''', cbb''''', g###'''',a##'''', b#'''', cb''''', dbbb''''', g####'''',a###'''', b##'''', dbb''''', h#'''',b###'''', db''''', ebbb''''', h##'''',c##''''', ebb''''', fbbb''''', h###'''',c###''''', eb''''', fbb''''',c####''''', d##''''', fb''''', gbbb''''',d###''''', e#''''', gbb''''',abbb''''', d####''''', e##''''', gb''''',abb''''', bbbb''''', e###''''', f##''''',ab''''', bbb''''', f###''''',bb''''', cbbb'''''', f####''''', g##''''',a#''''', cbb'''''', g###''''',a##''''', b#''''', cb'''''', dbbb'''''', g####''''',a###''''', b##''''', dbb'''''', h#''''',b###''''', db'''''', ebbb'''''', h##''''',c##'''''', ebb'''''', fbbb'''''', h###''''',c###'''''', eb'''''', fbb'''''',c####'''''', d##'''''', fb'''''', gbbb'''''',d###'''''', e#'''''', gbb'''''',abbb'''''', d####'''''', e##'''''', gb'''''',abb'''''', bbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "A###-6, B##-6, Dbb-5, Ebbbb-5, H#-6,B###-6, C#-5, Ebbb-5, H##-6,C##-5, Ebb-5, Fbbb-5, H###-6,C###-5, D#-5, Fbb-5, Gbbbb-5,D##-5, Fb-5, Gbbb-5,Abbbb-5, D###-5, E#-5, Gbb-5,Abbb-5, E##-5, F#-5,Abb-5, Bbbb-5, E###-5, F##-5,Bbb-5, F###-5, G#-5,Bb-5, Cbbb-4, G##-5,A#-5, Cbb-4, Dbbbb-4, G###-5,A##-5, B#-5, Cb-4, Dbbb-4,A###-5, B##-5, Dbb-4, Ebbbb-4, H#-5,B###-5, C#-4, Ebbb-4, H##-5,C##-4, Ebb-4, Fbbb-4, H###-5,C###-4, D#-4, Fbb-4, Gbbbb-4,D##-4, Fb-4, Gbbb-4,Abbbb-4, D###-4, E#-4, Gbb-4,Abbb-4, E##-4, F#-4,Abb-4, Bbbb-4, E###-4, F##-4,Bbb-4, F###-4, G#-4,Bb-4, Cbbb-3, G##-4,A#-4, Cbb-3, Dbbbb-3, G###-4,A##-4, B#-4, Cb-3, Dbbb-3,A###-4, B##-4, Dbb-3, Ebbbb-3, H#-4,B###-4, C#-3, Ebbb-3, H##-4,C##-3, Ebb-3, Fbbb-3, H###-4,C###-3, D#-3, Fbb-3, Gbbbb-3,D##-3, Fb-3, Gbbb-3,Abbbb-3, D###-3, E#-3, Gbb-3,Abbb-3, E##-3, F#-3,Abb-3, Bbbb-3, E###-3, F##-3,Bbb-3, F###-3, G#-3,Bb-3, Cbbb-2, G##-3,A#-3, Cbb-2, Dbbbb-2, G###-3,A##-3, B#-3, Cb-2, Dbbb-2,A###-3, B##-3, Dbb-2, Ebbbb-2, H#-3,B###-3, C#-2, Ebbb-2, H##-3,C##-2, Ebb-2, Fbbb-2, H###-3,C###-2, D#-2, Fbb-2, Gbbbb-2,D##-2, Fb-2, Gbbb-2,Abbbb-2, D###-2, E#-2, Gbb-2,Abbb-2, E##-2, F#-2,Abb-2, Bbbb-2, E###-2, F##-2,Bbb-2, F###-2, G#-2,Bb-2, Cbbb-, G##-2,A#-2, Cbb-, Dbbbb-, G###-2,A##-2, B#-2, Cb-, Dbbb-,A###-2, B##-2, Dbb-, Ebbbb-, H#-2,B###-2, C#-, Ebbb-, H##-2,C##-, Ebb-, Fbbb-, H###-2,C###-, D#-, Fbb-, Gbbbb-,D##-, Fb-, Gbbb-,Abbbb-, D###-, E#-, Gbb-,Abbb-, E##-, F#-,Abb-, Bbbb-, E###-, F##-,Bbb-, F###-, G#-,Bb-, Cbbb, G##-,A#-, Cbb, Dbbbb, G###-,A##-, B#-, Cb, Dbbb,A###-, B##-, Dbb, Ebbbb, H#-,B###-, C#, Ebbb, H##-,C##, Ebb, Fbbb, H###-,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbb, E###, F##,Bbb, F###, G#,Bb, Cbbb+, G##,A#, Cbb+, Dbbbb+, G###,A##, B#, Cb+, Dbbb+,A###, B##, Dbb+, Ebbbb+, H#,B###, C#+, Ebbb+, H##,C##+, Ebb+, Fbbb+, H###,C###+, D#+, Fbb+, Gbbbb+,D##+, Fb+, Gbbb+,Abbbb+, D###+, E#+, Gbb+,Abbb+, E##+, F#+,Abb+, Bbbb+, E###+, F##+,Bbb+, F###+, G#+,Bb+, Cbbb+2, G##+,A#+, Cbb+2, Dbbbb+2, G###+,A##+, B#+, Cb+2, Dbbb+2,A###+, B##+, Dbb+2, Ebbbb+2, H#+,B###+, C#+2, Ebbb+2, H##+,C##+2, Ebb+2, Fbbb+2, H###+,C###+2, D#+2, Fbb+2, Gbbbb+2,D##+2, Fb+2, Gbbb+2,Abbbb+2, D###+2, E#+2, Gbb+2,Abbb+2, E##+2, F#+2,Abb+2, Bbbb+2, E###+2, F##+2,Bbb+2, F###+2, G#+2,Bb+2, Cbbb+3, G##+2,A#+2, Cbb+3, Dbbbb+3, G###+2,A##+2, B#+2, Cb+3, Dbbb+3,A###+2, B##+2, Dbb+3, Ebbbb+3, H#+2,B###+2, C#+3, Ebbb+3, H##+2,C##+3, Ebb+3, Fbbb+3, H###+2,C###+3, D#+3, Fbb+3, Gbbbb+3,D##+3, Fb+3, Gbbb+3,Abbbb+3, D###+3, E#+3, Gbb+3,Abbb+3, E##+3, F#+3,Abb+3, Bbbb+3, E###+3, F##+3,Bbb+3, F###+3, G#+3,Bb+3, Cbbb+4, G##+3,A#+3, Cbb+4, Dbbbb+4, G###+3,A##+3, B#+3, Cb+4, Dbbb+4,A###+3, B##+3, Dbb+4, Ebbbb+4, H#+3,B###+3, C#+4, Ebbb+4, H##+3,C##+4, Ebb+4, Fbbb+4, H###+3,C###+4, D#+4, Fbb+4, Gbbbb+4,D##+4, Fb+4, Gbbb+4,Abbbb+4, D###+4, E#+4, Gbb+4,Abbb+4, E##+4, F#+4,Abb+4, Bbbb+4, E###+4, F##+4,Bbb+4, F###+4, G#+4,Bb+4, Cbbb+5, G##+4,A#+4, Cbb+5, Dbbbb+5, G###+4,A##+4, B#+4, Cb+5, Dbbb+5,A###+4, B##+4, Dbb+5, Ebbbb+5, H#+4,B###+4, C#+5, Ebbb+5, H##+4,C##+5, Ebb+5, Fbbb+5, H###+4,C###+5, D#+5, Fbb+5, Gbbbb+5,D##+5, Fb+5, Gbbb+5,Abbbb+5, D###+5, E#+5, Gbb+5,Abbb+5, E##+5, F#+5,Abb+5, Bbbb+5, E###+5, F##+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "A###------, B##------, Dbb-----, Ebbbb-----, H#------,B###------, C#-----, Ebbb-----, H##------,C##-----, Ebb-----, Fbbb-----, H###------,C###-----, D#-----, Fbb-----, Gbbbb-----,D##-----, Fb-----, Gbbb-----,Abbbb-----, D###-----, E#-----, Gbb-----,Abbb-----, E##-----, F#-----,Abb-----, Bbbb-----, E###-----, F##-----,Bbb-----, F###-----, G#-----,Bb-----, Cbbb----, G##-----,A#-----, Cbb----, Dbbbb----, G###-----,A##-----, B#-----, Cb----, Dbbb----,A###-----, B##-----, Dbb----, Ebbbb----, H#-----,B###-----, C#----, Ebbb----, H##-----,C##----, Ebb----, Fbbb----, H###-----,C###----, D#----, Fbb----, Gbbbb----,D##----, Fb----, Gbbb----,Abbbb----, D###----, E#----, Gbb----,Abbb----, E##----, F#----,Abb----, Bbbb----, E###----, F##----,Bbb----, F###----, G#----,Bb----, Cbbb---, G##----,A#----, Cbb---, Dbbbb---, G###----,A##----, B#----, Cb---, Dbbb---,A###----, B##----, Dbb---, Ebbbb---, H#----,B###----, C#---, Ebbb---, H##----,C##---, Ebb---, Fbbb---, H###----,C###---, D#---, Fbb---, Gbbbb---,D##---, Fb---, Gbbb---,Abbbb---, D###---, E#---, Gbb---,Abbb---, E##---, F#---,Abb---, Bbbb---, E###---, F##---,Bbb---, F###---, G#---,Bb---, Cbbb--, G##---,A#---, Cbb--, Dbbbb--, G###---,A##---, B#---, Cb--, Dbbb--,A###---, B##---, Dbb--, Ebbbb--, H#---,B###---, C#--, Ebbb--, H##---,C##--, Ebb--, Fbbb--, H###---,C###--, D#--, Fbb--, Gbbbb--,D##--, Fb--, Gbbb--,Abbbb--, D###--, E#--, Gbb--,Abbb--, E##--, F#--,Abb--, Bbbb--, E###--, F##--,Bbb--, F###--, G#--,Bb--, Cbbb-, G##--,A#--, Cbb-, Dbbbb-, G###--,A##--, B#--, Cb-, Dbbb-,A###--, B##--, Dbb-, Ebbbb-, H#--,B###--, C#-, Ebbb-, H##--,C##-, Ebb-, Fbbb-, H###--,C###-, D#-, Fbb-, Gbbbb-,D##-, Fb-, Gbbb-,Abbbb-, D###-, E#-, Gbb-,Abbb-, E##-, F#-,Abb-, Bbbb-, E###-, F##-,Bbb-, F###-, G#-,Bb-, Cbbb, G##-,A#-, Cbb, Dbbbb, G###-,A##-, B#-, Cb, Dbbb,A###-, B##-, Dbb, Ebbbb, H#-,B###-, C#, Ebbb, H##-,C##, Ebb, Fbbb, H###-,C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbb, E###, F##,Bbb, F###, G#,Bb, Cbbb+, G##,A#, Cbb+, Dbbbb+, G###,A##, B#, Cb+, Dbbb+,A###, B##, Dbb+, Ebbbb+, H#,B###, C#+, Ebbb+, H##,C##+, Ebb+, Fbbb+, H###,C###+, D#+, Fbb+, Gbbbb+,D##+, Fb+, Gbbb+,Abbbb+, D###+, E#+, Gbb+,Abbb+, E##+, F#+,Abb+, Bbbb+, E###+, F##+,Bbb+, F###+, G#+,Bb+, Cbbb++, G##+,A#+, Cbb++, Dbbbb++, G###+,A##+, B#+, Cb++, Dbbb++,A###+, B##+, Dbb++, Ebbbb++, H#+,B###+, C#++, Ebbb++, H##+,C##++, Ebb++, Fbbb++, H###+,C###++, D#++, Fbb++, Gbbbb++,D##++, Fb++, Gbbb++,Abbbb++, D###++, E#++, Gbb++,Abbb++, E##++, F#++,Abb++, Bbbb++, E###++, F##++,Bbb++, F###++, G#++,Bb++, Cbbb+++, G##++,A#++, Cbb+++, Dbbbb+++, G###++,A##++, B#++, Cb+++, Dbbb+++,A###++, B##++, Dbb+++, Ebbbb+++, H#++,B###++, C#+++, Ebbb+++, H##++,C##+++, Ebb+++, Fbbb+++, H###++,C###+++, D#+++, Fbb+++, Gbbbb+++,D##+++, Fb+++, Gbbb+++,Abbbb+++, D###+++, E#+++, Gbb+++,Abbb+++, E##+++, F#+++,Abb+++, Bbbb+++, E###+++, F##+++,Bbb+++, F###+++, G#+++,Bb+++, Cbbb++++, G##+++,A#+++, Cbb++++, Dbbbb++++, G###+++,A##+++, B#+++, Cb++++, Dbbb++++,A###+++, B##+++, Dbb++++, Ebbbb++++, H#+++,B###+++, C#++++, Ebbb++++, H##+++,C##++++, Ebb++++, Fbbb++++, H###+++,C###++++, D#++++, Fbb++++, Gbbbb++++,D##++++, Fb++++, Gbbb++++,Abbbb++++, D###++++, E#++++, Gbb++++,Abbb++++, E##++++, F#++++,Abb++++, Bbbb++++, E###++++, F##++++,Bbb++++, F###++++, G#++++,Bb++++, Cbbb+++++, G##++++,A#++++, Cbb+++++, Dbbbb+++++, G###++++,A##++++, B#++++, Cb+++++, Dbbb+++++,A###++++, B##++++, Dbb+++++, Ebbbb+++++, H#++++,B###++++, C#+++++, Ebbb+++++, H##++++,C##+++++, Ebb+++++, Fbbb+++++, H###++++,C###+++++, D#+++++, Fbb+++++, Gbbbb+++++,D##+++++, Fb+++++, Gbbb+++++,Abbbb+++++, D###+++++, E#+++++, Gbb+++++,Abbb+++++, E##+++++, F#+++++,Abb+++++, Bbbb+++++, E###+++++, F##+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "A###-2, B##-2, Dbb-1, Ebbbb-1, H#-2,B###-2, C#-1, Ebbb-1, H##-2,C##-1, Ebb-1, Fbbb-1, H###-2,C###-1, D#-1, Fbb-1, Gbbbb-1,D##-1, Fb-1, Gbbb-1,Abbbb-1, D###-1, E#-1, Gbb-1,Abbb-1, E##-1, F#-1,Abb-1, Bbbb-1, E###-1, F##-1,Bbb-1, F###-1, G#-1,Bb-1, Cbbb0, G##-1,A#-1, Cbb0, Dbbbb0, G###-1,A##-1, B#-1, Cb0, Dbbb0,A###-1, B##-1, Dbb0, Ebbbb0, H#-1,B###-1, C#0, Ebbb0, H##-1,C##0, Ebb0, Fbbb0, H###-1,C###0, D#0, Fbb0, Gbbbb0,D##0, Fb0, Gbbb0,Abbbb0, D###0, E#0, Gbb0,Abbb0, E##0, F#0,Abb0, Bbbb0, E###0, F##0,Bbb0, F###0, G#0,Bb0, Cbbb1, G##0,A#0, Cbb1, Dbbbb1, G###0,A##0, B#0, Cb1, Dbbb1,A###0, B##0, Dbb1, Ebbbb1, H#0,B###0, C#1, Ebbb1, H##0,C##1, Ebb1, Fbbb1, H###0,C###1, D#1, Fbb1, Gbbbb1,D##1, Fb1, Gbbb1,Abbbb1, D###1, E#1, Gbb1,Abbb1, E##1, F#1,Abb1, Bbbb1, E###1, F##1,Bbb1, F###1, G#1,Bb1, Cbbb2, G##1,A#1, Cbb2, Dbbbb2, G###1,A##1, B#1, Cb2, Dbbb2,A###1, B##1, Dbb2, Ebbbb2, H#1,B###1, C#2, Ebbb2, H##1,C##2, Ebb2, Fbbb2, H###1,C###2, D#2, Fbb2, Gbbbb2,D##2, Fb2, Gbbb2,Abbbb2, D###2, E#2, Gbb2,Abbb2, E##2, F#2,Abb2, Bbbb2, E###2, F##2,Bbb2, F###2, G#2,Bb2, Cbbb3, G##2,A#2, Cbb3, Dbbbb3, G###2,A##2, B#2, Cb3, Dbbb3,A###2, B##2, Dbb3, Ebbbb3, H#2,B###2, C#3, Ebbb3, H##2,C##3, Ebb3, Fbbb3, H###2,C###3, D#3, Fbb3, Gbbbb3,D##3, Fb3, Gbbb3,Abbbb3, D###3, E#3, Gbb3,Abbb3, E##3, F#3,Abb3, Bbbb3, E###3, F##3,Bbb3, F###3, G#3,Bb3, Cbbb4, G##3,A#3, Cbb4, Dbbbb4, G###3,A##3, B#3, Cb4, Dbbb4,A###3, B##3, Dbb4, Ebbbb4, H#3,B###3, C#4, Ebbb4, H##3,C##4, Ebb4, Fbbb4, H###3,C###4, D#4, Fbb4, Gbbbb4,D##4, Fb4, Gbbb4,Abbbb4, D###4, E#4, Gbb4,Abbb4, E##4, F#4,Abb4, Bbbb4, E###4, F##4,Bbb4, F###4, G#4,Bb4, Cbbb5, G##4,A#4, Cbb5, Dbbbb5, G###4,A##4, B#4, Cb5, Dbbb5,A###4, B##4, Dbb5, Ebbbb5, H#4,B###4, C#5, Ebbb5, H##4,C##5, Ebb5, Fbbb5, H###4,C###5, D#5, Fbb5, Gbbbb5,D##5, Fb5, Gbbb5,Abbbb5, D###5, E#5, Gbb5,Abbb5, E##5, F#5,Abb5, Bbbb5, E###5, F##5,Bbb5, F###5, G#5,Bb5, Cbbb6, G##5,A#5, Cbb6, Dbbbb6, G###5,A##5, B#5, Cb6, Dbbb6,A###5, B##5, Dbb6, Ebbbb6, H#5,B###5, C#6, Ebbb6, H##5,C##6, Ebb6, Fbbb6, H###5,C###6, D#6, Fbb6, Gbbbb6,D##6, Fb6, Gbbb6,Abbbb6, D###6, E#6, Gbb6,Abbb6, E##6, F#6,Abb6, Bbbb6, E###6, F##6,Bbb6, F###6, G#6,Bb6, Cbbb7, G##6,A#6, Cbb7, Dbbbb7, G###6,A##6, B#6, Cb7, Dbbb7,A###6, B##6, Dbb7, Ebbbb7, H#6,B###6, C#7, Ebbb7, H##6,C##7, Ebb7, Fbbb7, H###6,C###7, D#7, Fbb7, Gbbbb7,D##7, Fb7, Gbbb7,Abbbb7, D###7, E#7, Gbb7,Abbb7, E##7, F#7,Abb7, Bbbb7, E###7, F##7,Bbb7, F###7, G#7,Bb7, Cbbb8, G##7,A#7, Cbb8, Dbbbb8, G###7,A##7, B#7, Cb8, Dbbb8,A###7, B##7, Dbb8, Ebbbb8, H#7,B###7, C#8, Ebbb8, H##7,C##8, Ebb8, Fbbb8, H###7,C###8, D#8, Fbb8, Gbbbb8,D##8, Fb8, Gbbb8,Abbbb8, D###8, E#8, Gbb8,Abbb8, E##8, F#8,Abb8, Bbbb8, E###8, F##8,Bbb8, F###8, G#8,Bb8, Cbbb9, G##8,A#8, Cbb9, Dbbbb9, G###8,A##8, B#8, Cb9, Dbbb9,A###8, B##8, Dbb9, Ebbbb9, H#8,B###8, C#9, Ebbb9, H##8,C##9, Ebb9, Fbbb9, H###8,C###9, D#9, Fbb9, Gbbbb9,D##9, Fb9, Gbbb9,Abbbb9, D###9, E#9, Gbb9,Abbb9, E##9, F#9,Abb9, Bbbb9, E###9, F##9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_sharp/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A###'''', B##'''', Dbb''', Ebbbb''', H#'''',B###'''', C#''', Ebbb''', H##'''',C##''', Ebb''', Fbbb''', H###'''',C###''', D#''', Fbb''', Gbbbb''',D##''', Fb''', Gbbb''',Abbbb''', D###''', E#''', Gbb''',Abbb''', E##''', F#''',Abb''', Bbbb''', E###''', F##''',Bbb''', F###''', G#''',Bb''', Cbbb'', G##''',A#''', Cbb'', Dbbbb'', G###''',A##''', B#''', Cb'', Dbbb'',A###''', B##''', Dbb'', Ebbbb'', H#''',B###''', C#'', Ebbb'', H##''',C##'', Ebb'', Fbbb'', H###''',C###'', D#'', Fbb'', Gbbbb'',D##'', Fb'', Gbbb'',Abbbb'', D###'', E#'', Gbb'',Abbb'', E##'', F#'',Abb'', Bbbb'', E###'', F##'',Bbb'', F###'', G#'',Bb'', Cbbb', G##'',A#'', Cbb', Dbbbb', G###'',A##'', B#'', Cb', Dbbb',A###'', B##'', Dbb', Ebbbb', H#'',B###'', C#', Ebbb', H##'',C##', Ebb', Fbbb', H###'',C###', D#', Fbb', Gbbbb',D##', Fb', Gbbb',Abbbb', D###', E#', Gbb',Abbb', E##', F#',Abb', Bbbb', E###', F##',Bbb', F###', G#',Bb', Cbbb, G##',A#', Cbb, Dbbbb, G###',A##', B#', Cb, Dbbb,A###', B##', Dbb, Ebbbb, H#',B###', C#, Ebbb, H##',C##, Ebb, Fbbb, H###',C###, D#, Fbb, Gbbbb,D##, Fb, Gbbb,Abbbb, D###, E#, Gbb,Abbb, E##, F#,Abb, Bbbb, E###, F##,Bbb, F###, G#,Bb, G##, cbbb,A#, G###, cbb, dbbbb,A##, B#, cb, dbbb,A###, B##, H#, dbb, ebbbb,B###, H##, c#, ebbb,H###, c##, ebb, fbbb,c###, d#, fbb, gbbbb,d##, fb, gbbb,abbbb, d###, e#, gbb,abbb, e##, f#,abb, bbbb, e###, f##,bbb, f###, g#,bb, cbbb', g##,a#, cbb', dbbbb', g###,a##, b#, cb', dbbb',a###, b##, dbb', ebbbb', h#,b###, c#', ebbb', h##,c##', ebb', fbbb', h###,c###', d#', fbb', gbbbb',d##', fb', gbbb',abbbb', d###', e#', gbb',abbb', e##', f#',abb', bbbb', e###', f##',bbb', f###', g#',bb', cbbb'', g##',a#', cbb'', dbbbb'', g###',a##', b#', cb'', dbbb'',a###', b##', dbb'', ebbbb'', h#',b###', c#'', ebbb'', h##',c##'', ebb'', fbbb'', h###',c###'', d#'', fbb'', gbbbb'',d##'', fb'', gbbb'',abbbb'', d###'', e#'', gbb'',abbb'', e##'', f#'',abb'', bbbb'', e###'', f##'',bbb'', f###'', g#'',bb'', cbbb''', g##'',a#'', cbb''', dbbbb''', g###'',a##'', b#'', cb''', dbbb''',a###'', b##'', dbb''', ebbbb''', h#'',b###'', c#''', ebbb''', h##'',c##''', ebb''', fbbb''', h###'',c###''', d#''', fbb''', gbbbb''',d##''', fb''', gbbb''',abbbb''', d###''', e#''', gbb''',abbb''', e##''', f#''',abb''', bbbb''', e###''', f##''',bbb''', f###''', g#''',bb''', cbbb'''', g##''',a#''', cbb'''', dbbbb'''', g###''',a##''', b#''', cb'''', dbbb'''',a###''', b##''', dbb'''', ebbbb'''', h#''',b###''', c#'''', ebbb'''', h##''',c##'''', ebb'''', fbbb'''', h###''',c###'''', d#'''', fbb'''', gbbbb'''',d##'''', fb'''', gbbb'''',abbbb'''', d###'''', e#'''', gbb'''',abbb'''', e##'''', f#'''',abb'''', bbbb'''', e###'''', f##'''',bbb'''', f###'''', g#'''',bb'''', cbbb''''', g##'''',a#'''', cbb''''', dbbbb''''', g###'''',a##'''', b#'''', cb''''', dbbb''''',a###'''', b##'''', dbb''''', ebbbb''''', h#'''',b###'''', c#''''', ebbb''''', h##'''',c##''''', ebb''''', fbbb''''', h###'''',c###''''', d#''''', fbb''''', gbbbb''''',d##''''', fb''''', gbbb''''',abbbb''''', d###''''', e#''''', gbb''''',abbb''''', e##''''', f#''''',abb''''', bbbb''''', e###''''', f##''''',bbb''''', f###''''', g#''''',bb''''', cbbb'''''', g##''''',a#''''', cbb'''''', dbbbb'''''', g###''''',a##''''', b#''''', cb'''''', dbbb'''''',a###''''', b##''''', dbb'''''', ebbbb'''''', h#''''',b###''''', c#'''''', ebbb'''''', h##''''',c##'''''', ebb'''''', fbbb'''''', h###''''',c###'''''', d#'''''', fbb'''''', gbbbb'''''',d##'''''', fb'''''', gbbb'''''',abbbb'''''', d###'''''', e#'''''', gbb'''''',abbb'''''', e##'''''', f#'''''',abb'''''', bbbb'''''', e###'''''', f##''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "A-diesis-diesis-diesis-6, B-diesis-diesis-6, D-bemolle-bemolle-5, H-diesis-6,B-diesis-diesis-diesis-6, D-bemolle-5, E-bemolle-bemolle-bemolle-5, H-diesis-diesis-6,C-diesis-diesis-5, E-bemolle-bemolle-5, F-bemolle-bemolle-bemolle-5, H-diesis-diesis-diesis-6,C-diesis-diesis-diesis-5, E-bemolle-5, F-bemolle-bemolle-5,C-diesis-diesis-diesis-diesis-5, D-diesis-diesis-5, F-bemolle-5, G-bemolle-bemolle-bemolle-5,D-diesis-diesis-diesis-5, E-diesis-5, G-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-5, D-diesis-diesis-diesis-diesis-5, E-diesis-diesis-5, G-bemolle-5,A-bemolle-bemolle-5, B-bemolle-bemolle-bemolle-5, E-diesis-diesis-diesis-5, F-diesis-diesis-5,A-bemolle-5, B-bemolle-bemolle-5, F-diesis-diesis-diesis-5, H-bemolle-bemolle-bemolle-5,B-bemolle-5, C-bemolle-bemolle-bemolle-4, F-diesis-diesis-diesis-diesis-5, G-diesis-diesis-5, H-bemolle-bemolle-5,A-diesis-5, C-bemolle-bemolle-4, G-diesis-diesis-diesis-5, H-bemolle-5,A-diesis-diesis-5, B-diesis-5, C-bemolle-4, D-bemolle-bemolle-bemolle-4, G-diesis-diesis-diesis-diesis-5,A-diesis-diesis-diesis-5, B-diesis-diesis-5, D-bemolle-bemolle-4, H-diesis-5,B-diesis-diesis-diesis-5, D-bemolle-4, E-bemolle-bemolle-bemolle-4, H-diesis-diesis-5,C-diesis-diesis-4, E-bemolle-bemolle-4, F-bemolle-bemolle-bemolle-4, H-diesis-diesis-diesis-5,C-diesis-diesis-diesis-4, E-bemolle-4, F-bemolle-bemolle-4,C-diesis-diesis-diesis-diesis-4, D-diesis-diesis-4, F-bemolle-4, G-bemolle-bemolle-bemolle-4,D-diesis-diesis-diesis-4, E-diesis-4, G-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-4, D-diesis-diesis-diesis-diesis-4, E-diesis-diesis-4, G-bemolle-4,A-bemolle-bemolle-4, B-bemolle-bemolle-bemolle-4, E-diesis-diesis-diesis-4, F-diesis-diesis-4,A-bemolle-4, B-bemolle-bemolle-4, F-diesis-diesis-diesis-4, H-bemolle-bemolle-bemolle-4,B-bemolle-4, C-bemolle-bemolle-bemolle-3, F-diesis-diesis-diesis-diesis-4, G-diesis-diesis-4, H-bemolle-bemolle-4,A-diesis-4, C-bemolle-bemolle-3, G-diesis-diesis-diesis-4, H-bemolle-4,A-diesis-diesis-4, B-diesis-4, C-bemolle-3, D-bemolle-bemolle-bemolle-3, G-diesis-diesis-diesis-diesis-4,A-diesis-diesis-diesis-4, B-diesis-diesis-4, D-bemolle-bemolle-3, H-diesis-4,B-diesis-diesis-diesis-4, D-bemolle-3, E-bemolle-bemolle-bemolle-3, H-diesis-diesis-4,C-diesis-diesis-3, E-bemolle-bemolle-3, F-bemolle-bemolle-bemolle-3, H-diesis-diesis-diesis-4,C-diesis-diesis-diesis-3, E-bemolle-3, F-bemolle-bemolle-3,C-diesis-diesis-diesis-diesis-3, D-diesis-diesis-3, F-bemolle-3, G-bemolle-bemolle-bemolle-3,D-diesis-diesis-diesis-3, E-diesis-3, G-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-3, D-diesis-diesis-diesis-diesis-3, E-diesis-diesis-3, G-bemolle-3,A-bemolle-bemolle-3, B-bemolle-bemolle-bemolle-3, E-diesis-diesis-diesis-3, F-diesis-diesis-3,A-bemolle-3, B-bemolle-bemolle-3, F-diesis-diesis-diesis-3, H-bemolle-bemolle-bemolle-3,B-bemolle-3, C-bemolle-bemolle-bemolle-2, F-diesis-diesis-diesis-diesis-3, G-diesis-diesis-3, H-bemolle-bemolle-3,A-diesis-3, C-bemolle-bemolle-2, G-diesis-diesis-diesis-3, H-bemolle-3,A-diesis-diesis-3, B-diesis-3, C-bemolle-2, D-bemolle-bemolle-bemolle-2, G-diesis-diesis-diesis-diesis-3,A-diesis-diesis-diesis-3, B-diesis-diesis-3, D-bemolle-bemolle-2, H-diesis-3,B-diesis-diesis-diesis-3, D-bemolle-2, E-bemolle-bemolle-bemolle-2, H-diesis-diesis-3,C-diesis-diesis-2, E-bemolle-bemolle-2, F-bemolle-bemolle-bemolle-2, H-diesis-diesis-diesis-3,C-diesis-diesis-diesis-2, E-bemolle-2, F-bemolle-bemolle-2,C-diesis-diesis-diesis-diesis-2, D-diesis-diesis-2, F-bemolle-2, G-bemolle-bemolle-bemolle-2,D-diesis-diesis-diesis-2, E-diesis-2, G-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-2, D-diesis-diesis-diesis-diesis-2, E-diesis-diesis-2, G-bemolle-2,A-bemolle-bemolle-2, B-bemolle-bemolle-bemolle-2, E-diesis-diesis-diesis-2, F-diesis-diesis-2,A-bemolle-2, B-bemolle-bemolle-2, F-diesis-diesis-diesis-2, H-bemolle-bemolle-bemolle-2,B-bemolle-2, C-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-diesis-2, G-diesis-diesis-2, H-bemolle-bemolle-2,A-diesis-2, C-bemolle-bemolle-, G-diesis-diesis-diesis-2, H-bemolle-2,A-diesis-diesis-2, B-diesis-2, C-bemolle-, D-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-diesis-2,A-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-bemolle-, H-diesis-2,B-diesis-diesis-diesis-2, D-bemolle-, E-bemolle-bemolle-bemolle-, H-diesis-diesis-2,C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-, H-diesis-diesis-diesis-2,C-diesis-diesis-diesis-, E-bemolle-, F-bemolle-bemolle-,C-diesis-diesis-diesis-diesis-, D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-diesis-, E-diesis-diesis-, G-bemolle-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,A-bemolle-, B-bemolle-bemolle-, F-diesis-diesis-diesis-, H-bemolle-bemolle-bemolle-,B-bemolle-, C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis-, G-diesis-diesis-, H-bemolle-bemolle-,A-diesis-, C-bemolle-bemolle, G-diesis-diesis-diesis-, H-bemolle-,A-diesis-diesis-, B-diesis-, C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis-,A-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle-bemolle, H-diesis-,B-diesis-diesis-diesis-, D-bemolle, E-bemolle-bemolle-bemolle, H-diesis-diesis-,C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis-,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle, F-diesis-diesis-diesis, H-bemolle-bemolle-bemolle,B-bemolle, C-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis-diesis, G-diesis-diesis, H-bemolle-bemolle,A-diesis, C-bemolle-bemolle+, G-diesis-diesis-diesis, H-bemolle,A-diesis-diesis, B-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis-diesis,A-diesis-diesis-diesis, B-diesis-diesis, D-bemolle-bemolle+, H-diesis,B-diesis-diesis-diesis, D-bemolle+, E-bemolle-bemolle-bemolle+, H-diesis-diesis,C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+, H-diesis-diesis-diesis,C-diesis-diesis-diesis+, E-bemolle+, F-bemolle-bemolle+,C-diesis-diesis-diesis-diesis+, D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis-diesis+, E-diesis-diesis+, G-bemolle+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,A-bemolle+, B-bemolle-bemolle+, F-diesis-diesis-diesis+, H-bemolle-bemolle-bemolle+,B-bemolle+, C-bemolle-bemolle-bemolle+2, F-diesis-diesis-diesis-diesis+, G-diesis-diesis+, H-bemolle-bemolle+,A-diesis+, C-bemolle-bemolle+2, G-diesis-diesis-diesis+, H-bemolle+,A-diesis-diesis+, B-diesis+, C-bemolle+2, D-bemolle-bemolle-bemolle+2, G-diesis-diesis-diesis-diesis+,A-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle-bemolle+2, H-diesis+,B-diesis-diesis-diesis+, D-bemolle+2, E-bemolle-bemolle-bemolle+2, H-diesis-diesis+,C-diesis-diesis+2, E-bemolle-bemolle+2, F-bemolle-bemolle-bemolle+2, H-diesis-diesis-diesis+,C-diesis-diesis-diesis+2, E-bemolle+2, F-bemolle-bemolle+2,C-diesis-diesis-diesis-diesis+2, D-diesis-diesis+2, F-bemolle+2, G-bemolle-bemolle-bemolle+2,D-diesis-diesis-diesis+2, E-diesis+2, G-bemolle-bemolle+2,A-bemolle-bemolle-bemolle+2, D-diesis-diesis-diesis-diesis+2, E-diesis-diesis+2, G-bemolle+2,A-bemolle-bemolle+2, B-bemolle-bemolle-bemolle+2, E-diesis-diesis-diesis+2, F-diesis-diesis+2,A-bemolle+2, B-bemolle-bemolle+2, F-diesis-diesis-diesis+2, H-bemolle-bemolle-bemolle+2,B-bemolle+2, C-bemolle-bemolle-bemolle+3, F-diesis-diesis-diesis-diesis+2, G-diesis-diesis+2, H-bemolle-bemolle+2,A-diesis+2, C-bemolle-bemolle+3, G-diesis-diesis-diesis+2, H-bemolle+2,A-diesis-diesis+2, B-diesis+2, C-bemolle+3, D-bemolle-bemolle-bemolle+3, G-diesis-diesis-diesis-diesis+2,A-diesis-diesis-diesis+2, B-diesis-diesis+2, D-bemolle-bemolle+3, H-diesis+2,B-diesis-diesis-diesis+2, D-bemolle+3, E-bemolle-bemolle-bemolle+3, H-diesis-diesis+2,C-diesis-diesis+3, E-bemolle-bemolle+3, F-bemolle-bemolle-bemolle+3, H-diesis-diesis-diesis+2,C-diesis-diesis-diesis+3, E-bemolle+3, F-bemolle-bemolle+3,C-diesis-diesis-diesis-diesis+3, D-diesis-diesis+3, F-bemolle+3, G-bemolle-bemolle-bemolle+3,D-diesis-diesis-diesis+3, E-diesis+3, G-bemolle-bemolle+3,A-bemolle-bemolle-bemolle+3, D-diesis-diesis-diesis-diesis+3, E-diesis-diesis+3, G-bemolle+3,A-bemolle-bemolle+3, B-bemolle-bemolle-bemolle+3, E-diesis-diesis-diesis+3, F-diesis-diesis+3,A-bemolle+3, B-bemolle-bemolle+3, F-diesis-diesis-diesis+3, H-bemolle-bemolle-bemolle+3,B-bemolle+3, C-bemolle-bemolle-bemolle+4, F-diesis-diesis-diesis-diesis+3, G-diesis-diesis+3, H-bemolle-bemolle+3,A-diesis+3, C-bemolle-bemolle+4, G-diesis-diesis-diesis+3, H-bemolle+3,A-diesis-diesis+3, B-diesis+3, C-bemolle+4, D-bemolle-bemolle-bemolle+4, G-diesis-diesis-diesis-diesis+3,A-diesis-diesis-diesis+3, B-diesis-diesis+3, D-bemolle-bemolle+4, H-diesis+3,B-diesis-diesis-diesis+3, D-bemolle+4, E-bemolle-bemolle-bemolle+4, H-diesis-diesis+3,C-diesis-diesis+4, E-bemolle-bemolle+4, F-bemolle-bemolle-bemolle+4, H-diesis-diesis-diesis+3,C-diesis-diesis-diesis+4, E-bemolle+4, F-bemolle-bemolle+4,C-diesis-diesis-diesis-diesis+4, D-diesis-diesis+4, F-bemolle+4, G-bemolle-bemolle-bemolle+4,D-diesis-diesis-diesis+4, E-diesis+4, G-bemolle-bemolle+4,A-bemolle-bemolle-bemolle+4, D-diesis-diesis-diesis-diesis+4, E-diesis-diesis+4, G-bemolle+4,A-bemolle-bemolle+4, B-bemolle-bemolle-bemolle+4, E-diesis-diesis-diesis+4, F-diesis-diesis+4,A-bemolle+4, B-bemolle-bemolle+4, F-diesis-diesis-diesis+4, H-bemolle-bemolle-bemolle+4,B-bemolle+4, C-bemolle-bemolle-bemolle+5, F-diesis-diesis-diesis-diesis+4, G-diesis-diesis+4, H-bemolle-bemolle+4,A-diesis+4, C-bemolle-bemolle+5, G-diesis-diesis-diesis+4, H-bemolle+4,A-diesis-diesis+4, B-diesis+4, C-bemolle+5, D-bemolle-bemolle-bemolle+5, G-diesis-diesis-diesis-diesis+4,A-diesis-diesis-diesis+4, B-diesis-diesis+4, D-bemolle-bemolle+5, H-diesis+4,B-diesis-diesis-diesis+4, D-bemolle+5, E-bemolle-bemolle-bemolle+5, H-diesis-diesis+4,C-diesis-diesis+5, E-bemolle-bemolle+5, F-bemolle-bemolle-bemolle+5, H-diesis-diesis-diesis+4,C-diesis-diesis-diesis+5, E-bemolle+5, F-bemolle-bemolle+5,C-diesis-diesis-diesis-diesis+5, D-diesis-diesis+5, F-bemolle+5, G-bemolle-bemolle-bemolle+5,D-diesis-diesis-diesis+5, E-diesis+5, G-bemolle-bemolle+5,A-bemolle-bemolle-bemolle+5, D-diesis-diesis-diesis-diesis+5, E-diesis-diesis+5, G-bemolle+5,A-bemolle-bemolle+5, B-bemolle-bemolle-bemolle+5, E-diesis-diesis-diesis+5, F-diesis-diesis+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "A-diesis-diesis-diesis------, B-diesis-diesis------, D-bemolle-bemolle-----, H-diesis------,B-diesis-diesis-diesis------, D-bemolle-----, E-bemolle-bemolle-bemolle-----, H-diesis-diesis------,C-diesis-diesis-----, E-bemolle-bemolle-----, F-bemolle-bemolle-bemolle-----, H-diesis-diesis-diesis------,C-diesis-diesis-diesis-----, E-bemolle-----, F-bemolle-bemolle-----,C-diesis-diesis-diesis-diesis-----, D-diesis-diesis-----, F-bemolle-----, G-bemolle-bemolle-bemolle-----,D-diesis-diesis-diesis-----, E-diesis-----, G-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-----, D-diesis-diesis-diesis-diesis-----, E-diesis-diesis-----, G-bemolle-----,A-bemolle-bemolle-----, B-bemolle-bemolle-bemolle-----, E-diesis-diesis-diesis-----, F-diesis-diesis-----,A-bemolle-----, B-bemolle-bemolle-----, F-diesis-diesis-diesis-----, H-bemolle-bemolle-bemolle-----,B-bemolle-----, C-bemolle-bemolle-bemolle----, F-diesis-diesis-diesis-diesis-----, G-diesis-diesis-----, H-bemolle-bemolle-----,A-diesis-----, C-bemolle-bemolle----, G-diesis-diesis-diesis-----, H-bemolle-----,A-diesis-diesis-----, B-diesis-----, C-bemolle----, D-bemolle-bemolle-bemolle----, G-diesis-diesis-diesis-diesis-----,A-diesis-diesis-diesis-----, B-diesis-diesis-----, D-bemolle-bemolle----, H-diesis-----,B-diesis-diesis-diesis-----, D-bemolle----, E-bemolle-bemolle-bemolle----, H-diesis-diesis-----,C-diesis-diesis----, E-bemolle-bemolle----, F-bemolle-bemolle-bemolle----, H-diesis-diesis-diesis-----,C-diesis-diesis-diesis----, E-bemolle----, F-bemolle-bemolle----,C-diesis-diesis-diesis-diesis----, D-diesis-diesis----, F-bemolle----, G-bemolle-bemolle-bemolle----,D-diesis-diesis-diesis----, E-diesis----, G-bemolle-bemolle----,A-bemolle-bemolle-bemolle----, D-diesis-diesis-diesis-diesis----, E-diesis-diesis----, G-bemolle----,A-bemolle-bemolle----, B-bemolle-bemolle-bemolle----, E-diesis-diesis-diesis----, F-diesis-diesis----,A-bemolle----, B-bemolle-bemolle----, F-diesis-diesis-diesis----, H-bemolle-bemolle-bemolle----,B-bemolle----, C-bemolle-bemolle-bemolle---, F-diesis-diesis-diesis-diesis----, G-diesis-diesis----, H-bemolle-bemolle----,A-diesis----, C-bemolle-bemolle---, G-diesis-diesis-diesis----, H-bemolle----,A-diesis-diesis----, B-diesis----, C-bemolle---, D-bemolle-bemolle-bemolle---, G-diesis-diesis-diesis-diesis----,A-diesis-diesis-diesis----, B-diesis-diesis----, D-bemolle-bemolle---, H-diesis----,B-diesis-diesis-diesis----, D-bemolle---, E-bemolle-bemolle-bemolle---, H-diesis-diesis----,C-diesis-diesis---, E-bemolle-bemolle---, F-bemolle-bemolle-bemolle---, H-diesis-diesis-diesis----,C-diesis-diesis-diesis---, E-bemolle---, F-bemolle-bemolle---,C-diesis-diesis-diesis-diesis---, D-diesis-diesis---, F-bemolle---, G-bemolle-bemolle-bemolle---,D-diesis-diesis-diesis---, E-diesis---, G-bemolle-bemolle---,A-bemolle-bemolle-bemolle---, D-diesis-diesis-diesis-diesis---, E-diesis-diesis---, G-bemolle---,A-bemolle-bemolle---, B-bemolle-bemolle-bemolle---, E-diesis-diesis-diesis---, F-diesis-diesis---,A-bemolle---, B-bemolle-bemolle---, F-diesis-diesis-diesis---, H-bemolle-bemolle-bemolle---,B-bemolle---, C-bemolle-bemolle-bemolle--, F-diesis-diesis-diesis-diesis---, G-diesis-diesis---, H-bemolle-bemolle---,A-diesis---, C-bemolle-bemolle--, G-diesis-diesis-diesis---, H-bemolle---,A-diesis-diesis---, B-diesis---, C-bemolle--, D-bemolle-bemolle-bemolle--, G-diesis-diesis-diesis-diesis---,A-diesis-diesis-diesis---, B-diesis-diesis---, D-bemolle-bemolle--, H-diesis---,B-diesis-diesis-diesis---, D-bemolle--, E-bemolle-bemolle-bemolle--, H-diesis-diesis---,C-diesis-diesis--, E-bemolle-bemolle--, F-bemolle-bemolle-bemolle--, H-diesis-diesis-diesis---,C-diesis-diesis-diesis--, E-bemolle--, F-bemolle-bemolle--,C-diesis-diesis-diesis-diesis--, D-diesis-diesis--, F-bemolle--, G-bemolle-bemolle-bemolle--,D-diesis-diesis-diesis--, E-diesis--, G-bemolle-bemolle--,A-bemolle-bemolle-bemolle--, D-diesis-diesis-diesis-diesis--, E-diesis-diesis--, G-bemolle--,A-bemolle-bemolle--, B-bemolle-bemolle-bemolle--, E-diesis-diesis-diesis--, F-diesis-diesis--,A-bemolle--, B-bemolle-bemolle--, F-diesis-diesis-diesis--, H-bemolle-bemolle-bemolle--,B-bemolle--, C-bemolle-bemolle-bemolle-, F-diesis-diesis-diesis-diesis--, G-diesis-diesis--, H-bemolle-bemolle--,A-diesis--, C-bemolle-bemolle-, G-diesis-diesis-diesis--, H-bemolle--,A-diesis-diesis--, B-diesis--, C-bemolle-, D-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-diesis--,A-diesis-diesis-diesis--, B-diesis-diesis--, D-bemolle-bemolle-, H-diesis--,B-diesis-diesis-diesis--, D-bemolle-, E-bemolle-bemolle-bemolle-, H-diesis-diesis--,C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-, H-diesis-diesis-diesis--,C-diesis-diesis-diesis-, E-bemolle-, F-bemolle-bemolle-,C-diesis-diesis-diesis-diesis-, D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-diesis-, E-diesis-diesis-, G-bemolle-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,A-bemolle-, B-bemolle-bemolle-, F-diesis-diesis-diesis-, H-bemolle-bemolle-bemolle-,B-bemolle-, C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis-, G-diesis-diesis-, H-bemolle-bemolle-,A-diesis-, C-bemolle-bemolle, G-diesis-diesis-diesis-, H-bemolle-,A-diesis-diesis-, B-diesis-, C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis-,A-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle-bemolle, H-diesis-,B-diesis-diesis-diesis-, D-bemolle, E-bemolle-bemolle-bemolle, H-diesis-diesis-,C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis-,C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle, F-diesis-diesis-diesis, H-bemolle-bemolle-bemolle,B-bemolle, C-bemolle-bemolle-bemolle+, F-diesis-diesis-diesis-diesis, G-diesis-diesis, H-bemolle-bemolle,A-diesis, C-bemolle-bemolle+, G-diesis-diesis-diesis, H-bemolle,A-diesis-diesis, B-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis-diesis,A-diesis-diesis-diesis, B-diesis-diesis, D-bemolle-bemolle+, H-diesis,B-diesis-diesis-diesis, D-bemolle+, E-bemolle-bemolle-bemolle+, H-diesis-diesis,C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+, H-diesis-diesis-diesis,C-diesis-diesis-diesis+, E-bemolle+, F-bemolle-bemolle+,C-diesis-diesis-diesis-diesis+, D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis-diesis+, E-diesis-diesis+, G-bemolle+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,A-bemolle+, B-bemolle-bemolle+, F-diesis-diesis-diesis+, H-bemolle-bemolle-bemolle+,B-bemolle+, C-bemolle-bemolle-bemolle++, F-diesis-diesis-diesis-diesis+, G-diesis-diesis+, H-bemolle-bemolle+,A-diesis+, C-bemolle-bemolle++, G-diesis-diesis-diesis+, H-bemolle+,A-diesis-diesis+, B-diesis+, C-bemolle++, D-bemolle-bemolle-bemolle++, G-diesis-diesis-diesis-diesis+,A-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle-bemolle++, H-diesis+,B-diesis-diesis-diesis+, D-bemolle++, E-bemolle-bemolle-bemolle++, H-diesis-diesis+,C-diesis-diesis++, E-bemolle-bemolle++, F-bemolle-bemolle-bemolle++, H-diesis-diesis-diesis+,C-diesis-diesis-diesis++, E-bemolle++, F-bemolle-bemolle++,C-diesis-diesis-diesis-diesis++, D-diesis-diesis++, F-bemolle++, G-bemolle-bemolle-bemolle++,D-diesis-diesis-diesis++, E-diesis++, G-bemolle-bemolle++,A-bemolle-bemolle-bemolle++, D-diesis-diesis-diesis-diesis++, E-diesis-diesis++, G-bemolle++,A-bemolle-bemolle++, B-bemolle-bemolle-bemolle++, E-diesis-diesis-diesis++, F-diesis-diesis++,A-bemolle++, B-bemolle-bemolle++, F-diesis-diesis-diesis++, H-bemolle-bemolle-bemolle++,B-bemolle++, C-bemolle-bemolle-bemolle+++, F-diesis-diesis-diesis-diesis++, G-diesis-diesis++, H-bemolle-bemolle++,A-diesis++, C-bemolle-bemolle+++, G-diesis-diesis-diesis++, H-bemolle++,A-diesis-diesis++, B-diesis++, C-bemolle+++, D-bemolle-bemolle-bemolle+++, G-diesis-diesis-diesis-diesis++,A-diesis-diesis-diesis++, B-diesis-diesis++, D-bemolle-bemolle+++, H-diesis++,B-diesis-diesis-diesis++, D-bemolle+++, E-bemolle-bemolle-bemolle+++, H-diesis-diesis++,C-diesis-diesis+++, E-bemolle-bemolle+++, F-bemolle-bemolle-bemolle+++, H-diesis-diesis-diesis++,C-diesis-diesis-diesis+++, E-bemolle+++, F-bemolle-bemolle+++,C-diesis-diesis-diesis-diesis+++, D-diesis-diesis+++, F-bemolle+++, G-bemolle-bemolle-bemolle+++,D-diesis-diesis-diesis+++, E-diesis+++, G-bemolle-bemolle+++,A-bemolle-bemolle-bemolle+++, D-diesis-diesis-diesis-diesis+++, E-diesis-diesis+++, G-bemolle+++,A-bemolle-bemolle+++, B-bemolle-bemolle-bemolle+++, E-diesis-diesis-diesis+++, F-diesis-diesis+++,A-bemolle+++, B-bemolle-bemolle+++, F-diesis-diesis-diesis+++, H-bemolle-bemolle-bemolle+++,B-bemolle+++, C-bemolle-bemolle-bemolle++++, F-diesis-diesis-diesis-diesis+++, G-diesis-diesis+++, H-bemolle-bemolle+++,A-diesis+++, C-bemolle-bemolle++++, G-diesis-diesis-diesis+++, H-bemolle+++,A-diesis-diesis+++, B-diesis+++, C-bemolle++++, D-bemolle-bemolle-bemolle++++, G-diesis-diesis-diesis-diesis+++,A-diesis-diesis-diesis+++, B-diesis-diesis+++, D-bemolle-bemolle++++, H-diesis+++,B-diesis-diesis-diesis+++, D-bemolle++++, E-bemolle-bemolle-bemolle++++, H-diesis-diesis+++,C-diesis-diesis++++, E-bemolle-bemolle++++, F-bemolle-bemolle-bemolle++++, H-diesis-diesis-diesis+++,C-diesis-diesis-diesis++++, E-bemolle++++, F-bemolle-bemolle++++,C-diesis-diesis-diesis-diesis++++, D-diesis-diesis++++, F-bemolle++++, G-bemolle-bemolle-bemolle++++,D-diesis-diesis-diesis++++, E-diesis++++, G-bemolle-bemolle++++,A-bemolle-bemolle-bemolle++++, D-diesis-diesis-diesis-diesis++++, E-diesis-diesis++++, G-bemolle++++,A-bemolle-bemolle++++, B-bemolle-bemolle-bemolle++++, E-diesis-diesis-diesis++++, F-diesis-diesis++++,A-bemolle++++, B-bemolle-bemolle++++, F-diesis-diesis-diesis++++, H-bemolle-bemolle-bemolle++++,B-bemolle++++, C-bemolle-bemolle-bemolle+++++, F-diesis-diesis-diesis-diesis++++, G-diesis-diesis++++, H-bemolle-bemolle++++,A-diesis++++, C-bemolle-bemolle+++++, G-diesis-diesis-diesis++++, H-bemolle++++,A-diesis-diesis++++, B-diesis++++, C-bemolle+++++, D-bemolle-bemolle-bemolle+++++, G-diesis-diesis-diesis-diesis++++,A-diesis-diesis-diesis++++, B-diesis-diesis++++, D-bemolle-bemolle+++++, H-diesis++++,B-diesis-diesis-diesis++++, D-bemolle+++++, E-bemolle-bemolle-bemolle+++++, H-diesis-diesis++++,C-diesis-diesis+++++, E-bemolle-bemolle+++++, F-bemolle-bemolle-bemolle+++++, H-diesis-diesis-diesis++++,C-diesis-diesis-diesis+++++, E-bemolle+++++, F-bemolle-bemolle+++++,C-diesis-diesis-diesis-diesis+++++, D-diesis-diesis+++++, F-bemolle+++++, G-bemolle-bemolle-bemolle+++++,D-diesis-diesis-diesis+++++, E-diesis+++++, G-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle+++++, D-diesis-diesis-diesis-diesis+++++, E-diesis-diesis+++++, G-bemolle+++++,A-bemolle-bemolle+++++, B-bemolle-bemolle-bemolle+++++, E-diesis-diesis-diesis+++++, F-diesis-diesis+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "A-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-bemolle-1, H-diesis-2,B-diesis-diesis-diesis-2, D-bemolle-1, E-bemolle-bemolle-bemolle-1, H-diesis-diesis-2,C-diesis-diesis-1, E-bemolle-bemolle-1, F-bemolle-bemolle-bemolle-1, H-diesis-diesis-diesis-2,C-diesis-diesis-diesis-1, E-bemolle-1, F-bemolle-bemolle-1,C-diesis-diesis-diesis-diesis-1, D-diesis-diesis-1, F-bemolle-1, G-bemolle-bemolle-bemolle-1,D-diesis-diesis-diesis-1, E-diesis-1, G-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-1, D-diesis-diesis-diesis-diesis-1, E-diesis-diesis-1, G-bemolle-1,A-bemolle-bemolle-1, B-bemolle-bemolle-bemolle-1, E-diesis-diesis-diesis-1, F-diesis-diesis-1,A-bemolle-1, B-bemolle-bemolle-1, F-diesis-diesis-diesis-1, H-bemolle-bemolle-bemolle-1,B-bemolle-1, C-bemolle-bemolle-bemolle0, F-diesis-diesis-diesis-diesis-1, G-diesis-diesis-1, H-bemolle-bemolle-1,A-diesis-1, C-bemolle-bemolle0, G-diesis-diesis-diesis-1, H-bemolle-1,A-diesis-diesis-1, B-diesis-1, C-bemolle0, D-bemolle-bemolle-bemolle0, G-diesis-diesis-diesis-diesis-1,A-diesis-diesis-diesis-1, B-diesis-diesis-1, D-bemolle-bemolle0, H-diesis-1,B-diesis-diesis-diesis-1, D-bemolle0, E-bemolle-bemolle-bemolle0, H-diesis-diesis-1,C-diesis-diesis0, E-bemolle-bemolle0, F-bemolle-bemolle-bemolle0, H-diesis-diesis-diesis-1,C-diesis-diesis-diesis0, E-bemolle0, F-bemolle-bemolle0,C-diesis-diesis-diesis-diesis0, D-diesis-diesis0, F-bemolle0, G-bemolle-bemolle-bemolle0,D-diesis-diesis-diesis0, E-diesis0, G-bemolle-bemolle0,A-bemolle-bemolle-bemolle0, D-diesis-diesis-diesis-diesis0, E-diesis-diesis0, G-bemolle0,A-bemolle-bemolle0, B-bemolle-bemolle-bemolle0, E-diesis-diesis-diesis0, F-diesis-diesis0,A-bemolle0, B-bemolle-bemolle0, F-diesis-diesis-diesis0, H-bemolle-bemolle-bemolle0,B-bemolle0, C-bemolle-bemolle-bemolle1, F-diesis-diesis-diesis-diesis0, G-diesis-diesis0, H-bemolle-bemolle0,A-diesis0, C-bemolle-bemolle1, G-diesis-diesis-diesis0, H-bemolle0,A-diesis-diesis0, B-diesis0, C-bemolle1, D-bemolle-bemolle-bemolle1, G-diesis-diesis-diesis-diesis0,A-diesis-diesis-diesis0, B-diesis-diesis0, D-bemolle-bemolle1, H-diesis0,B-diesis-diesis-diesis0, D-bemolle1, E-bemolle-bemolle-bemolle1, H-diesis-diesis0,C-diesis-diesis1, E-bemolle-bemolle1, F-bemolle-bemolle-bemolle1, H-diesis-diesis-diesis0,C-diesis-diesis-diesis1, E-bemolle1, F-bemolle-bemolle1,C-diesis-diesis-diesis-diesis1, D-diesis-diesis1, F-bemolle1, G-bemolle-bemolle-bemolle1,D-diesis-diesis-diesis1, E-diesis1, G-bemolle-bemolle1,A-bemolle-bemolle-bemolle1, D-diesis-diesis-diesis-diesis1, E-diesis-diesis1, G-bemolle1,A-bemolle-bemolle1, B-bemolle-bemolle-bemolle1, E-diesis-diesis-diesis1, F-diesis-diesis1,A-bemolle1, B-bemolle-bemolle1, F-diesis-diesis-diesis1, H-bemolle-bemolle-bemolle1,B-bemolle1, C-bemolle-bemolle-bemolle2, F-diesis-diesis-diesis-diesis1, G-diesis-diesis1, H-bemolle-bemolle1,A-diesis1, C-bemolle-bemolle2, G-diesis-diesis-diesis1, H-bemolle1,A-diesis-diesis1, B-diesis1, C-bemolle2, D-bemolle-bemolle-bemolle2, G-diesis-diesis-diesis-diesis1,A-diesis-diesis-diesis1, B-diesis-diesis1, D-bemolle-bemolle2, H-diesis1,B-diesis-diesis-diesis1, D-bemolle2, E-bemolle-bemolle-bemolle2, H-diesis-diesis1,C-diesis-diesis2, E-bemolle-bemolle2, F-bemolle-bemolle-bemolle2, H-diesis-diesis-diesis1,C-diesis-diesis-diesis2, E-bemolle2, F-bemolle-bemolle2,C-diesis-diesis-diesis-diesis2, D-diesis-diesis2, F-bemolle2, G-bemolle-bemolle-bemolle2,D-diesis-diesis-diesis2, E-diesis2, G-bemolle-bemolle2,A-bemolle-bemolle-bemolle2, D-diesis-diesis-diesis-diesis2, E-diesis-diesis2, G-bemolle2,A-bemolle-bemolle2, B-bemolle-bemolle-bemolle2, E-diesis-diesis-diesis2, F-diesis-diesis2,A-bemolle2, B-bemolle-bemolle2, F-diesis-diesis-diesis2, H-bemolle-bemolle-bemolle2,B-bemolle2, C-bemolle-bemolle-bemolle3, F-diesis-diesis-diesis-diesis2, G-diesis-diesis2, H-bemolle-bemolle2,A-diesis2, C-bemolle-bemolle3, G-diesis-diesis-diesis2, H-bemolle2,A-diesis-diesis2, B-diesis2, C-bemolle3, D-bemolle-bemolle-bemolle3, G-diesis-diesis-diesis-diesis2,A-diesis-diesis-diesis2, B-diesis-diesis2, D-bemolle-bemolle3, H-diesis2,B-diesis-diesis-diesis2, D-bemolle3, E-bemolle-bemolle-bemolle3, H-diesis-diesis2,C-diesis-diesis3, E-bemolle-bemolle3, F-bemolle-bemolle-bemolle3, H-diesis-diesis-diesis2,C-diesis-diesis-diesis3, E-bemolle3, F-bemolle-bemolle3,C-diesis-diesis-diesis-diesis3, D-diesis-diesis3, F-bemolle3, G-bemolle-bemolle-bemolle3,D-diesis-diesis-diesis3, E-diesis3, G-bemolle-bemolle3,A-bemolle-bemolle-bemolle3, D-diesis-diesis-diesis-diesis3, E-diesis-diesis3, G-bemolle3,A-bemolle-bemolle3, B-bemolle-bemolle-bemolle3, E-diesis-diesis-diesis3, F-diesis-diesis3,A-bemolle3, B-bemolle-bemolle3, F-diesis-diesis-diesis3, H-bemolle-bemolle-bemolle3,B-bemolle3, C-bemolle-bemolle-bemolle4, F-diesis-diesis-diesis-diesis3, G-diesis-diesis3, H-bemolle-bemolle3,A-diesis3, C-bemolle-bemolle4, G-diesis-diesis-diesis3, H-bemolle3,A-diesis-diesis3, B-diesis3, C-bemolle4, D-bemolle-bemolle-bemolle4, G-diesis-diesis-diesis-diesis3,A-diesis-diesis-diesis3, B-diesis-diesis3, D-bemolle-bemolle4, H-diesis3,B-diesis-diesis-diesis3, D-bemolle4, E-bemolle-bemolle-bemolle4, H-diesis-diesis3,C-diesis-diesis4, E-bemolle-bemolle4, F-bemolle-bemolle-bemolle4, H-diesis-diesis-diesis3,C-diesis-diesis-diesis4, E-bemolle4, F-bemolle-bemolle4,C-diesis-diesis-diesis-diesis4, D-diesis-diesis4, F-bemolle4, G-bemolle-bemolle-bemolle4,D-diesis-diesis-diesis4, E-diesis4, G-bemolle-bemolle4,A-bemolle-bemolle-bemolle4, D-diesis-diesis-diesis-diesis4, E-diesis-diesis4, G-bemolle4,A-bemolle-bemolle4, B-bemolle-bemolle-bemolle4, E-diesis-diesis-diesis4, F-diesis-diesis4,A-bemolle4, B-bemolle-bemolle4, F-diesis-diesis-diesis4, H-bemolle-bemolle-bemolle4,B-bemolle4, C-bemolle-bemolle-bemolle5, F-diesis-diesis-diesis-diesis4, G-diesis-diesis4, H-bemolle-bemolle4,A-diesis4, C-bemolle-bemolle5, G-diesis-diesis-diesis4, H-bemolle4,A-diesis-diesis4, B-diesis4, C-bemolle5, D-bemolle-bemolle-bemolle5, G-diesis-diesis-diesis-diesis4,A-diesis-diesis-diesis4, B-diesis-diesis4, D-bemolle-bemolle5, H-diesis4,B-diesis-diesis-diesis4, D-bemolle5, E-bemolle-bemolle-bemolle5, H-diesis-diesis4,C-diesis-diesis5, E-bemolle-bemolle5, F-bemolle-bemolle-bemolle5, H-diesis-diesis-diesis4,C-diesis-diesis-diesis5, E-bemolle5, F-bemolle-bemolle5,C-diesis-diesis-diesis-diesis5, D-diesis-diesis5, F-bemolle5, G-bemolle-bemolle-bemolle5,D-diesis-diesis-diesis5, E-diesis5, G-bemolle-bemolle5,A-bemolle-bemolle-bemolle5, D-diesis-diesis-diesis-diesis5, E-diesis-diesis5, G-bemolle5,A-bemolle-bemolle5, B-bemolle-bemolle-bemolle5, E-diesis-diesis-diesis5, F-diesis-diesis5,A-bemolle5, B-bemolle-bemolle5, F-diesis-diesis-diesis5, H-bemolle-bemolle-bemolle5,B-bemolle5, C-bemolle-bemolle-bemolle6, F-diesis-diesis-diesis-diesis5, G-diesis-diesis5, H-bemolle-bemolle5,A-diesis5, C-bemolle-bemolle6, G-diesis-diesis-diesis5, H-bemolle5,A-diesis-diesis5, B-diesis5, C-bemolle6, D-bemolle-bemolle-bemolle6, G-diesis-diesis-diesis-diesis5,A-diesis-diesis-diesis5, B-diesis-diesis5, D-bemolle-bemolle6, H-diesis5,B-diesis-diesis-diesis5, D-bemolle6, E-bemolle-bemolle-bemolle6, H-diesis-diesis5,C-diesis-diesis6, E-bemolle-bemolle6, F-bemolle-bemolle-bemolle6, H-diesis-diesis-diesis5,C-diesis-diesis-diesis6, E-bemolle6, F-bemolle-bemolle6,C-diesis-diesis-diesis-diesis6, D-diesis-diesis6, F-bemolle6, G-bemolle-bemolle-bemolle6,D-diesis-diesis-diesis6, E-diesis6, G-bemolle-bemolle6,A-bemolle-bemolle-bemolle6, D-diesis-diesis-diesis-diesis6, E-diesis-diesis6, G-bemolle6,A-bemolle-bemolle6, B-bemolle-bemolle-bemolle6, E-diesis-diesis-diesis6, F-diesis-diesis6,A-bemolle6, B-bemolle-bemolle6, F-diesis-diesis-diesis6, H-bemolle-bemolle-bemolle6,B-bemolle6, C-bemolle-bemolle-bemolle7, F-diesis-diesis-diesis-diesis6, G-diesis-diesis6, H-bemolle-bemolle6,A-diesis6, C-bemolle-bemolle7, G-diesis-diesis-diesis6, H-bemolle6,A-diesis-diesis6, B-diesis6, C-bemolle7, D-bemolle-bemolle-bemolle7, G-diesis-diesis-diesis-diesis6,A-diesis-diesis-diesis6, B-diesis-diesis6, D-bemolle-bemolle7, H-diesis6,B-diesis-diesis-diesis6, D-bemolle7, E-bemolle-bemolle-bemolle7, H-diesis-diesis6,C-diesis-diesis7, E-bemolle-bemolle7, F-bemolle-bemolle-bemolle7, H-diesis-diesis-diesis6,C-diesis-diesis-diesis7, E-bemolle7, F-bemolle-bemolle7,C-diesis-diesis-diesis-diesis7, D-diesis-diesis7, F-bemolle7, G-bemolle-bemolle-bemolle7,D-diesis-diesis-diesis7, E-diesis7, G-bemolle-bemolle7,A-bemolle-bemolle-bemolle7, D-diesis-diesis-diesis-diesis7, E-diesis-diesis7, G-bemolle7,A-bemolle-bemolle7, B-bemolle-bemolle-bemolle7, E-diesis-diesis-diesis7, F-diesis-diesis7,A-bemolle7, B-bemolle-bemolle7, F-diesis-diesis-diesis7, H-bemolle-bemolle-bemolle7,B-bemolle7, C-bemolle-bemolle-bemolle8, F-diesis-diesis-diesis-diesis7, G-diesis-diesis7, H-bemolle-bemolle7,A-diesis7, C-bemolle-bemolle8, G-diesis-diesis-diesis7, H-bemolle7,A-diesis-diesis7, B-diesis7, C-bemolle8, D-bemolle-bemolle-bemolle8, G-diesis-diesis-diesis-diesis7,A-diesis-diesis-diesis7, B-diesis-diesis7, D-bemolle-bemolle8, H-diesis7,B-diesis-diesis-diesis7, D-bemolle8, E-bemolle-bemolle-bemolle8, H-diesis-diesis7,C-diesis-diesis8, E-bemolle-bemolle8, F-bemolle-bemolle-bemolle8, H-diesis-diesis-diesis7,C-diesis-diesis-diesis8, E-bemolle8, F-bemolle-bemolle8,C-diesis-diesis-diesis-diesis8, D-diesis-diesis8, F-bemolle8, G-bemolle-bemolle-bemolle8,D-diesis-diesis-diesis8, E-diesis8, G-bemolle-bemolle8,A-bemolle-bemolle-bemolle8, D-diesis-diesis-diesis-diesis8, E-diesis-diesis8, G-bemolle8,A-bemolle-bemolle8, B-bemolle-bemolle-bemolle8, E-diesis-diesis-diesis8, F-diesis-diesis8,A-bemolle8, B-bemolle-bemolle8, F-diesis-diesis-diesis8, H-bemolle-bemolle-bemolle8,B-bemolle8, C-bemolle-bemolle-bemolle9, F-diesis-diesis-diesis-diesis8, G-diesis-diesis8, H-bemolle-bemolle8,A-diesis8, C-bemolle-bemolle9, G-diesis-diesis-diesis8, H-bemolle8,A-diesis-diesis8, B-diesis8, C-bemolle9, D-bemolle-bemolle-bemolle9, G-diesis-diesis-diesis-diesis8,A-diesis-diesis-diesis8, B-diesis-diesis8, D-bemolle-bemolle9, H-diesis8,B-diesis-diesis-diesis8, D-bemolle9, E-bemolle-bemolle-bemolle9, H-diesis-diesis8,C-diesis-diesis9, E-bemolle-bemolle9, F-bemolle-bemolle-bemolle9, H-diesis-diesis-diesis8,C-diesis-diesis-diesis9, E-bemolle9, F-bemolle-bemolle9,C-diesis-diesis-diesis-diesis9, D-diesis-diesis9, F-bemolle9, G-bemolle-bemolle-bemolle9,D-diesis-diesis-diesis9, E-diesis9, G-bemolle-bemolle9,A-bemolle-bemolle-bemolle9, D-diesis-diesis-diesis-diesis9, E-diesis-diesis9, G-bemolle9,A-bemolle-bemolle9, B-bemolle-bemolle-bemolle9, E-diesis-diesis-diesis9, F-diesis-diesis9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle-bemolle''', H-diesis'''',B-diesis-diesis-diesis'''', D-bemolle''', E-bemolle-bemolle-bemolle''', H-diesis-diesis'''',C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''', H-diesis-diesis-diesis'''',C-diesis-diesis-diesis''', E-bemolle''', F-bemolle-bemolle''',C-diesis-diesis-diesis-diesis''', D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis-diesis''', E-diesis-diesis''', G-bemolle''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',A-bemolle''', B-bemolle-bemolle''', F-diesis-diesis-diesis''', H-bemolle-bemolle-bemolle''',B-bemolle''', C-bemolle-bemolle-bemolle'', F-diesis-diesis-diesis-diesis''', G-diesis-diesis''', H-bemolle-bemolle''',A-diesis''', C-bemolle-bemolle'', G-diesis-diesis-diesis''', H-bemolle''',A-diesis-diesis''', B-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis-diesis''',A-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle-bemolle'', H-diesis''',B-diesis-diesis-diesis''', D-bemolle'', E-bemolle-bemolle-bemolle'', H-diesis-diesis''',C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'', H-diesis-diesis-diesis''',C-diesis-diesis-diesis'', E-bemolle'', F-bemolle-bemolle'',C-diesis-diesis-diesis-diesis'', D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis-diesis'', E-diesis-diesis'', G-bemolle'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',A-bemolle'', B-bemolle-bemolle'', F-diesis-diesis-diesis'', H-bemolle-bemolle-bemolle'',B-bemolle'', C-bemolle-bemolle-bemolle', F-diesis-diesis-diesis-diesis'', G-diesis-diesis'', H-bemolle-bemolle'',A-diesis'', C-bemolle-bemolle', G-diesis-diesis-diesis'', H-bemolle'',A-diesis-diesis'', B-diesis'', C-bemolle', D-bemolle-bemolle-bemolle', G-diesis-diesis-diesis-diesis'',A-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle-bemolle', H-diesis'',B-diesis-diesis-diesis'', D-bemolle', E-bemolle-bemolle-bemolle', H-diesis-diesis'',C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle', H-diesis-diesis-diesis'',C-diesis-diesis-diesis', E-bemolle', F-bemolle-bemolle',C-diesis-diesis-diesis-diesis', D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', D-diesis-diesis-diesis-diesis', E-diesis-diesis', G-bemolle',A-bemolle-bemolle', B-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',A-bemolle', B-bemolle-bemolle', F-diesis-diesis-diesis', H-bemolle-bemolle-bemolle',B-bemolle', C-bemolle-bemolle-bemolle, F-diesis-diesis-diesis-diesis', G-diesis-diesis', H-bemolle-bemolle',A-diesis', C-bemolle-bemolle, G-diesis-diesis-diesis', H-bemolle',A-diesis-diesis', B-diesis', C-bemolle, D-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-diesis',A-diesis-diesis-diesis', B-diesis-diesis', D-bemolle-bemolle, H-diesis',B-diesis-diesis-diesis', D-bemolle, E-bemolle-bemolle-bemolle, H-diesis-diesis',C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis',C-diesis-diesis-diesis, E-bemolle, F-bemolle-bemolle,C-diesis-diesis-diesis-diesis, D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, D-diesis-diesis-diesis-diesis, E-diesis-diesis, G-bemolle,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,A-bemolle, B-bemolle-bemolle, F-diesis-diesis-diesis, H-bemolle-bemolle-bemolle,B-bemolle, F-diesis-diesis-diesis-diesis, G-diesis-diesis, H-bemolle-bemolle, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, H-bemolle, c-bemolle-bemolle,A-diesis-diesis, B-diesis, G-diesis-diesis-diesis-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis-diesis, H-diesis, d-bemolle-bemolle,B-diesis-diesis-diesis, H-diesis-diesis, d-bemolle, e-bemolle-bemolle-bemolle,H-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, e-bemolle, f-bemolle-bemolle,c-diesis-diesis-diesis-diesis, d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, d-diesis-diesis-diesis-diesis, e-diesis-diesis, g-bemolle,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,a-bemolle, b-bemolle-bemolle, f-diesis-diesis-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle', f-diesis-diesis-diesis-diesis, g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle', g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle', d-bemolle-bemolle-bemolle', g-diesis-diesis-diesis-diesis,a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle', h-diesis,b-diesis-diesis-diesis, d-bemolle', e-bemolle-bemolle-bemolle', h-diesis-diesis,c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle', h-diesis-diesis-diesis,c-diesis-diesis-diesis', e-bemolle', f-bemolle-bemolle',c-diesis-diesis-diesis-diesis', d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', d-diesis-diesis-diesis-diesis', e-diesis-diesis', g-bemolle',a-bemolle-bemolle', b-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',a-bemolle', b-bemolle-bemolle', f-diesis-diesis-diesis', h-bemolle-bemolle-bemolle',b-bemolle', c-bemolle-bemolle-bemolle'', f-diesis-diesis-diesis-diesis', g-diesis-diesis', h-bemolle-bemolle',a-diesis', c-bemolle-bemolle'', g-diesis-diesis-diesis', h-bemolle',a-diesis-diesis', b-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis-diesis',a-diesis-diesis-diesis', b-diesis-diesis', d-bemolle-bemolle'', h-diesis',b-diesis-diesis-diesis', d-bemolle'', e-bemolle-bemolle-bemolle'', h-diesis-diesis',c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'', h-diesis-diesis-diesis',c-diesis-diesis-diesis'', e-bemolle'', f-bemolle-bemolle'',c-diesis-diesis-diesis-diesis'', d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis-diesis'', e-diesis-diesis'', g-bemolle'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',a-bemolle'', b-bemolle-bemolle'', f-diesis-diesis-diesis'', h-bemolle-bemolle-bemolle'',b-bemolle'', c-bemolle-bemolle-bemolle''', f-diesis-diesis-diesis-diesis'', g-diesis-diesis'', h-bemolle-bemolle'',a-diesis'', c-bemolle-bemolle''', g-diesis-diesis-diesis'', h-bemolle'',a-diesis-diesis'', b-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis-diesis'',a-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle-bemolle''', h-diesis'',b-diesis-diesis-diesis'', d-bemolle''', e-bemolle-bemolle-bemolle''', h-diesis-diesis'',c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''', h-diesis-diesis-diesis'',c-diesis-diesis-diesis''', e-bemolle''', f-bemolle-bemolle''',c-diesis-diesis-diesis-diesis''', d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis-diesis''', e-diesis-diesis''', g-bemolle''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',a-bemolle''', b-bemolle-bemolle''', f-diesis-diesis-diesis''', h-bemolle-bemolle-bemolle''',b-bemolle''', c-bemolle-bemolle-bemolle'''', f-diesis-diesis-diesis-diesis''', g-diesis-diesis''', h-bemolle-bemolle''',a-diesis''', c-bemolle-bemolle'''', g-diesis-diesis-diesis''', h-bemolle''',a-diesis-diesis''', b-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis-diesis''',a-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle-bemolle'''', h-diesis''',b-diesis-diesis-diesis''', d-bemolle'''', e-bemolle-bemolle-bemolle'''', h-diesis-diesis''',c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''', h-diesis-diesis-diesis''',c-diesis-diesis-diesis'''', e-bemolle'''', f-bemolle-bemolle'''',c-diesis-diesis-diesis-diesis'''', d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis-diesis'''', e-diesis-diesis'''', g-bemolle'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',a-bemolle'''', b-bemolle-bemolle'''', f-diesis-diesis-diesis'''', h-bemolle-bemolle-bemolle'''',b-bemolle'''', c-bemolle-bemolle-bemolle''''', f-diesis-diesis-diesis-diesis'''', g-diesis-diesis'''', h-bemolle-bemolle'''',a-diesis'''', c-bemolle-bemolle''''', g-diesis-diesis-diesis'''', h-bemolle'''',a-diesis-diesis'''', b-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis-diesis'''',a-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle-bemolle''''', h-diesis'''',b-diesis-diesis-diesis'''', d-bemolle''''', e-bemolle-bemolle-bemolle''''', h-diesis-diesis'''',c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''', h-diesis-diesis-diesis'''',c-diesis-diesis-diesis''''', e-bemolle''''', f-bemolle-bemolle''''',c-diesis-diesis-diesis-diesis''''', d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis-diesis''''', e-diesis-diesis''''', g-bemolle''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',a-bemolle''''', b-bemolle-bemolle''''', f-diesis-diesis-diesis''''', h-bemolle-bemolle-bemolle''''',b-bemolle''''', c-bemolle-bemolle-bemolle'''''', f-diesis-diesis-diesis-diesis''''', g-diesis-diesis''''', h-bemolle-bemolle''''',a-diesis''''', c-bemolle-bemolle'''''', g-diesis-diesis-diesis''''', h-bemolle''''',a-diesis-diesis''''', b-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis-diesis''''',a-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle-bemolle'''''', h-diesis''''',b-diesis-diesis-diesis''''', d-bemolle'''''', e-bemolle-bemolle-bemolle'''''', h-diesis-diesis''''',c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''', h-diesis-diesis-diesis''''',c-diesis-diesis-diesis'''''', e-bemolle'''''', f-bemolle-bemolle'''''',c-diesis-diesis-diesis-diesis'''''', d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis-diesis'''''', e-diesis-diesis'''''', g-bemolle'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "A-diesis-diesis-diesis-6, B-diesis-diesis-6, D-bemolle-bemolle-5, E-bemolle-bemolle-bemolle-bemolle-5, H-diesis-6,B-diesis-diesis-diesis-6, C-diesis-5, E-bemolle-bemolle-bemolle-5, H-diesis-diesis-6,C-diesis-diesis-5, E-bemolle-bemolle-5, F-bemolle-bemolle-bemolle-5, H-diesis-diesis-diesis-6,C-diesis-diesis-diesis-5, D-diesis-5, F-bemolle-bemolle-5, G-bemolle-bemolle-bemolle-bemolle-5,D-diesis-diesis-5, F-bemolle-5, G-bemolle-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-bemolle-5, D-diesis-diesis-diesis-5, E-diesis-5, G-bemolle-bemolle-5,A-bemolle-bemolle-bemolle-5, E-diesis-diesis-5, F-diesis-5,A-bemolle-bemolle-5, B-bemolle-bemolle-bemolle-5, E-diesis-diesis-diesis-5, F-diesis-diesis-5,B-bemolle-bemolle-5, F-diesis-diesis-diesis-5, G-diesis-5, H-bemolle-bemolle-bemolle-5,B-bemolle-5, C-bemolle-bemolle-bemolle-4, G-diesis-diesis-5, H-bemolle-bemolle-5,A-diesis-5, C-bemolle-bemolle-4, D-bemolle-bemolle-bemolle-bemolle-4, G-diesis-diesis-diesis-5, H-bemolle-5,A-diesis-diesis-5, B-diesis-5, C-bemolle-4, D-bemolle-bemolle-bemolle-4,A-diesis-diesis-diesis-5, B-diesis-diesis-5, D-bemolle-bemolle-4, E-bemolle-bemolle-bemolle-bemolle-4, H-diesis-5,B-diesis-diesis-diesis-5, C-diesis-4, E-bemolle-bemolle-bemolle-4, H-diesis-diesis-5,C-diesis-diesis-4, E-bemolle-bemolle-4, F-bemolle-bemolle-bemolle-4, H-diesis-diesis-diesis-5,C-diesis-diesis-diesis-4, D-diesis-4, F-bemolle-bemolle-4, G-bemolle-bemolle-bemolle-bemolle-4,D-diesis-diesis-4, F-bemolle-4, G-bemolle-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-bemolle-4, D-diesis-diesis-diesis-4, E-diesis-4, G-bemolle-bemolle-4,A-bemolle-bemolle-bemolle-4, E-diesis-diesis-4, F-diesis-4,A-bemolle-bemolle-4, B-bemolle-bemolle-bemolle-4, E-diesis-diesis-diesis-4, F-diesis-diesis-4,B-bemolle-bemolle-4, F-diesis-diesis-diesis-4, G-diesis-4, H-bemolle-bemolle-bemolle-4,B-bemolle-4, C-bemolle-bemolle-bemolle-3, G-diesis-diesis-4, H-bemolle-bemolle-4,A-diesis-4, C-bemolle-bemolle-3, D-bemolle-bemolle-bemolle-bemolle-3, G-diesis-diesis-diesis-4, H-bemolle-4,A-diesis-diesis-4, B-diesis-4, C-bemolle-3, D-bemolle-bemolle-bemolle-3,A-diesis-diesis-diesis-4, B-diesis-diesis-4, D-bemolle-bemolle-3, E-bemolle-bemolle-bemolle-bemolle-3, H-diesis-4,B-diesis-diesis-diesis-4, C-diesis-3, E-bemolle-bemolle-bemolle-3, H-diesis-diesis-4,C-diesis-diesis-3, E-bemolle-bemolle-3, F-bemolle-bemolle-bemolle-3, H-diesis-diesis-diesis-4,C-diesis-diesis-diesis-3, D-diesis-3, F-bemolle-bemolle-3, G-bemolle-bemolle-bemolle-bemolle-3,D-diesis-diesis-3, F-bemolle-3, G-bemolle-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-bemolle-3, D-diesis-diesis-diesis-3, E-diesis-3, G-bemolle-bemolle-3,A-bemolle-bemolle-bemolle-3, E-diesis-diesis-3, F-diesis-3,A-bemolle-bemolle-3, B-bemolle-bemolle-bemolle-3, E-diesis-diesis-diesis-3, F-diesis-diesis-3,B-bemolle-bemolle-3, F-diesis-diesis-diesis-3, G-diesis-3, H-bemolle-bemolle-bemolle-3,B-bemolle-3, C-bemolle-bemolle-bemolle-2, G-diesis-diesis-3, H-bemolle-bemolle-3,A-diesis-3, C-bemolle-bemolle-2, D-bemolle-bemolle-bemolle-bemolle-2, G-diesis-diesis-diesis-3, H-bemolle-3,A-diesis-diesis-3, B-diesis-3, C-bemolle-2, D-bemolle-bemolle-bemolle-2,A-diesis-diesis-diesis-3, B-diesis-diesis-3, D-bemolle-bemolle-2, E-bemolle-bemolle-bemolle-bemolle-2, H-diesis-3,B-diesis-diesis-diesis-3, C-diesis-2, E-bemolle-bemolle-bemolle-2, H-diesis-diesis-3,C-diesis-diesis-2, E-bemolle-bemolle-2, F-bemolle-bemolle-bemolle-2, H-diesis-diesis-diesis-3,C-diesis-diesis-diesis-2, D-diesis-2, F-bemolle-bemolle-2, G-bemolle-bemolle-bemolle-bemolle-2,D-diesis-diesis-2, F-bemolle-2, G-bemolle-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-bemolle-2, D-diesis-diesis-diesis-2, E-diesis-2, G-bemolle-bemolle-2,A-bemolle-bemolle-bemolle-2, E-diesis-diesis-2, F-diesis-2,A-bemolle-bemolle-2, B-bemolle-bemolle-bemolle-2, E-diesis-diesis-diesis-2, F-diesis-diesis-2,B-bemolle-bemolle-2, F-diesis-diesis-diesis-2, G-diesis-2, H-bemolle-bemolle-bemolle-2,B-bemolle-2, C-bemolle-bemolle-bemolle-, G-diesis-diesis-2, H-bemolle-bemolle-2,A-diesis-2, C-bemolle-bemolle-, D-bemolle-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis-2, H-bemolle-2,A-diesis-diesis-2, B-diesis-2, C-bemolle-, D-bemolle-bemolle-bemolle-,A-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-bemolle-, E-bemolle-bemolle-bemolle-bemolle-, H-diesis-2,B-diesis-diesis-diesis-2, C-diesis-, E-bemolle-bemolle-bemolle-, H-diesis-diesis-2,C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-, H-diesis-diesis-diesis-2,C-diesis-diesis-diesis-, D-diesis-, F-bemolle-bemolle-, G-bemolle-bemolle-bemolle-bemolle-,D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,A-bemolle-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, E-diesis-diesis-, F-diesis-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,B-bemolle-bemolle-, F-diesis-diesis-diesis-, G-diesis-, H-bemolle-bemolle-bemolle-,B-bemolle-, C-bemolle-bemolle-bemolle, G-diesis-diesis-, H-bemolle-bemolle-,A-diesis-, C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-, H-bemolle-,A-diesis-diesis-, B-diesis-, C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle, H-diesis-,B-diesis-diesis-diesis-, C-diesis, E-bemolle-bemolle-bemolle, H-diesis-diesis-,C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis-,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis, H-bemolle-bemolle-bemolle,B-bemolle, C-bemolle-bemolle-bemolle+, G-diesis-diesis, H-bemolle-bemolle,A-diesis, C-bemolle-bemolle+, D-bemolle-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis, H-bemolle,A-diesis-diesis, B-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+,A-diesis-diesis-diesis, B-diesis-diesis, D-bemolle-bemolle+, E-bemolle-bemolle-bemolle-bemolle+, H-diesis,B-diesis-diesis-diesis, C-diesis+, E-bemolle-bemolle-bemolle+, H-diesis-diesis,C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+, H-diesis-diesis-diesis,C-diesis-diesis-diesis+, D-diesis+, F-bemolle-bemolle+, G-bemolle-bemolle-bemolle-bemolle+,D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,A-bemolle-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, E-diesis-diesis+, F-diesis+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,B-bemolle-bemolle+, F-diesis-diesis-diesis+, G-diesis+, H-bemolle-bemolle-bemolle+,B-bemolle+, C-bemolle-bemolle-bemolle+2, G-diesis-diesis+, H-bemolle-bemolle+,A-diesis+, C-bemolle-bemolle+2, D-bemolle-bemolle-bemolle-bemolle+2, G-diesis-diesis-diesis+, H-bemolle+,A-diesis-diesis+, B-diesis+, C-bemolle+2, D-bemolle-bemolle-bemolle+2,A-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle-bemolle+2, E-bemolle-bemolle-bemolle-bemolle+2, H-diesis+,B-diesis-diesis-diesis+, C-diesis+2, E-bemolle-bemolle-bemolle+2, H-diesis-diesis+,C-diesis-diesis+2, E-bemolle-bemolle+2, F-bemolle-bemolle-bemolle+2, H-diesis-diesis-diesis+,C-diesis-diesis-diesis+2, D-diesis+2, F-bemolle-bemolle+2, G-bemolle-bemolle-bemolle-bemolle+2,D-diesis-diesis+2, F-bemolle+2, G-bemolle-bemolle-bemolle+2,A-bemolle-bemolle-bemolle-bemolle+2, D-diesis-diesis-diesis+2, E-diesis+2, G-bemolle-bemolle+2,A-bemolle-bemolle-bemolle+2, E-diesis-diesis+2, F-diesis+2,A-bemolle-bemolle+2, B-bemolle-bemolle-bemolle+2, E-diesis-diesis-diesis+2, F-diesis-diesis+2,B-bemolle-bemolle+2, F-diesis-diesis-diesis+2, G-diesis+2, H-bemolle-bemolle-bemolle+2,B-bemolle+2, C-bemolle-bemolle-bemolle+3, G-diesis-diesis+2, H-bemolle-bemolle+2,A-diesis+2, C-bemolle-bemolle+3, D-bemolle-bemolle-bemolle-bemolle+3, G-diesis-diesis-diesis+2, H-bemolle+2,A-diesis-diesis+2, B-diesis+2, C-bemolle+3, D-bemolle-bemolle-bemolle+3,A-diesis-diesis-diesis+2, B-diesis-diesis+2, D-bemolle-bemolle+3, E-bemolle-bemolle-bemolle-bemolle+3, H-diesis+2,B-diesis-diesis-diesis+2, C-diesis+3, E-bemolle-bemolle-bemolle+3, H-diesis-diesis+2,C-diesis-diesis+3, E-bemolle-bemolle+3, F-bemolle-bemolle-bemolle+3, H-diesis-diesis-diesis+2,C-diesis-diesis-diesis+3, D-diesis+3, F-bemolle-bemolle+3, G-bemolle-bemolle-bemolle-bemolle+3,D-diesis-diesis+3, F-bemolle+3, G-bemolle-bemolle-bemolle+3,A-bemolle-bemolle-bemolle-bemolle+3, D-diesis-diesis-diesis+3, E-diesis+3, G-bemolle-bemolle+3,A-bemolle-bemolle-bemolle+3, E-diesis-diesis+3, F-diesis+3,A-bemolle-bemolle+3, B-bemolle-bemolle-bemolle+3, E-diesis-diesis-diesis+3, F-diesis-diesis+3,B-bemolle-bemolle+3, F-diesis-diesis-diesis+3, G-diesis+3, H-bemolle-bemolle-bemolle+3,B-bemolle+3, C-bemolle-bemolle-bemolle+4, G-diesis-diesis+3, H-bemolle-bemolle+3,A-diesis+3, C-bemolle-bemolle+4, D-bemolle-bemolle-bemolle-bemolle+4, G-diesis-diesis-diesis+3, H-bemolle+3,A-diesis-diesis+3, B-diesis+3, C-bemolle+4, D-bemolle-bemolle-bemolle+4,A-diesis-diesis-diesis+3, B-diesis-diesis+3, D-bemolle-bemolle+4, E-bemolle-bemolle-bemolle-bemolle+4, H-diesis+3,B-diesis-diesis-diesis+3, C-diesis+4, E-bemolle-bemolle-bemolle+4, H-diesis-diesis+3,C-diesis-diesis+4, E-bemolle-bemolle+4, F-bemolle-bemolle-bemolle+4, H-diesis-diesis-diesis+3,C-diesis-diesis-diesis+4, D-diesis+4, F-bemolle-bemolle+4, G-bemolle-bemolle-bemolle-bemolle+4,D-diesis-diesis+4, F-bemolle+4, G-bemolle-bemolle-bemolle+4,A-bemolle-bemolle-bemolle-bemolle+4, D-diesis-diesis-diesis+4, E-diesis+4, G-bemolle-bemolle+4,A-bemolle-bemolle-bemolle+4, E-diesis-diesis+4, F-diesis+4,A-bemolle-bemolle+4, B-bemolle-bemolle-bemolle+4, E-diesis-diesis-diesis+4, F-diesis-diesis+4,B-bemolle-bemolle+4, F-diesis-diesis-diesis+4, G-diesis+4, H-bemolle-bemolle-bemolle+4,B-bemolle+4, C-bemolle-bemolle-bemolle+5, G-diesis-diesis+4, H-bemolle-bemolle+4,A-diesis+4, C-bemolle-bemolle+5, D-bemolle-bemolle-bemolle-bemolle+5, G-diesis-diesis-diesis+4, H-bemolle+4,A-diesis-diesis+4, B-diesis+4, C-bemolle+5, D-bemolle-bemolle-bemolle+5,A-diesis-diesis-diesis+4, B-diesis-diesis+4, D-bemolle-bemolle+5, E-bemolle-bemolle-bemolle-bemolle+5, H-diesis+4,B-diesis-diesis-diesis+4, C-diesis+5, E-bemolle-bemolle-bemolle+5, H-diesis-diesis+4,C-diesis-diesis+5, E-bemolle-bemolle+5, F-bemolle-bemolle-bemolle+5, H-diesis-diesis-diesis+4,C-diesis-diesis-diesis+5, D-diesis+5, F-bemolle-bemolle+5, G-bemolle-bemolle-bemolle-bemolle+5,D-diesis-diesis+5, F-bemolle+5, G-bemolle-bemolle-bemolle+5,A-bemolle-bemolle-bemolle-bemolle+5, D-diesis-diesis-diesis+5, E-diesis+5, G-bemolle-bemolle+5,A-bemolle-bemolle-bemolle+5, E-diesis-diesis+5, F-diesis+5,A-bemolle-bemolle+5, B-bemolle-bemolle-bemolle+5, E-diesis-diesis-diesis+5, F-diesis-diesis+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "A-diesis-diesis-diesis------, B-diesis-diesis------, D-bemolle-bemolle-----, E-bemolle-bemolle-bemolle-bemolle-----, H-diesis------,B-diesis-diesis-diesis------, C-diesis-----, E-bemolle-bemolle-bemolle-----, H-diesis-diesis------,C-diesis-diesis-----, E-bemolle-bemolle-----, F-bemolle-bemolle-bemolle-----, H-diesis-diesis-diesis------,C-diesis-diesis-diesis-----, D-diesis-----, F-bemolle-bemolle-----, G-bemolle-bemolle-bemolle-bemolle-----,D-diesis-diesis-----, F-bemolle-----, G-bemolle-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-bemolle-----, D-diesis-diesis-diesis-----, E-diesis-----, G-bemolle-bemolle-----,A-bemolle-bemolle-bemolle-----, E-diesis-diesis-----, F-diesis-----,A-bemolle-bemolle-----, B-bemolle-bemolle-bemolle-----, E-diesis-diesis-diesis-----, F-diesis-diesis-----,B-bemolle-bemolle-----, F-diesis-diesis-diesis-----, G-diesis-----, H-bemolle-bemolle-bemolle-----,B-bemolle-----, C-bemolle-bemolle-bemolle----, G-diesis-diesis-----, H-bemolle-bemolle-----,A-diesis-----, C-bemolle-bemolle----, D-bemolle-bemolle-bemolle-bemolle----, G-diesis-diesis-diesis-----, H-bemolle-----,A-diesis-diesis-----, B-diesis-----, C-bemolle----, D-bemolle-bemolle-bemolle----,A-diesis-diesis-diesis-----, B-diesis-diesis-----, D-bemolle-bemolle----, E-bemolle-bemolle-bemolle-bemolle----, H-diesis-----,B-diesis-diesis-diesis-----, C-diesis----, E-bemolle-bemolle-bemolle----, H-diesis-diesis-----,C-diesis-diesis----, E-bemolle-bemolle----, F-bemolle-bemolle-bemolle----, H-diesis-diesis-diesis-----,C-diesis-diesis-diesis----, D-diesis----, F-bemolle-bemolle----, G-bemolle-bemolle-bemolle-bemolle----,D-diesis-diesis----, F-bemolle----, G-bemolle-bemolle-bemolle----,A-bemolle-bemolle-bemolle-bemolle----, D-diesis-diesis-diesis----, E-diesis----, G-bemolle-bemolle----,A-bemolle-bemolle-bemolle----, E-diesis-diesis----, F-diesis----,A-bemolle-bemolle----, B-bemolle-bemolle-bemolle----, E-diesis-diesis-diesis----, F-diesis-diesis----,B-bemolle-bemolle----, F-diesis-diesis-diesis----, G-diesis----, H-bemolle-bemolle-bemolle----,B-bemolle----, C-bemolle-bemolle-bemolle---, G-diesis-diesis----, H-bemolle-bemolle----,A-diesis----, C-bemolle-bemolle---, D-bemolle-bemolle-bemolle-bemolle---, G-diesis-diesis-diesis----, H-bemolle----,A-diesis-diesis----, B-diesis----, C-bemolle---, D-bemolle-bemolle-bemolle---,A-diesis-diesis-diesis----, B-diesis-diesis----, D-bemolle-bemolle---, E-bemolle-bemolle-bemolle-bemolle---, H-diesis----,B-diesis-diesis-diesis----, C-diesis---, E-bemolle-bemolle-bemolle---, H-diesis-diesis----,C-diesis-diesis---, E-bemolle-bemolle---, F-bemolle-bemolle-bemolle---, H-diesis-diesis-diesis----,C-diesis-diesis-diesis---, D-diesis---, F-bemolle-bemolle---, G-bemolle-bemolle-bemolle-bemolle---,D-diesis-diesis---, F-bemolle---, G-bemolle-bemolle-bemolle---,A-bemolle-bemolle-bemolle-bemolle---, D-diesis-diesis-diesis---, E-diesis---, G-bemolle-bemolle---,A-bemolle-bemolle-bemolle---, E-diesis-diesis---, F-diesis---,A-bemolle-bemolle---, B-bemolle-bemolle-bemolle---, E-diesis-diesis-diesis---, F-diesis-diesis---,B-bemolle-bemolle---, F-diesis-diesis-diesis---, G-diesis---, H-bemolle-bemolle-bemolle---,B-bemolle---, C-bemolle-bemolle-bemolle--, G-diesis-diesis---, H-bemolle-bemolle---,A-diesis---, C-bemolle-bemolle--, D-bemolle-bemolle-bemolle-bemolle--, G-diesis-diesis-diesis---, H-bemolle---,A-diesis-diesis---, B-diesis---, C-bemolle--, D-bemolle-bemolle-bemolle--,A-diesis-diesis-diesis---, B-diesis-diesis---, D-bemolle-bemolle--, E-bemolle-bemolle-bemolle-bemolle--, H-diesis---,B-diesis-diesis-diesis---, C-diesis--, E-bemolle-bemolle-bemolle--, H-diesis-diesis---,C-diesis-diesis--, E-bemolle-bemolle--, F-bemolle-bemolle-bemolle--, H-diesis-diesis-diesis---,C-diesis-diesis-diesis--, D-diesis--, F-bemolle-bemolle--, G-bemolle-bemolle-bemolle-bemolle--,D-diesis-diesis--, F-bemolle--, G-bemolle-bemolle-bemolle--,A-bemolle-bemolle-bemolle-bemolle--, D-diesis-diesis-diesis--, E-diesis--, G-bemolle-bemolle--,A-bemolle-bemolle-bemolle--, E-diesis-diesis--, F-diesis--,A-bemolle-bemolle--, B-bemolle-bemolle-bemolle--, E-diesis-diesis-diesis--, F-diesis-diesis--,B-bemolle-bemolle--, F-diesis-diesis-diesis--, G-diesis--, H-bemolle-bemolle-bemolle--,B-bemolle--, C-bemolle-bemolle-bemolle-, G-diesis-diesis--, H-bemolle-bemolle--,A-diesis--, C-bemolle-bemolle-, D-bemolle-bemolle-bemolle-bemolle-, G-diesis-diesis-diesis--, H-bemolle--,A-diesis-diesis--, B-diesis--, C-bemolle-, D-bemolle-bemolle-bemolle-,A-diesis-diesis-diesis--, B-diesis-diesis--, D-bemolle-bemolle-, E-bemolle-bemolle-bemolle-bemolle-, H-diesis--,B-diesis-diesis-diesis--, C-diesis-, E-bemolle-bemolle-bemolle-, H-diesis-diesis--,C-diesis-diesis-, E-bemolle-bemolle-, F-bemolle-bemolle-bemolle-, H-diesis-diesis-diesis--,C-diesis-diesis-diesis-, D-diesis-, F-bemolle-bemolle-, G-bemolle-bemolle-bemolle-bemolle-,D-diesis-diesis-, F-bemolle-, G-bemolle-bemolle-bemolle-,A-bemolle-bemolle-bemolle-bemolle-, D-diesis-diesis-diesis-, E-diesis-, G-bemolle-bemolle-,A-bemolle-bemolle-bemolle-, E-diesis-diesis-, F-diesis-,A-bemolle-bemolle-, B-bemolle-bemolle-bemolle-, E-diesis-diesis-diesis-, F-diesis-diesis-,B-bemolle-bemolle-, F-diesis-diesis-diesis-, G-diesis-, H-bemolle-bemolle-bemolle-,B-bemolle-, C-bemolle-bemolle-bemolle, G-diesis-diesis-, H-bemolle-bemolle-,A-diesis-, C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis-, H-bemolle-,A-diesis-diesis-, B-diesis-, C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis-, B-diesis-diesis-, D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle, H-diesis-,B-diesis-diesis-diesis-, C-diesis, E-bemolle-bemolle-bemolle, H-diesis-diesis-,C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis-,C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis, H-bemolle-bemolle-bemolle,B-bemolle, C-bemolle-bemolle-bemolle+, G-diesis-diesis, H-bemolle-bemolle,A-diesis, C-bemolle-bemolle+, D-bemolle-bemolle-bemolle-bemolle+, G-diesis-diesis-diesis, H-bemolle,A-diesis-diesis, B-diesis, C-bemolle+, D-bemolle-bemolle-bemolle+,A-diesis-diesis-diesis, B-diesis-diesis, D-bemolle-bemolle+, E-bemolle-bemolle-bemolle-bemolle+, H-diesis,B-diesis-diesis-diesis, C-diesis+, E-bemolle-bemolle-bemolle+, H-diesis-diesis,C-diesis-diesis+, E-bemolle-bemolle+, F-bemolle-bemolle-bemolle+, H-diesis-diesis-diesis,C-diesis-diesis-diesis+, D-diesis+, F-bemolle-bemolle+, G-bemolle-bemolle-bemolle-bemolle+,D-diesis-diesis+, F-bemolle+, G-bemolle-bemolle-bemolle+,A-bemolle-bemolle-bemolle-bemolle+, D-diesis-diesis-diesis+, E-diesis+, G-bemolle-bemolle+,A-bemolle-bemolle-bemolle+, E-diesis-diesis+, F-diesis+,A-bemolle-bemolle+, B-bemolle-bemolle-bemolle+, E-diesis-diesis-diesis+, F-diesis-diesis+,B-bemolle-bemolle+, F-diesis-diesis-diesis+, G-diesis+, H-bemolle-bemolle-bemolle+,B-bemolle+, C-bemolle-bemolle-bemolle++, G-diesis-diesis+, H-bemolle-bemolle+,A-diesis+, C-bemolle-bemolle++, D-bemolle-bemolle-bemolle-bemolle++, G-diesis-diesis-diesis+, H-bemolle+,A-diesis-diesis+, B-diesis+, C-bemolle++, D-bemolle-bemolle-bemolle++,A-diesis-diesis-diesis+, B-diesis-diesis+, D-bemolle-bemolle++, E-bemolle-bemolle-bemolle-bemolle++, H-diesis+,B-diesis-diesis-diesis+, C-diesis++, E-bemolle-bemolle-bemolle++, H-diesis-diesis+,C-diesis-diesis++, E-bemolle-bemolle++, F-bemolle-bemolle-bemolle++, H-diesis-diesis-diesis+,C-diesis-diesis-diesis++, D-diesis++, F-bemolle-bemolle++, G-bemolle-bemolle-bemolle-bemolle++,D-diesis-diesis++, F-bemolle++, G-bemolle-bemolle-bemolle++,A-bemolle-bemolle-bemolle-bemolle++, D-diesis-diesis-diesis++, E-diesis++, G-bemolle-bemolle++,A-bemolle-bemolle-bemolle++, E-diesis-diesis++, F-diesis++,A-bemolle-bemolle++, B-bemolle-bemolle-bemolle++, E-diesis-diesis-diesis++, F-diesis-diesis++,B-bemolle-bemolle++, F-diesis-diesis-diesis++, G-diesis++, H-bemolle-bemolle-bemolle++,B-bemolle++, C-bemolle-bemolle-bemolle+++, G-diesis-diesis++, H-bemolle-bemolle++,A-diesis++, C-bemolle-bemolle+++, D-bemolle-bemolle-bemolle-bemolle+++, G-diesis-diesis-diesis++, H-bemolle++,A-diesis-diesis++, B-diesis++, C-bemolle+++, D-bemolle-bemolle-bemolle+++,A-diesis-diesis-diesis++, B-diesis-diesis++, D-bemolle-bemolle+++, E-bemolle-bemolle-bemolle-bemolle+++, H-diesis++,B-diesis-diesis-diesis++, C-diesis+++, E-bemolle-bemolle-bemolle+++, H-diesis-diesis++,C-diesis-diesis+++, E-bemolle-bemolle+++, F-bemolle-bemolle-bemolle+++, H-diesis-diesis-diesis++,C-diesis-diesis-diesis+++, D-diesis+++, F-bemolle-bemolle+++, G-bemolle-bemolle-bemolle-bemolle+++,D-diesis-diesis+++, F-bemolle+++, G-bemolle-bemolle-bemolle+++,A-bemolle-bemolle-bemolle-bemolle+++, D-diesis-diesis-diesis+++, E-diesis+++, G-bemolle-bemolle+++,A-bemolle-bemolle-bemolle+++, E-diesis-diesis+++, F-diesis+++,A-bemolle-bemolle+++, B-bemolle-bemolle-bemolle+++, E-diesis-diesis-diesis+++, F-diesis-diesis+++,B-bemolle-bemolle+++, F-diesis-diesis-diesis+++, G-diesis+++, H-bemolle-bemolle-bemolle+++,B-bemolle+++, C-bemolle-bemolle-bemolle++++, G-diesis-diesis+++, H-bemolle-bemolle+++,A-diesis+++, C-bemolle-bemolle++++, D-bemolle-bemolle-bemolle-bemolle++++, G-diesis-diesis-diesis+++, H-bemolle+++,A-diesis-diesis+++, B-diesis+++, C-bemolle++++, D-bemolle-bemolle-bemolle++++,A-diesis-diesis-diesis+++, B-diesis-diesis+++, D-bemolle-bemolle++++, E-bemolle-bemolle-bemolle-bemolle++++, H-diesis+++,B-diesis-diesis-diesis+++, C-diesis++++, E-bemolle-bemolle-bemolle++++, H-diesis-diesis+++,C-diesis-diesis++++, E-bemolle-bemolle++++, F-bemolle-bemolle-bemolle++++, H-diesis-diesis-diesis+++,C-diesis-diesis-diesis++++, D-diesis++++, F-bemolle-bemolle++++, G-bemolle-bemolle-bemolle-bemolle++++,D-diesis-diesis++++, F-bemolle++++, G-bemolle-bemolle-bemolle++++,A-bemolle-bemolle-bemolle-bemolle++++, D-diesis-diesis-diesis++++, E-diesis++++, G-bemolle-bemolle++++,A-bemolle-bemolle-bemolle++++, E-diesis-diesis++++, F-diesis++++,A-bemolle-bemolle++++, B-bemolle-bemolle-bemolle++++, E-diesis-diesis-diesis++++, F-diesis-diesis++++,B-bemolle-bemolle++++, F-diesis-diesis-diesis++++, G-diesis++++, H-bemolle-bemolle-bemolle++++,B-bemolle++++, C-bemolle-bemolle-bemolle+++++, G-diesis-diesis++++, H-bemolle-bemolle++++,A-diesis++++, C-bemolle-bemolle+++++, D-bemolle-bemolle-bemolle-bemolle+++++, G-diesis-diesis-diesis++++, H-bemolle++++,A-diesis-diesis++++, B-diesis++++, C-bemolle+++++, D-bemolle-bemolle-bemolle+++++,A-diesis-diesis-diesis++++, B-diesis-diesis++++, D-bemolle-bemolle+++++, E-bemolle-bemolle-bemolle-bemolle+++++, H-diesis++++,B-diesis-diesis-diesis++++, C-diesis+++++, E-bemolle-bemolle-bemolle+++++, H-diesis-diesis++++,C-diesis-diesis+++++, E-bemolle-bemolle+++++, F-bemolle-bemolle-bemolle+++++, H-diesis-diesis-diesis++++,C-diesis-diesis-diesis+++++, D-diesis+++++, F-bemolle-bemolle+++++, G-bemolle-bemolle-bemolle-bemolle+++++,D-diesis-diesis+++++, F-bemolle+++++, G-bemolle-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle-bemolle+++++, D-diesis-diesis-diesis+++++, E-diesis+++++, G-bemolle-bemolle+++++,A-bemolle-bemolle-bemolle+++++, E-diesis-diesis+++++, F-diesis+++++,A-bemolle-bemolle+++++, B-bemolle-bemolle-bemolle+++++, E-diesis-diesis-diesis+++++, F-diesis-diesis+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "A-diesis-diesis-diesis-2, B-diesis-diesis-2, D-bemolle-bemolle-1, E-bemolle-bemolle-bemolle-bemolle-1, H-diesis-2,B-diesis-diesis-diesis-2, C-diesis-1, E-bemolle-bemolle-bemolle-1, H-diesis-diesis-2,C-diesis-diesis-1, E-bemolle-bemolle-1, F-bemolle-bemolle-bemolle-1, H-diesis-diesis-diesis-2,C-diesis-diesis-diesis-1, D-diesis-1, F-bemolle-bemolle-1, G-bemolle-bemolle-bemolle-bemolle-1,D-diesis-diesis-1, F-bemolle-1, G-bemolle-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-bemolle-1, D-diesis-diesis-diesis-1, E-diesis-1, G-bemolle-bemolle-1,A-bemolle-bemolle-bemolle-1, E-diesis-diesis-1, F-diesis-1,A-bemolle-bemolle-1, B-bemolle-bemolle-bemolle-1, E-diesis-diesis-diesis-1, F-diesis-diesis-1,B-bemolle-bemolle-1, F-diesis-diesis-diesis-1, G-diesis-1, H-bemolle-bemolle-bemolle-1,B-bemolle-1, C-bemolle-bemolle-bemolle0, G-diesis-diesis-1, H-bemolle-bemolle-1,A-diesis-1, C-bemolle-bemolle0, D-bemolle-bemolle-bemolle-bemolle0, G-diesis-diesis-diesis-1, H-bemolle-1,A-diesis-diesis-1, B-diesis-1, C-bemolle0, D-bemolle-bemolle-bemolle0,A-diesis-diesis-diesis-1, B-diesis-diesis-1, D-bemolle-bemolle0, E-bemolle-bemolle-bemolle-bemolle0, H-diesis-1,B-diesis-diesis-diesis-1, C-diesis0, E-bemolle-bemolle-bemolle0, H-diesis-diesis-1,C-diesis-diesis0, E-bemolle-bemolle0, F-bemolle-bemolle-bemolle0, H-diesis-diesis-diesis-1,C-diesis-diesis-diesis0, D-diesis0, F-bemolle-bemolle0, G-bemolle-bemolle-bemolle-bemolle0,D-diesis-diesis0, F-bemolle0, G-bemolle-bemolle-bemolle0,A-bemolle-bemolle-bemolle-bemolle0, D-diesis-diesis-diesis0, E-diesis0, G-bemolle-bemolle0,A-bemolle-bemolle-bemolle0, E-diesis-diesis0, F-diesis0,A-bemolle-bemolle0, B-bemolle-bemolle-bemolle0, E-diesis-diesis-diesis0, F-diesis-diesis0,B-bemolle-bemolle0, F-diesis-diesis-diesis0, G-diesis0, H-bemolle-bemolle-bemolle0,B-bemolle0, C-bemolle-bemolle-bemolle1, G-diesis-diesis0, H-bemolle-bemolle0,A-diesis0, C-bemolle-bemolle1, D-bemolle-bemolle-bemolle-bemolle1, G-diesis-diesis-diesis0, H-bemolle0,A-diesis-diesis0, B-diesis0, C-bemolle1, D-bemolle-bemolle-bemolle1,A-diesis-diesis-diesis0, B-diesis-diesis0, D-bemolle-bemolle1, E-bemolle-bemolle-bemolle-bemolle1, H-diesis0,B-diesis-diesis-diesis0, C-diesis1, E-bemolle-bemolle-bemolle1, H-diesis-diesis0,C-diesis-diesis1, E-bemolle-bemolle1, F-bemolle-bemolle-bemolle1, H-diesis-diesis-diesis0,C-diesis-diesis-diesis1, D-diesis1, F-bemolle-bemolle1, G-bemolle-bemolle-bemolle-bemolle1,D-diesis-diesis1, F-bemolle1, G-bemolle-bemolle-bemolle1,A-bemolle-bemolle-bemolle-bemolle1, D-diesis-diesis-diesis1, E-diesis1, G-bemolle-bemolle1,A-bemolle-bemolle-bemolle1, E-diesis-diesis1, F-diesis1,A-bemolle-bemolle1, B-bemolle-bemolle-bemolle1, E-diesis-diesis-diesis1, F-diesis-diesis1,B-bemolle-bemolle1, F-diesis-diesis-diesis1, G-diesis1, H-bemolle-bemolle-bemolle1,B-bemolle1, C-bemolle-bemolle-bemolle2, G-diesis-diesis1, H-bemolle-bemolle1,A-diesis1, C-bemolle-bemolle2, D-bemolle-bemolle-bemolle-bemolle2, G-diesis-diesis-diesis1, H-bemolle1,A-diesis-diesis1, B-diesis1, C-bemolle2, D-bemolle-bemolle-bemolle2,A-diesis-diesis-diesis1, B-diesis-diesis1, D-bemolle-bemolle2, E-bemolle-bemolle-bemolle-bemolle2, H-diesis1,B-diesis-diesis-diesis1, C-diesis2, E-bemolle-bemolle-bemolle2, H-diesis-diesis1,C-diesis-diesis2, E-bemolle-bemolle2, F-bemolle-bemolle-bemolle2, H-diesis-diesis-diesis1,C-diesis-diesis-diesis2, D-diesis2, F-bemolle-bemolle2, G-bemolle-bemolle-bemolle-bemolle2,D-diesis-diesis2, F-bemolle2, G-bemolle-bemolle-bemolle2,A-bemolle-bemolle-bemolle-bemolle2, D-diesis-diesis-diesis2, E-diesis2, G-bemolle-bemolle2,A-bemolle-bemolle-bemolle2, E-diesis-diesis2, F-diesis2,A-bemolle-bemolle2, B-bemolle-bemolle-bemolle2, E-diesis-diesis-diesis2, F-diesis-diesis2,B-bemolle-bemolle2, F-diesis-diesis-diesis2, G-diesis2, H-bemolle-bemolle-bemolle2,B-bemolle2, C-bemolle-bemolle-bemolle3, G-diesis-diesis2, H-bemolle-bemolle2,A-diesis2, C-bemolle-bemolle3, D-bemolle-bemolle-bemolle-bemolle3, G-diesis-diesis-diesis2, H-bemolle2,A-diesis-diesis2, B-diesis2, C-bemolle3, D-bemolle-bemolle-bemolle3,A-diesis-diesis-diesis2, B-diesis-diesis2, D-bemolle-bemolle3, E-bemolle-bemolle-bemolle-bemolle3, H-diesis2,B-diesis-diesis-diesis2, C-diesis3, E-bemolle-bemolle-bemolle3, H-diesis-diesis2,C-diesis-diesis3, E-bemolle-bemolle3, F-bemolle-bemolle-bemolle3, H-diesis-diesis-diesis2,C-diesis-diesis-diesis3, D-diesis3, F-bemolle-bemolle3, G-bemolle-bemolle-bemolle-bemolle3,D-diesis-diesis3, F-bemolle3, G-bemolle-bemolle-bemolle3,A-bemolle-bemolle-bemolle-bemolle3, D-diesis-diesis-diesis3, E-diesis3, G-bemolle-bemolle3,A-bemolle-bemolle-bemolle3, E-diesis-diesis3, F-diesis3,A-bemolle-bemolle3, B-bemolle-bemolle-bemolle3, E-diesis-diesis-diesis3, F-diesis-diesis3,B-bemolle-bemolle3, F-diesis-diesis-diesis3, G-diesis3, H-bemolle-bemolle-bemolle3,B-bemolle3, C-bemolle-bemolle-bemolle4, G-diesis-diesis3, H-bemolle-bemolle3,A-diesis3, C-bemolle-bemolle4, D-bemolle-bemolle-bemolle-bemolle4, G-diesis-diesis-diesis3, H-bemolle3,A-diesis-diesis3, B-diesis3, C-bemolle4, D-bemolle-bemolle-bemolle4,A-diesis-diesis-diesis3, B-diesis-diesis3, D-bemolle-bemolle4, E-bemolle-bemolle-bemolle-bemolle4, H-diesis3,B-diesis-diesis-diesis3, C-diesis4, E-bemolle-bemolle-bemolle4, H-diesis-diesis3,C-diesis-diesis4, E-bemolle-bemolle4, F-bemolle-bemolle-bemolle4, H-diesis-diesis-diesis3,C-diesis-diesis-diesis4, D-diesis4, F-bemolle-bemolle4, G-bemolle-bemolle-bemolle-bemolle4,D-diesis-diesis4, F-bemolle4, G-bemolle-bemolle-bemolle4,A-bemolle-bemolle-bemolle-bemolle4, D-diesis-diesis-diesis4, E-diesis4, G-bemolle-bemolle4,A-bemolle-bemolle-bemolle4, E-diesis-diesis4, F-diesis4,A-bemolle-bemolle4, B-bemolle-bemolle-bemolle4, E-diesis-diesis-diesis4, F-diesis-diesis4,B-bemolle-bemolle4, F-diesis-diesis-diesis4, G-diesis4, H-bemolle-bemolle-bemolle4,B-bemolle4, C-bemolle-bemolle-bemolle5, G-diesis-diesis4, H-bemolle-bemolle4,A-diesis4, C-bemolle-bemolle5, D-bemolle-bemolle-bemolle-bemolle5, G-diesis-diesis-diesis4, H-bemolle4,A-diesis-diesis4, B-diesis4, C-bemolle5, D-bemolle-bemolle-bemolle5,A-diesis-diesis-diesis4, B-diesis-diesis4, D-bemolle-bemolle5, E-bemolle-bemolle-bemolle-bemolle5, H-diesis4,B-diesis-diesis-diesis4, C-diesis5, E-bemolle-bemolle-bemolle5, H-diesis-diesis4,C-diesis-diesis5, E-bemolle-bemolle5, F-bemolle-bemolle-bemolle5, H-diesis-diesis-diesis4,C-diesis-diesis-diesis5, D-diesis5, F-bemolle-bemolle5, G-bemolle-bemolle-bemolle-bemolle5,D-diesis-diesis5, F-bemolle5, G-bemolle-bemolle-bemolle5,A-bemolle-bemolle-bemolle-bemolle5, D-diesis-diesis-diesis5, E-diesis5, G-bemolle-bemolle5,A-bemolle-bemolle-bemolle5, E-diesis-diesis5, F-diesis5,A-bemolle-bemolle5, B-bemolle-bemolle-bemolle5, E-diesis-diesis-diesis5, F-diesis-diesis5,B-bemolle-bemolle5, F-diesis-diesis-diesis5, G-diesis5, H-bemolle-bemolle-bemolle5,B-bemolle5, C-bemolle-bemolle-bemolle6, G-diesis-diesis5, H-bemolle-bemolle5,A-diesis5, C-bemolle-bemolle6, D-bemolle-bemolle-bemolle-bemolle6, G-diesis-diesis-diesis5, H-bemolle5,A-diesis-diesis5, B-diesis5, C-bemolle6, D-bemolle-bemolle-bemolle6,A-diesis-diesis-diesis5, B-diesis-diesis5, D-bemolle-bemolle6, E-bemolle-bemolle-bemolle-bemolle6, H-diesis5,B-diesis-diesis-diesis5, C-diesis6, E-bemolle-bemolle-bemolle6, H-diesis-diesis5,C-diesis-diesis6, E-bemolle-bemolle6, F-bemolle-bemolle-bemolle6, H-diesis-diesis-diesis5,C-diesis-diesis-diesis6, D-diesis6, F-bemolle-bemolle6, G-bemolle-bemolle-bemolle-bemolle6,D-diesis-diesis6, F-bemolle6, G-bemolle-bemolle-bemolle6,A-bemolle-bemolle-bemolle-bemolle6, D-diesis-diesis-diesis6, E-diesis6, G-bemolle-bemolle6,A-bemolle-bemolle-bemolle6, E-diesis-diesis6, F-diesis6,A-bemolle-bemolle6, B-bemolle-bemolle-bemolle6, E-diesis-diesis-diesis6, F-diesis-diesis6,B-bemolle-bemolle6, F-diesis-diesis-diesis6, G-diesis6, H-bemolle-bemolle-bemolle6,B-bemolle6, C-bemolle-bemolle-bemolle7, G-diesis-diesis6, H-bemolle-bemolle6,A-diesis6, C-bemolle-bemolle7, D-bemolle-bemolle-bemolle-bemolle7, G-diesis-diesis-diesis6, H-bemolle6,A-diesis-diesis6, B-diesis6, C-bemolle7, D-bemolle-bemolle-bemolle7,A-diesis-diesis-diesis6, B-diesis-diesis6, D-bemolle-bemolle7, E-bemolle-bemolle-bemolle-bemolle7, H-diesis6,B-diesis-diesis-diesis6, C-diesis7, E-bemolle-bemolle-bemolle7, H-diesis-diesis6,C-diesis-diesis7, E-bemolle-bemolle7, F-bemolle-bemolle-bemolle7, H-diesis-diesis-diesis6,C-diesis-diesis-diesis7, D-diesis7, F-bemolle-bemolle7, G-bemolle-bemolle-bemolle-bemolle7,D-diesis-diesis7, F-bemolle7, G-bemolle-bemolle-bemolle7,A-bemolle-bemolle-bemolle-bemolle7, D-diesis-diesis-diesis7, E-diesis7, G-bemolle-bemolle7,A-bemolle-bemolle-bemolle7, E-diesis-diesis7, F-diesis7,A-bemolle-bemolle7, B-bemolle-bemolle-bemolle7, E-diesis-diesis-diesis7, F-diesis-diesis7,B-bemolle-bemolle7, F-diesis-diesis-diesis7, G-diesis7, H-bemolle-bemolle-bemolle7,B-bemolle7, C-bemolle-bemolle-bemolle8, G-diesis-diesis7, H-bemolle-bemolle7,A-diesis7, C-bemolle-bemolle8, D-bemolle-bemolle-bemolle-bemolle8, G-diesis-diesis-diesis7, H-bemolle7,A-diesis-diesis7, B-diesis7, C-bemolle8, D-bemolle-bemolle-bemolle8,A-diesis-diesis-diesis7, B-diesis-diesis7, D-bemolle-bemolle8, E-bemolle-bemolle-bemolle-bemolle8, H-diesis7,B-diesis-diesis-diesis7, C-diesis8, E-bemolle-bemolle-bemolle8, H-diesis-diesis7,C-diesis-diesis8, E-bemolle-bemolle8, F-bemolle-bemolle-bemolle8, H-diesis-diesis-diesis7,C-diesis-diesis-diesis8, D-diesis8, F-bemolle-bemolle8, G-bemolle-bemolle-bemolle-bemolle8,D-diesis-diesis8, F-bemolle8, G-bemolle-bemolle-bemolle8,A-bemolle-bemolle-bemolle-bemolle8, D-diesis-diesis-diesis8, E-diesis8, G-bemolle-bemolle8,A-bemolle-bemolle-bemolle8, E-diesis-diesis8, F-diesis8,A-bemolle-bemolle8, B-bemolle-bemolle-bemolle8, E-diesis-diesis-diesis8, F-diesis-diesis8,B-bemolle-bemolle8, F-diesis-diesis-diesis8, G-diesis8, H-bemolle-bemolle-bemolle8,B-bemolle8, C-bemolle-bemolle-bemolle9, G-diesis-diesis8, H-bemolle-bemolle8,A-diesis8, C-bemolle-bemolle9, D-bemolle-bemolle-bemolle-bemolle9, G-diesis-diesis-diesis8, H-bemolle8,A-diesis-diesis8, B-diesis8, C-bemolle9, D-bemolle-bemolle-bemolle9,A-diesis-diesis-diesis8, B-diesis-diesis8, D-bemolle-bemolle9, E-bemolle-bemolle-bemolle-bemolle9, H-diesis8,B-diesis-diesis-diesis8, C-diesis9, E-bemolle-bemolle-bemolle9, H-diesis-diesis8,C-diesis-diesis9, E-bemolle-bemolle9, F-bemolle-bemolle-bemolle9, H-diesis-diesis-diesis8,C-diesis-diesis-diesis9, D-diesis9, F-bemolle-bemolle9, G-bemolle-bemolle-bemolle-bemolle9,D-diesis-diesis9, F-bemolle9, G-bemolle-bemolle-bemolle9,A-bemolle-bemolle-bemolle-bemolle9, D-diesis-diesis-diesis9, E-diesis9, G-bemolle-bemolle9,A-bemolle-bemolle-bemolle9, E-diesis-diesis9, F-diesis9,A-bemolle-bemolle9, B-bemolle-bemolle-bemolle9, E-diesis-diesis-diesis9, F-diesis-diesis9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_diesis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "A-diesis-diesis-diesis'''', B-diesis-diesis'''', D-bemolle-bemolle''', E-bemolle-bemolle-bemolle-bemolle''', H-diesis'''',B-diesis-diesis-diesis'''', C-diesis''', E-bemolle-bemolle-bemolle''', H-diesis-diesis'''',C-diesis-diesis''', E-bemolle-bemolle''', F-bemolle-bemolle-bemolle''', H-diesis-diesis-diesis'''',C-diesis-diesis-diesis''', D-diesis''', F-bemolle-bemolle''', G-bemolle-bemolle-bemolle-bemolle''',D-diesis-diesis''', F-bemolle''', G-bemolle-bemolle-bemolle''',A-bemolle-bemolle-bemolle-bemolle''', D-diesis-diesis-diesis''', E-diesis''', G-bemolle-bemolle''',A-bemolle-bemolle-bemolle''', E-diesis-diesis''', F-diesis''',A-bemolle-bemolle''', B-bemolle-bemolle-bemolle''', E-diesis-diesis-diesis''', F-diesis-diesis''',B-bemolle-bemolle''', F-diesis-diesis-diesis''', G-diesis''', H-bemolle-bemolle-bemolle''',B-bemolle''', C-bemolle-bemolle-bemolle'', G-diesis-diesis''', H-bemolle-bemolle''',A-diesis''', C-bemolle-bemolle'', D-bemolle-bemolle-bemolle-bemolle'', G-diesis-diesis-diesis''', H-bemolle''',A-diesis-diesis''', B-diesis''', C-bemolle'', D-bemolle-bemolle-bemolle'',A-diesis-diesis-diesis''', B-diesis-diesis''', D-bemolle-bemolle'', E-bemolle-bemolle-bemolle-bemolle'', H-diesis''',B-diesis-diesis-diesis''', C-diesis'', E-bemolle-bemolle-bemolle'', H-diesis-diesis''',C-diesis-diesis'', E-bemolle-bemolle'', F-bemolle-bemolle-bemolle'', H-diesis-diesis-diesis''',C-diesis-diesis-diesis'', D-diesis'', F-bemolle-bemolle'', G-bemolle-bemolle-bemolle-bemolle'',D-diesis-diesis'', F-bemolle'', G-bemolle-bemolle-bemolle'',A-bemolle-bemolle-bemolle-bemolle'', D-diesis-diesis-diesis'', E-diesis'', G-bemolle-bemolle'',A-bemolle-bemolle-bemolle'', E-diesis-diesis'', F-diesis'',A-bemolle-bemolle'', B-bemolle-bemolle-bemolle'', E-diesis-diesis-diesis'', F-diesis-diesis'',B-bemolle-bemolle'', F-diesis-diesis-diesis'', G-diesis'', H-bemolle-bemolle-bemolle'',B-bemolle'', C-bemolle-bemolle-bemolle', G-diesis-diesis'', H-bemolle-bemolle'',A-diesis'', C-bemolle-bemolle', D-bemolle-bemolle-bemolle-bemolle', G-diesis-diesis-diesis'', H-bemolle'',A-diesis-diesis'', B-diesis'', C-bemolle', D-bemolle-bemolle-bemolle',A-diesis-diesis-diesis'', B-diesis-diesis'', D-bemolle-bemolle', E-bemolle-bemolle-bemolle-bemolle', H-diesis'',B-diesis-diesis-diesis'', C-diesis', E-bemolle-bemolle-bemolle', H-diesis-diesis'',C-diesis-diesis', E-bemolle-bemolle', F-bemolle-bemolle-bemolle', H-diesis-diesis-diesis'',C-diesis-diesis-diesis', D-diesis', F-bemolle-bemolle', G-bemolle-bemolle-bemolle-bemolle',D-diesis-diesis', F-bemolle', G-bemolle-bemolle-bemolle',A-bemolle-bemolle-bemolle-bemolle', D-diesis-diesis-diesis', E-diesis', G-bemolle-bemolle',A-bemolle-bemolle-bemolle', E-diesis-diesis', F-diesis',A-bemolle-bemolle', B-bemolle-bemolle-bemolle', E-diesis-diesis-diesis', F-diesis-diesis',B-bemolle-bemolle', F-diesis-diesis-diesis', G-diesis', H-bemolle-bemolle-bemolle',B-bemolle', C-bemolle-bemolle-bemolle, G-diesis-diesis', H-bemolle-bemolle',A-diesis', C-bemolle-bemolle, D-bemolle-bemolle-bemolle-bemolle, G-diesis-diesis-diesis', H-bemolle',A-diesis-diesis', B-diesis', C-bemolle, D-bemolle-bemolle-bemolle,A-diesis-diesis-diesis', B-diesis-diesis', D-bemolle-bemolle, E-bemolle-bemolle-bemolle-bemolle, H-diesis',B-diesis-diesis-diesis', C-diesis, E-bemolle-bemolle-bemolle, H-diesis-diesis',C-diesis-diesis, E-bemolle-bemolle, F-bemolle-bemolle-bemolle, H-diesis-diesis-diesis',C-diesis-diesis-diesis, D-diesis, F-bemolle-bemolle, G-bemolle-bemolle-bemolle-bemolle,D-diesis-diesis, F-bemolle, G-bemolle-bemolle-bemolle,A-bemolle-bemolle-bemolle-bemolle, D-diesis-diesis-diesis, E-diesis, G-bemolle-bemolle,A-bemolle-bemolle-bemolle, E-diesis-diesis, F-diesis,A-bemolle-bemolle, B-bemolle-bemolle-bemolle, E-diesis-diesis-diesis, F-diesis-diesis,B-bemolle-bemolle, F-diesis-diesis-diesis, G-diesis, H-bemolle-bemolle-bemolle,B-bemolle, G-diesis-diesis, H-bemolle-bemolle, c-bemolle-bemolle-bemolle,A-diesis, G-diesis-diesis-diesis, H-bemolle, c-bemolle-bemolle, d-bemolle-bemolle-bemolle-bemolle,A-diesis-diesis, B-diesis, c-bemolle, d-bemolle-bemolle-bemolle,A-diesis-diesis-diesis, B-diesis-diesis, H-diesis, d-bemolle-bemolle, e-bemolle-bemolle-bemolle-bemolle,B-diesis-diesis-diesis, H-diesis-diesis, c-diesis, e-bemolle-bemolle-bemolle,H-diesis-diesis-diesis, c-diesis-diesis, e-bemolle-bemolle, f-bemolle-bemolle-bemolle,c-diesis-diesis-diesis, d-diesis, f-bemolle-bemolle, g-bemolle-bemolle-bemolle-bemolle,d-diesis-diesis, f-bemolle, g-bemolle-bemolle-bemolle,a-bemolle-bemolle-bemolle-bemolle, d-diesis-diesis-diesis, e-diesis, g-bemolle-bemolle,a-bemolle-bemolle-bemolle, e-diesis-diesis, f-diesis,a-bemolle-bemolle, b-bemolle-bemolle-bemolle, e-diesis-diesis-diesis, f-diesis-diesis,b-bemolle-bemolle, f-diesis-diesis-diesis, g-diesis, h-bemolle-bemolle-bemolle,b-bemolle, c-bemolle-bemolle-bemolle', g-diesis-diesis, h-bemolle-bemolle,a-diesis, c-bemolle-bemolle', d-bemolle-bemolle-bemolle-bemolle', g-diesis-diesis-diesis, h-bemolle,a-diesis-diesis, b-diesis, c-bemolle', d-bemolle-bemolle-bemolle',a-diesis-diesis-diesis, b-diesis-diesis, d-bemolle-bemolle', e-bemolle-bemolle-bemolle-bemolle', h-diesis,b-diesis-diesis-diesis, c-diesis', e-bemolle-bemolle-bemolle', h-diesis-diesis,c-diesis-diesis', e-bemolle-bemolle', f-bemolle-bemolle-bemolle', h-diesis-diesis-diesis,c-diesis-diesis-diesis', d-diesis', f-bemolle-bemolle', g-bemolle-bemolle-bemolle-bemolle',d-diesis-diesis', f-bemolle', g-bemolle-bemolle-bemolle',a-bemolle-bemolle-bemolle-bemolle', d-diesis-diesis-diesis', e-diesis', g-bemolle-bemolle',a-bemolle-bemolle-bemolle', e-diesis-diesis', f-diesis',a-bemolle-bemolle', b-bemolle-bemolle-bemolle', e-diesis-diesis-diesis', f-diesis-diesis',b-bemolle-bemolle', f-diesis-diesis-diesis', g-diesis', h-bemolle-bemolle-bemolle',b-bemolle', c-bemolle-bemolle-bemolle'', g-diesis-diesis', h-bemolle-bemolle',a-diesis', c-bemolle-bemolle'', d-bemolle-bemolle-bemolle-bemolle'', g-diesis-diesis-diesis', h-bemolle',a-diesis-diesis', b-diesis', c-bemolle'', d-bemolle-bemolle-bemolle'',a-diesis-diesis-diesis', b-diesis-diesis', d-bemolle-bemolle'', e-bemolle-bemolle-bemolle-bemolle'', h-diesis',b-diesis-diesis-diesis', c-diesis'', e-bemolle-bemolle-bemolle'', h-diesis-diesis',c-diesis-diesis'', e-bemolle-bemolle'', f-bemolle-bemolle-bemolle'', h-diesis-diesis-diesis',c-diesis-diesis-diesis'', d-diesis'', f-bemolle-bemolle'', g-bemolle-bemolle-bemolle-bemolle'',d-diesis-diesis'', f-bemolle'', g-bemolle-bemolle-bemolle'',a-bemolle-bemolle-bemolle-bemolle'', d-diesis-diesis-diesis'', e-diesis'', g-bemolle-bemolle'',a-bemolle-bemolle-bemolle'', e-diesis-diesis'', f-diesis'',a-bemolle-bemolle'', b-bemolle-bemolle-bemolle'', e-diesis-diesis-diesis'', f-diesis-diesis'',b-bemolle-bemolle'', f-diesis-diesis-diesis'', g-diesis'', h-bemolle-bemolle-bemolle'',b-bemolle'', c-bemolle-bemolle-bemolle''', g-diesis-diesis'', h-bemolle-bemolle'',a-diesis'', c-bemolle-bemolle''', d-bemolle-bemolle-bemolle-bemolle''', g-diesis-diesis-diesis'', h-bemolle'',a-diesis-diesis'', b-diesis'', c-bemolle''', d-bemolle-bemolle-bemolle''',a-diesis-diesis-diesis'', b-diesis-diesis'', d-bemolle-bemolle''', e-bemolle-bemolle-bemolle-bemolle''', h-diesis'',b-diesis-diesis-diesis'', c-diesis''', e-bemolle-bemolle-bemolle''', h-diesis-diesis'',c-diesis-diesis''', e-bemolle-bemolle''', f-bemolle-bemolle-bemolle''', h-diesis-diesis-diesis'',c-diesis-diesis-diesis''', d-diesis''', f-bemolle-bemolle''', g-bemolle-bemolle-bemolle-bemolle''',d-diesis-diesis''', f-bemolle''', g-bemolle-bemolle-bemolle''',a-bemolle-bemolle-bemolle-bemolle''', d-diesis-diesis-diesis''', e-diesis''', g-bemolle-bemolle''',a-bemolle-bemolle-bemolle''', e-diesis-diesis''', f-diesis''',a-bemolle-bemolle''', b-bemolle-bemolle-bemolle''', e-diesis-diesis-diesis''', f-diesis-diesis''',b-bemolle-bemolle''', f-diesis-diesis-diesis''', g-diesis''', h-bemolle-bemolle-bemolle''',b-bemolle''', c-bemolle-bemolle-bemolle'''', g-diesis-diesis''', h-bemolle-bemolle''',a-diesis''', c-bemolle-bemolle'''', d-bemolle-bemolle-bemolle-bemolle'''', g-diesis-diesis-diesis''', h-bemolle''',a-diesis-diesis''', b-diesis''', c-bemolle'''', d-bemolle-bemolle-bemolle'''',a-diesis-diesis-diesis''', b-diesis-diesis''', d-bemolle-bemolle'''', e-bemolle-bemolle-bemolle-bemolle'''', h-diesis''',b-diesis-diesis-diesis''', c-diesis'''', e-bemolle-bemolle-bemolle'''', h-diesis-diesis''',c-diesis-diesis'''', e-bemolle-bemolle'''', f-bemolle-bemolle-bemolle'''', h-diesis-diesis-diesis''',c-diesis-diesis-diesis'''', d-diesis'''', f-bemolle-bemolle'''', g-bemolle-bemolle-bemolle-bemolle'''',d-diesis-diesis'''', f-bemolle'''', g-bemolle-bemolle-bemolle'''',a-bemolle-bemolle-bemolle-bemolle'''', d-diesis-diesis-diesis'''', e-diesis'''', g-bemolle-bemolle'''',a-bemolle-bemolle-bemolle'''', e-diesis-diesis'''', f-diesis'''',a-bemolle-bemolle'''', b-bemolle-bemolle-bemolle'''', e-diesis-diesis-diesis'''', f-diesis-diesis'''',b-bemolle-bemolle'''', f-diesis-diesis-diesis'''', g-diesis'''', h-bemolle-bemolle-bemolle'''',b-bemolle'''', c-bemolle-bemolle-bemolle''''', g-diesis-diesis'''', h-bemolle-bemolle'''',a-diesis'''', c-bemolle-bemolle''''', d-bemolle-bemolle-bemolle-bemolle''''', g-diesis-diesis-diesis'''', h-bemolle'''',a-diesis-diesis'''', b-diesis'''', c-bemolle''''', d-bemolle-bemolle-bemolle''''',a-diesis-diesis-diesis'''', b-diesis-diesis'''', d-bemolle-bemolle''''', e-bemolle-bemolle-bemolle-bemolle''''', h-diesis'''',b-diesis-diesis-diesis'''', c-diesis''''', e-bemolle-bemolle-bemolle''''', h-diesis-diesis'''',c-diesis-diesis''''', e-bemolle-bemolle''''', f-bemolle-bemolle-bemolle''''', h-diesis-diesis-diesis'''',c-diesis-diesis-diesis''''', d-diesis''''', f-bemolle-bemolle''''', g-bemolle-bemolle-bemolle-bemolle''''',d-diesis-diesis''''', f-bemolle''''', g-bemolle-bemolle-bemolle''''',a-bemolle-bemolle-bemolle-bemolle''''', d-diesis-diesis-diesis''''', e-diesis''''', g-bemolle-bemolle''''',a-bemolle-bemolle-bemolle''''', e-diesis-diesis''''', f-diesis''''',a-bemolle-bemolle''''', b-bemolle-bemolle-bemolle''''', e-diesis-diesis-diesis''''', f-diesis-diesis''''',b-bemolle-bemolle''''', f-diesis-diesis-diesis''''', g-diesis''''', h-bemolle-bemolle-bemolle''''',b-bemolle''''', c-bemolle-bemolle-bemolle'''''', g-diesis-diesis''''', h-bemolle-bemolle''''',a-diesis''''', c-bemolle-bemolle'''''', d-bemolle-bemolle-bemolle-bemolle'''''', g-diesis-diesis-diesis''''', h-bemolle''''',a-diesis-diesis''''', b-diesis''''', c-bemolle'''''', d-bemolle-bemolle-bemolle'''''',a-diesis-diesis-diesis''''', b-diesis-diesis''''', d-bemolle-bemolle'''''', e-bemolle-bemolle-bemolle-bemolle'''''', h-diesis''''',b-diesis-diesis-diesis''''', c-diesis'''''', e-bemolle-bemolle-bemolle'''''', h-diesis-diesis''''',c-diesis-diesis'''''', e-bemolle-bemolle'''''', f-bemolle-bemolle-bemolle'''''', h-diesis-diesis-diesis''''',c-diesis-diesis-diesis'''''', d-diesis'''''', f-bemolle-bemolle'''''', g-bemolle-bemolle-bemolle-bemolle'''''',d-diesis-diesis'''''', f-bemolle'''''', g-bemolle-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle-bemolle'''''', d-diesis-diesis-diesis'''''', e-diesis'''''', g-bemolle-bemolle'''''',a-bemolle-bemolle-bemolle'''''', e-diesis-diesis'''''', f-diesis'''''',a-bemolle-bemolle'''''', b-bemolle-bemolle-bemolle'''''', e-diesis-diesis-diesis'''''', f-diesis-diesis''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus_n:\n"
			+ "Aisisis-6, Bisis-6, Deses-5, His-6,Bisisis-6, Des-5, Eseses-5, Hisis-6,Cisis-5, Eses-5, Feseses-5, Hisisis-6,Cisisis-5, Es-5, Feses-5,Cisisisis-5, Disis-5, Fes-5, Geseses-5,Disisis-5, Eis-5, Geses-5,Aseses-5, Disisisis-5, Eisis-5, Ges-5,Ases-5, Beseses-5, Eisisis-5, Fisis-5,As-5, Beses-5, Fisisis-5,Bes-5, Ceseses-4, Fisisisis-5, Gisis-5,Ais-5, Ceses-4, Gisisis-5,Aisis-5, Bis-5, Ces-4, Deseses-4, Gisisisis-5,Aisisis-5, Bisis-5, Deses-4, His-5,Bisisis-5, Des-4, Eseses-4, Hisis-5,Cisis-4, Eses-4, Feseses-4, Hisisis-5,Cisisis-4, Es-4, Feses-4,Cisisisis-4, Disis-4, Fes-4, Geseses-4,Disisis-4, Eis-4, Geses-4,Aseses-4, Disisisis-4, Eisis-4, Ges-4,Ases-4, Beseses-4, Eisisis-4, Fisis-4,As-4, Beses-4, Fisisis-4,Bes-4, Ceseses-3, Fisisisis-4, Gisis-4,Ais-4, Ceses-3, Gisisis-4,Aisis-4, Bis-4, Ces-3, Deseses-3, Gisisisis-4,Aisisis-4, Bisis-4, Deses-3, His-4,Bisisis-4, Des-3, Eseses-3, Hisis-4,Cisis-3, Eses-3, Feseses-3, Hisisis-4,Cisisis-3, Es-3, Feses-3,Cisisisis-3, Disis-3, Fes-3, Geseses-3,Disisis-3, Eis-3, Geses-3,Aseses-3, Disisisis-3, Eisis-3, Ges-3,Ases-3, Beseses-3, Eisisis-3, Fisis-3,As-3, Beses-3, Fisisis-3,Bes-3, Ceseses-2, Fisisisis-3, Gisis-3,Ais-3, Ceses-2, Gisisis-3,Aisis-3, Bis-3, Ces-2, Deseses-2, Gisisisis-3,Aisisis-3, Bisis-3, Deses-2, His-3,Bisisis-3, Des-2, Eseses-2, Hisis-3,Cisis-2, Eses-2, Feseses-2, Hisisis-3,Cisisis-2, Es-2, Feses-2,Cisisisis-2, Disis-2, Fes-2, Geseses-2,Disisis-2, Eis-2, Geses-2,Aseses-2, Disisisis-2, Eisis-2, Ges-2,Ases-2, Beseses-2, Eisisis-2, Fisis-2,As-2, Beses-2, Fisisis-2,Bes-2, Ceseses-, Fisisisis-2, Gisis-2,Ais-2, Ceses-, Gisisis-2,Aisis-2, Bis-2, Ces-, Deseses-, Gisisisis-2,Aisisis-2, Bisis-2, Deses-, His-2,Bisisis-2, Des-, Eseses-, Hisis-2,Cisis-, Eses-, Feseses-, Hisisis-2,Cisisis-, Es-, Feses-,Cisisisis-, Disis-, Fes-, Geseses-,Disisis-, Eis-, Geses-,Aseses-, Disisisis-, Eisis-, Ges-,Ases-, Beseses-, Eisisis-, Fisis-,As-, Beses-, Fisisis-,Bes-, Ceseses, Fisisisis-, Gisis-,Ais-, Ceses, Gisisis-,Aisis-, Bis-, Ces, Deseses, Gisisisis-,Aisisis-, Bisis-, Deses, His-,Bisisis-, Des, Eseses, Hisis-,Cisis, Eses, Feseses, Hisisis-,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Beseses, Eisisis, Fisis,As, Beses, Fisisis,Bes, Ceseses+, Fisisisis, Gisis,Ais, Ceses+, Gisisis,Aisis, Bis, Ces+, Deseses+, Gisisisis,Aisisis, Bisis, Deses+, His,Bisisis, Des+, Eseses+, Hisis,Cisis+, Eses+, Feseses+, Hisisis,Cisisis+, Es+, Feses+,Cisisisis+, Disis+, Fes+, Geseses+,Disisis+, Eis+, Geses+,Aseses+, Disisisis+, Eisis+, Ges+,Ases+, Beseses+, Eisisis+, Fisis+,As+, Beses+, Fisisis+,Bes+, Ceseses+2, Fisisisis+, Gisis+,Ais+, Ceses+2, Gisisis+,Aisis+, Bis+, Ces+2, Deseses+2, Gisisisis+,Aisisis+, Bisis+, Deses+2, His+,Bisisis+, Des+2, Eseses+2, Hisis+,Cisis+2, Eses+2, Feseses+2, Hisisis+,Cisisis+2, Es+2, Feses+2,Cisisisis+2, Disis+2, Fes+2, Geseses+2,Disisis+2, Eis+2, Geses+2,Aseses+2, Disisisis+2, Eisis+2, Ges+2,Ases+2, Beseses+2, Eisisis+2, Fisis+2,As+2, Beses+2, Fisisis+2,Bes+2, Ceseses+3, Fisisisis+2, Gisis+2,Ais+2, Ceses+3, Gisisis+2,Aisis+2, Bis+2, Ces+3, Deseses+3, Gisisisis+2,Aisisis+2, Bisis+2, Deses+3, His+2,Bisisis+2, Des+3, Eseses+3, Hisis+2,Cisis+3, Eses+3, Feseses+3, Hisisis+2,Cisisis+3, Es+3, Feses+3,Cisisisis+3, Disis+3, Fes+3, Geseses+3,Disisis+3, Eis+3, Geses+3,Aseses+3, Disisisis+3, Eisis+3, Ges+3,Ases+3, Beseses+3, Eisisis+3, Fisis+3,As+3, Beses+3, Fisisis+3,Bes+3, Ceseses+4, Fisisisis+3, Gisis+3,Ais+3, Ceses+4, Gisisis+3,Aisis+3, Bis+3, Ces+4, Deseses+4, Gisisisis+3,Aisisis+3, Bisis+3, Deses+4, His+3,Bisisis+3, Des+4, Eseses+4, Hisis+3,Cisis+4, Eses+4, Feseses+4, Hisisis+3,Cisisis+4, Es+4, Feses+4,Cisisisis+4, Disis+4, Fes+4, Geseses+4,Disisis+4, Eis+4, Geses+4,Aseses+4, Disisisis+4, Eisis+4, Ges+4,Ases+4, Beseses+4, Eisisis+4, Fisis+4,As+4, Beses+4, Fisisis+4,Bes+4, Ceseses+5, Fisisisis+4, Gisis+4,Ais+4, Ceses+5, Gisisis+4,Aisis+4, Bis+4, Ces+5, Deseses+5, Gisisisis+4,Aisisis+4, Bisis+4, Deses+5, His+4,Bisisis+4, Des+5, Eseses+5, Hisis+4,Cisis+5, Eses+5, Feseses+5, Hisisis+4,Cisisis+5, Es+5, Feses+5,Cisisisis+5, Disis+5, Fes+5, Geseses+5,Disisis+5, Eis+5, Geses+5,Aseses+5, Disisisis+5, Eisis+5, Ges+5,Ases+5, Beseses+5, Eisisis+5, Fisis+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_plus_minus:\n"
			+ "Aisisis------, Bisis------, Deses-----, His------,Bisisis------, Des-----, Eseses-----, Hisis------,Cisis-----, Eses-----, Feseses-----, Hisisis------,Cisisis-----, Es-----, Feses-----,Cisisisis-----, Disis-----, Fes-----, Geseses-----,Disisis-----, Eis-----, Geses-----,Aseses-----, Disisisis-----, Eisis-----, Ges-----,Ases-----, Beseses-----, Eisisis-----, Fisis-----,As-----, Beses-----, Fisisis-----,Bes-----, Ceseses----, Fisisisis-----, Gisis-----,Ais-----, Ceses----, Gisisis-----,Aisis-----, Bis-----, Ces----, Deseses----, Gisisisis-----,Aisisis-----, Bisis-----, Deses----, His-----,Bisisis-----, Des----, Eseses----, Hisis-----,Cisis----, Eses----, Feseses----, Hisisis-----,Cisisis----, Es----, Feses----,Cisisisis----, Disis----, Fes----, Geseses----,Disisis----, Eis----, Geses----,Aseses----, Disisisis----, Eisis----, Ges----,Ases----, Beseses----, Eisisis----, Fisis----,As----, Beses----, Fisisis----,Bes----, Ceseses---, Fisisisis----, Gisis----,Ais----, Ceses---, Gisisis----,Aisis----, Bis----, Ces---, Deseses---, Gisisisis----,Aisisis----, Bisis----, Deses---, His----,Bisisis----, Des---, Eseses---, Hisis----,Cisis---, Eses---, Feseses---, Hisisis----,Cisisis---, Es---, Feses---,Cisisisis---, Disis---, Fes---, Geseses---,Disisis---, Eis---, Geses---,Aseses---, Disisisis---, Eisis---, Ges---,Ases---, Beseses---, Eisisis---, Fisis---,As---, Beses---, Fisisis---,Bes---, Ceseses--, Fisisisis---, Gisis---,Ais---, Ceses--, Gisisis---,Aisis---, Bis---, Ces--, Deseses--, Gisisisis---,Aisisis---, Bisis---, Deses--, His---,Bisisis---, Des--, Eseses--, Hisis---,Cisis--, Eses--, Feseses--, Hisisis---,Cisisis--, Es--, Feses--,Cisisisis--, Disis--, Fes--, Geseses--,Disisis--, Eis--, Geses--,Aseses--, Disisisis--, Eisis--, Ges--,Ases--, Beseses--, Eisisis--, Fisis--,As--, Beses--, Fisisis--,Bes--, Ceseses-, Fisisisis--, Gisis--,Ais--, Ceses-, Gisisis--,Aisis--, Bis--, Ces-, Deseses-, Gisisisis--,Aisisis--, Bisis--, Deses-, His--,Bisisis--, Des-, Eseses-, Hisis--,Cisis-, Eses-, Feseses-, Hisisis--,Cisisis-, Es-, Feses-,Cisisisis-, Disis-, Fes-, Geseses-,Disisis-, Eis-, Geses-,Aseses-, Disisisis-, Eisis-, Ges-,Ases-, Beseses-, Eisisis-, Fisis-,As-, Beses-, Fisisis-,Bes-, Ceseses, Fisisisis-, Gisis-,Ais-, Ceses, Gisisis-,Aisis-, Bis-, Ces, Deseses, Gisisisis-,Aisisis-, Bisis-, Deses, His-,Bisisis-, Des, Eseses, Hisis-,Cisis, Eses, Feseses, Hisisis-,Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Beseses, Eisisis, Fisis,As, Beses, Fisisis,Bes, Ceseses+, Fisisisis, Gisis,Ais, Ceses+, Gisisis,Aisis, Bis, Ces+, Deseses+, Gisisisis,Aisisis, Bisis, Deses+, His,Bisisis, Des+, Eseses+, Hisis,Cisis+, Eses+, Feseses+, Hisisis,Cisisis+, Es+, Feses+,Cisisisis+, Disis+, Fes+, Geseses+,Disisis+, Eis+, Geses+,Aseses+, Disisisis+, Eisis+, Ges+,Ases+, Beseses+, Eisisis+, Fisis+,As+, Beses+, Fisisis+,Bes+, Ceseses++, Fisisisis+, Gisis+,Ais+, Ceses++, Gisisis+,Aisis+, Bis+, Ces++, Deseses++, Gisisisis+,Aisisis+, Bisis+, Deses++, His+,Bisisis+, Des++, Eseses++, Hisis+,Cisis++, Eses++, Feseses++, Hisisis+,Cisisis++, Es++, Feses++,Cisisisis++, Disis++, Fes++, Geseses++,Disisis++, Eis++, Geses++,Aseses++, Disisisis++, Eisis++, Ges++,Ases++, Beseses++, Eisisis++, Fisis++,As++, Beses++, Fisisis++,Bes++, Ceseses+++, Fisisisis++, Gisis++,Ais++, Ceses+++, Gisisis++,Aisis++, Bis++, Ces+++, Deseses+++, Gisisisis++,Aisisis++, Bisis++, Deses+++, His++,Bisisis++, Des+++, Eseses+++, Hisis++,Cisis+++, Eses+++, Feseses+++, Hisisis++,Cisisis+++, Es+++, Feses+++,Cisisisis+++, Disis+++, Fes+++, Geseses+++,Disisis+++, Eis+++, Geses+++,Aseses+++, Disisisis+++, Eisis+++, Ges+++,Ases+++, Beseses+++, Eisisis+++, Fisis+++,As+++, Beses+++, Fisisis+++,Bes+++, Ceseses++++, Fisisisis+++, Gisis+++,Ais+++, Ceses++++, Gisisis+++,Aisis+++, Bis+++, Ces++++, Deseses++++, Gisisisis+++,Aisisis+++, Bisis+++, Deses++++, His+++,Bisisis+++, Des++++, Eseses++++, Hisis+++,Cisis++++, Eses++++, Feseses++++, Hisisis+++,Cisisis++++, Es++++, Feses++++,Cisisisis++++, Disis++++, Fes++++, Geseses++++,Disisis++++, Eis++++, Geses++++,Aseses++++, Disisisis++++, Eisis++++, Ges++++,Ases++++, Beseses++++, Eisisis++++, Fisis++++,As++++, Beses++++, Fisisis++++,Bes++++, Ceseses+++++, Fisisisis++++, Gisis++++,Ais++++, Ceses+++++, Gisisis++++,Aisis++++, Bis++++, Ces+++++, Deseses+++++, Gisisisis++++,Aisisis++++, Bisis++++, Deses+++++, His++++,Bisisis++++, Des+++++, Eseses+++++, Hisis++++,Cisis+++++, Eses+++++, Feseses+++++, Hisisis++++,Cisisis+++++, Es+++++, Feses+++++,Cisisisis+++++, Disis+++++, Fes+++++, Geseses+++++,Disisis+++++, Eis+++++, Geses+++++,Aseses+++++, Disisisis+++++, Eisis+++++, Ges+++++,Ases+++++, Beseses+++++, Eisisis+++++, Fisis+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_international:\n"
			+ "Aisisis-2, Bisis-2, Deses-1, His-2,Bisisis-2, Des-1, Eseses-1, Hisis-2,Cisis-1, Eses-1, Feseses-1, Hisisis-2,Cisisis-1, Es-1, Feses-1,Cisisisis-1, Disis-1, Fes-1, Geseses-1,Disisis-1, Eis-1, Geses-1,Aseses-1, Disisisis-1, Eisis-1, Ges-1,Ases-1, Beseses-1, Eisisis-1, Fisis-1,As-1, Beses-1, Fisisis-1,Bes-1, Ceseses0, Fisisisis-1, Gisis-1,Ais-1, Ceses0, Gisisis-1,Aisis-1, Bis-1, Ces0, Deseses0, Gisisisis-1,Aisisis-1, Bisis-1, Deses0, His-1,Bisisis-1, Des0, Eseses0, Hisis-1,Cisis0, Eses0, Feseses0, Hisisis-1,Cisisis0, Es0, Feses0,Cisisisis0, Disis0, Fes0, Geseses0,Disisis0, Eis0, Geses0,Aseses0, Disisisis0, Eisis0, Ges0,Ases0, Beseses0, Eisisis0, Fisis0,As0, Beses0, Fisisis0,Bes0, Ceseses1, Fisisisis0, Gisis0,Ais0, Ceses1, Gisisis0,Aisis0, Bis0, Ces1, Deseses1, Gisisisis0,Aisisis0, Bisis0, Deses1, His0,Bisisis0, Des1, Eseses1, Hisis0,Cisis1, Eses1, Feseses1, Hisisis0,Cisisis1, Es1, Feses1,Cisisisis1, Disis1, Fes1, Geseses1,Disisis1, Eis1, Geses1,Aseses1, Disisisis1, Eisis1, Ges1,Ases1, Beseses1, Eisisis1, Fisis1,As1, Beses1, Fisisis1,Bes1, Ceseses2, Fisisisis1, Gisis1,Ais1, Ceses2, Gisisis1,Aisis1, Bis1, Ces2, Deseses2, Gisisisis1,Aisisis1, Bisis1, Deses2, His1,Bisisis1, Des2, Eseses2, Hisis1,Cisis2, Eses2, Feseses2, Hisisis1,Cisisis2, Es2, Feses2,Cisisisis2, Disis2, Fes2, Geseses2,Disisis2, Eis2, Geses2,Aseses2, Disisisis2, Eisis2, Ges2,Ases2, Beseses2, Eisisis2, Fisis2,As2, Beses2, Fisisis2,Bes2, Ceseses3, Fisisisis2, Gisis2,Ais2, Ceses3, Gisisis2,Aisis2, Bis2, Ces3, Deseses3, Gisisisis2,Aisisis2, Bisis2, Deses3, His2,Bisisis2, Des3, Eseses3, Hisis2,Cisis3, Eses3, Feseses3, Hisisis2,Cisisis3, Es3, Feses3,Cisisisis3, Disis3, Fes3, Geseses3,Disisis3, Eis3, Geses3,Aseses3, Disisisis3, Eisis3, Ges3,Ases3, Beseses3, Eisisis3, Fisis3,As3, Beses3, Fisisis3,Bes3, Ceseses4, Fisisisis3, Gisis3,Ais3, Ceses4, Gisisis3,Aisis3, Bis3, Ces4, Deseses4, Gisisisis3,Aisisis3, Bisis3, Deses4, His3,Bisisis3, Des4, Eseses4, Hisis3,Cisis4, Eses4, Feseses4, Hisisis3,Cisisis4, Es4, Feses4,Cisisisis4, Disis4, Fes4, Geseses4,Disisis4, Eis4, Geses4,Aseses4, Disisisis4, Eisis4, Ges4,Ases4, Beseses4, Eisisis4, Fisis4,As4, Beses4, Fisisis4,Bes4, Ceseses5, Fisisisis4, Gisis4,Ais4, Ceses5, Gisisis4,Aisis4, Bis4, Ces5, Deseses5, Gisisisis4,Aisisis4, Bisis4, Deses5, His4,Bisisis4, Des5, Eseses5, Hisis4,Cisis5, Eses5, Feseses5, Hisisis4,Cisisis5, Es5, Feses5,Cisisisis5, Disis5, Fes5, Geseses5,Disisis5, Eis5, Geses5,Aseses5, Disisisis5, Eisis5, Ges5,Ases5, Beseses5, Eisisis5, Fisis5,As5, Beses5, Fisisis5,Bes5, Ceseses6, Fisisisis5, Gisis5,Ais5, Ceses6, Gisisis5,Aisis5, Bis5, Ces6, Deseses6, Gisisisis5,Aisisis5, Bisis5, Deses6, His5,Bisisis5, Des6, Eseses6, Hisis5,Cisis6, Eses6, Feseses6, Hisisis5,Cisisis6, Es6, Feses6,Cisisisis6, Disis6, Fes6, Geseses6,Disisis6, Eis6, Geses6,Aseses6, Disisisis6, Eisis6, Ges6,Ases6, Beseses6, Eisisis6, Fisis6,As6, Beses6, Fisisis6,Bes6, Ceseses7, Fisisisis6, Gisis6,Ais6, Ceses7, Gisisis6,Aisis6, Bis6, Ces7, Deseses7, Gisisisis6,Aisisis6, Bisis6, Deses7, His6,Bisisis6, Des7, Eseses7, Hisis6,Cisis7, Eses7, Feseses7, Hisisis6,Cisisis7, Es7, Feses7,Cisisisis7, Disis7, Fes7, Geseses7,Disisis7, Eis7, Geses7,Aseses7, Disisisis7, Eisis7, Ges7,Ases7, Beseses7, Eisisis7, Fisis7,As7, Beses7, Fisisis7,Bes7, Ceseses8, Fisisisis7, Gisis7,Ais7, Ceses8, Gisisis7,Aisis7, Bis7, Ces8, Deseses8, Gisisisis7,Aisisis7, Bisis7, Deses8, His7,Bisisis7, Des8, Eseses8, Hisis7,Cisis8, Eses8, Feseses8, Hisisis7,Cisisis8, Es8, Feses8,Cisisisis8, Disis8, Fes8, Geseses8,Disisis8, Eis8, Geses8,Aseses8, Disisisis8, Eisis8, Ges8,Ases8, Beseses8, Eisisis8, Fisis8,As8, Beses8, Fisisis8,Bes8, Ceseses9, Fisisisis8, Gisis8,Ais8, Ceses9, Gisisis8,Aisis8, Bis8, Ces9, Deseses9, Gisisisis8,Aisisis8, Bisis8, Deses9, His8,Bisisis8, Des9, Eseses9, Hisis8,Cisis9, Eses9, Feseses9, Hisisis8,Cisisis9, Es9, Feses9,Cisisisis9, Disis9, Fes9, Geseses9,Disisis9, Eis9, Geses9,Aseses9, Disisisis9, Eisis9, Ges9,Ases9, Beseses9, Eisisis9, Fisis9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_sharp/cbx_octave_german:\n"
			+ "Aisisis'''', Bisis'''', Deses''', His'''',Bisisis'''', Des''', Eseses''', Hisis'''',Cisis''', Eses''', Feseses''', Hisisis'''',Cisisis''', Es''', Feses''',Cisisisis''', Disis''', Fes''', Geseses''',Disisis''', Eis''', Geses''',Aseses''', Disisisis''', Eisis''', Ges''',Ases''', Beseses''', Eisisis''', Fisis''',As''', Beses''', Fisisis''',Bes''', Ceseses'', Fisisisis''', Gisis''',Ais''', Ceses'', Gisisis''',Aisis''', Bis''', Ces'', Deseses'', Gisisisis''',Aisisis''', Bisis''', Deses'', His''',Bisisis''', Des'', Eseses'', Hisis''',Cisis'', Eses'', Feseses'', Hisisis''',Cisisis'', Es'', Feses'',Cisisisis'', Disis'', Fes'', Geseses'',Disisis'', Eis'', Geses'',Aseses'', Disisisis'', Eisis'', Ges'',Ases'', Beseses'', Eisisis'', Fisis'',As'', Beses'', Fisisis'',Bes'', Ceseses', Fisisisis'', Gisis'',Ais'', Ceses', Gisisis'',Aisis'', Bis'', Ces', Deseses', Gisisisis'',Aisisis'', Bisis'', Deses', His'',Bisisis'', Des', Eseses', Hisis'',Cisis', Eses', Feseses', Hisisis'',Cisisis', Es', Feses',Cisisisis', Disis', Fes', Geseses',Disisis', Eis', Geses',Aseses', Disisisis', Eisis', Ges',Ases', Beseses', Eisisis', Fisis',As', Beses', Fisisis',Bes', Ceseses, Fisisisis', Gisis',Ais', Ceses, Gisisis',Aisis', Bis', Ces, Deseses, Gisisisis',Aisisis', Bisis', Deses, His',Bisisis', Des, Eseses, Hisis',Cisis, Eses, Feseses, Hisisis',Cisisis, Es, Feses,Cisisisis, Disis, Fes, Geseses,Disisis, Eis, Geses,Aseses, Disisisis, Eisis, Ges,Ases, Beseses, Eisisis, Fisis,As, Beses, Fisisis,Bes, Fisisisis, Gisis, ceseses,Ais, Gisisis, ceses,Aisis, Bis, Gisisisis, ces, deseses,Aisisis, Bisis, His, deses,Bisisis, Hisis, des, eseses,Hisisis, cisis, eses, feseses,cisisis, es, feses,cisisisis, disis, fes, geseses,disisis, eis, geses,aseses, disisisis, eisis, ges,ases, beseses, eisisis, fisis,as, beses, fisisis,bes, ceseses', fisisisis, gisis,ais, ceses', gisisis,aisis, bis, ces', deseses', gisisisis,aisisis, bisis, deses', his,bisisis, des', eseses', hisis,cisis', eses', feseses', hisisis,cisisis', es', feses',cisisisis', disis', fes', geseses',disisis', eis', geses',aseses', disisisis', eisis', ges',ases', beseses', eisisis', fisis',as', beses', fisisis',bes', ceseses'', fisisisis', gisis',ais', ceses'', gisisis',aisis', bis', ces'', deseses'', gisisisis',aisisis', bisis', deses'', his',bisisis', des'', eseses'', hisis',cisis'', eses'', feseses'', hisisis',cisisis'', es'', feses'',cisisisis'', disis'', fes'', geseses'',disisis'', eis'', geses'',aseses'', disisisis'', eisis'', ges'',ases'', beseses'', eisisis'', fisis'',as'', beses'', fisisis'',bes'', ceseses''', fisisisis'', gisis'',ais'', ceses''', gisisis'',aisis'', bis'', ces''', deseses''', gisisisis'',aisisis'', bisis'', deses''', his'',bisisis'', des''', eseses''', hisis'',cisis''', eses''', feseses''', hisisis'',cisisis''', es''', feses''',cisisisis''', disis''', fes''', geseses''',disisis''', eis''', geses''',aseses''', disisisis''', eisis''', ges''',ases''', beseses''', eisisis''', fisis''',as''', beses''', fisisis''',bes''', ceseses'''', fisisisis''', gisis''',ais''', ceses'''', gisisis''',aisis''', bis''', ces'''', deseses'''', gisisisis''',aisisis''', bisis''', deses'''', his''',bisisis''', des'''', eseses'''', hisis''',cisis'''', eses'''', feseses'''', hisisis''',cisisis'''', es'''', feses'''',cisisisis'''', disis'''', fes'''', geseses'''',disisis'''', eis'''', geses'''',aseses'''', disisisis'''', eisis'''', ges'''',ases'''', beseses'''', eisisis'''', fisis'''',as'''', beses'''', fisisis'''',bes'''', ceseses''''', fisisisis'''', gisis'''',ais'''', ceses''''', gisisis'''',aisis'''', bis'''', ces''''', deseses''''', gisisisis'''',aisisis'''', bisis'''', deses''''', his'''',bisisis'''', des''''', eseses''''', hisis'''',cisis''''', eses''''', feseses''''', hisisis'''',cisisis''''', es''''', feses''''',cisisisis''''', disis''''', fes''''', geseses''''',disisis''''', eis''''', geses''''',aseses''''', disisisis''''', eisis''''', ges''''',ases''''', beseses''''', eisisis''''', fisis''''',as''''', beses''''', fisisis''''',bes''''', ceseses'''''', fisisisis''''', gisis''''',ais''''', ceses'''''', gisisis''''',aisis''''', bis''''', ces'''''', deseses'''''', gisisisis''''',aisisis''''', bisis''''', deses'''''', his''''',bisisis''''', des'''''', eseses'''''', hisis''''',cisis'''''', eses'''''', feseses'''''', hisisis''''',cisisis'''''', es'''''', feses'''''',cisisisis'''''', disis'''''', fes'''''', geseses'''''',disisis'''''', eis'''''', geses'''''',aseses'''''', disisisis'''''', eisis'''''', ges'''''',ases'''''', beseses'''''', eisisis'''''', fisis''''''\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus_n:\n"
			+ "Aisisis-6, Bisis-6, Deses-5, Eseseses-5, His-6,Bisisis-6, Cis-5, Eseses-5, Hisis-6,Cisis-5, Eses-5, Feseses-5, Hisisis-6,Cisisis-5, Dis-5, Feses-5, Geseseses-5,Disis-5, Fes-5, Geseses-5,Aseseses-5, Disisis-5, Eis-5, Geses-5,Aseses-5, Eisis-5, Fis-5,Ases-5, Beseses-5, Eisisis-5, Fisis-5,Beses-5, Fisisis-5, Gis-5,Bes-5, Ceseses-4, Gisis-5,Ais-5, Ceses-4, Deseseses-4, Gisisis-5,Aisis-5, Bis-5, Ces-4, Deseses-4,Aisisis-5, Bisis-5, Deses-4, Eseseses-4, His-5,Bisisis-5, Cis-4, Eseses-4, Hisis-5,Cisis-4, Eses-4, Feseses-4, Hisisis-5,Cisisis-4, Dis-4, Feses-4, Geseseses-4,Disis-4, Fes-4, Geseses-4,Aseseses-4, Disisis-4, Eis-4, Geses-4,Aseses-4, Eisis-4, Fis-4,Ases-4, Beseses-4, Eisisis-4, Fisis-4,Beses-4, Fisisis-4, Gis-4,Bes-4, Ceseses-3, Gisis-4,Ais-4, Ceses-3, Deseseses-3, Gisisis-4,Aisis-4, Bis-4, Ces-3, Deseses-3,Aisisis-4, Bisis-4, Deses-3, Eseseses-3, His-4,Bisisis-4, Cis-3, Eseses-3, Hisis-4,Cisis-3, Eses-3, Feseses-3, Hisisis-4,Cisisis-3, Dis-3, Feses-3, Geseseses-3,Disis-3, Fes-3, Geseses-3,Aseseses-3, Disisis-3, Eis-3, Geses-3,Aseses-3, Eisis-3, Fis-3,Ases-3, Beseses-3, Eisisis-3, Fisis-3,Beses-3, Fisisis-3, Gis-3,Bes-3, Ceseses-2, Gisis-3,Ais-3, Ceses-2, Deseseses-2, Gisisis-3,Aisis-3, Bis-3, Ces-2, Deseses-2,Aisisis-3, Bisis-3, Deses-2, Eseseses-2, His-3,Bisisis-3, Cis-2, Eseses-2, Hisis-3,Cisis-2, Eses-2, Feseses-2, Hisisis-3,Cisisis-2, Dis-2, Feses-2, Geseseses-2,Disis-2, Fes-2, Geseses-2,Aseseses-2, Disisis-2, Eis-2, Geses-2,Aseses-2, Eisis-2, Fis-2,Ases-2, Beseses-2, Eisisis-2, Fisis-2,Beses-2, Fisisis-2, Gis-2,Bes-2, Ceseses-, Gisis-2,Ais-2, Ceses-, Deseseses-, Gisisis-2,Aisis-2, Bis-2, Ces-, Deseses-,Aisisis-2, Bisis-2, Deses-, Eseseses-, His-2,Bisisis-2, Cis-, Eseses-, Hisis-2,Cisis-, Eses-, Feseses-, Hisisis-2,Cisisis-, Dis-, Feses-, Geseseses-,Disis-, Fes-, Geseses-,Aseseses-, Disisis-, Eis-, Geses-,Aseses-, Eisis-, Fis-,Ases-, Beseses-, Eisisis-, Fisis-,Beses-, Fisisis-, Gis-,Bes-, Ceseses, Gisis-,Ais-, Ceses, Deseseses, Gisisis-,Aisis-, Bis-, Ces, Deseses,Aisisis-, Bisis-, Deses, Eseseses, His-,Bisisis-, Cis, Eseses, Hisis-,Cisis, Eses, Feseses, Hisisis-,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseses, Eisisis, Fisis,Beses, Fisisis, Gis,Bes, Ceseses+, Gisis,Ais, Ceses+, Deseseses+, Gisisis,Aisis, Bis, Ces+, Deseses+,Aisisis, Bisis, Deses+, Eseseses+, His,Bisisis, Cis+, Eseses+, Hisis,Cisis+, Eses+, Feseses+, Hisisis,Cisisis+, Dis+, Feses+, Geseseses+,Disis+, Fes+, Geseses+,Aseseses+, Disisis+, Eis+, Geses+,Aseses+, Eisis+, Fis+,Ases+, Beseses+, Eisisis+, Fisis+,Beses+, Fisisis+, Gis+,Bes+, Ceseses+2, Gisis+,Ais+, Ceses+2, Deseseses+2, Gisisis+,Aisis+, Bis+, Ces+2, Deseses+2,Aisisis+, Bisis+, Deses+2, Eseseses+2, His+,Bisisis+, Cis+2, Eseses+2, Hisis+,Cisis+2, Eses+2, Feseses+2, Hisisis+,Cisisis+2, Dis+2, Feses+2, Geseseses+2,Disis+2, Fes+2, Geseses+2,Aseseses+2, Disisis+2, Eis+2, Geses+2,Aseses+2, Eisis+2, Fis+2,Ases+2, Beseses+2, Eisisis+2, Fisis+2,Beses+2, Fisisis+2, Gis+2,Bes+2, Ceseses+3, Gisis+2,Ais+2, Ceses+3, Deseseses+3, Gisisis+2,Aisis+2, Bis+2, Ces+3, Deseses+3,Aisisis+2, Bisis+2, Deses+3, Eseseses+3, His+2,Bisisis+2, Cis+3, Eseses+3, Hisis+2,Cisis+3, Eses+3, Feseses+3, Hisisis+2,Cisisis+3, Dis+3, Feses+3, Geseseses+3,Disis+3, Fes+3, Geseses+3,Aseseses+3, Disisis+3, Eis+3, Geses+3,Aseses+3, Eisis+3, Fis+3,Ases+3, Beseses+3, Eisisis+3, Fisis+3,Beses+3, Fisisis+3, Gis+3,Bes+3, Ceseses+4, Gisis+3,Ais+3, Ceses+4, Deseseses+4, Gisisis+3,Aisis+3, Bis+3, Ces+4, Deseses+4,Aisisis+3, Bisis+3, Deses+4, Eseseses+4, His+3,Bisisis+3, Cis+4, Eseses+4, Hisis+3,Cisis+4, Eses+4, Feseses+4, Hisisis+3,Cisisis+4, Dis+4, Feses+4, Geseseses+4,Disis+4, Fes+4, Geseses+4,Aseseses+4, Disisis+4, Eis+4, Geses+4,Aseses+4, Eisis+4, Fis+4,Ases+4, Beseses+4, Eisisis+4, Fisis+4,Beses+4, Fisisis+4, Gis+4,Bes+4, Ceseses+5, Gisis+4,Ais+4, Ceses+5, Deseseses+5, Gisisis+4,Aisis+4, Bis+4, Ces+5, Deseses+5,Aisisis+4, Bisis+4, Deses+5, Eseseses+5, His+4,Bisisis+4, Cis+5, Eseses+5, Hisis+4,Cisis+5, Eses+5, Feseses+5, Hisisis+4,Cisisis+5, Dis+5, Feses+5, Geseseses+5,Disis+5, Fes+5, Geseses+5,Aseseses+5, Disisis+5, Eis+5, Geses+5,Aseses+5, Eisis+5, Fis+5,Ases+5, Beseses+5, Eisisis+5, Fisis+5\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_plus_minus:\n"
			+ "Aisisis------, Bisis------, Deses-----, Eseseses-----, His------,Bisisis------, Cis-----, Eseses-----, Hisis------,Cisis-----, Eses-----, Feseses-----, Hisisis------,Cisisis-----, Dis-----, Feses-----, Geseseses-----,Disis-----, Fes-----, Geseses-----,Aseseses-----, Disisis-----, Eis-----, Geses-----,Aseses-----, Eisis-----, Fis-----,Ases-----, Beseses-----, Eisisis-----, Fisis-----,Beses-----, Fisisis-----, Gis-----,Bes-----, Ceseses----, Gisis-----,Ais-----, Ceses----, Deseseses----, Gisisis-----,Aisis-----, Bis-----, Ces----, Deseses----,Aisisis-----, Bisis-----, Deses----, Eseseses----, His-----,Bisisis-----, Cis----, Eseses----, Hisis-----,Cisis----, Eses----, Feseses----, Hisisis-----,Cisisis----, Dis----, Feses----, Geseseses----,Disis----, Fes----, Geseses----,Aseseses----, Disisis----, Eis----, Geses----,Aseses----, Eisis----, Fis----,Ases----, Beseses----, Eisisis----, Fisis----,Beses----, Fisisis----, Gis----,Bes----, Ceseses---, Gisis----,Ais----, Ceses---, Deseseses---, Gisisis----,Aisis----, Bis----, Ces---, Deseses---,Aisisis----, Bisis----, Deses---, Eseseses---, His----,Bisisis----, Cis---, Eseses---, Hisis----,Cisis---, Eses---, Feseses---, Hisisis----,Cisisis---, Dis---, Feses---, Geseseses---,Disis---, Fes---, Geseses---,Aseseses---, Disisis---, Eis---, Geses---,Aseses---, Eisis---, Fis---,Ases---, Beseses---, Eisisis---, Fisis---,Beses---, Fisisis---, Gis---,Bes---, Ceseses--, Gisis---,Ais---, Ceses--, Deseseses--, Gisisis---,Aisis---, Bis---, Ces--, Deseses--,Aisisis---, Bisis---, Deses--, Eseseses--, His---,Bisisis---, Cis--, Eseses--, Hisis---,Cisis--, Eses--, Feseses--, Hisisis---,Cisisis--, Dis--, Feses--, Geseseses--,Disis--, Fes--, Geseses--,Aseseses--, Disisis--, Eis--, Geses--,Aseses--, Eisis--, Fis--,Ases--, Beseses--, Eisisis--, Fisis--,Beses--, Fisisis--, Gis--,Bes--, Ceseses-, Gisis--,Ais--, Ceses-, Deseseses-, Gisisis--,Aisis--, Bis--, Ces-, Deseses-,Aisisis--, Bisis--, Deses-, Eseseses-, His--,Bisisis--, Cis-, Eseses-, Hisis--,Cisis-, Eses-, Feseses-, Hisisis--,Cisisis-, Dis-, Feses-, Geseseses-,Disis-, Fes-, Geseses-,Aseseses-, Disisis-, Eis-, Geses-,Aseses-, Eisis-, Fis-,Ases-, Beseses-, Eisisis-, Fisis-,Beses-, Fisisis-, Gis-,Bes-, Ceseses, Gisis-,Ais-, Ceses, Deseseses, Gisisis-,Aisis-, Bis-, Ces, Deseses,Aisisis-, Bisis-, Deses, Eseseses, His-,Bisisis-, Cis, Eseses, Hisis-,Cisis, Eses, Feseses, Hisisis-,Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseses, Eisisis, Fisis,Beses, Fisisis, Gis,Bes, Ceseses+, Gisis,Ais, Ceses+, Deseseses+, Gisisis,Aisis, Bis, Ces+, Deseses+,Aisisis, Bisis, Deses+, Eseseses+, His,Bisisis, Cis+, Eseses+, Hisis,Cisis+, Eses+, Feseses+, Hisisis,Cisisis+, Dis+, Feses+, Geseseses+,Disis+, Fes+, Geseses+,Aseseses+, Disisis+, Eis+, Geses+,Aseses+, Eisis+, Fis+,Ases+, Beseses+, Eisisis+, Fisis+,Beses+, Fisisis+, Gis+,Bes+, Ceseses++, Gisis+,Ais+, Ceses++, Deseseses++, Gisisis+,Aisis+, Bis+, Ces++, Deseses++,Aisisis+, Bisis+, Deses++, Eseseses++, His+,Bisisis+, Cis++, Eseses++, Hisis+,Cisis++, Eses++, Feseses++, Hisisis+,Cisisis++, Dis++, Feses++, Geseseses++,Disis++, Fes++, Geseses++,Aseseses++, Disisis++, Eis++, Geses++,Aseses++, Eisis++, Fis++,Ases++, Beseses++, Eisisis++, Fisis++,Beses++, Fisisis++, Gis++,Bes++, Ceseses+++, Gisis++,Ais++, Ceses+++, Deseseses+++, Gisisis++,Aisis++, Bis++, Ces+++, Deseses+++,Aisisis++, Bisis++, Deses+++, Eseseses+++, His++,Bisisis++, Cis+++, Eseses+++, Hisis++,Cisis+++, Eses+++, Feseses+++, Hisisis++,Cisisis+++, Dis+++, Feses+++, Geseseses+++,Disis+++, Fes+++, Geseses+++,Aseseses+++, Disisis+++, Eis+++, Geses+++,Aseses+++, Eisis+++, Fis+++,Ases+++, Beseses+++, Eisisis+++, Fisis+++,Beses+++, Fisisis+++, Gis+++,Bes+++, Ceseses++++, Gisis+++,Ais+++, Ceses++++, Deseseses++++, Gisisis+++,Aisis+++, Bis+++, Ces++++, Deseses++++,Aisisis+++, Bisis+++, Deses++++, Eseseses++++, His+++,Bisisis+++, Cis++++, Eseses++++, Hisis+++,Cisis++++, Eses++++, Feseses++++, Hisisis+++,Cisisis++++, Dis++++, Feses++++, Geseseses++++,Disis++++, Fes++++, Geseses++++,Aseseses++++, Disisis++++, Eis++++, Geses++++,Aseses++++, Eisis++++, Fis++++,Ases++++, Beseses++++, Eisisis++++, Fisis++++,Beses++++, Fisisis++++, Gis++++,Bes++++, Ceseses+++++, Gisis++++,Ais++++, Ceses+++++, Deseseses+++++, Gisisis++++,Aisis++++, Bis++++, Ces+++++, Deseses+++++,Aisisis++++, Bisis++++, Deses+++++, Eseseses+++++, His++++,Bisisis++++, Cis+++++, Eseses+++++, Hisis++++,Cisis+++++, Eses+++++, Feseses+++++, Hisisis++++,Cisisis+++++, Dis+++++, Feses+++++, Geseseses+++++,Disis+++++, Fes+++++, Geseses+++++,Aseseses+++++, Disisis+++++, Eis+++++, Geses+++++,Aseses+++++, Eisis+++++, Fis+++++,Ases+++++, Beseses+++++, Eisisis+++++, Fisis+++++\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_international:\n"
			+ "Aisisis-2, Bisis-2, Deses-1, Eseseses-1, His-2,Bisisis-2, Cis-1, Eseses-1, Hisis-2,Cisis-1, Eses-1, Feseses-1, Hisisis-2,Cisisis-1, Dis-1, Feses-1, Geseseses-1,Disis-1, Fes-1, Geseses-1,Aseseses-1, Disisis-1, Eis-1, Geses-1,Aseses-1, Eisis-1, Fis-1,Ases-1, Beseses-1, Eisisis-1, Fisis-1,Beses-1, Fisisis-1, Gis-1,Bes-1, Ceseses0, Gisis-1,Ais-1, Ceses0, Deseseses0, Gisisis-1,Aisis-1, Bis-1, Ces0, Deseses0,Aisisis-1, Bisis-1, Deses0, Eseseses0, His-1,Bisisis-1, Cis0, Eseses0, Hisis-1,Cisis0, Eses0, Feseses0, Hisisis-1,Cisisis0, Dis0, Feses0, Geseseses0,Disis0, Fes0, Geseses0,Aseseses0, Disisis0, Eis0, Geses0,Aseses0, Eisis0, Fis0,Ases0, Beseses0, Eisisis0, Fisis0,Beses0, Fisisis0, Gis0,Bes0, Ceseses1, Gisis0,Ais0, Ceses1, Deseseses1, Gisisis0,Aisis0, Bis0, Ces1, Deseses1,Aisisis0, Bisis0, Deses1, Eseseses1, His0,Bisisis0, Cis1, Eseses1, Hisis0,Cisis1, Eses1, Feseses1, Hisisis0,Cisisis1, Dis1, Feses1, Geseseses1,Disis1, Fes1, Geseses1,Aseseses1, Disisis1, Eis1, Geses1,Aseses1, Eisis1, Fis1,Ases1, Beseses1, Eisisis1, Fisis1,Beses1, Fisisis1, Gis1,Bes1, Ceseses2, Gisis1,Ais1, Ceses2, Deseseses2, Gisisis1,Aisis1, Bis1, Ces2, Deseses2,Aisisis1, Bisis1, Deses2, Eseseses2, His1,Bisisis1, Cis2, Eseses2, Hisis1,Cisis2, Eses2, Feseses2, Hisisis1,Cisisis2, Dis2, Feses2, Geseseses2,Disis2, Fes2, Geseses2,Aseseses2, Disisis2, Eis2, Geses2,Aseses2, Eisis2, Fis2,Ases2, Beseses2, Eisisis2, Fisis2,Beses2, Fisisis2, Gis2,Bes2, Ceseses3, Gisis2,Ais2, Ceses3, Deseseses3, Gisisis2,Aisis2, Bis2, Ces3, Deseses3,Aisisis2, Bisis2, Deses3, Eseseses3, His2,Bisisis2, Cis3, Eseses3, Hisis2,Cisis3, Eses3, Feseses3, Hisisis2,Cisisis3, Dis3, Feses3, Geseseses3,Disis3, Fes3, Geseses3,Aseseses3, Disisis3, Eis3, Geses3,Aseses3, Eisis3, Fis3,Ases3, Beseses3, Eisisis3, Fisis3,Beses3, Fisisis3, Gis3,Bes3, Ceseses4, Gisis3,Ais3, Ceses4, Deseseses4, Gisisis3,Aisis3, Bis3, Ces4, Deseses4,Aisisis3, Bisis3, Deses4, Eseseses4, His3,Bisisis3, Cis4, Eseses4, Hisis3,Cisis4, Eses4, Feseses4, Hisisis3,Cisisis4, Dis4, Feses4, Geseseses4,Disis4, Fes4, Geseses4,Aseseses4, Disisis4, Eis4, Geses4,Aseses4, Eisis4, Fis4,Ases4, Beseses4, Eisisis4, Fisis4,Beses4, Fisisis4, Gis4,Bes4, Ceseses5, Gisis4,Ais4, Ceses5, Deseseses5, Gisisis4,Aisis4, Bis4, Ces5, Deseses5,Aisisis4, Bisis4, Deses5, Eseseses5, His4,Bisisis4, Cis5, Eseses5, Hisis4,Cisis5, Eses5, Feseses5, Hisisis4,Cisisis5, Dis5, Feses5, Geseseses5,Disis5, Fes5, Geseses5,Aseseses5, Disisis5, Eis5, Geses5,Aseses5, Eisis5, Fis5,Ases5, Beseses5, Eisisis5, Fisis5,Beses5, Fisisis5, Gis5,Bes5, Ceseses6, Gisis5,Ais5, Ceses6, Deseseses6, Gisisis5,Aisis5, Bis5, Ces6, Deseses6,Aisisis5, Bisis5, Deses6, Eseseses6, His5,Bisisis5, Cis6, Eseses6, Hisis5,Cisis6, Eses6, Feseses6, Hisisis5,Cisisis6, Dis6, Feses6, Geseseses6,Disis6, Fes6, Geseses6,Aseseses6, Disisis6, Eis6, Geses6,Aseses6, Eisis6, Fis6,Ases6, Beseses6, Eisisis6, Fisis6,Beses6, Fisisis6, Gis6,Bes6, Ceseses7, Gisis6,Ais6, Ceses7, Deseseses7, Gisisis6,Aisis6, Bis6, Ces7, Deseses7,Aisisis6, Bisis6, Deses7, Eseseses7, His6,Bisisis6, Cis7, Eseses7, Hisis6,Cisis7, Eses7, Feseses7, Hisisis6,Cisisis7, Dis7, Feses7, Geseseses7,Disis7, Fes7, Geseses7,Aseseses7, Disisis7, Eis7, Geses7,Aseses7, Eisis7, Fis7,Ases7, Beseses7, Eisisis7, Fisis7,Beses7, Fisisis7, Gis7,Bes7, Ceseses8, Gisis7,Ais7, Ceses8, Deseseses8, Gisisis7,Aisis7, Bis7, Ces8, Deseses8,Aisisis7, Bisis7, Deses8, Eseseses8, His7,Bisisis7, Cis8, Eseses8, Hisis7,Cisis8, Eses8, Feseses8, Hisisis7,Cisisis8, Dis8, Feses8, Geseseses8,Disis8, Fes8, Geseses8,Aseseses8, Disisis8, Eis8, Geses8,Aseses8, Eisis8, Fis8,Ases8, Beseses8, Eisisis8, Fisis8,Beses8, Fisisis8, Gis8,Bes8, Ceseses9, Gisis8,Ais8, Ceses9, Deseseses9, Gisisis8,Aisis8, Bis8, Ces9, Deseses9,Aisisis8, Bisis8, Deses9, Eseseses9, His8,Bisisis8, Cis9, Eseses9, Hisis8,Cisis9, Eses9, Feseses9, Hisisis8,Cisisis9, Dis9, Feses9, Geseseses9,Disis9, Fes9, Geseses9,Aseseses9, Disisis9, Eis9, Geses9,Aseses9, Eisis9, Fis9,Ases9, Beseses9, Eisisis9, Fisis9\n"
			+ "cbx_note_id_german_uc/cbx_halftone_id_cis/cbx_sharp_flat_flat/cbx_octave_german:\n"
			+ "Aisisis'''', Bisis'''', Deses''', Eseseses''', His'''',Bisisis'''', Cis''', Eseses''', Hisis'''',Cisis''', Eses''', Feseses''', Hisisis'''',Cisisis''', Dis''', Feses''', Geseseses''',Disis''', Fes''', Geseses''',Aseseses''', Disisis''', Eis''', Geses''',Aseses''', Eisis''', Fis''',Ases''', Beseses''', Eisisis''', Fisis''',Beses''', Fisisis''', Gis''',Bes''', Ceseses'', Gisis''',Ais''', Ceses'', Deseseses'', Gisisis''',Aisis''', Bis''', Ces'', Deseses'',Aisisis''', Bisis''', Deses'', Eseseses'', His''',Bisisis''', Cis'', Eseses'', Hisis''',Cisis'', Eses'', Feseses'', Hisisis''',Cisisis'', Dis'', Feses'', Geseseses'',Disis'', Fes'', Geseses'',Aseseses'', Disisis'', Eis'', Geses'',Aseses'', Eisis'', Fis'',Ases'', Beseses'', Eisisis'', Fisis'',Beses'', Fisisis'', Gis'',Bes'', Ceseses', Gisis'',Ais'', Ceses', Deseseses', Gisisis'',Aisis'', Bis'', Ces', Deseses',Aisisis'', Bisis'', Deses', Eseseses', His'',Bisisis'', Cis', Eseses', Hisis'',Cisis', Eses', Feseses', Hisisis'',Cisisis', Dis', Feses', Geseseses',Disis', Fes', Geseses',Aseseses', Disisis', Eis', Geses',Aseses', Eisis', Fis',Ases', Beseses', Eisisis', Fisis',Beses', Fisisis', Gis',Bes', Ceseses, Gisis',Ais', Ceses, Deseseses, Gisisis',Aisis', Bis', Ces, Deseses,Aisisis', Bisis', Deses, Eseseses, His',Bisisis', Cis, Eseses, Hisis',Cisis, Eses, Feseses, Hisisis',Cisisis, Dis, Feses, Geseseses,Disis, Fes, Geseses,Aseseses, Disisis, Eis, Geses,Aseses, Eisis, Fis,Ases, Beseses, Eisisis, Fisis,Beses, Fisisis, Gis,Bes, Gisis, ceseses,Ais, Gisisis, ceses, deseseses,Aisis, Bis, ces, deseses,Aisisis, Bisis, His, deses, eseseses,Bisisis, Hisis, cis, eseses,Hisisis, cisis, eses, feseses,cisisis, dis, feses, geseseses,disis, fes, geseses,aseseses, disisis, eis, geses,aseses, eisis, fis,ases, beseses, eisisis, fisis,beses, fisisis, gis,bes, ceseses', gisis,ais, ceses', deseseses', gisisis,aisis, bis, ces', deseses',aisisis, bisis, deses', eseseses', his,bisisis, cis', eseses', hisis,cisis', eses', feseses', hisisis,cisisis', dis', feses', geseseses',disis', fes', geseses',aseseses', disisis', eis', geses',aseses', eisis', fis',ases', beseses', eisisis', fisis',beses', fisisis', gis',bes', ceseses'', gisis',ais', ceses'', deseseses'', gisisis',aisis', bis', ces'', deseses'',aisisis', bisis', deses'', eseseses'', his',bisisis', cis'', eseses'', hisis',cisis'', eses'', feseses'', hisisis',cisisis'', dis'', feses'', geseseses'',disis'', fes'', geseses'',aseseses'', disisis'', eis'', geses'',aseses'', eisis'', fis'',ases'', beseses'', eisisis'', fisis'',beses'', fisisis'', gis'',bes'', ceseses''', gisis'',ais'', ceses''', deseseses''', gisisis'',aisis'', bis'', ces''', deseses''',aisisis'', bisis'', deses''', eseseses''', his'',bisisis'', cis''', eseses''', hisis'',cisis''', eses''', feseses''', hisisis'',cisisis''', dis''', feses''', geseseses''',disis''', fes''', geseses''',aseseses''', disisis''', eis''', geses''',aseses''', eisis''', fis''',ases''', beseses''', eisisis''', fisis''',beses''', fisisis''', gis''',bes''', ceseses'''', gisis''',ais''', ceses'''', deseseses'''', gisisis''',aisis''', bis''', ces'''', deseses'''',aisisis''', bisis''', deses'''', eseseses'''', his''',bisisis''', cis'''', eseses'''', hisis''',cisis'''', eses'''', feseses'''', hisisis''',cisisis'''', dis'''', feses'''', geseseses'''',disis'''', fes'''', geseses'''',aseseses'''', disisis'''', eis'''', geses'''',aseses'''', eisis'''', fis'''',ases'''', beseses'''', eisisis'''', fisis'''',beses'''', fisisis'''', gis'''',bes'''', ceseses''''', gisis'''',ais'''', ceses''''', deseseses''''', gisisis'''',aisis'''', bis'''', ces''''', deseses''''',aisisis'''', bisis'''', deses''''', eseseses''''', his'''',bisisis'''', cis''''', eseses''''', hisis'''',cisis''''', eses''''', feseses''''', hisisis'''',cisisis''''', dis''''', feses''''', geseseses''''',disis''''', fes''''', geseses''''',aseseses''''', disisis''''', eis''''', geses''''',aseses''''', eisis''''', fis''''',ases''''', beseses''''', eisisis''''', fisis''''',beses''''', fisisis''''', gis''''',bes''''', ceseses'''''', gisis''''',ais''''', ceses'''''', deseseses'''''', gisisis''''',aisis''''', bis''''', ces'''''', deseses'''''',aisisis''''', bisis''''', deses'''''', eseseses'''''', his''''',bisisis''''', cis'''''', eseses'''''', hisis''''',cisis'''''', eses'''''', feseses'''''', hisisis''''',cisisis'''''', dis'''''', feses'''''', geseseses'''''',disis'''''', fes'''''', geseses'''''',aseseses'''''', disisis'''''', eis'''''', geses'''''',aseses'''''', eisis'''''', fis'''''',ases'''''', beseses'''''', eisisis'''''', fisis''''''\n",
			altNoteNames.toString()
		);
		
		// switch back to default
		cbxs[1].setSelectedIndex(0); 
		cbxs[2].setSelectedIndex(0);
		cbxs[3].setSelectedIndex(0);
		cbxs[4].setSelectedIndex(0);
	}
}
